@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2022, The HSQL Development Group
+ * Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -73,6 +73,7 @@ package org.hsqldb.server;
 import java.io.DataInputStream;
 import java.io.IOException;
 import java.io.PrintWriter;
+
 import java.util.TimeZone;
 
 import javax.servlet.ServletConfig;
@@ -99,7 +100,7 @@ import org.hsqldb.rowio.RowOutputBinary;
 // fredt@users 20041112 - patch by William Crick - use web_inf directory
 
 /**
- * Servlet can act as an interface between the client and the database for the
+ * Servlet can act as an interface between the client and the database for
  * the client / server mode of HSQL Database Engine. It uses the HTTP protocol
  * for communication. This class is not required if the included HSQLDB
  * Weberver is used on the server host. But if the host is running a J2EE
@@ -156,16 +157,18 @@ public class Servlet extends HttpServlet {
         }
 
 // begin WEB-INF patch */
-        String useWebInfStr =
-            getInitParameter("hsqldb.server.use_web-inf_path");
+        String useWebInfStr = getInitParameter(
+            "hsqldb.server.use_web-inf_path");
 
         if (!dbStr.equals(".") && "true".equalsIgnoreCase(useWebInfStr)) {
             String realPath = getServletContext().getRealPath("/");
+
             // bug #1350 to work with Tomcat 8 and above
             if (realPath != null) {
                 if (!realPath.endsWith("/")) {
                     realPath += '/';
                 }
+
                 dbStr = realPath + "WEB-INF/" + dbStr;
             }
         }
@@ -205,13 +208,14 @@ public class Servlet extends HttpServlet {
         return lModified++;
     }
 
-    public void doGet(HttpServletRequest request,
-                      HttpServletResponse response)
-                      throws IOException, ServletException {
+    public void doGet(
+            HttpServletRequest request,
+            HttpServletResponse response)
+            throws IOException {
 
         String query = request.getQueryString();
 
-        if ((query == null) || (query.length() == 0)) {
+        if (query == null || query.isEmpty()) {
             response.setContentType("text/html");
 
             // fredt@users 20020130 - patch 1.7.0 by fredt
@@ -238,9 +242,10 @@ public class Servlet extends HttpServlet {
         }
     }
 
-    public void doPost(HttpServletRequest request,
-                       HttpServletResponse response)
-                       throws IOException, ServletException {
+    public void doPost(
+            HttpServletRequest request,
+            HttpServletResponse response)
+            throws IOException {
 
         DataInputStream  inStream = null;
         DataOutputStream dataOut  = null;
@@ -252,8 +257,7 @@ public class Servlet extends HttpServlet {
             long           sessionID  = inStream.readLong();
             int            mode       = inStream.readByte();
             RowInputBinary rowIn      = new RowInputBinary(BUFFER_SIZE);
-            Session session = DatabaseManager.getSession(databaseID,
-                sessionID);
+            Session session = DatabaseManager.getSession(databaseID, sessionID);
             Result resultIn = Result.newResult(session, mode, inStream, rowIn);
 
             resultIn.setDatabaseId(databaseID);
@@ -264,21 +268,22 @@ public class Servlet extends HttpServlet {
 
             if (type == ResultConstants.CONNECT) {
                 try {
-                    session =
-                        DatabaseManager.newSession(dbType, dbPath,
-                                                   resultIn.getMainString(),
-                                                   resultIn.getSubString(),
-                                                   new HsqlProperties(),
-                                                   TimeZone.getDefault());
-                    resultOut =
-                        Result.newConnectionAcknowledgeResponse(session);
+                    session = DatabaseManager.newSession(
+                        dbType,
+                        dbPath,
+                        resultIn.getMainString(),
+                        resultIn.getSubString(),
+                        new HsqlProperties(),
+                        TimeZone.getDefault());
+                    resultOut = Result.newConnectionAcknowledgeResponse(
+                        session);
                 } catch (HsqlException e) {
                     resultOut = Result.newErrorResult(e);
                 }
             } else if (type == ResultConstants.DISCONNECT
                        || type == ResultConstants.RESETSESSION) {
 
-                // Upon DISCONNECT 6 bytes are read by the ClientConnectionHTTP": mode (1 byte), a length (int), and an 'additional results (1 byte)
+                // Upon DISCONNECT 6 bytes are read by the ClientConnectionHTTP: mode (1 byte), a length (int), and an 'additional results (1 byte)
                 response.setHeader("Cache-Control", "no-cache");    // DB-traffic should not be cached by proxies
                 response.setContentType("application/octet-stream");
                 response.setContentLength(6);
@@ -286,9 +291,9 @@ public class Servlet extends HttpServlet {
                 // Only acquire output-stream after headers are set
                 dataOut = new DataOutputStream(response.getOutputStream());
 
-                dataOut.writeByte(ResultConstants.DISCONNECT);      // Mode
-                dataOut.writeInt(4);                                // Length Int of first result is always read! Minvalue is 4: It is the number of bytes of the current result (it includes the length of this Int itself)
-                dataOut.writeByte(ResultConstants.NONE);            // No Additional results
+                dataOut.writeByte(ResultConstants.DISCONNECT);    // Mode
+                dataOut.writeInt(4);                              // Length Int of first result is always read! Minvalue is 4: It is the number of bytes of the current result (it includes the length of this Int itself)
+                dataOut.writeByte(ResultConstants.NONE);          // No Additional results
                 dataOut.close();
 
                 return;
@@ -315,7 +320,7 @@ public class Servlet extends HttpServlet {
             RowOutputBinary  rowOut     = new RowOutputBinary(BUFFER_SIZE, 1);
 
             resultOut.write(session, tempOutput, rowOut);
-            response.setHeader("Cache-Control", "no-cache");        // DB-traffic should not be cached by proxies
+            response.setHeader("Cache-Control", "no-cache");      // DB-traffic should not be cached by proxies
             response.setContentType("application/octet-stream");
             response.setContentLength(memStream.size());
 
