@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2023, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,8 +34,11 @@ package org.hsqldb;
 import java.io.BufferedInputStream;
 import java.io.DataInputStream;
 import java.io.IOException;
+
 import java.net.Socket;
+
 import java.text.SimpleDateFormat;
+
 import java.util.Calendar;
 import java.util.GregorianCalendar;
 import java.util.TimeZone;
@@ -56,6 +59,7 @@ import org.hsqldb.rowio.RowOutputInterface;
 import org.hsqldb.server.HsqlSocketFactory;
 import org.hsqldb.types.BlobDataID;
 import org.hsqldb.types.ClobDataID;
+import org.hsqldb.types.HsqlDateTime;
 
 /**
  * Base remote session proxy implementation. Uses instances of Result to
@@ -63,7 +67,7 @@ import org.hsqldb.types.ClobDataID;
  * protocol.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.1
+ * @version 2.7.3
  * @since 1.7.2
  */
 public class ClientConnection implements SessionInterface, Cloneable {
@@ -102,9 +106,8 @@ public class ClientConnection implements SessionInterface, Cloneable {
     //
     private boolean  isReadOnlyDefault = false;
     private boolean  isAutoCommit      = true;
-    private int      zoneSeconds;
+    private TimeZone timeZone;
     private Scanner  scanner;
-    private String   zoneString;
     private Calendar calendar;
     private Calendar calendarGMT;
     SimpleDateFormat simpleDateFormatGMT;
@@ -125,10 +128,16 @@ public class ClientConnection implements SessionInterface, Cloneable {
     /**
      * Establishes a connection to the server.
      */
-    public ClientConnection(String host, int port, String path,
-                            String database, boolean isTLS,
-                            boolean isTLSWrapper, String user,
-                            String password, TimeZone timeZone) {
+    public ClientConnection(
+            String host,
+            int port,
+            String path,
+            String database,
+            boolean isTLS,
+            boolean isTLSWrapper,
+            String user,
+            String password,
+            TimeZone timeZone) {
 
         this.host         = host;
         this.port         = port;
@@ -136,15 +145,17 @@ public class ClientConnection implements SessionInterface, Cloneable {
         this.database     = database;
         this.isTLS        = isTLS;
         this.isTLSWrapper = isTLSWrapper;
-        this.zoneSeconds = timeZone.getOffset(System.currentTimeMillis())
-                           / 1000;
-        this.zoneString = timeZone.getID();
+        this.timeZone     = timeZone;
 
         initStructures();
         initConnection(host, port, isTLS);
 
-        Result login = Result.newConnectionAttemptRequest(user, password,
-            database, zoneString, zoneSeconds);
+        Result login = Result.newConnectionAttemptRequest(
+            user,
+            password,
+            database,
+            timeZone.getID(),
+            timeZone.getOffset(System.currentTimeMillis()) / 1000);
         Result resultIn = execute(login);
 
         if (resultIn.isError()) {
@@ -166,8 +177,7 @@ public class ClientConnection implements SessionInterface, Cloneable {
         this.database     = other.database;
         this.isTLS        = other.isTLS;
         this.isTLSWrapper = other.isTLSWrapper;
-        this.zoneSeconds  = other.zoneSeconds;
-        this.zoneString   = other.zoneString;
+        this.timeZone     = other.timeZone;
 
         //
         this.sessionID              = other.sessionID;
@@ -201,13 +211,12 @@ public class ClientConnection implements SessionInterface, Cloneable {
 
         try {
             if (isTLSWrapper) {
-                socket =
-                    HsqlSocketFactory.getInstance(false).createSocket(host,
-                                                  port);
+                socket = HsqlSocketFactory.getInstance(false)
+                                          .createSocket(host, port);
             }
 
-            socket = HsqlSocketFactory.getInstance(isTLS).createSocket(socket,
-                                                   host, port);
+            socket = HsqlSocketFactory.getInstance(isTLS)
+                                      .createSocket(socket, host, port);
 
             socket.setTcpNoDelay(true);
 
@@ -220,8 +229,10 @@ public class ClientConnection implements SessionInterface, Cloneable {
 
             // The details from "e" should not be thrown away here.  This is
             // very useful info for end users to diagnose the runtime problem.
-            throw new HsqlException(e, Error.getStateString(ErrorCode.X_08001),
-                                    -ErrorCode.X_08001);
+            throw new HsqlException(
+                e,
+                Error.getStateString(ErrorCode.X_08001),
+                -ErrorCode.X_08001);
         }
     }
 
@@ -253,8 +264,10 @@ public class ClientConnection implements SessionInterface, Cloneable {
         }
     }
 
-    public synchronized RowSetNavigatorClient getRows(long navigatorId,
-            int offset, int size) {
+    public synchronized RowSetNavigatorClient getRows(
+            long navigatorId,
+            int offset,
+            int size) {
 
         try {
             resultOut.setResultType(ResultConstants.REQUESTDATA);
@@ -297,6 +310,25 @@ public class ClientConnection implements SessionInterface, Cloneable {
         isClosed = true;
     }
 
+    public void setAttributeFromResult(Result result) {
+
+        Object[] data = result.getSingleRowData();
+        int      id   = (Integer) data[AttributePos.INFO_ID];
+
+        switch (id) {
+
+            case Attributes.INFO_AUTOCOMMIT :
+                isAutoCommit = (Boolean) data[AttributePos.INFO_BOOLEAN];
+                break;
+
+            case Attributes.INFO_TIMEZONE :
+                String zoneID = (String) data[AttributePos.INFO_VARCHAR];
+
+                timeZone = TimeZone.getTimeZone(zoneID);
+                break;
+        }
+    }
+
     public synchronized Object getAttribute(int id) {
 
         resultOut.setResultType(ResultConstants.GETSESSIONATTR);
@@ -308,21 +340,27 @@ public class ClientConnection implements SessionInterface, Cloneable {
             throw Error.error(in);
         }
 
-        Object[] data = in.getSingleRowData();
+        return getAttributeFromData(in, id);
+    }
+
+    public static Object getAttributeFromData(Result result, int id) {
+
+        Object[] data = result.getSingleRowData();
 
         switch (id) {
 
-            case SessionInterface.INFO_AUTOCOMMIT :
-                return data[SessionInterface.INFO_BOOLEAN];
+            case Attributes.INFO_AUTOCOMMIT :
+            case Attributes.INFO_CONNECTION_READONLY :
+                return data[AttributePos.INFO_BOOLEAN];
 
-            case SessionInterface.INFO_CONNECTION_READONLY :
-                return data[SessionInterface.INFO_BOOLEAN];
+            case Attributes.INFO_ISOLATION :
+                return data[AttributePos.INFO_INTEGER];
 
-            case SessionInterface.INFO_ISOLATION :
-                return data[SessionInterface.INFO_INTEGER];
+            case Attributes.INFO_CATALOG :
+                return data[AttributePos.INFO_VARCHAR];
 
-            case SessionInterface.INFO_CATALOG :
-                return data[SessionInterface.INFO_VARCHAR];
+            case Attributes.INFO_TIMEZONE :
+                return data[AttributePos.INFO_VARCHAR];
         }
 
         return null;
@@ -330,29 +368,7 @@ public class ClientConnection implements SessionInterface, Cloneable {
 
     public synchronized void setAttribute(int id, Object value) {
 
-        resultOut.setResultType(ResultConstants.SETSESSIONATTR);
-
-        Object[] data = resultOut.getSingleRowData();
-
-        data[SessionInterface.INFO_ID] = ValuePool.getInt(id);
-
-        switch (id) {
-
-            case SessionInterface.INFO_AUTOCOMMIT :
-            case SessionInterface.INFO_CONNECTION_READONLY :
-                data[SessionInterface.INFO_BOOLEAN] = value;
-                break;
-
-            case SessionInterface.INFO_ISOLATION :
-                data[SessionInterface.INFO_INTEGER] = value;
-                break;
-
-            case SessionInterface.INFO_CATALOG :
-                data[SessionInterface.INFO_VARCHAR] = value;
-                break;
-
-            default :
-        }
+        setAttributeResult(resultOut, id, value);
 
         Result resultIn = execute(resultOut);
 
@@ -361,9 +377,46 @@ public class ClientConnection implements SessionInterface, Cloneable {
         }
     }
 
+    public static Result setAttributeResult(
+            Result result,
+            int id,
+            Object value) {
+
+        if (result == null) {
+            result = Result.newSessionAttributesResult();
+        }
+
+        result.setResultType(ResultConstants.SETSESSIONATTR);
+
+        Object[] data = result.getSingleRowData();
+
+        data[AttributePos.INFO_ID] = ValuePool.getInt(id);
+
+        switch (id) {
+
+            case Attributes.INFO_AUTOCOMMIT :
+            case Attributes.INFO_CONNECTION_READONLY :
+                data[AttributePos.INFO_BOOLEAN] = value;
+                break;
+
+            case Attributes.INFO_ISOLATION :
+                data[AttributePos.INFO_INTEGER] = value;
+                break;
+
+            case Attributes.INFO_CATALOG :
+            case Attributes.INFO_TIMEZONE :
+                data[AttributePos.INFO_VARCHAR] = value;
+                break;
+
+            default :
+        }
+
+        return result;
+    }
+
     public synchronized boolean isReadOnlyDefault() {
 
-        Object info = getAttribute(SessionInterface.INFO_CONNECTION_READONLY);
+        Object info = getAttribute(Attributes.INFO_CONNECTION_READONLY);
 
         isReadOnlyDefault = ((Boolean) info).booleanValue();
 
@@ -373,9 +426,11 @@ public class ClientConnection implements SessionInterface, Cloneable {
     public synchronized void setReadOnlyDefault(boolean mode) {
 
         if (mode != isReadOnlyDefault) {
-            setAttribute(SessionInterface.INFO_CONNECTION_READONLY,
-                         mode ? Boolean.TRUE
-                              : Boolean.FALSE);
+            setAttribute(
+                Attributes.INFO_CONNECTION_READONLY,
+                mode
+                ? Boolean.TRUE
+                : Boolean.FALSE);
 
             isReadOnlyDefault = mode;
         }
@@ -383,7 +438,7 @@ public class ClientConnection implements SessionInterface, Cloneable {
 
     public synchronized boolean isAutoCommit() {
 
-        Object info = getAttribute(SessionInterface.INFO_AUTOCOMMIT);
+        Object info = getAttribute(Attributes.INFO_AUTOCOMMIT);
 
         isAutoCommit = ((Boolean) info).booleanValue();
 
@@ -393,21 +448,22 @@ public class ClientConnection implements SessionInterface, Cloneable {
     public synchronized void setAutoCommit(boolean mode) {
 
         if (mode != isAutoCommit) {
-            setAttribute(SessionInterface.INFO_AUTOCOMMIT, mode ? Boolean.TRUE
-                                                                : Boolean
-                                                                .FALSE);
+            setAttribute(
+                Attributes.INFO_AUTOCOMMIT,
+                mode
+                ? Boolean.TRUE
+                : Boolean.FALSE);
 
             isAutoCommit = mode;
         }
     }
 
     public synchronized void setIsolationDefault(int level) {
-        setAttribute(SessionInterface.INFO_ISOLATION, ValuePool.getInt(level));
+        setAttribute(Attributes.INFO_ISOLATION, ValuePool.getInt(level));
     }
 
     public synchronized int getIsolation() {
-
-        Object info = getAttribute(SessionInterface.INFO_ISOLATION);
+        Object info = getAttribute(Attributes.INFO_ISOLATION);
 
         return ((Integer) info).intValue();
     }
@@ -424,8 +480,9 @@ public class ClientConnection implements SessionInterface, Cloneable {
 
     public synchronized void prepareCommit() {
 
-        resultOut.setAsTransactionEndRequest(ResultConstants.PREPARECOMMIT,
-                                             null);
+        resultOut.setAsTransactionEndRequest(
+            ResultConstants.PREPARECOMMIT,
+            null);
 
         Result in = execute(resultOut);
 
@@ -447,8 +504,7 @@ public class ClientConnection implements SessionInterface, Cloneable {
 
     public synchronized void rollback(boolean chain) {
 
-        resultOut.setAsTransactionEndRequest(ResultConstants.TX_ROLLBACK,
-                                             null);
+        resultOut.setAsTransactionEndRequest(ResultConstants.TX_ROLLBACK, null);
 
         Result in = execute(resultOut);
 
@@ -460,7 +516,8 @@ public class ClientConnection implements SessionInterface, Cloneable {
     public synchronized void rollbackToSavepoint(String name) {
 
         resultOut.setAsTransactionEndRequest(
-            ResultConstants.TX_SAVEPOINT_NAME_ROLLBACK, name);
+            ResultConstants.TX_SAVEPOINT_NAME_ROLLBACK,
+            name);
 
         Result in = execute(resultOut);
 
@@ -482,7 +539,8 @@ public class ClientConnection implements SessionInterface, Cloneable {
     public synchronized void releaseSavepoint(String name) {
 
         resultOut.setAsTransactionEndRequest(
-            ResultConstants.TX_SAVEPOINT_NAME_RELEASE, name);
+            ResultConstants.TX_SAVEPOINT_NAME_RELEASE,
+            name);
 
         Result in = execute(resultOut);
 
@@ -527,11 +585,13 @@ public class ClientConnection implements SessionInterface, Cloneable {
         databaseID = resultIn.getDatabaseId();
     }
 
-    protected void write(Result r) throws IOException, HsqlException {
+    protected void write(Result r) throws IOException,
+            HsqlException {
         r.write(this, dataOutput, rowOut);
     }
 
-    protected Result read() throws IOException, HsqlException {
+    protected Result read() throws IOException,
+                                   HsqlException {
 
         Result result = Result.newResult(dataInput, rowIn);
 
@@ -565,14 +625,12 @@ public class ClientConnection implements SessionInterface, Cloneable {
     }
 
     public BlobDataID createBlob(long length) {
-
         BlobDataID blob = new BlobDataID(getLobId());
 
         return blob;
     }
 
     public ClobDataID createClob(long length) {
-
         ClobDataID clob = new ClobDataID(getLobId());
 
         return clob;
@@ -597,9 +655,7 @@ public class ClientConnection implements SessionInterface, Cloneable {
     public Calendar getCalendar() {
 
         if (calendar == null) {
-            TimeZone zone = TimeZone.getTimeZone(zoneString);
-
-            calendar = new GregorianCalendar(zone);
+            calendar = new GregorianCalendar(timeZone);
         }
 
         return calendar;
@@ -608,8 +664,9 @@ public class ClientConnection implements SessionInterface, Cloneable {
     public Calendar getCalendarGMT() {
 
         if (calendarGMT == null) {
-            calendarGMT = new GregorianCalendar(TimeZone.getTimeZone("GMT"),
-                                                HsqlDateTime.defaultLocale);
+            calendarGMT = new GregorianCalendar(
+                TimeZone.getTimeZone("GMT"),
+                HsqlDateTime.defaultLocale);
 
             calendarGMT.setLenient(false);
         }
@@ -620,11 +677,13 @@ public class ClientConnection implements SessionInterface, Cloneable {
     public SimpleDateFormat getSimpleDateFormatGMT() {
 
         if (simpleDateFormatGMT == null) {
-            simpleDateFormatGMT = new SimpleDateFormat("MMMM",
-                    HsqlDateTime.defaultLocale);
+            simpleDateFormatGMT = new SimpleDateFormat(
+                "MMMM",
+                HsqlDateTime.defaultLocale);
 
-            Calendar cal = new GregorianCalendar(TimeZone.getTimeZone("GMT"),
-                                                 HsqlDateTime.defaultLocale);
+            Calendar cal = new GregorianCalendar(
+                TimeZone.getTimeZone("GMT"),
+                HsqlDateTime.defaultLocale);
 
             cal.setLenient(false);
             simpleDateFormatGMT.setCalendar(cal);
@@ -633,8 +692,12 @@ public class ClientConnection implements SessionInterface, Cloneable {
         return simpleDateFormatGMT;
     }
 
+    public TimeZone getTimeZone() {
+        return timeZone;
+    }
+
     public int getZoneSeconds() {
-        return zoneSeconds;
+        return timeZone.getOffset(System.currentTimeMillis()) / 1000;
     }
 
     public int getStreamBlockSize() {
@@ -646,7 +709,10 @@ public class ClientConnection implements SessionInterface, Cloneable {
         if (clientProperties == null) {
             if (clientPropertiesString.length() > 0) {
                 clientProperties = HsqlProperties.delimitedArgPairsToProps(
-                    clientPropertiesString, "=", ";", null);
+                    clientPropertiesString,
+                    "=",
+                    ";",
+                    null);
             } else {
                 clientProperties = new HsqlProperties();
             }
