@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,6 +41,7 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.FrameworkLogger;
 import org.hsqldb.lib.HsqlArrayList;
 import org.hsqldb.lib.HsqlTimer;
+import org.hsqldb.lib.List;
 import org.hsqldb.lib.OrderedHashMap;
 import org.hsqldb.map.ValuePool;
 import org.hsqldb.persist.HsqlDatabaseProperties;
@@ -63,7 +64,7 @@ import org.hsqldb.types.Collation;
  * It holds the data structures that form an HSQLDB database instance.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.3
  * @since 1.9.0
  */
 public class Database {
@@ -181,8 +182,11 @@ public class Database {
      *      combination is illegal or unavailable, or the database files the
      *      name and path resolves to are in use by another process
      */
-    Database(DatabaseType type, String path, String canonicalPath,
-             HsqlProperties props) {
+    Database(
+            DatabaseType type,
+            String path,
+            String canonicalPath,
+            HsqlProperties props) {
 
         setState(Database.DATABASE_SHUTDOWN);
 
@@ -197,10 +201,11 @@ public class Database {
         }
 
         logger = new Logger(this);
-        shutdownOnNoConnection =
-            urlProperties.isPropertyTrue(HsqlDatabaseProperties.url_shutdown);
+        shutdownOnNoConnection = urlProperties.isPropertyTrue(
+            HsqlDatabaseProperties.url_shutdown);
         recoveryMode = urlProperties.getIntegerProperty(
-            HsqlDatabaseProperties.url_recover, 0);
+            HsqlDatabaseProperties.url_recover,
+            0);
     }
 
     /**
@@ -222,7 +227,7 @@ public class Database {
      */
     void reopen() {
 
-        boolean isNew = false;
+        boolean isNew;
 
         setState(DATABASE_OPENING);
 
@@ -249,19 +254,18 @@ public class Database {
             checkpointRunner = new CheckpointRunner();
             timeoutRunner    = new TimeoutRunner();
         } catch (Throwable e) {
+            logger.logSevereEvent("could not reopen database", e);
             logger.close(Database.CLOSEMODE_IMMEDIATELY);
             logger.releaseLock();
             setState(DATABASE_SHUTDOWN);
             clearStructures();
             DatabaseManager.removeDatabase(this);
 
-            if (!(e instanceof HsqlException)) {
-                e = Error.error(ErrorCode.GENERAL_ERROR, e);
+            if (e instanceof HsqlException) {
+                throw(e);
+            } else {
+                throw(Error.error(ErrorCode.GENERAL_ERROR, e));
             }
-
-            logger.logSevereEvent("could not reopen database", e);
-
-            throw (HsqlException) e;
         }
 
         setState(DATABASE_ONLINE);
@@ -297,20 +301,21 @@ public class Database {
 
     public void createObjectStructures() {
 
-        nameManager = new HsqlNameManager(this);
-        databaseUniqueName = nameManager.newHsqlName("", false,
-                SchemaObject.DATABASE);
-        lobManager     = new LobManager(this);
-        granteeManager = new GranteeManager(this);
-        userManager    = new UserManager(this);
-        schemaManager  = new SchemaManager(this);
-        persistentStoreCollection =
-            new PersistentStoreCollectionDatabase(this);
-        isReferentialIntegrity = true;
-        sessionManager         = new SessionManager(this);
-        collation              = Collation.newDatabaseInstance();
+        nameManager               = new HsqlNameManager(this);
+        databaseUniqueName = nameManager.newHsqlName(
+            "",
+            false,
+            SchemaObject.DATABASE);
+        lobManager                = new LobManager(this);
+        granteeManager            = new GranteeManager(this);
+        userManager               = new UserManager(this);
+        schemaManager             = new SchemaManager(this);
+        persistentStoreCollection = new PersistentStoreCollectionDatabase(this);
+        isReferentialIntegrity    = true;
+        sessionManager            = new SessionManager(this);
+        collation                 = Collation.newDatabaseInstance();
         dbInfo = DatabaseInformation.newDatabaseInformation(this);
-        txManager              = new TransactionManager2PL(this);
+        txManager                 = new TransactionManager2PL(this);
 
         lobManager.createSchema();
         sessionManager.getSysLobSession().setSchema(SqlInvariants.LOBS_SCHEMA);
@@ -392,8 +397,10 @@ public class Database {
      *
      * Throws if username or password is invalid.
      */
-    synchronized Session connect(String username, String password,
-                                 TimeZone zone) {
+    synchronized Session connect(
+            String username,
+            String password,
+            TimeZone zone) {
 
         if (getState() != DATABASE_ONLINE) {
             throw Error.error(ErrorCode.X_08001);
@@ -404,8 +411,12 @@ public class Database {
         }
 
         User user = userManager.getUser(username, password);
-        Session session = sessionManager.newSession(this, user,
-            databaseReadOnly, true, zone);
+        Session session = sessionManager.newSession(
+            this,
+            user,
+            databaseReadOnly,
+            true,
+            zone);
 
         return session;
     }
@@ -494,7 +505,6 @@ public class Database {
     }
 
     public void setRegularNames(boolean mode) {
-
         sqlRegularNames = mode;
 
         nameManager.setSqlRegularNames(mode);
@@ -726,13 +736,12 @@ public class Database {
         }
     }
 
-    public String[] getSettingsSQL() {
+    public List<String> getSettingsSQLArray() {
 
-        HsqlArrayList list = new HsqlArrayList();
-        StringBuilder sb   = new StringBuilder();
+        HsqlArrayList<String> list = new HsqlArrayList<>();
+        StringBuilder         sb   = new StringBuilder();
 
-        if (!getCatalogName().name.equals(
-                SqlInvariants.DEFAULT_CATALOG_NAME)) {
+        if (!getCatalogName().name.equals(SqlInvariants.DEFAULT_CATALOG_NAME)) {
             String name = getCatalogName().statementName;
 
             sb.append("ALTER CATALOG PUBLIC RENAME TO ").append(name);
@@ -742,28 +751,28 @@ public class Database {
 
         list.add(collation.getDatabaseCollationSQL());
 
-        OrderedHashMap lobTables =
-            schemaManager.getTables(SqlInvariants.LOBS_SCHEMA);
+        OrderedHashMap<String, Table> lobTables = schemaManager.getTables(
+            SqlInvariants.LOBS_SCHEMA);
 
         for (int i = 0; i < lobTables.size(); i++) {
-            Table table = (Table) lobTables.get(i);
+            Table table = lobTables.get(i);
 
             if (table.isCached()) {
-                sb.append(Tokens.T_SET).append(' ').append(Tokens.T_TABLE);
-                sb.append(' ');
-                sb.append(table.getName().getSchemaQualifiedStatementName());
-                sb.append(' ').append(Tokens.T_TYPE).append(' ');
-                sb.append(Tokens.T_CACHED);
+                sb.append(Tokens.T_SET)
+                  .append(' ')
+                  .append(Tokens.T_TABLE)
+                  .append(' ')
+                  .append(table.getName().getSchemaQualifiedStatementName())
+                  .append(' ')
+                  .append(Tokens.T_TYPE)
+                  .append(' ')
+                  .append(Tokens.T_CACHED);
                 list.add(sb.toString());
                 sb.setLength(0);
             }
         }
 
-        String[] array = new String[list.size()];
-
-        list.toArray(array);
-
-        return array;
+        return list;
     }
 
     /**
@@ -774,15 +783,15 @@ public class Database {
         Result r = Result.newSingleColumnResult("COMMAND");
 
         // properties
-        String[] list = logger.getPropertiesSQL(indexRoots);
+        List<String> list = logger.getPropertiesSQLArray(indexRoots);
 
         r.addRows(list);
 
-        list = getSettingsSQL();
+        list = getSettingsSQLArray();
 
         r.addRows(list);
 
-        list = granteeManager.getSQL();
+        list = granteeManager.getSQLArray();
 
         r.addRows(list);
 
@@ -792,34 +801,34 @@ public class Database {
         r.addRows(list);
 
         // table spaces
-        list = schemaManager.getTableSpaceSQL();
+        list = schemaManager.getTableSpaceSQLArray();
 
         r.addRows(list);
 
         // index roots
         if (indexRoots) {
-            list = schemaManager.getIndexRootsSQL();
+            list = schemaManager.getIndexRootsSQLArray();
 
             r.addRows(list);
         }
 
         // text headers - readonly - clustered
-        list = schemaManager.getTablePropsSQL(!indexRoots);
+        list = schemaManager.getTablePropsSQLArray(!indexRoots);
 
         r.addRows(list);
 
         // password complexity
-        list = userManager.getAuthenticationSQL();
+        list = userManager.getAuthenticationSQLArray();
 
         r.addRows(list);
 
         // user session start schema names
-        list = userManager.getInitialSchemaSQL();
+        list = userManager.getInitialSchemaSQLArray();
 
         r.addRows(list);
 
         // grantee rights
-        list = granteeManager.getRightsSQL();
+        list = granteeManager.getRightsSQLArray();
 
         r.addRows(list);
 
@@ -849,14 +858,15 @@ public class Database {
 
         public void run() {
 
-            Statement checkpoint =
-                ParserCommand.getAutoCheckpointStatement(Database.this);
+            Statement checkpoint = ParserCommand.getAutoCheckpointStatement(
+                Database.this);
             Session sysSession = sessionManager.newSysSession();
 
             try {
-                sysSession.executeCompiledStatement(checkpoint,
-                                                    ValuePool.emptyObjectArray,
-                                                    0);
+                sysSession.executeCompiledStatement(
+                    checkpoint,
+                    ValuePool.emptyObjectArray,
+                    0);
             } catch (Throwable e) {
 
                 // ignore exceptions
@@ -873,6 +883,7 @@ public class Database {
 
         public void start() {
 
+            // started only when maxLogSize is reached in file: or when deleted lobs exceed maxLogSize in mem:
             synchronized (this) {
                 if (waiting) {
                     return;
@@ -903,9 +914,9 @@ public class Database {
      */
     static class TimeoutRunner implements Runnable {
 
-        private Object        timerTask;
-        private HsqlArrayList timeoutList;
-        int                   abortCount;
+        private Object                        timerTask;
+        private HsqlArrayList<TimeoutManager> timeoutList;
+        int                                   abortCount;
 
         public void run() {
 
@@ -914,14 +925,12 @@ public class Database {
                     long systemMillis = System.currentTimeMillis();
 
                     for (int i = 0; i < timeoutList.size(); i++) {
-                        TimeoutManager timeOut =
-                            (TimeoutManager) timeoutList.get(i);
+                        TimeoutManager timeOut = timeoutList.get(i);
 
                         if (timeOut.isClosed()) {
                             timeoutList.remove(i);
 
                             i--;
-
                             continue;
                         }
 
@@ -966,10 +975,13 @@ public class Database {
 
         private void start() {
 
-            timeoutList = new HsqlArrayList();
-            timerTask =
-                DatabaseManager.getTimer().schedulePeriodicallyAfter(1000,
-                    1000, this, true);
+            timeoutList = new HsqlArrayList<>();
+            timerTask = DatabaseManager.getTimer()
+                                       .schedulePeriodicallyAfter(
+                                           1000,
+                                           1000,
+                                           this,
+                                           true);
         }
     }
 }
