@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,37 +50,39 @@ import org.hsqldb.types.Type;
  * Implementation of column, variable, parameter, etc. access operations.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.1
+ * @version 2.7.3
  * @since 1.9.0
  */
 public class ExpressionColumn extends Expression {
 
     public static final ExpressionColumn[] emptyArray =
         new ExpressionColumn[]{};
-    static final SimpleName rownumName =
-        HsqlNameManager.getSimpleName("ROWNUM", false);
+    static final SimpleName rownumName = HsqlNameManager.getSimpleName(
+        "ROWNUM",
+        false);
 
     //
-    public static final OrderedHashMap diagnosticsList = new OrderedHashMap();
-    static final String[] diagnosticsVariableTokens    = new String[] {
-        Tokens.T_NUMBER, Tokens.T_MORE, Tokens.T_ROW_COUNT
-    };
-    public static final int            idx_number      = 0;
-    public static final int            idx_more        = 1;
-    public static final int            idx_row_count   = 2;
+    public static final OrderedHashMap<String, ColumnSchema> diagnosticsList =
+        new OrderedHashMap<>();
+    static final String[] diagnosticsVariableTokens = new String[]{
+        Tokens.T_NUMBER,
+        Tokens.T_MORE, Tokens.T_ROW_COUNT };
+    public static final int idx_number    = 0;
+    public static final int idx_more      = 1;
+    public static final int idx_row_count = 2;
 
     static {
         for (int i = 0; i < diagnosticsVariableTokens.length; i++) {
             HsqlName name = HsqlNameManager.newSystemObjectName(
-                diagnosticsVariableTokens[i], SchemaObject.VARIABLE);
+                diagnosticsVariableTokens[i],
+                SchemaObject.VARIABLE);
             Type type = Type.SQL_INTEGER;
 
             if (Tokens.T_MORE.equals(diagnosticsVariableTokens[i])) {
                 type = Type.SQL_CHAR;
             }
 
-            ColumnSchema col = new ColumnSchema(name, type, false, false,
-                                                null);
+            ColumnSchema col = new ColumnSchema(name, type, false, false, null);
 
             diagnosticsList.add(diagnosticsVariableTokens[i], col);
         }
@@ -197,7 +199,7 @@ public class ExpressionColumn extends Expression {
             return;
         }
 
-        this.column      = (ColumnSchema) diagnosticsList.get(columnIndex);
+        this.column      = diagnosticsList.get(columnIndex);
         this.columnIndex = columnIndex;
         this.dataType    = column.dataType;
     }
@@ -328,7 +330,6 @@ public class ExpressionColumn extends Expression {
         }
 
         switch (opType) {
-
             case OpTypes.COLUMN :
             case OpTypes.COALESCE :
             case OpTypes.ROWNUM :
@@ -338,7 +339,7 @@ public class ExpressionColumn extends Expression {
         return "";
     }
 
-    void collectObjectNames(Set set) {
+    void collectObjectNames(Set<HsqlName> set) {
 
         switch (opType) {
 
@@ -354,8 +355,6 @@ public class ExpressionColumn extends Expression {
             case OpTypes.ASTERISK :
             case OpTypes.SIMPLE_COLUMN :
             case OpTypes.COALESCE :
-                break;
-
             case OpTypes.PARAMETER :
             case OpTypes.VARIABLE :
                 break;
@@ -400,11 +399,13 @@ public class ExpressionColumn extends Expression {
         return rangeVariable;
     }
 
-    public List resolveColumnReferences(Session session,
-                                        RangeGroup rangeGroup, int rangeCount,
-                                        RangeGroup[] rangeGroups,
-                                        List unresolvedSet,
-                                        boolean acceptsSequences) {
+    public List<Expression> resolveColumnReferences(
+            Session session,
+            RangeGroup rangeGroup,
+            int rangeCount,
+            RangeGroup[] rangeGroups,
+            List<Expression> unresolvedSet,
+            boolean acceptsSequences) {
 
         switch (opType) {
 
@@ -412,10 +413,12 @@ public class ExpressionColumn extends Expression {
                 if (!acceptsSequences) {
                     throw Error.error(ErrorCode.X_42598);
                 }
+
                 break;
 
             case OpTypes.MULTICOLUMN :
                 throw Error.error(ErrorCode.X_42581, "*");
+
             case OpTypes.ROWNUM :
             case OpTypes.DYNAMIC_PARAM :
             case OpTypes.ASTERISK :
@@ -426,10 +429,13 @@ public class ExpressionColumn extends Expression {
             case OpTypes.GROUPING :
             case OpTypes.COALESCE :
                 for (int i = 0; i < nodes.length; i++) {
-                    nodes[i].resolveColumnReferences(session, rangeGroup,
-                                                     rangeGroups,
-                                                     unresolvedSet);
+                    nodes[i].resolveColumnReferences(
+                        session,
+                        rangeGroup,
+                        rangeGroups,
+                        unresolvedSet);
                 }
+
                 break;
 
             case OpTypes.COLUMN :
@@ -444,7 +450,7 @@ public class ExpressionColumn extends Expression {
 
                 if (isUpdateColumn) {
                     if (unresolvedSet == null) {
-                        unresolvedSet = new ArrayListIdentity();
+                        unresolvedSet = new ArrayListIdentity<>();
                     }
 
                     unresolvedSet.add(this);
@@ -465,11 +471,13 @@ public class ExpressionColumn extends Expression {
                                 String message = getColumnName();
 
                                 if (alias != null) {
-                                    StringBuilder sb =
-                                        new StringBuilder(message);
+                                    StringBuilder sb = new StringBuilder(64);
 
-                                    sb.append(' ').append(Tokens.T_AS).append(
-                                        ' ').append(alias.getStatementName());
+                                    sb.append(message)
+                                      .append(' ')
+                                      .append(Tokens.T_AS)
+                                      .append(' ')
+                                      .append(alias.getStatementName());
 
                                     message = sb.toString();
                                 }
@@ -499,7 +507,9 @@ public class ExpressionColumn extends Expression {
                                 || Tokens.T_PREVVAL.equals(columnName)) {
                             NumberSequence seq =
                                 session.database.schemaManager.findSequence(
-                                    session, tableName, schema);
+                                    session,
+                                    tableName,
+                                    schema);
 
                             if (seq != null) {
                                 opType     = OpTypes.SEQUENCE_CURRENT;
@@ -513,7 +523,9 @@ public class ExpressionColumn extends Expression {
                         } else if (Tokens.T_NEXTVAL.equals(columnName)) {
                             NumberSequence seq =
                                 session.database.schemaManager.findSequence(
-                                    session, tableName, schema);
+                                    session,
+                                    tableName,
+                                    schema);
 
                             if (seq != null) {
                                 opType     = OpTypes.SEQUENCE;
@@ -537,21 +549,22 @@ public class ExpressionColumn extends Expression {
                 }
 
                 if (unresolvedSet == null) {
-                    unresolvedSet = new ArrayListIdentity();
+                    unresolvedSet = new ArrayListIdentity<>();
                 }
 
                 unresolvedSet.add(this);
-
                 break;
             }
+
             default :
         }
 
         return unresolvedSet;
     }
 
-    private boolean resolveCorrelated(RangeGroup rangeGroup,
-                                      RangeGroup[] rangeGroups) {
+    private boolean resolveCorrelated(
+            RangeGroup rangeGroup,
+            RangeGroup[] rangeGroups) {
 
         for (int idx = rangeGroups.length - 1; idx >= 0; idx--) {
             RangeVariable[] rangeVarArray =
@@ -620,14 +633,14 @@ public class ExpressionColumn extends Expression {
                         == SchemaObject.ParameterModes.PARAM_OUT) {
                     return false;
                 } else {
-                    opType = rangeVar.rangeType
-                             == RangeVariable.VARIALBE_RANGE ? OpTypes.VARIABLE
-                                                             : OpTypes
-                                                             .PARAMETER;
+                    opType = rangeVar.rangeType == RangeVariable.VARIALBE_RANGE
+                             ? OpTypes.VARIABLE
+                             : OpTypes.PARAMETER;
                 }
 
                 break;
             }
+
             case RangeVariable.TRANSITION_RANGE : {
                 if (tableName == null) {
                     return false;
@@ -638,9 +651,9 @@ public class ExpressionColumn extends Expression {
                 }
 
                 opType = OpTypes.TRANSITION_VARIABLE;
-
                 break;
             }
+
             default : {
                 break;
             }
@@ -669,8 +682,10 @@ public class ExpressionColumn extends Expression {
                 return false;
 
             default :
-                int colIndex = rangeVar.findColumn(schema, tableName,
-                                                   columnName);
+                int colIndex = rangeVar.findColumn(
+                    schema,
+                    tableName,
+                    columnName);
 
                 return colIndex != -1;
         }
@@ -684,6 +699,7 @@ public class ExpressionColumn extends Expression {
                 if (parent != null && parent.opType != OpTypes.ROW) {
                     throw Error.error(ErrorCode.X_42544);
                 }
+
                 break;
 
             case OpTypes.COALESCE : {
@@ -696,9 +712,9 @@ public class ExpressionColumn extends Expression {
                 }
 
                 dataType = type;
-
                 break;
             }
+
             case OpTypes.COLUMN : {
                 if (dataType == null) {
                     dataType = column.getDataType();
@@ -717,7 +733,8 @@ public class ExpressionColumn extends Expression {
                 }
 
                 return session.sessionContext.groupSet.isGrouped(
-                    session.sessionContext.currentGroup, this);
+                    session.sessionContext.currentGroup,
+                    this);
 
             case OpTypes.DEFAULT :
                 return null;
@@ -725,16 +742,19 @@ public class ExpressionColumn extends Expression {
             case OpTypes.DIAGNOSTICS_VARIABLE : {
                 return getDiagnosticsVariable(session);
             }
+
             case OpTypes.VARIABLE : {
                 return session.sessionContext.routineVariables[columnIndex];
             }
+
             case OpTypes.PARAMETER : {
                 return session.sessionContext.routineArguments[columnIndex];
             }
+
             case OpTypes.TRANSITION_VARIABLE : {
-                return session.sessionContext
-                    .triggerArguments[rangeVariable.rangePosition][columnIndex];
+                return session.sessionContext.triggerArguments[rangeVariable.rangePosition][columnIndex];
             }
+
             case OpTypes.COLUMN : {
                 RangeIterator[] iterators =
                     session.sessionContext.rangeIterators;
@@ -742,49 +762,55 @@ public class ExpressionColumn extends Expression {
                     columnIndex);
 
                 if (dataType != column.dataType) {
-                    value = dataType.convertToType(session, value,
-                                                   column.dataType);
+                    value = dataType.convertToType(
+                        session,
+                        value,
+                        column.dataType);
                 }
 
                 return value;
             }
+
             case OpTypes.SIMPLE_COLUMN : {
                 Object value =
-                    session.sessionContext.rangeIterators[rangePosition]
-                        .getField(columnIndex);
+                    session.sessionContext.rangeIterators[rangePosition].getField(
+                        columnIndex);
 
                 return value;
             }
-            case OpTypes.COALESCE : {
-                Object value = null;
 
+            case OpTypes.COALESCE : {
                 for (int i = 0; i < nodes.length; i++) {
-                    value = nodes[i].getValue(session, dataType);
+                    Object value = nodes[i].getValue(session, dataType);
 
                     if (value != null) {
                         return value;
                     }
                 }
 
-                return value;
+                return null;
             }
+
             case OpTypes.DYNAMIC_PARAM : {
                 return session.sessionContext.dynamicArguments[parameterIndex];
             }
+
             case OpTypes.SEQUENCE : {
                 return session.sessionData.getSequenceValue(sequence);
             }
+
             case OpTypes.SEQUENCE_CURRENT : {
                 return session.sessionData.getSequenceCurrent(sequence);
             }
+
             case OpTypes.ROWNUM : {
                 return ValuePool.getInt(session.sessionContext.rownum);
             }
+
             case OpTypes.ASTERISK :
             case OpTypes.MULTICOLUMN :
             default :
-                throw Error.runtimeError(ErrorCode.U_S0500,
-                                         "ExpressionColumn");
+                throw Error.runtimeError(ErrorCode.U_S0500, "ExpressionColumn");
         }
     }
 
@@ -817,12 +843,13 @@ public class ExpressionColumn extends Expression {
                 return column.getName().statementName;
 
             case OpTypes.ROWNUM : {
-                StringBuilder sb = new StringBuilder(Tokens.T_ROWNUM);
+                StringBuilder sb = new StringBuilder();
 
-                sb.append('(').append(')');
+                sb.append(Tokens.T_ROWNUM).append('(').append(')');
 
                 return sb.toString();
             }
+
             case OpTypes.COLUMN : {
                 if (column == null) {
                     if (alias != null) {
@@ -832,11 +859,9 @@ public class ExpressionColumn extends Expression {
                             return columnName;
                         }
 
-                        StringBuilder sb = new StringBuilder();
+                        StringBuilder sb = new StringBuilder(64);
 
-                        sb.append(tableName);
-                        sb.append('.');
-                        sb.append(columnName);
+                        sb.append(tableName).append('.').append(columnName);
 
                         return sb.toString();
                     }
@@ -845,15 +870,16 @@ public class ExpressionColumn extends Expression {
                 if (rangeVariable.tableAlias == null) {
                     return column.getName().getSchemaQualifiedStatementName();
                 } else {
-                    StringBuilder sb = new StringBuilder();
+                    StringBuilder sb = new StringBuilder(64);
 
-                    sb.append(rangeVariable.tableAlias.getStatementName());
-                    sb.append('.');
-                    sb.append(column.getName().statementName);
+                    sb.append(rangeVariable.tableAlias.getStatementName())
+                      .append('.')
+                      .append(column.getName().statementName);
 
                     return sb.toString();
                 }
             }
+
             case OpTypes.SIMPLE_COLUMN : {
                 if (alias != null) {
                     return alias.getStatementName();
@@ -861,6 +887,7 @@ public class ExpressionColumn extends Expression {
                     return Tokens.T_COLUMN_NAME;
                 }
             }
+
             case OpTypes.MULTICOLUMN : {
                 if (nodes.length == 0) {
                     return "*";
@@ -882,8 +909,9 @@ public class ExpressionColumn extends Expression {
 
                 return sb.toString();
             }
+
             case OpTypes.GROUPING : {
-                StringBuffer sb = new StringBuffer();
+                StringBuilder sb = new StringBuilder();
 
                 sb.append("GROUPING(");
 
@@ -903,9 +931,9 @@ public class ExpressionColumn extends Expression {
 
                 return sb.toString();
             }
+
             default :
-                throw Error.runtimeError(ErrorCode.U_S0500,
-                                         "ExpressionColumn");
+                throw Error.runtimeError(ErrorCode.U_S0500, "ExpressionColumn");
         }
     }
 
@@ -928,41 +956,45 @@ public class ExpressionColumn extends Expression {
                 break;
 
             case OpTypes.VARIABLE :
-                sb.append("VARIABLE: ");
-                sb.append(column.getName().name);
+                sb.append("VARIABLE: ").append(column.getName().name);
                 break;
 
             case OpTypes.PARAMETER :
-                sb.append(Tokens.T_PARAMETER).append(": ");
-                sb.append(column.getName().name);
+                sb.append(Tokens.T_PARAMETER)
+                  .append(": ")
+                  .append(column.getName().name);
                 break;
 
             case OpTypes.COALESCE :
-                sb.append(Tokens.T_COLUMN).append(": ");
-                sb.append(columnName);
+                sb.append(Tokens.T_COLUMN).append(": ").append(columnName);
 
                 if (alias != null) {
                     sb.append(" AS ").append(alias.name);
                 }
+
                 break;
 
             case OpTypes.COLUMN :
-                sb.append(Tokens.T_COLUMN).append(": ");
-                sb.append(column.getName().getSchemaQualifiedStatementName());
+                sb.append(Tokens.T_COLUMN)
+                  .append(": ")
+                  .append(column.getName().getSchemaQualifiedStatementName());
 
                 if (alias != null) {
                     sb.append(" AS ").append(alias.name);
                 }
+
                 break;
 
             case OpTypes.DYNAMIC_PARAM :
-                sb.append("DYNAMIC PARAM: ");
-                sb.append(", TYPE = ").append(dataType.getDefinition());
+                sb.append("DYNAMIC PARAM: ")
+                  .append(", TYPE = ")
+                  .append(dataType.getDefinition());
                 break;
 
             case OpTypes.SEQUENCE :
-                sb.append(Tokens.T_SEQUENCE).append(": ");
-                sb.append(sequence.getName().name);
+                sb.append(Tokens.T_SEQUENCE)
+                  .append(": ")
+                  .append(sequence.getName().name);
                 break;
 
             case OpTypes.MULTICOLUMN :
@@ -997,10 +1029,10 @@ public class ExpressionColumn extends Expression {
         return "";
     }
 
-    public static void checkColumnsResolved(List set) {
+    public static void checkColumnsResolved(List<Expression> set) {
 
         if (set != null && !set.isEmpty()) {
-            Expression e = (Expression) set.get(0);
+            Expression e = set.get(0);
 
             if (e instanceof ExpressionColumn) {
                 StringBuilder    sb = new StringBuilder();
@@ -1018,10 +1050,12 @@ public class ExpressionColumn extends Expression {
 
                 throw Error.error(ErrorCode.X_42501, sb.toString());
             } else {
-                OrderedHashSet newSet = new OrderedHashSet();
+                OrderedHashSet<Expression> newSet = new OrderedHashSet<>();
 
-                e.collectAllExpressions(newSet, OpTypes.columnExpressionSet,
-                                        OpTypes.emptyExpressionSet);
+                e.collectAllExpressions(
+                    newSet,
+                    OpTypes.columnExpressionSet,
+                    OpTypes.emptyExpressionSet);
 
                 // throw with column name
                 checkColumnsResolved(newSet);
@@ -1032,7 +1066,8 @@ public class ExpressionColumn extends Expression {
         }
     }
 
-    public OrderedHashSet getUnkeyedColumns(OrderedHashSet unresolvedSet) {
+    public OrderedHashSet<Expression> getUnkeyedColumns(
+            OrderedHashSet<Expression> unresolvedSet) {
 
         for (int i = 0; i < nodes.length; i++) {
             if (nodes[i] == null) {
@@ -1045,7 +1080,7 @@ public class ExpressionColumn extends Expression {
         if (opType == OpTypes.COLUMN
                 && !rangeVariable.hasKeyedColumnInGroupBy) {
             if (unresolvedSet == null) {
-                unresolvedSet = new OrderedHashSet();
+                unresolvedSet = new OrderedHashSet<>();
             }
 
             unresolvedSet.add(this);
@@ -1057,7 +1092,8 @@ public class ExpressionColumn extends Expression {
     /**
      * collects all range variables in expression tree
      */
-    OrderedHashSet collectRangeVariables(OrderedHashSet set) {
+    OrderedHashSet<RangeVariable> collectRangeVariables(
+            OrderedHashSet<RangeVariable> set) {
 
         for (int i = 0; i < nodes.length; i++) {
             if (nodes[i] != null) {
@@ -1067,7 +1103,7 @@ public class ExpressionColumn extends Expression {
 
         if (rangeVariable != null) {
             if (set == null) {
-                set = new OrderedHashSet();
+                set = new OrderedHashSet<>();
             }
 
             set.add(rangeVariable);
@@ -1076,8 +1112,9 @@ public class ExpressionColumn extends Expression {
         return set;
     }
 
-    OrderedHashSet collectRangeVariables(RangeVariable[] rangeVariables,
-                                         OrderedHashSet set) {
+    OrderedHashSet<RangeVariable> collectRangeVariables(
+            RangeVariable[] rangeVariables,
+            OrderedHashSet<RangeVariable> set) {
 
         for (int i = 0; i < nodes.length; i++) {
             if (nodes[i] != null) {
@@ -1089,11 +1126,10 @@ public class ExpressionColumn extends Expression {
             for (int i = 0; i < rangeVariables.length; i++) {
                 if (rangeVariables[i] == rangeVariable) {
                     if (set == null) {
-                        set = new OrderedHashSet();
+                        set = new OrderedHashSet<>();
                     }
 
                     set.add(rangeVariable);
-
                     break;
                 }
             }
@@ -1102,16 +1138,17 @@ public class ExpressionColumn extends Expression {
         return set;
     }
 
-    Expression replaceAliasInOrderBy(Session session, Expression[] columns,
-                                     int length) {
+    Expression replaceAliasInOrderBy(
+            Session session,
+            List<Expression> columns,
+            int length) {
 
         for (int i = 0; i < nodes.length; i++) {
             if (nodes[i] == null) {
                 continue;
             }
 
-            nodes[i] = nodes[i].replaceAliasInOrderBy(session, columns,
-                    length);
+            nodes[i] = nodes[i].replaceAliasInOrderBy(session, columns, length);
         }
 
         switch (opType) {
@@ -1121,11 +1158,14 @@ public class ExpressionColumn extends Expression {
                 int matchIndex = -1;
 
                 for (int i = 0; i < length; i++) {
-                    SimpleName aliasName = columns[i].alias;
-                    String     alias     = aliasName == null ? null
-                                                             : aliasName.name;
+                    Expression e         = columns.get(i);
+                    SimpleName aliasName = e.alias;
+                    String     alias     = aliasName == null
+                                           ? null
+                                           : aliasName.name;
 
-                    if (schema == null && tableName == null
+                    if (schema == null
+                            && tableName == null
                             && columnName.equals(alias)) {
                         if (matchIndex < 0) {
                             matchIndex = i;
@@ -1138,11 +1178,11 @@ public class ExpressionColumn extends Expression {
                 }
 
                 if (matchIndex >= 0) {
-                    return columns[matchIndex];
+                    return columns.get(matchIndex);
                 }
 
                 for (int i = 0; i < length; i++) {
-                    Expression e = (Expression) columns[i];
+                    Expression e = columns.get(i);
 
                     if (e instanceof ExpressionColumn) {
                         if (equals(e)) {
@@ -1155,7 +1195,8 @@ public class ExpressionColumn extends Expression {
                             }
                         }
 
-                        if (tableName == null && schema == null
+                        if (tableName == null
+                                && schema == null
                                 && columnName.equals(
                                     ((ExpressionColumn) e).columnName)) {
                             if (matchIndex < 0) {
@@ -1170,19 +1211,22 @@ public class ExpressionColumn extends Expression {
                 }
 
                 if (matchIndex >= 0) {
-                    return columns[matchIndex];
+                    return columns.get(matchIndex);
                 }
 
                 break;
             }
+
             default :
         }
 
         return this;
     }
 
-    Expression replaceColumnReferences(Session session, RangeVariable range,
-                                       Expression[] list) {
+    Expression replaceColumnReferences(
+            Session session,
+            RangeVariable range,
+            Expression[] list) {
 
         if (opType == OpTypes.COLUMN && rangeVariable == range) {
             Expression e = list[columnIndex];
@@ -1270,8 +1314,9 @@ public class ExpressionColumn extends Expression {
         }
     }
 
-    void replaceRangeVariables(RangeVariable[] ranges,
-                               RangeVariable[] newRanges) {
+    void replaceRangeVariables(
+            RangeVariable[] ranges,
+            RangeVariable[] newRanges) {
 
         for (int i = 0; i < nodes.length; i++) {
             nodes[i].replaceRangeVariables(ranges, newRanges);
@@ -1280,7 +1325,6 @@ public class ExpressionColumn extends Expression {
         for (int i = 0; i < ranges.length; i++) {
             if (rangeVariable == ranges[i]) {
                 rangeVariable = newRanges[i];
-
                 break;
             }
         }
@@ -1308,7 +1352,9 @@ public class ExpressionColumn extends Expression {
         return isParam;
     }
 
-    void getJoinRangeVariables(RangeVariable[] ranges, List list) {
+    void getJoinRangeVariables(
+            RangeVariable[] ranges,
+            List<RangeVariable> list) {
 
         if (opType == OpTypes.COLUMN) {
             for (int i = 0; i < ranges.length; i++) {
@@ -1332,9 +1378,10 @@ public class ExpressionColumn extends Expression {
         }
 
         PersistentStore store = range.rangeTable.getRowStore(session);
-        int indexType = range.rangeTable.indexTypeForColumn(session,
+        int indexType = range.rangeTable.indexTypeForColumn(
+            session,
             columnIndex);
-        double factor;
+        double          factor;
 
         switch (indexType) {
 
@@ -1344,6 +1391,7 @@ public class ExpressionColumn extends Expression {
                 } else {
                     factor = store.elementCount() / 2.0;
                 }
+
                 break;
 
             case Index.INDEX_NON_UNIQUE :
@@ -1356,6 +1404,7 @@ public class ExpressionColumn extends Expression {
                 } else {
                     factor = store.elementCount() / 2.0;
                 }
+
                 break;
 
             case Index.INDEX_NONE :
@@ -1364,8 +1413,7 @@ public class ExpressionColumn extends Expression {
                 break;
         }
 
-        return factor < Index.minimumSelectivity ? Index.minimumSelectivity
-                                                 : factor;
+        return Math.max(factor, Index.minimumSelectivity);
     }
 
     public Expression duplicate() {
