@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2023, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,17 +39,20 @@ import org.hsqldb.map.ValuePool;
 import org.hsqldb.types.BinaryData;
 import org.hsqldb.types.BinaryType;
 import org.hsqldb.types.CharacterType;
+import org.hsqldb.types.DateFormat;
 import org.hsqldb.types.DateTimeType;
-import org.hsqldb.types.IntervalType;
+import org.hsqldb.types.IntervalSecondData;
 import org.hsqldb.types.Type;
 import org.hsqldb.types.Types;
 
+import java.time.format.DateTimeFormatter;
+
 /**
  * Implementation of CAST, CASE, LIMIT and ZONE operations.
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.2
+ * @version 2.7.3
  * @since 1.9.0
  */
 public class ExpressionOp extends Expression {
@@ -58,6 +61,8 @@ public class ExpressionOp extends Expression {
         OpTypes.LIMIT,
         new ExpressionValue(ValuePool.INTEGER_0, Type.SQL_INTEGER),
         new ExpressionValue(ValuePool.INTEGER_1, Type.SQL_INTEGER));
+    String            template;
+    DateTimeFormatter dateTimeFormatter;
 
     /**
      * Creates a multiple arg operation expression
@@ -85,9 +90,7 @@ public class ExpressionOp extends Expression {
 
         super(type);
 
-        nodes        = new Expression[BINARY];
-        nodes[LEFT]  = left;
-        nodes[RIGHT] = right;
+        nodes = new Expression[]{ left, right };
 
         switch (opType) {
 
@@ -115,24 +118,23 @@ public class ExpressionOp extends Expression {
 
         super(OpTypes.CAST);
 
-        nodes         = new Expression[UNARY];
-        nodes[LEFT]   = e;
+        nodes         = new Expression[]{ e };
         this.dataType = dataType;
         this.alias    = e.alias;
     }
 
     /**
-     * creates a CONVERT expression with format
-     * when format is null, it is a simple CAST
+     * creates a CAST expression with template
+     * when template is null, it is a simple CAST
      */
-    ExpressionOp(Expression e, Type dataType, Expression format) {
+    ExpressionOp(Expression e, Type dataType, String template) {
 
         super(OpTypes.CAST);
 
-        nodes         = new Expression[UNARY];
-        nodes[LEFT]   = e;
+        nodes         = new Expression[]{ e };
         this.dataType = dataType;
         this.alias    = e.alias;
+        this.template = template;
     }
 
     /**
@@ -142,30 +144,32 @@ public class ExpressionOp extends Expression {
 
         super(OpTypes.CAST);
 
-        nodes       = new Expression[UNARY];
-        nodes[LEFT] = e;
+        nodes = new Expression[]{ e };
 
         switch (e.dataType.typeCode) {
 
             case Types.SQL_TIME_WITH_TIME_ZONE :
-                dataType = DateTimeType.getDateTimeType(Types.SQL_TIME,
-                        e.dataType.scale);
+                dataType = DateTimeType.getDateTimeType(
+                    Types.SQL_TIME,
+                    e.dataType.scale);
                 break;
 
             case Types.SQL_TIMESTAMP_WITH_TIME_ZONE :
-                dataType = DateTimeType.getDateTimeType(Types.SQL_TIMESTAMP,
-                        e.dataType.scale);
+                dataType = DateTimeType.getDateTimeType(
+                    Types.SQL_TIMESTAMP,
+                    e.dataType.scale);
                 break;
 
             case Types.SQL_TIME :
-                dataType =
-                    DateTimeType.getDateTimeType(Types.SQL_TIME_WITH_TIME_ZONE,
-                                                 e.dataType.scale);
+                dataType = DateTimeType.getDateTimeType(
+                    Types.SQL_TIME_WITH_TIME_ZONE,
+                    e.dataType.scale);
                 break;
 
             case Types.SQL_TIMESTAMP :
                 dataType = DateTimeType.getDateTimeType(
-                    Types.SQL_TIMESTAMP_WITH_TIME_ZONE, e.dataType.scale);
+                    Types.SQL_TIMESTAMP_WITH_TIME_ZONE,
+                    e.dataType.scale);
                 break;
 
             default :
@@ -175,12 +179,16 @@ public class ExpressionOp extends Expression {
         this.alias = e.alias;
     }
 
-    public static Expression getCastExpression(Session session, Expression e,
+    public static Expression getCastExpression(
+            Session session,
+            Expression e,
             Type dataType) {
 
         if (e.getType() == OpTypes.VALUE) {
-            Object value = dataType.castToType(session, e.getValue(session),
-                                               e.getDataType());
+            Object value = dataType.castToType(
+                session,
+                e.getValue(session),
+                e.getDataType());
 
             return new ExpressionValue(value, dataType);
         }
@@ -188,13 +196,16 @@ public class ExpressionOp extends Expression {
         return new ExpressionOp(e, dataType);
     }
 
-    public static Expression getConvertExpression(Session session,
-            Expression e, Type dataType) {
+    public static Expression getConvertExpression(
+            Session session,
+            Expression e,
+            Type dataType) {
 
         if (e.getType() == OpTypes.VALUE) {
-            Object value = dataType.convertToType(session,
-                                                  e.getValue(session),
-                                                  e.getDataType());
+            Object value = dataType.convertToType(
+                session,
+                e.getValue(session),
+                e.getDataType());
 
             return new ExpressionValue(value, dataType);
         }
@@ -209,10 +220,12 @@ public class ExpressionOp extends Expression {
     public String getSQL() {
 
         StringBuilder sb    = new StringBuilder(64);
-        String        left  = getContextSQL(nodes.length > 0 ? nodes[LEFT]
-                                                             : null);
-        String        right = getContextSQL(nodes.length > 1 ? nodes[RIGHT]
-                                                             : null);
+        String        left  = getContextSQL(nodes.length > 0
+                ? nodes[LEFT]
+                : null);
+        String        right = getContextSQL(nodes.length > 1
+                ? nodes[RIGHT]
+                : null);
 
         switch (opType) {
 
@@ -222,21 +235,40 @@ public class ExpressionOp extends Expression {
                 }
 
                 if (dataType == null) {
-                    throw Error.runtimeError(ErrorCode.U_S0500,
-                                             "ExpressionOp");
+                    throw Error.runtimeError(ErrorCode.U_S0500, "ExpressionOp");
                 }
 
                 return dataType.convertToSQLString(valueData);
 
             case OpTypes.LIKE_ARG :
-                sb.append(' ').append(Tokens.T_LIKE).append(' ');
-                sb.append(left).append(' ').append(right).append(' ');
+                sb.append(' ')
+                  .append(Tokens.T_LIKE)
+                  .append(' ')
+                  .append(left)
+                  .append(' ')
+                  .append(right)
+                  .append(' ');
                 break;
 
             case OpTypes.CAST :
-                sb.append(' ').append(Tokens.T_CAST).append('(');
-                sb.append(left).append(' ').append(Tokens.T_AS).append(' ');
-                sb.append(dataType.getTypeDefinition());
+                sb.append(' ')
+                  .append(Tokens.T_CAST)
+                  .append('(')
+                  .append(left)
+                  .append(' ')
+                  .append(Tokens.T_AS)
+                  .append(' ')
+                  .append(dataType.getTypeDefinition());
+
+                if (template != null) {
+                    sb.append(' ')
+                      .append(Tokens.T_FORMAT)
+                      .append(' ')
+                      .append('\'')
+                      .append(template)
+                      .append('\'');
+                }
+
                 sb.append(')');
                 break;
 
@@ -245,8 +277,13 @@ public class ExpressionOp extends Expression {
                 break;
 
             case OpTypes.CASEWHEN :
-                sb.append(' ').append(Tokens.T_CASEWHEN).append('(');
-                sb.append(left).append(',').append(right).append(')');
+                sb.append(' ')
+                  .append(Tokens.T_CASEWHEN)
+                  .append('(')
+                  .append(left)
+                  .append(',')
+                  .append(right)
+                  .append(')');
                 break;
 
             case OpTypes.ALTERNATIVE :
@@ -255,17 +292,28 @@ public class ExpressionOp extends Expression {
 
             case OpTypes.LIMIT :
                 if (left != null) {
-                    sb.append(' ').append(Tokens.T_OFFSET).append(' ');
-                    sb.append(left).append(' ');
+                    sb.append(' ')
+                      .append(Tokens.T_OFFSET)
+                      .append(' ')
+                      .append(left)
+                      .append(' ');
                 }
 
                 if (right != null) {
-                    sb.append(' ').append(Tokens.T_FETCH).append(' ');
-                    sb.append(Tokens.T_FIRST);
-                    sb.append(right).append(' ').append(right).append(' ');
-                    sb.append(Tokens.T_ROWS).append(' ').append(Tokens.T_ONLY);
-                    sb.append(' ');
+                    sb.append(' ')
+                      .append(Tokens.T_FETCH)
+                      .append(' ')
+                      .append(Tokens.T_FIRST)
+                      .append(right)
+                      .append(' ')
+                      .append(right)
+                      .append(' ')
+                      .append(Tokens.T_ROWS)
+                      .append(' ')
+                      .append(Tokens.T_ONLY)
+                      .append(' ');
                 }
+
                 break;
 
             case OpTypes.ZONE_MODIFIER :
@@ -273,18 +321,20 @@ public class ExpressionOp extends Expression {
 
                 if (nodes[RIGHT] == null) {
                     sb.append(Tokens.T_LOCAL).append(' ');
-
                     break;
                 }
 
-                sb.append(Tokens.T_TIME).append(' ').append(Tokens.T_ZONE);
-                sb.append(' ');
-                sb.append(right);
+                sb.append(Tokens.T_TIME)
+                  .append(' ')
+                  .append(Tokens.T_ZONE)
+                  .append(' ')
+                  .append(right);
                 break;
 
             case OpTypes.CONCAT_WS :
-                sb.append(Tokens.T_CONCAT_WS).append(Tokens.OPENBRACKET);
-                sb.append(left);
+                sb.append(Tokens.T_CONCAT_WS)
+                  .append(Tokens.OPENBRACKET)
+                  .append(left);
 
                 for (int i = 0; i < nodes.length; i++) {
                     sb.append(',').append(nodes[i].getSQL());
@@ -313,38 +363,43 @@ public class ExpressionOp extends Expression {
         switch (opType) {
 
             case OpTypes.VALUE :
-                sb.append("VALUE = ").append(
-                    dataType.convertToSQLString(valueData));
-                sb.append(", TYPE = ").append(dataType.getNameString());
+                sb.append("VALUE = ")
+                  .append(dataType.convertToSQLString(valueData))
+                  .append(", TYPE = ")
+                  .append(dataType.getNameString());
 
                 return sb.toString();
 
             case OpTypes.LIKE_ARG :
-                sb.append(Tokens.T_LIKE).append(' ').append("ARG ");
-                sb.append(dataType.getTypeDefinition());
-                sb.append(' ');
+                sb.append(Tokens.T_LIKE)
+                  .append(' ')
+                  .append("ARG ")
+                  .append(dataType.getTypeDefinition())
+                  .append(' ');
                 break;
 
             case OpTypes.VALUELIST :
                 sb.append(Tokens.T_VALUE).append(' ').append("LIST ");
 
                 for (int i = 0; i < nodes.length; i++) {
-                    sb.append(nodes[i].describe(session, blanks + 1));
-                    sb.append(' ');
+                    sb.append(nodes[i].describe(session, blanks + 1))
+                      .append(' ');
                 }
 
                 return sb.toString();
 
             case OpTypes.CAST :
-                sb.append(Tokens.T_CAST).append(' ');
-                sb.append(dataType.getTypeDefinition());
-                sb.append(' ');
+                sb.append(Tokens.T_CAST)
+                  .append(' ')
+                  .append(dataType.getTypeDefinition())
+                  .append(' ');
                 break;
 
             case OpTypes.CONVERT :
-                sb.append(Tokens.T_CONVERT).append(' ');
-                sb.append(dataType.getTypeDefinition());
-                sb.append(' ');
+                sb.append(Tokens.T_CONVERT)
+                  .append(' ')
+                  .append(dataType.getTypeDefinition())
+                  .append(' ');
                 break;
 
             case OpTypes.CASEWHEN :
@@ -359,25 +414,27 @@ public class ExpressionOp extends Expression {
         }
 
         if (getLeftNode() != null) {
-            sb.append(" arg_left=[");
-            sb.append(nodes[LEFT].describe(session, blanks + 1));
-            sb.append(']');
+            sb.append(" arg_left=[")
+              .append(nodes[LEFT].describe(session, blanks + 1))
+              .append(']');
         }
 
         if (getRightNode() != null) {
-            sb.append(" arg_right=[");
-            sb.append(nodes[RIGHT].describe(session, blanks + 1));
-            sb.append(']');
+            sb.append(" arg_right=[")
+              .append(nodes[RIGHT].describe(session, blanks + 1))
+              .append(']');
         }
 
         return sb.toString();
     }
 
-    public List resolveColumnReferences(Session session,
-                                        RangeGroup rangeGroup, int rangeCount,
-                                        RangeGroup[] rangeGroups,
-                                        List unresolvedSet,
-                                        boolean acceptsSequences) {
+    public List<Expression> resolveColumnReferences(
+            Session session,
+            RangeGroup rangeGroup,
+            int rangeCount,
+            RangeGroup[] rangeGroups,
+            List<Expression> unresolvedSet,
+            boolean acceptsSequences) {
 
         if (opType == OpTypes.VALUE) {
             return unresolvedSet;
@@ -397,9 +454,13 @@ public class ExpressionOp extends Expression {
                 continue;
             }
 
-            unresolvedSet = nodes[i].resolveColumnReferences(session,
-                    rangeGroup, rangeCount, rangeGroups, unresolvedSet,
-                    acceptsSequences);
+            unresolvedSet = nodes[i].resolveColumnReferences(
+                session,
+                rangeGroup,
+                rangeCount,
+                rangeGroups,
+                unresolvedSet,
+                acceptsSequences);
         }
 
         return unresolvedSet;
@@ -432,12 +493,12 @@ public class ExpressionOp extends Expression {
                         && (nodes[RIGHT] == null
                             || nodes[RIGHT].opType == OpTypes.VALUE)) {
                     setAsConstantValue(session, parent);
-
                     break;
                 }
 
                 break;
             }
+
             case OpTypes.CAST :
             case OpTypes.CONVERT : {
                 Expression node     = nodes[LEFT];
@@ -447,14 +508,45 @@ public class ExpressionOp extends Expression {
                     throw Error.error(ErrorCode.X_42561);
                 }
 
-                if (node.opType == OpTypes.VALUE) {
-                    setAsConstantValue(session, parent);
-                } else if (nodes[LEFT].opType == OpTypes.DYNAMIC_PARAM) {
-                    node.dataType = dataType;
+                if (template == null) {
+                    if (node.opType == OpTypes.VALUE) {
+                        setAsConstantValue(session, parent);
+                    } else if (node.opType == OpTypes.DYNAMIC_PARAM) {
+                        node.dataType = dataType;
+                    }
+                } else {
+                    if (dataType.isCharacterType()) {
+                        if (node.opType == OpTypes.DYNAMIC_PARAM) {
+                            node.dataType = Type.SQL_TIMESTAMP;
+                        }
+
+                        if (!node.dataType.isDateTimeType()) {
+                            throw Error.error(ErrorCode.X_42561);
+                        }
+
+                        dateTimeFormatter = DateFormat.toFormatter(
+                            template,
+                            false);
+                    } else if (dataType.isDateTimeType()) {
+                        if (node.opType == OpTypes.DYNAMIC_PARAM) {
+                            node.dataType = Type.SQL_VARCHAR_DEFAULT;
+                        }
+
+                        if (!node.dataType.isCharacterType()) {
+                            throw Error.error(ErrorCode.X_42561);
+                        }
+
+                        dateTimeFormatter = DateFormat.toFormatter(
+                            template,
+                            true);
+                    } else {
+                        throw Error.error(ErrorCode.X_42561);
+                    }
                 }
 
                 break;
             }
+
             case OpTypes.ZONE_MODIFIER :
                 if (nodes[LEFT].dataType == null) {
                     throw Error.error(ErrorCode.X_42567);
@@ -543,6 +635,7 @@ public class ExpressionOp extends Expression {
                         throw Error.error(ErrorCode.X_42563);
                     }
                 }
+
                 break;
 
             case OpTypes.PREFIX :
@@ -598,8 +691,9 @@ public class ExpressionOp extends Expression {
             if (expr.exprSubType == OpTypes.CAST) {
                 dataType = expr.nodes[RIGHT].dataType;
             } else {
-                dataType = Type.getAggregateType(expr.nodes[RIGHT].dataType,
-                                                 dataType);
+                dataType = Type.getAggregateType(
+                    expr.nodes[RIGHT].dataType,
+                    dataType);
             }
 
             if (expr.nodes[RIGHT].nodes[RIGHT].opType == OpTypes.CASEWHEN) {
@@ -640,12 +734,14 @@ public class ExpressionOp extends Expression {
                 expr.nodes[LEFT].dataType = Type.SQL_BOOLEAN;
             }
 
-            expr.nodes[RIGHT].nodes[LEFT].resolveTypes(session,
-                    expr.nodes[RIGHT]);
+            expr.nodes[RIGHT].nodes[LEFT].resolveTypes(
+                session,
+                expr.nodes[RIGHT]);
 
             if (expr.nodes[RIGHT].nodes[RIGHT].opType != OpTypes.CASEWHEN) {
-                expr.nodes[RIGHT].nodes[RIGHT].resolveTypes(session,
-                        expr.nodes[RIGHT]);
+                expr.nodes[RIGHT].nodes[RIGHT].resolveTypes(
+                    session,
+                    expr.nodes[RIGHT]);
             }
 
             expr = expr.nodes[RIGHT].nodes[RIGHT];
@@ -670,16 +766,16 @@ public class ExpressionOp extends Expression {
                 int     escapeChar = Integer.MAX_VALUE;
 
                 if (dataType.isBinaryType()) {
-                    BinaryData left =
-                        (BinaryData) nodes[LEFT].getValue(session);
+                    BinaryData left = (BinaryData) nodes[LEFT].getValue(
+                        session);
 
                     if (left == null) {
                         return null;
                     }
 
                     if (hasEscape) {
-                        BinaryData right =
-                            (BinaryData) nodes[RIGHT].getValue(session);
+                        BinaryData right = (BinaryData) nodes[RIGHT].getValue(
+                            session);
 
                         if (right == null) {
                             return null;
@@ -706,7 +802,6 @@ public class ExpressionOp extends Expression {
 
                                 newArray[j++] = array[i];
                                 wasEscape     = false;
-
                                 continue;
                             }
 
@@ -725,7 +820,6 @@ public class ExpressionOp extends Expression {
 
                                 newArray[j++] = array[i];
                                 wasEscape     = false;
-
                                 continue;
                             }
 
@@ -739,25 +833,26 @@ public class ExpressionOp extends Expression {
                         newArray[j++] = array[i];
                     }
 
-                    newArray =
-                        (byte[]) ArrayUtil.resizeArrayIfDifferent(newArray, j);
+                    newArray = (byte[]) ArrayUtil.resizeArrayIfDifferent(
+                        newArray,
+                        j);
 
                     return new BinaryData(newArray, false);
                 } else {
-                    String left =
-                        (String) Type.SQL_VARCHAR.convertToType(session,
-                            nodes[LEFT].getValue(session),
-                            nodes[LEFT].getDataType());
+                    String left = (String) Type.SQL_VARCHAR.convertToType(
+                        session,
+                        nodes[LEFT].getValue(session),
+                        nodes[LEFT].getDataType());
 
                     if (left == null) {
                         return null;
                     }
 
                     if (hasEscape) {
-                        String right =
-                            (String) Type.SQL_VARCHAR.convertToType(session,
-                                nodes[RIGHT].getValue(session),
-                                nodes[RIGHT].getDataType());
+                        String right = (String) Type.SQL_VARCHAR.convertToType(
+                            session,
+                            nodes[RIGHT].getValue(session),
+                            nodes[RIGHT].getDataType());
 
                         if (right == null) {
                             return null;
@@ -784,7 +879,6 @@ public class ExpressionOp extends Expression {
 
                                 newArray[j++] = array[i];
                                 wasEscape     = false;
-
                                 continue;
                             }
 
@@ -803,7 +897,6 @@ public class ExpressionOp extends Expression {
 
                                 newArray[j++] = array[i];
                                 wasEscape     = false;
-
                                 continue;
                             }
 
@@ -820,6 +913,7 @@ public class ExpressionOp extends Expression {
                     return new String(newArray, 0, j);
                 }
             }
+
             case OpTypes.ORDER_BY :
                 return nodes[LEFT].getValue(session);
 
@@ -831,10 +925,9 @@ public class ExpressionOp extends Expression {
                         return null;
                     }
 
-                    CharacterType type = (CharacterType) nodes[RIGHT].dataType;
-                    long length =
-                        ((CharacterType) nodes[RIGHT].dataType).size(session,
-                            value);
+                    CharacterType type   =
+                        (CharacterType) nodes[RIGHT].dataType;
+                    long          length = type.size(session, value);
 
                     type  = (CharacterType) nodes[LEFT].dataType;
                     value = nodes[LEFT].getValue(session);
@@ -843,11 +936,16 @@ public class ExpressionOp extends Expression {
                         return null;
                     }
 
-                    return type.substring(session, value, 0, length, true,
-                                          false);
+                    return type.substring(
+                        session,
+                        value,
+                        0,
+                        length,
+                        true,
+                        false);
                 } else {
-                    BinaryData value =
-                        (BinaryData) nodes[RIGHT].getValue(session);
+                    BinaryData value = (BinaryData) nodes[RIGHT].getValue(
+                        session);
 
                     if (value == null) {
                         return null;
@@ -865,53 +963,82 @@ public class ExpressionOp extends Expression {
                     return type.substring(session, value, 0, length, true);
                 }
             }
+
             case OpTypes.CAST : {
-                Object value =
-                    dataType.castToType(session,
-                                        nodes[LEFT].getValue(session),
-                                        nodes[LEFT].dataType);
+                Object value;
+
+                if (dateTimeFormatter == null) {
+                    value = dataType.castToType(
+                        session,
+                        nodes[LEFT].getValue(session),
+                        nodes[LEFT].dataType);
+                } else {
+                    if (dataType.isDateTimeType()) {
+                        String string = (String) nodes[LEFT].getValue(session);
+
+                        value = DateFormat.toDate(
+                            (DateTimeType) dataType,
+                            string,
+                            dateTimeFormatter);
+                    } else {
+                        value = nodes[LEFT].getValue(session);
+                        value = DateFormat.toFormattedDate(
+                            (DateTimeType) nodes[LEFT].dataType,
+                            value,
+                            dateTimeFormatter);
+                    }
+                }
 
                 if (dataType.userTypeModifier != null) {
                     Constraint[] constraints =
                         dataType.userTypeModifier.getConstraints();
 
                     for (int i = 0; i < constraints.length; i++) {
-                        constraints[i].checkCheckConstraint(session, null,
-                                                            null, value);
+                        constraints[i].checkCheckConstraint(
+                            session,
+                            null,
+                            null,
+                            value);
                     }
                 }
 
                 return value;
             }
+
             case OpTypes.CONVERT : {
-                Object value =
-                    dataType.convertToType(session,
-                                           nodes[LEFT].getValue(session),
-                                           nodes[LEFT].dataType);
+                Object value = dataType.convertToType(
+                    session,
+                    nodes[LEFT].getValue(session),
+                    nodes[LEFT].dataType);
 
                 if (dataType.userTypeModifier != null) {
                     Constraint[] constraints =
                         dataType.userTypeModifier.getConstraints();
 
                     for (int i = 0; i < constraints.length; i++) {
-                        constraints[i].checkCheckConstraint(session, null,
-                                                            null, value);
+                        constraints[i].checkCheckConstraint(
+                            session,
+                            null,
+                            null,
+                            value);
                     }
                 }
 
                 return value;
             }
+
             case OpTypes.CASEWHEN : {
                 Boolean result = (Boolean) nodes[LEFT].getValue(session);
 
                 if (Boolean.TRUE.equals(result)) {
-                    return nodes[RIGHT].nodes[LEFT].getValue(session,
-                            dataType);
+                    return nodes[RIGHT].nodes[LEFT].getValue(session, dataType);
                 } else {
-                    return nodes[RIGHT].nodes[RIGHT].getValue(session,
-                            dataType);
+                    return nodes[RIGHT].nodes[RIGHT].getValue(
+                        session,
+                        dataType);
                 }
             }
+
             case OpTypes.CONCAT_WS : {
                 String sep = (String) nodes[LEFT].getValue(session);
 
@@ -940,12 +1067,12 @@ public class ExpressionOp extends Expression {
 
                 return sb.toString();
             }
+
             case OpTypes.ZONE_MODIFIER : {
                 Object leftValue  = nodes[LEFT].getValue(session);
-                Object rightValue = nodes[RIGHT] == null ? null
-                                                         : nodes[RIGHT]
-                                                             .getValue(
-                                                                 session);
+                Object rightValue = nodes[RIGHT] == null
+                                    ? null
+                                    : nodes[RIGHT].getValue(session);
 
                 if (leftValue == null) {
                     return null;
@@ -954,8 +1081,12 @@ public class ExpressionOp extends Expression {
                 boolean atLocal = nodes[RIGHT] == null;
 
                 if (atLocal) {
-                    return ((DateTimeType) dataType).changeZone(session,
-                            leftValue, nodes[LEFT].dataType, 0, atLocal);
+                    return ((DateTimeType) dataType).changeZone(
+                        session,
+                        leftValue,
+                        nodes[LEFT].dataType,
+                        0,
+                        true);
                 }
 
                 if (rightValue == null) {
@@ -964,24 +1095,30 @@ public class ExpressionOp extends Expression {
 
                 if (nodes[RIGHT].dataType.isCharacterType()) {
                     if (DateTimeType.zoneIDs.contains(rightValue)) {
-                        return ((DateTimeType) dataType).changeZone(session,
-                                leftValue, nodes[LEFT].dataType,
-                                (String) rightValue);
+                        return ((DateTimeType) dataType).changeZone(
+                            session,
+                            leftValue,
+                            nodes[LEFT].dataType,
+                            (String) rightValue);
                     } else {
                         rightValue =
-                            Type.SQL_INTERVAL_HOUR_TO_MINUTE
-                                .convertToDefaultType(session, rightValue);
+                            Type.SQL_INTERVAL_HOUR_TO_MINUTE.convertToDefaultType(
+                                session,
+                                rightValue);
                     }
                 }
 
                 long zoneSeconds =
-                    ((IntervalType) nodes[RIGHT].dataType).getSeconds(
-                        rightValue);
+                    ((IntervalSecondData) rightValue).getSeconds();
 
-                return ((DateTimeType) dataType).changeZone(session,
-                        leftValue, nodes[LEFT].dataType, (int) zoneSeconds,
-                        false);
+                return ((DateTimeType) dataType).changeZone(
+                    session,
+                    leftValue,
+                    nodes[LEFT].dataType,
+                    (int) zoneSeconds,
+                    false);
             }
+
             case OpTypes.LIMIT :
 
             // fall through
@@ -989,4 +1126,15 @@ public class ExpressionOp extends Expression {
                 throw Error.runtimeError(ErrorCode.U_S0500, "ExpressionOp");
         }
     }
+
+    public boolean equals(Expression other) {
+
+        boolean value = super.equals(other);
+
+        if (opType == OpTypes.CAST) {
+            value = value && equals(template, ((ExpressionOp) other).template);
+        }
+
+        return value;
+    }
 }
