@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -144,8 +144,7 @@ public class GroupSet {
         Expression[] exprs = e.nodes;
 
         if (exprs.length == 0
-                || (e.opType != OpTypes.VALUELIST
-                    && e.opType != OpTypes.ROW)) {
+                || (e.opType != OpTypes.VALUELIST && e.opType != OpTypes.ROW)) {
             exprs    = new Expression[1];
             exprs[0] = e;
         }
@@ -236,8 +235,8 @@ public class GroupSet {
             first.add(tmp);
         }
 
-        HsqlArrayList results = powerSet(Arrays.copyOfRange(expressions, 1,
-            expressions.length));
+        HsqlArrayList results = powerSet(
+            Arrays.copyOfRange(expressions, 1, expressions.length));
         Iterator itFirst = first.iterator();
 
         while (itFirst.hasNext()) {
@@ -287,8 +286,8 @@ public class GroupSet {
             first.add(tmp);
         }
 
-        HsqlArrayList results = rollUp(Arrays.copyOfRange(expressions, 1,
-            expressions.length));
+        HsqlArrayList results = rollUp(
+            Arrays.copyOfRange(expressions, 1, expressions.length));
         Iterator it = results.iterator();
 
         while (it.hasNext()) {
@@ -334,8 +333,8 @@ public class GroupSet {
             sets.add(tmp);
         }
 
-        HsqlArrayList results = grouping(Arrays.copyOfRange(expressions, 1,
-            expressions.length));
+        HsqlArrayList results = grouping(
+            Arrays.copyOfRange(expressions, 1, expressions.length));
 
         sets.addAll(results);
 
