@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,8 +48,8 @@ public class HsqlException extends RuntimeException {
 
     //
     public static final HsqlException[] emptyArray = new HsqlException[]{};
-    public static final HsqlException noDataCondition =
-        Error.error(ErrorCode.N_02000);
+    public static final HsqlException noDataCondition = Error.error(
+        ErrorCode.N_02000);
 
     //
     private String message;
@@ -59,7 +59,8 @@ public class HsqlException extends RuntimeException {
     private int    statementGroup;
     private int    statementCode;
     private String token;
-    public  Object info;
+    public Object  info;
+
     /**
      * @param message String
      * @param state XOPEN / SQL code for exception
@@ -78,7 +79,6 @@ public class HsqlException extends RuntimeException {
      * @param r containing the members
      */
     public HsqlException(Result r) {
-
         this.message = r.getMainString();
         this.state   = r.getSubString();
         this.code    = r.getErrorCode();
@@ -152,7 +152,8 @@ public class HsqlException extends RuntimeException {
         if (other instanceof HsqlException) {
             HsqlException o = (HsqlException) other;
 
-            return code == o.code && equals(state, o.state)
+            return code == o.code
+                   && equals(state, o.state)
                    && equals(message, o.message);
         }
 
