@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@ import org.hsqldb.lib.OrderedIntHashSet;
  * Enumerate expression operation types<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.4
  * @since 1.9.0
  */
 public interface OpTypes {
@@ -124,8 +124,7 @@ public interface OpTypes {
         VAR_POP                    = 83,
         VAR_SAMP                   = 84,
         ARRAY_AGG                  = 85,
-        GROUP_CONCAT               = 86,
-        STRING_AGG                 = 87,
+        LISTAGG                    = 87,
         PREFIX                     = 88,
         MEDIAN                     = 89,
         CONCAT_WS                  = 90,
@@ -142,7 +141,10 @@ public interface OpTypes {
         ARRAY_SUBQUERY             = 102,
         JSON_FUNCTION              = 103,
         JSON_SQL_FUNCTION          = 104,
-        GROUPING                   = 105;    // grouping function
+        GROUPING                   = 105,    // grouping function
+        STDDEV                     = 106,
+        VARIANCE                   = 107,
+        ANY_VALUE                  = 108;
     //J-
     int[] aggOpTypes = new int[] {
 
@@ -152,6 +154,7 @@ public interface OpTypes {
         OpTypes.MIN,
         OpTypes.SUM,
         OpTypes.EVERY,
+        OpTypes.ANY_VALUE,
         OpTypes.SOME,
         OpTypes.STDDEV_POP,
         OpTypes.STDDEV_SAMP,
@@ -159,9 +162,11 @@ public interface OpTypes {
         OpTypes.VAR_SAMP,
         OpTypes.ARRAY_AGG,
         OpTypes.USER_AGGREGATE,
-        OpTypes.GROUP_CONCAT,
-        OpTypes.STRING_AGG,
+        OpTypes.LISTAGG,
         OpTypes.MEDIAN,
+        OpTypes.VARIANCE,
+        OpTypes.STDDEV,
+        OpTypes.ANY_VALUE,
     };
 
     int[] columnOpTypes = new int[]{ OpTypes.COLUMN };
@@ -180,16 +185,18 @@ public interface OpTypes {
         OpTypes.SEQUENCE
     };
     //J+
-    OrderedIntHashSet emptyExpressionSet   = new OrderedIntHashSet();
+
+    OrderedIntHashSet emptyExpressionSet = new OrderedIntHashSet();
     OrderedIntHashSet aggregateFunctionSet = new OrderedIntHashSet(aggOpTypes);
-    OrderedIntHashSet columnExpressionSet =
-        new OrderedIntHashSet(columnOpTypes);
-    OrderedIntHashSet subqueryExpressionSet =
-        new OrderedIntHashSet(subqueryOpTypes);
-    OrderedIntHashSet subqueryAggregateExpressionSet =
-        new OrderedIntHashSet(subqueryOpTypes, aggOpTypes);
-    OrderedIntHashSet functionExpressionSet =
-        new OrderedIntHashSet(functionOpTypes);
-    OrderedIntHashSet sequenceExpressionSet =
-        new OrderedIntHashSet(sequenceOpTypes);
+    OrderedIntHashSet columnExpressionSet = new OrderedIntHashSet(
+        columnOpTypes);
+    OrderedIntHashSet subqueryExpressionSet = new OrderedIntHashSet(
+        subqueryOpTypes);
+    OrderedIntHashSet subqueryAggregateExpressionSet = new OrderedIntHashSet(
+        subqueryOpTypes,
+        aggOpTypes);
+    OrderedIntHashSet functionExpressionSet = new OrderedIntHashSet(
+        functionOpTypes);
+    OrderedIntHashSet sequenceExpressionSet = new OrderedIntHashSet(
+        sequenceOpTypes);
 }
