@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,7 @@ package org.hsqldb;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
+
 import java.sql.ResultSet;
 
 import org.hsqldb.HsqlNameManager.HsqlName;
@@ -59,7 +60,7 @@ import org.hsqldb.types.Types;
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
  *
- * @version 2.6.0
+ * @version 2.7.3
  * @since 1.9.0
  */
 public class Routine implements SchemaObject, RangeGroup, Cloneable {
@@ -112,15 +113,15 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
     private boolean isLibraryRoutine;
 
     //
-    OrderedHashMap  parameterList = new OrderedHashMap();
-    RangeVariable[] ranges        = RangeVariable.emptyArray;
+    OrderedHashMap<String, ColumnSchema> parameterList = new OrderedHashMap<>();
+    RangeVariable[]                      ranges = RangeVariable.emptyArray;
 
     //
     int variableCount;
     int cursorCount;
 
     //
-    OrderedHashSet references;
+    OrderedHashSet<HsqlName> references;
 
     //
     Table triggerTable;
@@ -131,13 +132,19 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
         routineType = type;
         returnType  = Type.SQL_ALL_TYPES;
-        ranges = new RangeVariable[]{
-            new RangeVariable(parameterList, null, false,
-                              RangeVariable.PARAMETER_RANGE) };
+        ranges = new RangeVariable[]{ new RangeVariable(
+            parameterList,
+            null,
+            false,
+            RangeVariable.PARAMETER_RANGE) };
     }
 
-    public Routine(Table table, RangeVariable[] ranges, int impact,
-                   int triggerType, int operationType) {
+    public Routine(
+            Table table,
+            RangeVariable[] ranges,
+            int impact,
+            int triggerType,
+            int operationType) {
 
         routineType           = SchemaObject.TRIGGER;
         returnType            = Type.SQL_ALL_TYPES;
@@ -173,19 +180,15 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         return name.schema.owner;
     }
 
-    public OrderedHashSet getReferences() {
+    public OrderedHashSet<HsqlName> getReferences() {
         return references;
     }
 
-    public OrderedHashSet getComponents() {
-        return null;
-    }
-
     public void compile(Session session, SchemaObject parentObject) {
 
-        ParserRoutine p = new ParserRoutine(session,
-                                            new Scanner(session,
-                                                statement.getSQL()));
+        ParserRoutine p = new ParserRoutine(
+            session,
+            new Scanner(session, statement.getSQL()));
 
         session.sessionContext.pushRoutineTables();
 
@@ -193,9 +196,10 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             p.read();
 
             Recorder recorder = p.startRecording();
-            Statement newStatement = p.compileSQLProcedureStatementOrNull(this,
+            Statement newStatement = p.compileSQLProcedureStatementOrNull(
+                this,
                 null);
-            String sql = recorder.getSQL();
+            String   sql      = recorder.getSQL();
 
             newStatement.setSQL(sql);
             setProcedure(newStatement);
@@ -211,13 +215,19 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
     public String getSQLAlter() {
 
-        StringBuilder sb = new StringBuilder();
+        StringBuilder sb = new StringBuilder(64);
 
-        sb.append(Tokens.T_ALTER).append(' ').append(Tokens.T_SPECIFIC);
-        sb.append(' ').append(Tokens.T_ROUTINE).append(' ');
-        sb.append(specificName.getSchemaQualifiedStatementName());
-        sb.append(' ').append(Tokens.T_BODY);
-        sb.append(' ').append(statement.getSQL());
+        sb.append(Tokens.T_ALTER)
+          .append(' ')
+          .append(Tokens.T_SPECIFIC)
+          .append(' ')
+          .append(Tokens.T_ROUTINE)
+          .append(' ')
+          .append(specificName.getSchemaQualifiedStatementName())
+          .append(' ')
+          .append(Tokens.T_BODY)
+          .append(' ')
+          .append(statement.getSQL());
 
         return sb.toString();
     }
@@ -242,31 +252,29 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             sb.append(Tokens.T_FUNCTION);
         }
 
-        sb.append(' ');
-        sb.append(name.getSchemaQualifiedStatementName());
-        sb.append('(');
+        sb.append(' ')
+          .append(name.getSchemaQualifiedStatementName())
+          .append('(');
 
         for (int i = 0; i < parameterList.size(); i++) {
             if (i > 0) {
                 sb.append(',');
             }
 
-            ColumnSchema param = (ColumnSchema) parameterList.get(i);
+            ColumnSchema param = parameterList.get(i);
 
             // in - out
             sb.append(param.getSQL());
         }
 
-        sb.append(')');
-        sb.append(' ');
+        sb.append(')').append(' ');
 
         if (routineType == SchemaObject.FUNCTION) {
-            sb.append(Tokens.T_RETURNS);
-            sb.append(' ');
+            sb.append(Tokens.T_RETURNS).append(' ');
 
             if (returnsTable) {
-                sb.append(Tokens.T_TABLE);
-                sb.append(returnTable.getColumnListWithTypeSQL());
+                sb.append(Tokens.T_TABLE)
+                  .append(returnTable.getColumnListWithTypeSQL());
             } else {
                 sb.append(returnType.getTypeDefinition());
             }
@@ -276,15 +284,14 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
         // SPECIFIC
         if (specificName != null) {
-            sb.append(Tokens.T_SPECIFIC);
-            sb.append(' ');
-            sb.append(specificName.getStatementName());
-            sb.append(' ');
+            sb.append(Tokens.T_SPECIFIC)
+              .append(' ')
+              .append(specificName.getStatementName())
+              .append(' ');
         }
 
         //
-        sb.append(Tokens.T_LANGUAGE);
-        sb.append(' ');
+        sb.append(Tokens.T_LANGUAGE).append(' ');
 
         if (language == LANGUAGE_JAVA) {
             sb.append(Tokens.T_JAVA);
@@ -296,16 +303,13 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
         //
         if (!isDeterministic) {
-            sb.append(Tokens.T_NOT);
-            sb.append(' ');
+            sb.append(Tokens.T_NOT).append(' ');
         }
 
-        sb.append(Tokens.T_DETERMINISTIC);
-        sb.append(' ');
+        sb.append(Tokens.T_DETERMINISTIC).append(' ');
 
         //
-        sb.append(getDataImpactString());
-        sb.append(' ');
+        sb.append(getDataImpactString()).append(' ');
 
         //
         if (routineType == SchemaObject.FUNCTION) {
@@ -315,9 +319,13 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                 sb.append(Tokens.T_CALLED);
             }
 
-            sb.append(' ').append(Tokens.T_ON).append(' ');
-            sb.append(Tokens.T_NULL).append(' ').append(Tokens.T_INPUT);
-            sb.append(' ');
+            sb.append(' ')
+              .append(Tokens.T_ON)
+              .append(' ')
+              .append(Tokens.T_NULL)
+              .append(' ')
+              .append(Tokens.T_INPUT)
+              .append(' ');
         } else {
             if (isNewSavepointLevel) {
                 sb.append(Tokens.T_NEW);
@@ -325,26 +333,44 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                 sb.append(Tokens.T_OLD);
             }
 
-            sb.append(' ').append(Tokens.T_SAVEPOINT).append(' ');
-            sb.append(Tokens.T_LEVEL).append(' ');
+            sb.append(' ')
+              .append(Tokens.T_SAVEPOINT)
+              .append(' ')
+              .append(Tokens.T_LEVEL)
+              .append(' ');
 
             if (maxDynamicResults != 0) {
-                sb.append(' ').append(Tokens.T_DYNAMIC).append(' ');
-                sb.append(Tokens.T_RESULT).append(' ').append(Tokens.T_SETS);
-                sb.append(' ').append(maxDynamicResults).append(' ');
+                sb.append(' ')
+                  .append(Tokens.T_DYNAMIC)
+                  .append(' ')
+                  .append(Tokens.T_RESULT)
+                  .append(' ')
+                  .append(Tokens.T_SETS)
+                  .append(' ')
+                  .append(maxDynamicResults)
+                  .append(' ');
             }
         }
 
         if (language == LANGUAGE_JAVA) {
-            sb.append(Tokens.T_EXTERNAL).append(' ').append(Tokens.T_NAME);
-            sb.append(' ').append('\'').append(methodName).append('\'');
+            sb.append(Tokens.T_EXTERNAL)
+              .append(' ')
+              .append(Tokens.T_NAME)
+              .append(' ')
+              .append('\'')
+              .append(methodName)
+              .append('\'');
         } else {
             if (withBody) {
                 sb.append(statement.getSQL());
             } else {
-                sb.append(Tokens.T_SIGNAL).append(' ');
-                sb.append(Tokens.T_SQLSTATE).append(' ');
-                sb.append('\'').append("45000").append('\'');
+                sb.append(Tokens.T_SIGNAL)
+                  .append(' ')
+                  .append(Tokens.T_SQLSTATE)
+                  .append(' ')
+                  .append('\'')
+                  .append("45000")
+                  .append('\'');
             }
         }
 
@@ -356,8 +382,13 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         StringBuilder sb = new StringBuilder();
 
         if (language == LANGUAGE_JAVA) {
-            sb.append(Tokens.T_EXTERNAL).append(' ').append(Tokens.T_NAME);
-            sb.append(' ').append('\'').append(methodName).append('\'');
+            sb.append(Tokens.T_EXTERNAL)
+              .append(' ')
+              .append(Tokens.T_NAME)
+              .append(' ')
+              .append('\'')
+              .append(methodName)
+              .append('\'');
         } else {
             sb.append(statement.getSQL());
         }
@@ -380,13 +411,12 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
     public void addParameter(ColumnSchema param) {
 
-        HsqlName name = param.getName();
-        String paramName =
-            name == null
-            ? HsqlNameManager.getAutoNoNameColumnString(parameterList.size())
-            : name.name;
-
-        boolean result = parameterList.add(paramName, param);
+        HsqlName name      = param.getName();
+        String   paramName = name == null
+                             ? HsqlNameManager.getAutoNoNameColumnString(
+                                 parameterList.size())
+                             : name.name;
+        boolean  result    = parameterList.add(paramName, param);
 
         if (!result) {
             throw Error.error(ErrorCode.X_42614);
@@ -428,13 +458,19 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                 break;
 
             case READS_SQL :
-                sb.append(Tokens.T_READS).append(' ').append(
-                    Tokens.T_SQL).append(' ').append(Tokens.T_DATA);
+                sb.append(Tokens.T_READS)
+                  .append(' ')
+                  .append(Tokens.T_SQL)
+                  .append(' ')
+                  .append(Tokens.T_DATA);
                 break;
 
             case MODIFIES_SQL :
-                sb.append(Tokens.T_MODIFIES).append(' ').append(
-                    Tokens.T_SQL).append(' ').append(Tokens.T_DATA);
+                sb.append(Tokens.T_MODIFIES)
+                  .append(' ')
+                  .append(Tokens.T_SQL)
+                  .append(' ')
+                  .append(Tokens.T_DATA);
                 break;
         }
 
@@ -564,15 +600,15 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         typeGroups     = 0;
 
         for (int i = 0; i < parameterTypes.length; i++) {
-            ColumnSchema param = (ColumnSchema) parameterList.get(i);
+            ColumnSchema param = parameterList.get(i);
 
             parameterTypes[i] = param.dataType;
 
             if (i < 4) {
-                typeGroups =
-                    BitMap.setByte(typeGroups,
-                                   (byte) param.dataType.typeComparisonGroup,
-                                   i * 8);
+                typeGroups = BitMap.setByte(
+                    typeGroups,
+                    (byte) param.dataType.typeComparisonGroup,
+                    i * 8);
             }
         }
 
@@ -584,17 +620,17 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             boolean check = parameterTypes[1].typeCode == Types.BOOLEAN;
 
             //
-            ColumnSchema param = (ColumnSchema) parameterList.get(0);
+            ColumnSchema param = parameterList.get(0);
 
             check &= param.getParameterMode()
                      == SchemaObject.ParameterModes.PARAM_IN;
-            param = (ColumnSchema) parameterList.get(1);
+            param = parameterList.get(1);
             check &= param.getParameterMode()
                      == SchemaObject.ParameterModes.PARAM_IN;
-            param = (ColumnSchema) parameterList.get(2);
+            param = parameterList.get(2);
             check &= param.getParameterMode()
                      == SchemaObject.ParameterModes.PARAM_INOUT;
-            param = (ColumnSchema) parameterList.get(3);
+            param = parameterList.get(3);
             check &= param.getParameterMode()
                      == SchemaObject.ParameterModes.PARAM_INOUT;
 
@@ -616,8 +652,11 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         if (methodName != null && javaMethod == null) {
             boolean[] hasConnection = new boolean[1];
 
-            javaMethod = getMethod(methodName, this, hasConnection,
-                                   returnsTable);
+            javaMethod = getMethod(
+                methodName,
+                this,
+                hasConnection,
+                returnsTable);
 
             if (javaMethod == null) {
                 throw Error.error(ErrorCode.X_46103);
@@ -637,11 +676,11 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
     private void setReferences() {
 
-        OrderedHashSet set = new OrderedHashSet();
+        OrderedHashSet<HsqlName> set = new OrderedHashSet<>();
 
         for (int i = 0; i < parameterTypes.length; i++) {
-            ColumnSchema   param = (ColumnSchema) parameterList.get(i);
-            OrderedHashSet refs  = param.getReferences();
+            ColumnSchema             param = parameterList.get(i);
+            OrderedHashSet<HsqlName> refs  = param.getReferences();
 
             if (refs != null) {
                 set.addAll(refs);
@@ -665,29 +704,30 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
     void checkSQLData(Session session) {
 
-        OrderedHashSet set = statement.getReferences();
+        OrderedHashSet<HsqlName> set = statement.getReferences();
 
         for (int i = 0; i < set.size(); i++) {
-            HsqlName name = (HsqlName) set.get(i);
+            HsqlName name = set.get(i);
 
             if (name.type == SchemaObject.SPECIFIC_ROUTINE) {
                 Routine routine =
-                    (Routine) session.database.schemaManager.getSchemaObject(
+                    (Routine) session.database.schemaManager.findSchemaObject(
                         name);
 
                 if (routine.dataImpact == Routine.READS_SQL) {
                     if (dataImpact == Routine.CONTAINS_SQL) {
-                        throw Error.error(ErrorCode.X_42608,
-                                          Tokens.T_READS + ' ' + Tokens.T_SQL
-                                          + ' ' + Tokens.T_DATA);
+                        throw Error.error(
+                            ErrorCode.X_42608,
+                            Tokens.T_READS + ' ' + Tokens.T_SQL + ' '
+                            + Tokens.T_DATA);
                     }
                 } else if (routine.dataImpact == Routine.MODIFIES_SQL) {
                     if (dataImpact == Routine.CONTAINS_SQL
                             || dataImpact == Routine.READS_SQL) {
-                        throw Error.error(ErrorCode.X_42608,
-                                          Tokens.T_MODIFIES + ' '
-                                          + Tokens.T_SQL + ' '
-                                          + Tokens.T_DATA);
+                        throw Error.error(
+                            ErrorCode.X_42608,
+                            Tokens.T_MODIFIES + ' ' + Tokens.T_SQL + ' '
+                            + Tokens.T_DATA);
                     }
                 }
             }
@@ -699,9 +739,10 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
             for (int i = 0; i < names.length; i++) {
                 if (names[i].schema != SqlInvariants.SYSTEM_SCHEMA_HSQLNAME) {
-                    throw Error.error(ErrorCode.X_42608,
-                                      Tokens.T_MODIFIES + ' ' + Tokens.T_SQL
-                                      + ' ' + Tokens.T_DATA);
+                    throw Error.error(
+                        ErrorCode.X_42608,
+                        Tokens.T_MODIFIES + ' ' + Tokens.T_SQL + ' '
+                        + Tokens.T_DATA);
                 }
             }
         }
@@ -711,9 +752,10 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
             for (int i = 0; i < names.length; i++) {
                 if (names[i].schema != SqlInvariants.SYSTEM_SCHEMA_HSQLNAME) {
-                    throw Error.error(ErrorCode.X_42608,
-                                      Tokens.T_READS + ' ' + Tokens.T_SQL
-                                      + ' ' + Tokens.T_DATA);
+                    throw Error.error(
+                        ErrorCode.X_42608,
+                        Tokens.T_READS + ' ' + Tokens.T_SQL + ' '
+                        + Tokens.T_DATA);
                 }
             }
         }
@@ -732,7 +774,7 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
     }
 
     public ColumnSchema getParameter(int i) {
-        return (ColumnSchema) parameterList.get(i);
+        return parameterList.get(i);
     }
 
     Type[] getParameterTypes() {
@@ -752,7 +794,7 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         int count = 0;
 
         for (int i = 0; i < parameterList.size(); i++) {
-            ColumnSchema col = (ColumnSchema) parameterList.get(i);
+            ColumnSchema col = parameterList.get(i);
 
             if (col.getParameterMode() == type) {
                 count++;
@@ -853,8 +895,9 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
     Object[] convertArgsToJava(Session session, Object[] callArguments) {
 
-        int      extraArg = javaMethodWithConnection ? 1
-                                                     : 0;
+        int      extraArg = javaMethodWithConnection
+                            ? 1
+                            : 0;
         Object[] data     = new Object[javaMethod.getParameterTypes().length];
         Type[]   types    = getParameterTypes();
         int      i        = 0;
@@ -866,9 +909,9 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             if (param.parameterMode == SchemaObject.ParameterModes.PARAM_IN) {
                 data[i + extraArg] = types[i].convertSQLToJava(session, value);
             } else {
-                Object jdbcValue = types[i].convertSQLToJava(session, value);
-                Class  cl        = types[i].getJDBCClass();
-                Object array     = java.lang.reflect.Array.newInstance(cl, 1);
+                Object   jdbcValue = types[i].convertSQLToJava(session, value);
+                Class<?> cl        = types[i].getJDBCClass();
+                Object   array     = java.lang.reflect.Array.newInstance(cl, 1);
 
                 java.lang.reflect.Array.set(array, 0, jdbcValue);
 
@@ -883,11 +926,14 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         return data;
     }
 
-    void convertArgsToSQL(Session session, Object[] callArguments,
-                          Object[] data) {
+    void convertArgsToSQL(
+            Session session,
+            Object[] callArguments,
+            Object[] data) {
 
-        int    extraArg = javaMethodWithConnection ? 1
-                                                   : 0;
+        int    extraArg = javaMethodWithConnection
+                          ? 1
+                          : 0;
         Type[] types    = getParameterTypes();
         int    i        = 0;
 
@@ -918,8 +964,9 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                         head.addChainedResult(r);
                     }
                 } else {
-                    throw Error.error(ErrorCode.X_46000,
-                                      "ResultSet not native");
+                    throw Error.error(
+                        ErrorCode.X_46000,
+                        "ResultSet not native");
                 }
             }
         }
@@ -935,8 +982,8 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             returnValue = returnType.convertJavaToSQL(null, returnValue);
             result      = Result.newPSMResult(returnValue);
         } catch (Throwable t) {
-            result = Result.newErrorResult(Error.error(t, ErrorCode.X_46000,
-                    getName().name));
+            result = Result.newErrorResult(
+                Error.error(t, ErrorCode.X_46000, getName().name));
         }
 
         return result;
@@ -968,23 +1015,23 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                 } else {
 
                     // convert ResultSet to table
-                    throw Error.runtimeError(ErrorCode.U_S0500,
-                                             "FunctionSQLInvoked");
+                    throw Error.runtimeError(
+                        ErrorCode.U_S0500,
+                        "FunctionSQLInvoked");
                 }
             } else {
-                returnValue = returnType.convertJavaToSQL(session,
-                        returnValue);
-                result = Result.newPSMResult(returnValue);
+                returnValue = returnType.convertJavaToSQL(session, returnValue);
+                result      = Result.newPSMResult(returnValue);
             }
         } catch (InvocationTargetException e) {
-            result = Result.newErrorResult(Error.error(e, ErrorCode.X_46000,
-                    getName().name));
+            result = Result.newErrorResult(
+                Error.error(e, ErrorCode.X_46000, getName().name));
         } catch (IllegalAccessException e) {
-            result = Result.newErrorResult(Error.error(e, ErrorCode.X_46000,
-                    getName().name));
+            result = Result.newErrorResult(
+                Error.error(e, ErrorCode.X_46000, getName().name));
         } catch (Throwable e) {
-            result = Result.newErrorResult(Error.error(e, ErrorCode.X_46000,
-                    getName().name));
+            result = Result.newErrorResult(
+                Error.error(e, ErrorCode.X_46000, getName().name));
         }
 
         session.setCurrentSchemaHsqlName(oldSessionSchema);
@@ -992,8 +1039,11 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         return result;
     }
 
-    public Result invoke(Session session, Object[] data,
-                         Object[] aggregateData, boolean push) {
+    public Result invoke(
+            Session session,
+            Object[] data,
+            Object[] aggregateData,
+            boolean push) {
 
         Result result;
 
@@ -1022,9 +1072,12 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                 result = statement.execute(session);
 
                 if (aggregateData != null) {
-                    for (int i = 0; i < aggregateData.length; i++) {
-                        aggregateData[i] = data[i + 1];
-                    }
+                    System.arraycopy(
+                        data,
+                        1,
+                        aggregateData,
+                        0,
+                        aggregateData.length);
                 }
             } catch (Throwable e) {
                 result = Result.newErrorResult(e);
@@ -1040,10 +1093,12 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                 Object[] callResult = new Object[data.length];
 
                 convertArgsToSQL(session, callResult, data);
-
-                for (int i = 0; i < aggregateData.length; i++) {
-                    aggregateData[i] = callResult[i + 1];
-                }
+                System.arraycopy(
+                    callResult,
+                    1,
+                    aggregateData,
+                    0,
+                    aggregateData.length);
             }
         }
 
@@ -1063,8 +1118,11 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         }
     }
 
-    static Method getMethod(String name, Routine routine,
-                            boolean[] hasConnection, boolean returnsTable) {
+    static Method getMethod(
+            String name,
+            Routine routine,
+            boolean[] hasConnection,
+            boolean returnsTable) {
 
         int i = name.indexOf(':');
 
@@ -1084,9 +1142,9 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
             hasConnection[0] = false;
 
-            Method  method = methods[i];
-            Class[] params = method.getParameterTypes();
-            int     matchedParamCount;
+            Method     method = methods[i];
+            Class<?>[] params = method.getParameterTypes();
+            int        matchedParamCount;
 
             if (params.length > 0
                     && params[0].equals(java.sql.Connection.class)) {
@@ -1102,7 +1160,6 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                             && java.sql.ResultSet.class.isAssignableFrom(
                                 params[j].getComponentType())) {
                         matchedParamCount = j - offset;
-
                         break;
                     }
                 }
@@ -1118,8 +1175,8 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                     continue;
                 }
             } else {
-                Type methodReturnType =
-                    Types.getParameterSQLType(method.getReturnType());
+                Type methodReturnType = Types.getParameterSQLType(
+                    method.getReturnType());
 
                 if (methodReturnType == null) {
                     continue;
@@ -1148,8 +1205,8 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             }
 
             for (int j = 0; j < routine.parameterTypes.length; j++) {
-                boolean isInOut = false;
-                Class   param   = params[j + offset];
+                boolean  isInOut = false;
+                Class<?> param   = params[j + offset];
 
                 if (param.isArray()) {
                     if (!byte[].class.equals(param)) {
@@ -1157,7 +1214,6 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
                         if (param.isPrimitive()) {
                             method = null;
-
                             break;
                         }
 
@@ -1169,7 +1225,6 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
                 if (methodParamType == null) {
                     method = null;
-
                     break;
                 }
 
@@ -1206,8 +1261,8 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
             if (method != null) {
                 for (int j = 0; j < routine.parameterTypes.length; j++) {
-                    routine.getParameter(j).setNullable(
-                        !params[j + offset].isPrimitive());
+                    routine.getParameter(j)
+                           .setNullable(!params[j + offset].isPrimitive());
                 }
 
                 return method;
@@ -1233,7 +1288,7 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
         String   className  = name.substring(0, i);
         String   methodname = name.substring(i + 1);
-        Class    cl;
+        Class<?> cl;
         Method[] methods = null;
 
         if (!HsqlDatabaseProperties.supportsJavaMethod(name)) {
@@ -1241,29 +1296,33 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         }
 
         try {
-            cl = Class.forName(className, true,
-                               Thread.currentThread().getContextClassLoader());
+            cl = Class.forName(
+                className,
+                true,
+                Thread.currentThread().getContextClassLoader());
         } catch (Throwable t1) {
             try {
                 cl = Class.forName(className);
             } catch (Throwable t) {
-                throw Error.error(t, ErrorCode.X_42501,
-                                  ErrorCode.M_Message_Pair, new String[] {
-                    t.toString(), className
-                });
+                throw Error.error(
+                    t,
+                    ErrorCode.X_42501,
+                    ErrorCode.M_Message_Pair,
+                    new String[]{ t.toString(), className });
             }
         }
 
         try {
             methods = cl.getMethods();
         } catch (Throwable t) {
-            throw Error.error(t, ErrorCode.X_42501, ErrorCode.M_Message_Pair,
-                              new String[] {
-                t.toString(), className
-            });
+            throw Error.error(
+                t,
+                ErrorCode.X_42501,
+                ErrorCode.M_Message_Pair,
+                new String[]{ t.toString(), className });
         }
 
-        HsqlArrayList list = new HsqlArrayList();
+        HsqlArrayList<Method> list = new HsqlArrayList<>();
 
         for (i = 0; i < methods.length; i++) {
             int    offset    = 0;
@@ -1277,7 +1336,7 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                 continue;
             }
 
-            Class[] params = methods[i].getParameterTypes();
+            Class<?>[] params = methods[i].getParameterTypes();
 
             if (params.length > 0
                     && params[0].equals(java.sql.Connection.class)) {
@@ -1285,7 +1344,7 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
             }
 
             for (int j = offset; j < params.length; j++) {
-                Class param = params[j];
+                Class<?> param = params[j];
 
                 if (param.isArray()) {
                     if (!byte[].class.equals(param)) {
@@ -1293,7 +1352,6 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
                         if (param.isPrimitive()) {
                             method = null;
-
                             break;
                         }
 
@@ -1309,14 +1367,12 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                             continue;
                         } else {
                             method = null;
-
                             break;
                         }
                     }
                 } else {
                     if (j > endIndex) {
                         method = null;
-
                         break;
                     }
                 }
@@ -1325,7 +1381,6 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
                 if (methodParamType == null) {
                     method = null;
-
                     break;
                 }
             }
@@ -1338,8 +1393,8 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
                     method.getReturnType())) {
                 list.add(methods[i]);
             } else {
-                Type methodReturnType =
-                    Types.getParameterSQLType(method.getReturnType());
+                Type methodReturnType = Types.getParameterSQLType(
+                    method.getReturnType());
 
                 if (methodReturnType != null) {
                     list.add(methods[i]);
@@ -1372,21 +1427,26 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
      */
     public static Routine newRoutine(Session session, Method method) {
 
-        Routine       routine   = new Routine(SchemaObject.FUNCTION);
-        int           offset    = 0;
-        Class[]       params    = method.getParameterTypes();
-        String        className = method.getDeclaringClass().getName();
-        StringBuilder sb        = new StringBuilder();
-
-        sb.append("CLASSPATH:");
-        sb.append(method.getDeclaringClass().getName()).append('.');
-        sb.append(method.getName());
+        Routine    routine   = new Routine(SchemaObject.FUNCTION);
+        Class<?>[] params    = method.getParameterTypes();
+        String     className = method.getDeclaringClass().getName();
+        String     name;
+        int        offset;
 
         if (params.length > 0 && params[0].equals(java.sql.Connection.class)) {
             offset = 1;
+        } else {
+            offset = 0;
         }
 
-        String name = sb.toString();
+        StringBuilder sb = new StringBuilder(64);
+
+        sb.append("CLASSPATH:")
+          .append(method.getDeclaringClass().getName())
+          .append('.')
+          .append(method.getName());
+
+        name = sb.toString();
 
         if (className.equals("java.lang.Math")) {
             routine.isLibraryRoutine = true;
@@ -1394,11 +1454,16 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
 
         for (int j = offset; j < params.length; j++) {
             Type methodParamType = Types.getParameterSQLType(params[j]);
-            HsqlName colName = session.database.nameManager.newHsqlName("C"
-                + (j - offset + 1), false, SchemaObject.PARAMETER);
-            ColumnSchema param = new ColumnSchema(colName, methodParamType,
-                                                  !params[j].isPrimitive(),
-                                                  false, null);
+            HsqlName colName = session.database.nameManager.newHsqlName(
+                "C" + (j - offset + 1),
+                false,
+                SchemaObject.PARAMETER);
+            ColumnSchema param = new ColumnSchema(
+                colName,
+                methodParamType,
+                !params[j].isPrimitive(),
+                false,
+                null);
 
             routine.addParameter(param);
         }
@@ -1408,8 +1473,8 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
         routine.setMethodURL(name);
         routine.setDataImpact(Routine.NO_SQL);
 
-        Type methodReturnType =
-            Types.getParameterSQLType(method.getReturnType());
+        Type methodReturnType = Types.getParameterSQLType(
+            method.getReturnType());
 
         routine.javaMethodWithConnection = offset == 1;
 
@@ -1422,13 +1487,18 @@ public class Routine implements SchemaObject, RangeGroup, Cloneable {
     /**
      * simply named function only - requires return type
      */
-    public static void createRoutines(Session session, HsqlName schema,
-                                      String name) {
+    public static void createRoutines(
+            Session session,
+            HsqlName schema,
+            String name) {
 
         Method[]  methods  = Routine.getMethods(name);
         Routine[] routines = Routine.newRoutines(session, methods);
-        HsqlName routineName = session.database.nameManager.newHsqlName(schema,
-            name, true, SchemaObject.FUNCTION);
+        HsqlName routineName = session.database.nameManager.newHsqlName(
+            schema,
+            name,
+            true,
+            SchemaObject.FUNCTION);
 
         for (int i = 0; i < routines.length; i++) {
             if (routines[i].getReturnType() != Type.SQL_ALL_TYPES) {
