@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,7 +34,6 @@ package org.hsqldb;
 import org.hsqldb.HsqlNameManager.HsqlName;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
-import org.hsqldb.lib.HashMap;
 import org.hsqldb.lib.HsqlArrayList;
 import org.hsqldb.lib.Iterator;
 import org.hsqldb.lib.OrderedHashMap;
@@ -44,13 +43,16 @@ import org.hsqldb.lib.OrderedHashSet;
  * Collection of SQL schema objects of a specific type in a schema
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.1
+ * @version 2.7.3
  * @since 1.9.0
  */
 public class SchemaObjectSet {
 
-    HashMap map;
-    int     type;
+    static final int addErrorCode = ErrorCode.X_42504;
+    static final int getErrorCode = ErrorCode.X_42501;
+    private final OrderedHashMap<String, SchemaObject> map;
+    private final OrderedHashMap<String, HsqlName>     nameMap;
+    private final int                                  type;
 
     SchemaObjectSet(int type) {
 
@@ -58,27 +60,28 @@ public class SchemaObjectSet {
 
         switch (type) {
 
-            case SchemaObject.VIEW :
-            case SchemaObject.TABLE :
-            case SchemaObject.SEQUENCE :
-            case SchemaObject.CHARSET :
-            case SchemaObject.DOMAIN :
-            case SchemaObject.TYPE :
-            case SchemaObject.COLLATION :
-            case SchemaObject.PROCEDURE :
-            case SchemaObject.FUNCTION :
-            case SchemaObject.SPECIFIC_ROUTINE :
             case SchemaObject.ASSERTION :
-            case SchemaObject.TRIGGER :
-            case SchemaObject.REFERENCE :
+            case SchemaObject.CHARSET :
+            case SchemaObject.COLLATION :
+            case SchemaObject.DOMAIN :
             case SchemaObject.EXCEPTION :
+            case SchemaObject.FUNCTION :
             case SchemaObject.MODULE :
-                map = new OrderedHashMap();
+            case SchemaObject.PROCEDURE :
+            case SchemaObject.REFERENCE :
+            case SchemaObject.SEQUENCE :
+            case SchemaObject.SPECIFIC_ROUTINE :
+            case SchemaObject.TABLE :    // includes VIEW
+            case SchemaObject.TRIGGER :
+            case SchemaObject.TYPE :
+                map     = new OrderedHashMap<>();
+                nameMap = null;
                 break;
 
             case SchemaObject.CONSTRAINT :
             case SchemaObject.INDEX :
-                map = new HashMap();
+                map     = null;
+                nameMap = new OrderedHashMap<>();
                 break;
 
             default :
@@ -86,36 +89,25 @@ public class SchemaObjectSet {
         }
     }
 
+    OrderedHashMap<String, ? extends SchemaObject> getMap() {
+        return map;
+    }
+
     HsqlName getName(String name) {
 
         switch (type) {
 
-            case SchemaObject.VIEW :
-            case SchemaObject.TABLE :
-            case SchemaObject.SEQUENCE :
-            case SchemaObject.CHARSET :
-            case SchemaObject.DOMAIN :
-            case SchemaObject.TYPE :
-            case SchemaObject.COLLATION :
-            case SchemaObject.PROCEDURE :
-            case SchemaObject.SPECIFIC_ROUTINE :
-            case SchemaObject.FUNCTION :
-            case SchemaObject.ASSERTION :
-            case SchemaObject.TRIGGER :
-            case SchemaObject.REFERENCE :
-            case SchemaObject.EXCEPTION :
-            case SchemaObject.MODULE :
-                SchemaObject object = ((SchemaObject) map.get(name));
+            default :
+                SchemaObject object = map.get(name);
 
-                return object == null ? null
-                                      : object.getName();
+                return object == null
+                       ? null
+                       : object.getName();
 
             case SchemaObject.CONSTRAINT :
             case SchemaObject.INDEX : {
-                return (HsqlName) map.get(name);
+                return nameMap.get(name);
             }
-            default :
-                return (HsqlName) map.get(name);
         }
     }
 
@@ -123,51 +115,112 @@ public class SchemaObjectSet {
 
         switch (type) {
 
-            case SchemaObject.VIEW :
-            case SchemaObject.TABLE :
-            case SchemaObject.SEQUENCE :
-            case SchemaObject.CHARSET :
-            case SchemaObject.DOMAIN :
-            case SchemaObject.TYPE :
-            case SchemaObject.COLLATION :
-            case SchemaObject.PROCEDURE :
-            case SchemaObject.SPECIFIC_ROUTINE :
-            case SchemaObject.FUNCTION :
-            case SchemaObject.ASSERTION :
-            case SchemaObject.TRIGGER :
-            case SchemaObject.REFERENCE :
-            case SchemaObject.EXCEPTION :
-            case SchemaObject.MODULE :
-                return (SchemaObject) map.get(name);
-
             default :
+                return map.get(name);
+
+            case SchemaObject.CONSTRAINT :
+            case SchemaObject.INDEX :
                 throw Error.runtimeError(ErrorCode.U_S0500, "SchemaObjectSet");
         }
     }
 
+    public Iterator<SchemaObject> getIterator() {
+
+        switch (type) {
+
+            default :
+                return map.values().iterator();
+
+            case SchemaObject.CONSTRAINT :
+            case SchemaObject.INDEX :
+                throw Error.runtimeError(ErrorCode.U_S0500, "SchemaObjectSet");
+        }
+    }
+
+    public Iterator<HsqlName> getNameIterator() {
+
+        switch (type) {
+
+            default :
+                return nameIterator(map.values().iterator());
+
+            case SchemaObject.CONSTRAINT :
+            case SchemaObject.INDEX :
+                return nameMap.values().iterator();
+        }
+    }
+
+    private Iterator<HsqlName> nameIterator(Iterator<SchemaObject> it) {
+
+        return new Iterator<HsqlName>() {
+
+            @Override
+            public boolean hasNext() {
+                return it.hasNext();
+            }
+            @Override
+            public HsqlName next() {
+                return it.next().getName();
+            }
+        };
+    }
+
     public boolean contains(String name) {
         return map.containsKey(name);
     }
 
     void checkAdd(HsqlName name) {
 
-        if (map.containsKey(name.name)) {
-            int code = getAddErrorCode(name.type);
+        switch (type) {
 
-            throw Error.error(code, name.name);
+            default :
+                if (map.containsKey(name.name)) {
+                    throw Error.error(addErrorCode, name.name);
+                }
+
+                break;
+
+            case SchemaObject.CONSTRAINT :
+            case SchemaObject.INDEX :
+                if (nameMap.containsKey(name.name)) {
+                    throw Error.error(addErrorCode, name.name);
+                }
+
+                break;
         }
     }
 
-    boolean isEmpty() {
-        return map.isEmpty();
-    }
-
     void checkExists(String name) {
 
-        if (!map.containsKey(name)) {
-            int code = getGetErrorCode(type);
+        switch (type) {
 
-            throw Error.error(code, name);
+            default :
+                if (!map.containsKey(name)) {
+                    throw Error.error(getErrorCode, name);
+                }
+
+                break;
+
+            case SchemaObject.CONSTRAINT :
+            case SchemaObject.INDEX :
+                if (!nameMap.containsKey(name)) {
+                    throw Error.error(getErrorCode, name);
+                }
+
+                break;
+        }
+    }
+
+    boolean isEmpty() {
+
+        switch (type) {
+
+            default :
+                return map.isEmpty();
+
+            case SchemaObject.CONSTRAINT :
+            case SchemaObject.INDEX :
+                return nameMap.isEmpty();
         }
     }
 
@@ -179,259 +232,199 @@ public class SchemaObjectSet {
             name = ((Routine) object).getSpecificName();
         }
 
-        if (!replace && map.containsKey(name.name)) {
-            int code = getAddErrorCode(name.type);
+        switch (type) {
 
-            throw Error.error(code, name.name);
-        }
+            default :
+                if (!replace && map.containsKey(name.name)) {
+                    throw Error.error(addErrorCode, name.name);
+                }
 
-        Object value = object;
-
-        switch (name.type) {
+                map.put(name.name, object);
+                break;
 
             case SchemaObject.CONSTRAINT :
             case SchemaObject.INDEX :
-                value = name;
+                if (!replace && nameMap.containsKey(name.name)) {
+                    throw Error.error(addErrorCode, name.name);
+                }
+
+                nameMap.put(name.name, name);
                 break;
-
-            default :
         }
-
-        map.put(name.name, value);
     }
 
     void remove(String name) {
-        map.remove(name);
+
+        switch (type) {
+
+            default :
+                map.remove(name);
+                break;
+
+            case SchemaObject.CONSTRAINT :
+            case SchemaObject.INDEX :
+                nameMap.remove(name);
+                break;
+        }
     }
 
     void removeParent(HsqlName parent) {
 
-        Iterator it = map.values().iterator();
+        switch (type) {
 
-        while (it.hasNext()) {
-            if (type == SchemaObject.TRIGGER
-                    || type == SchemaObject.SPECIFIC_ROUTINE) {
-                SchemaObject object = (SchemaObject) it.next();
+            default : {
+                Iterator<SchemaObject> it = map.values().iterator();
 
-                if (object.getName().parent == parent) {
-                    it.remove();
+                while (it.hasNext()) {
+                    SchemaObject object = it.next();
+
+                    if (object.getName().parent.equals(parent)) {
+                        it.remove();
+                    }
                 }
-            } else {
-                HsqlName name = (HsqlName) it.next();
 
-                if (name.parent == parent) {
-                    it.remove();
+                break;
+            }
+
+            case SchemaObject.CONSTRAINT :
+            case SchemaObject.INDEX : {
+                Iterator<HsqlName> it = nameMap.values().iterator();
+
+                while (it.hasNext()) {
+                    HsqlName name = it.next();
+
+                    if (name.parent.equals(parent)) {
+                        it.remove();
+                    }
                 }
+
+                break;
             }
         }
     }
 
     void rename(HsqlName name, HsqlName newName) {
 
-        if (map.containsKey(newName.name)) {
-            int code = getAddErrorCode(name.type);
-
-            throw Error.error(code, newName.name);
-        }
+        HsqlName objectName;
 
         switch (newName.type) {
 
-            case SchemaObject.VIEW :
-            case SchemaObject.TABLE :
-            case SchemaObject.SEQUENCE :
-            case SchemaObject.CHARSET :
-            case SchemaObject.COLLATION :
-            case SchemaObject.PROCEDURE :
-            case SchemaObject.FUNCTION :
-            case SchemaObject.DOMAIN :
-            case SchemaObject.TYPE :
-            case SchemaObject.ASSERTION :
-            case SchemaObject.TRIGGER :
-            case SchemaObject.ROUTINE :
-            case SchemaObject.REFERENCE :
-            case SchemaObject.EXCEPTION :
-            case SchemaObject.MODULE : {
-                int i = ((OrderedHashMap) map).getIndex(name.name);
+            default : {
+                SchemaObject object = map.get(name.name);
 
-                if (i == -1) {
-                    int code = getGetErrorCode(name.type);
-
-                    throw Error.error(code, name.name);
+                if (object == null) {
+                    throw Error.error(getErrorCode, name.name);
+                } else if (type == SchemaObject.SPECIFIC_ROUTINE) {
+                    objectName = ((Routine) object).getSpecificName();
+                } else {
+                    objectName = object.getName();
                 }
 
-                SchemaObject object =
-                    (SchemaObject) ((OrderedHashMap) map).get(i);
-
-                object.getName().rename(newName);
-                ((OrderedHashMap) map).setKeyAt(i, newName.name);
-
-                break;
-            }
-            case SchemaObject.SPECIFIC_ROUTINE : {
-                int i = ((OrderedHashMap) map).getIndex(name.name);
-
-                if (i == -1) {
-                    int code = getGetErrorCode(name.type);
-
-                    throw Error.error(code, name.name);
+                if (map.containsKey(newName.name)) {
+                    throw Error.error(addErrorCode, newName.name);
                 }
 
-                Routine routine = (Routine) ((OrderedHashMap) map).get(i);
-
-                routine.getSpecificName().rename(newName);
-                ((OrderedHashMap) map).setKeyAt(i, newName.name);
+                int i = map.getIndex(name.name);
 
+                map.setKeyAt(i, newName.name);
+                objectName.rename(newName);
                 break;
             }
+
             case SchemaObject.CONSTRAINT :
             case SchemaObject.INDEX : {
-                map.remove(name.name);
-                name.rename(newName);
-                map.put(name.name, name);
+                objectName = nameMap.get(name.name);
 
+                if (objectName == null) {
+                    throw Error.error(getErrorCode, name.name);
+                }
+
+                if (nameMap.containsKey(newName.name)) {
+                    throw Error.error(addErrorCode, newName.name);
+                }
+
+                int i = nameMap.getIndex(name.name);
+
+                nameMap.setKeyAt(i, newName.name);
+                objectName.rename(newName);
                 break;
             }
-            default :
         }
     }
 
-    static int getAddErrorCode(int type) {
-
-        int code;
-
-        switch (type) {
-
-            case SchemaObject.VIEW :
-            case SchemaObject.TABLE :
-            case SchemaObject.SEQUENCE :
-            case SchemaObject.CHARSET :
-            case SchemaObject.DOMAIN :
-            case SchemaObject.TYPE :
-            case SchemaObject.COLLATION :
-            case SchemaObject.PROCEDURE :
-            case SchemaObject.FUNCTION :
-            case SchemaObject.SPECIFIC_ROUTINE :
-            case SchemaObject.ASSERTION :
-            case SchemaObject.TRIGGER :
-            case SchemaObject.REFERENCE :
-            case SchemaObject.EXCEPTION :
-            case SchemaObject.MODULE :
-            case SchemaObject.CONSTRAINT :
-            case SchemaObject.INDEX :
-                code = ErrorCode.X_42504;
-                break;
-
-            default :
-                throw Error.runtimeError(ErrorCode.U_S0500, "SchemaObjectSet");
-        }
-
-        return code;
-    }
-
-    static int getGetErrorCode(int type) {
-
-        int code;
-
-        switch (type) {
-
-            case SchemaObject.VIEW :
-            case SchemaObject.TABLE :
-            case SchemaObject.SEQUENCE :
-            case SchemaObject.CHARSET :
-            case SchemaObject.DOMAIN :
-            case SchemaObject.TYPE :
-            case SchemaObject.COLLATION :
-            case SchemaObject.PROCEDURE :
-            case SchemaObject.FUNCTION :
-            case SchemaObject.SPECIFIC_ROUTINE :
-            case SchemaObject.ASSERTION :
-            case SchemaObject.TRIGGER :
-            case SchemaObject.REFERENCE :
-            case SchemaObject.EXCEPTION :
-            case SchemaObject.MODULE :
-            case SchemaObject.CONSTRAINT :
-            case SchemaObject.INDEX :
-                code = ErrorCode.X_42501;
-                break;
-
-            default :
-                throw Error.runtimeError(ErrorCode.U_S0500, "SchemaObjectSet");
-        }
-
-        return code;
-    }
-
     public static String getName(int type) {
 
         switch (type) {
 
-            case SchemaObject.VIEW :
-                return Tokens.T_VIEW;
-
-            case SchemaObject.TABLE :
-                return Tokens.T_TABLE;
-
-            case SchemaObject.SEQUENCE :
-                return Tokens.T_SEQUENCE;
+            case SchemaObject.ASSERTION :
+                return Tokens.T_ASSERTION;
 
             case SchemaObject.CHARSET :
                 return Tokens.T_CHARACTER + ' ' + Tokens.T_SET;
 
-            case SchemaObject.DOMAIN :
-                return Tokens.T_DOMAIN;
-
-            case SchemaObject.TYPE :
-                return Tokens.T_TYPE;
-
             case SchemaObject.COLLATION :
                 return Tokens.T_COLLATION;
 
-            case SchemaObject.PROCEDURE :
-                return Tokens.T_PROCEDURE;
-
-            case SchemaObject.FUNCTION :
-                return Tokens.T_FUNCTION;
-
-            case SchemaObject.SPECIFIC_ROUTINE :
-                return Tokens.T_SPECIFIC + ' ' + Tokens.T_ROUTINE;
-
-            case SchemaObject.ASSERTION :
-                return Tokens.T_ASSERTION;
-
-            case SchemaObject.TRIGGER :
-                return Tokens.T_TRIGGER;
-
-            case SchemaObject.EXCEPTION :
-                return Tokens.T_EXCEPTION;
-
-            case SchemaObject.MODULE :
-                return Tokens.T_MODULE;
-
-            case SchemaObject.REFERENCE :
-                return Tokens.T_SYNONYM;
-
-            case SchemaObject.PARAMETER :
-                return Tokens.T_PARAMETER;
-
             case SchemaObject.CONSTRAINT :
                 return Tokens.T_CONSTRAINT;
 
+            case SchemaObject.DOMAIN :
+                return Tokens.T_DOMAIN;
+
+            case SchemaObject.EXCEPTION :
+                return Tokens.T_EXCEPTION;
+
+            case SchemaObject.FUNCTION :
+                return Tokens.T_FUNCTION;
+
             case SchemaObject.INDEX :
                 return Tokens.T_INDEX;
 
+            case SchemaObject.MODULE :
+                return Tokens.T_MODULE;
+
+            case SchemaObject.PARAMETER :
+                return Tokens.T_PARAMETER;
+
             case SchemaObject.PERIOD :
                 return Tokens.T_PERIOD;
 
+            case SchemaObject.PROCEDURE :
+                return Tokens.T_PROCEDURE;
+
+            case SchemaObject.REFERENCE :
+                return Tokens.T_SYNONYM;
+
+            case SchemaObject.SEQUENCE :
+                return Tokens.T_SEQUENCE;
+
+            case SchemaObject.SPECIFIC_ROUTINE :
+                return Tokens.T_SPECIFIC + ' ' + Tokens.T_ROUTINE;
+
+            case SchemaObject.TABLE :
+                return Tokens.T_TABLE;
+
+            case SchemaObject.TRIGGER :
+                return Tokens.T_TRIGGER;
+
+            case SchemaObject.TYPE :
+                return Tokens.T_TYPE;
+
+            case SchemaObject.VIEW :
+                return Tokens.T_VIEW;
+
             default :
                 throw Error.runtimeError(ErrorCode.U_S0500, "SchemaObjectSet");
         }
     }
 
-    void getSQL(HsqlArrayList list, OrderedHashSet resolved,
-                OrderedHashSet unresolved) {
+    void getSQL(
+            HsqlArrayList<String> list,
+            OrderedHashSet<HsqlName> resolved,
+            OrderedHashSet<SchemaObject> unresolved) {
 
-        // HashMap lists are not persisted with this method
-        if (!(map instanceof OrderedHashMap)) {
+        // HsqlName lists are not persisted with this method
+        if (type == SchemaObject.CONSTRAINT || type == SchemaObject.INDEX) {
             return;
         }
 
@@ -439,10 +432,10 @@ public class SchemaObjectSet {
             return;
         }
 
-        Iterator it = map.values().iterator();
+        Iterator<SchemaObject> it = map.values().iterator();
 
         if (type == SchemaObject.FUNCTION || type == SchemaObject.PROCEDURE) {
-            OrderedHashSet set = new OrderedHashSet();
+            OrderedHashSet<SchemaObject> set = new OrderedHashSet<>();
 
             while (it.hasNext()) {
                 RoutineSchema routineSchema = (RoutineSchema) it.next();
@@ -460,14 +453,17 @@ public class SchemaObjectSet {
         addAllSQL(resolved, unresolved, list, it, null);
     }
 
-    static void addAllSQL(OrderedHashSet resolved, OrderedHashSet unresolved,
-                          HsqlArrayList list, Iterator it,
-                          OrderedHashSet newResolved) {
+    static void addAllSQL(
+            OrderedHashSet<HsqlName> resolved,
+            OrderedHashSet<SchemaObject> unresolved,
+            HsqlArrayList<String> list,
+            Iterator<SchemaObject> it,
+            OrderedHashSet<SchemaObject> newResolved) {
 
         while (it.hasNext()) {
-            SchemaObject   object     = (SchemaObject) it.next();
-            boolean        isResolved = true;
-            OrderedHashSet references;
+            SchemaObject             object     = it.next();
+            boolean                  isResolved = true;
+            OrderedHashSet<HsqlName> references;
 
             if (object.getType() == SchemaObject.TABLE) {
                 ((Table) object).setForwardConstraints(resolved);
@@ -478,7 +474,7 @@ public class SchemaObjectSet {
             }
 
             for (int j = 0; j < references.size(); j++) {
-                HsqlName name = (HsqlName) references.get(j);
+                HsqlName name = references.get(j);
 
                 if (SqlInvariants.isSchemaNameSystem(name)) {
                     continue;
@@ -490,13 +486,14 @@ public class SchemaObjectSet {
                         if (!resolved.contains(name)) {
                             isResolved = false;
                         }
+
                         break;
 
                     case SchemaObject.COLUMN : {
                         if (object.getType() == SchemaObject.TABLE) {
                             int index = ((Table) object).findColumn(name.name);
-                            ColumnSchema column =
-                                ((Table) object).getColumn(index);
+                            ColumnSchema column = ((Table) object).getColumn(
+                                index);
 
                             if (!isChildObjectResolved(column, resolved)) {
                                 isResolved = false;
@@ -511,10 +508,12 @@ public class SchemaObjectSet {
 
                         break;
                     }
+
                     case SchemaObject.CONSTRAINT : {
                         if (name.parent == object.getName()) {
                             Constraint constraint =
-                                ((Table) object).getConstraint(name.name);
+                                ((Table) object).getConstraint(
+                                    name.name);
 
                             if (constraint.getConstraintType()
                                     == SchemaObject.ConstraintTypes.CHECK) {
@@ -528,22 +527,24 @@ public class SchemaObjectSet {
                         // only UNIQUE constraint referenced by FK in table
                         break;
                     }
+
                     case SchemaObject.CHARSET :
                         if (name.schema == null) {
                             continue;
                         }
 
                     // fall through
-                    case SchemaObject.TYPE :
-                    case SchemaObject.DOMAIN :
                     case SchemaObject.COLLATION :
+                    case SchemaObject.DOMAIN :
                     case SchemaObject.FUNCTION :
                     case SchemaObject.PROCEDURE :
-                    case SchemaObject.SPECIFIC_ROUTINE :
                     case SchemaObject.SEQUENCE :
+                    case SchemaObject.SPECIFIC_ROUTINE :
+                    case SchemaObject.TYPE :
                         if (!resolved.contains(name)) {
                             isResolved = false;
                         }
+
                         break;
 
                     default :
@@ -552,7 +553,6 @@ public class SchemaObjectSet {
 
             if (!isResolved) {
                 unresolved.add(object);
-
                 continue;
             }
 
@@ -576,8 +576,8 @@ public class SchemaObjectSet {
                 case SchemaObject.TABLE : {
                     list.addAll(((Table) object).getSQL(resolved, unresolved));
 
-                    String comment =
-                        object.getName().getCommentSQL(Tokens.T_TABLE);
+                    String comment = object.getName()
+                                           .getCommentSQL(Tokens.T_TABLE);
 
                     if (comment != null) {
                         list.add(comment);
@@ -587,8 +587,8 @@ public class SchemaObjectSet {
                             j++) {
                         ColumnSchema column = ((Table) object).getColumn(j);
 
-                        comment =
-                            column.getName().getCommentSQL(Tokens.T_COLUMN);
+                        comment = column.getName()
+                                        .getCommentSQL(Tokens.T_COLUMN);
 
                         if (comment != null) {
                             list.add(comment);
@@ -597,6 +597,20 @@ public class SchemaObjectSet {
 
                     break;
                 }
+
+                case SchemaObject.VIEW : {
+                    list.add(object.getSQL());
+
+                    String comment = object.getName()
+                                           .getCommentSQL(Tokens.T_TABLE);
+
+                    if (comment != null) {
+                        list.add(comment);
+                    }
+
+                    break;
+                }
+
                 case SchemaObject.FUNCTION :
                 case SchemaObject.PROCEDURE : {
                     Routine routine = ((Routine) object);
@@ -608,8 +622,8 @@ public class SchemaObjectSet {
                         list.add(object.getSQL());
                     }
 
-                    String comment =
-                        object.getName().getCommentSQL(Tokens.T_ROUTINE);
+                    String comment = object.getName()
+                                           .getCommentSQL(Tokens.T_ROUTINE);
 
                     if (comment != null) {
                         list.add(comment);
@@ -617,13 +631,12 @@ public class SchemaObjectSet {
 
                     break;
                 }
-                case SchemaObject.TRIGGER : {
-                    TriggerDef trigger = ((TriggerDef) object);
 
+                case SchemaObject.TRIGGER : {
                     list.add(object.getSQL());
 
-                    String comment =
-                        object.getName().getCommentSQL(Tokens.T_TRIGGER);
+                    String comment = object.getName()
+                                           .getCommentSQL(Tokens.T_TRIGGER);
 
                     if (comment != null) {
                         list.add(comment);
@@ -631,11 +644,12 @@ public class SchemaObjectSet {
 
                     break;
                 }
+
                 case SchemaObject.SEQUENCE : {
                     list.add(object.getSQL());
 
-                    String comment =
-                        object.getName().getCommentSQL(Tokens.T_SEQUENCE);
+                    String comment = object.getName()
+                                           .getCommentSQL(Tokens.T_SEQUENCE);
 
                     if (comment != null) {
                         list.add(comment);
@@ -643,6 +657,7 @@ public class SchemaObjectSet {
 
                     break;
                 }
+
                 case SchemaObject.CONSTRAINT : {
                     list.add(object.getSQL());
 
@@ -654,19 +669,21 @@ public class SchemaObjectSet {
 
                     break;
                 }
+
                 default :
                     list.add(object.getSQL());
             }
         }
     }
 
-    static boolean isChildObjectResolved(SchemaObject object,
-                                         OrderedHashSet resolved) {
+    static boolean isChildObjectResolved(
+            SchemaObject object,
+            OrderedHashSet<HsqlName> resolved) {
 
-        OrderedHashSet refs = object.getReferences();
+        OrderedHashSet<HsqlName> refs = object.getReferences();
 
         for (int i = 0; i < refs.size(); i++) {
-            HsqlName name = (HsqlName) refs.get(i);
+            HsqlName name = refs.get(i);
 
             if (SqlInvariants.isSchemaNameSystem(name)) {
                 continue;
