@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,9 @@
 package org.hsqldb;
 
 import java.text.SimpleDateFormat;
+
 import java.util.Calendar;
+import java.util.TimeZone;
 
 import org.hsqldb.jdbc.JDBCConnection;
 import org.hsqldb.navigator.RowSetNavigatorClient;
@@ -48,22 +50,28 @@ import org.hsqldb.types.ClobDataID;
  * the session level.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.3
  * @since 1.7.2
  */
 public interface SessionInterface {
 
-    int INFO_ID      = 0;                // used
-    int INFO_INTEGER = 1;                // used
-    int INFO_BOOLEAN = 2;                // used
-    int INFO_VARCHAR = 3;                // used
-    int INFO_LIMIT   = 4;
+    public interface AttributePos {
 
-    //
-    int INFO_ISOLATION           = 0;    // used
-    int INFO_AUTOCOMMIT          = 1;    // used
-    int INFO_CONNECTION_READONLY = 2;    // used
-    int INFO_CATALOG             = 3;    // used
+        int INFO_ID      = 0;
+        int INFO_INTEGER = 1;
+        int INFO_BOOLEAN = 2;
+        int INFO_VARCHAR = 3;
+        int INFO_LIMIT   = 4;
+    }
+
+    public interface Attributes {
+
+        int INFO_ISOLATION           = 0;
+        int INFO_AUTOCOMMIT          = 1;
+        int INFO_CONNECTION_READONLY = 2;
+        int INFO_CATALOG             = 3;
+        int INFO_TIMEZONE            = 4;
+    }
 
     //
     int TX_READ_UNCOMMITTED = 1;
@@ -118,6 +126,8 @@ public interface SessionInterface {
 
     void setAttribute(int id, Object value);
 
+    void setAttributeFromResult(Result result);
+
     long getId();
 
     int getRandomId();
@@ -140,6 +150,8 @@ public interface SessionInterface {
 
     SimpleDateFormat getSimpleDateFormatGMT();
 
+    TimeZone getTimeZone();
+
     int getZoneSeconds();
 
     int getStreamBlockSize();
