@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,15 +44,15 @@ import java.util.TimeZone;
  * Responsible for managing opening and closing of sessions.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.3
  * @since 1.7.2
  */
 public class SessionManager {
 
-    AtomicLong             sessionIdCount = new AtomicLong();
-    private LongKeyHashMap sessionMap     = new LongKeyHashMap();
-    private Session        sysSession;
-    private Session        sysLobSession;
+    AtomicLong                            sessionIdCount = new AtomicLong();
+    private final LongKeyHashMap<Session> sessionMap = new LongKeyHashMap<>();
+    private final Session                 sysSession;
+    private final Session                 sysLobSession;
 
     /*
      * @todo:
@@ -62,19 +62,27 @@ public class SessionManager {
      */
 
     /**
-     * Constructs an new SessionManager handling the specified Database.
+     * Constructs a new SessionManager handling the specified Database.
      * Creates a SYS User.
      */
     public SessionManager(Database db) {
 
         User sysUser = db.getUserManager().getSysUser();
 
-        sysSession = new Session(db, sysUser, false, false,
-                                 sessionIdCount.getAndIncrement(),
-                                 TimeZone.getTimeZone("GMT"));
-        sysLobSession = new Session(db, sysUser, true, false,
-                                    sessionIdCount.getAndIncrement(),
-                                    TimeZone.getTimeZone("GMT"));
+        sysSession = new Session(
+            db,
+            sysUser,
+            false,
+            false,
+            sessionIdCount.getAndIncrement(),
+            TimeZone.getTimeZone("GMT"));
+        sysLobSession = new Session(
+            db,
+            sysUser,
+            true,
+            false,
+            sessionIdCount.getAndIncrement(),
+            TimeZone.getTimeZone("GMT"));
     }
 
     /*
@@ -102,13 +110,21 @@ public class SessionManager {
      * @param zone the session time zone
      * @return Session
      */
-    public synchronized Session newSession(Database db, User user,
-                                           boolean readonly,
-                                           boolean autoCommit, TimeZone zone) {
+    public synchronized Session newSession(
+            Database db,
+            User user,
+            boolean readonly,
+            boolean autoCommit,
+            TimeZone zone) {
 
-        long sessionId = sessionIdCount.getAndIncrement();
-        Session s = new Session(db, user, autoCommit, readonly, sessionId,
-                                zone);
+        long    sessionId = sessionIdCount.getAndIncrement();
+        Session s = new Session(
+            db,
+            user,
+            autoCommit,
+            readonly,
+            sessionId,
+            zone);
 
         sessionMap.put(sessionId, s);
 
@@ -118,8 +134,13 @@ public class SessionManager {
     public synchronized Session newSessionForLog(Database db) {
 
         long sessionId = sessionIdCount.getAndIncrement();
-        Session s = new Session(db, db.getUserManager().getSysUser(), false,
-                                false, sessionId, TimeZone.getTimeZone("GMT"));
+        Session s = new Session(
+            db,
+            db.getUserManager().getSysUser(),
+            false,
+            false,
+            sessionId,
+            TimeZone.getTimeZone("GMT"));
 
         s.isProcessingLog = true;
 
@@ -133,9 +154,13 @@ public class SessionManager {
      */
     public Session getSysSessionForScript(Database db) {
 
-        Session session = new Session(db, db.getUserManager().getSysUser(),
-                                      false, false, 0,
-                                      TimeZone.getTimeZone("GMT"));
+        Session session = new Session(
+            db,
+            db.getUserManager().getSysUser(),
+            false,
+            false,
+            0,
+            TimeZone.getTimeZone("GMT"));
 
         // some old 1.8.0 do not have SET SCHEMA PUBLIC
         session.setCurrentSchemaHsqlName(
@@ -171,9 +196,13 @@ public class SessionManager {
     synchronized public Session newSysSession() {
 
         long sessionId = sessionIdCount.getAndIncrement();
-        Session session = new Session(sysSession.database,
-                                      sysSession.getUser(), false, false,
-                                      sessionId, TimeZone.getTimeZone("GMT"));
+        Session session = new Session(
+            sysSession.database,
+            sysSession.getUser(),
+            false,
+            false,
+            sessionId,
+            TimeZone.getTimeZone("GMT"));
 
         session.currentSchema =
             sysSession.database.schemaManager.getDefaultSchemaHsqlName();
@@ -186,8 +215,13 @@ public class SessionManager {
     synchronized public Session newSysSession(HsqlName schema, User user) {
 
         long sessionId = sessionIdCount.getAndIncrement();
-        Session session = new Session(sysSession.database, user, false, false,
-                                      sessionId, TimeZone.getTimeZone("GMT"));
+        Session session = new Session(
+            sysSession.database,
+            user,
+            false,
+            false,
+            sessionId,
+            TimeZone.getTimeZone("GMT"));
 
         session.currentSchema = schema;
 
@@ -222,7 +256,6 @@ public class SessionManager {
      * Closes all sessions and system
      */
     synchronized void close() {
-
         closeAllSessions();
         sysSession.close();
         sysLobSession.close();
@@ -241,8 +274,9 @@ public class SessionManager {
      * the Session User.
      */
     public synchronized Session[] getVisibleSessions(Session session) {
-        return session.isAdmin() ? getAllSessions()
-                                 : new Session[]{ session };
+        return session.isAdmin()
+               ? getAllSessions()
+               : new Session[]{ session };
     }
 
     /**
@@ -250,16 +284,16 @@ public class SessionManager {
      * if no such Session is registered with this SessionManager.
      */
     synchronized Session getSession(long id) {
-        return (Session) sessionMap.get(id);
+        return sessionMap.get(id);
     }
 
     public synchronized Session[] getAllSessions() {
 
-        Session[] sessions = new Session[sessionMap.size()];
-        Iterator  it       = sessionMap.values().iterator();
+        Session[]         sessions = new Session[sessionMap.size()];
+        Iterator<Session> it       = sessionMap.values().iterator();
 
         for (int i = 0; it.hasNext(); i++) {
-            sessions[i] = (Session) it.next();
+            sessions[i] = it.next();
         }
 
         return sessions;
@@ -267,10 +301,10 @@ public class SessionManager {
 
     public synchronized boolean isUserActive(String userName) {
 
-        Iterator it = sessionMap.values().iterator();
+        Iterator<Session> it = sessionMap.values().iterator();
 
         for (int i = 0; it.hasNext(); i++) {
-            Session session = (Session) it.next();
+            Session session = it.next();
 
             if (!session.isClosed()
                     && userName.equals(
@@ -284,10 +318,10 @@ public class SessionManager {
 
     public synchronized void removeSchemaReference(HsqlName schemaName) {
 
-        Iterator it = sessionMap.values().iterator();
+        Iterator<Session> it = sessionMap.values().iterator();
 
         for (int i = 0; it.hasNext(); i++) {
-            Session session = (Session) it.next();
+            Session session = it.next();
 
             if (session.getCurrentSchemaHsqlName() == schemaName) {
                 session.resetSchema();
@@ -297,14 +331,34 @@ public class SessionManager {
 
     public synchronized void resetLoggedSchemas() {
 
-        Iterator it = sessionMap.values().iterator();
+        Iterator<Session> it = sessionMap.values().iterator();
 
         for (int i = 0; it.hasNext(); i++) {
-            Session session = (Session) it.next();
+            Session session = it.next();
 
             session.loggedSchema = null;
         }
 
         this.sysLobSession.loggedSchema = null;
     }
+
+    public synchronized long resetNewLobIDs() {
+
+        Iterator<Session> it          = sessionMap.values().iterator();
+        long              newLobFloor = Long.MAX_VALUE;
+
+        for (int i = 0; it.hasNext(); i++) {
+            Session session      = it.next();
+            long    currentFloor = session.sessionData.newLobFloor;
+
+            if (currentFloor != SessionData.noLobFloor
+                    && currentFloor < newLobFloor) {
+                newLobFloor = currentFloor;
+            }
+
+            session.sessionData.newLobFloor = SessionData.noLobFloor;
+        }
+
+        return newLobFloor;
+    }
 }
