@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,6 +33,7 @@ package org.hsqldb;
 
 import java.sql.Connection;
 
+import org.hsqldb.HsqlNameManager.HsqlName;
 import org.hsqldb.ParserDQL.CompileContext;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
@@ -46,7 +47,7 @@ import org.hsqldb.types.Type;
  * Implementation of Statement for callable procedures.<p>
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.0
+ * @version 2.7.3
  * @since 1.9.0
  */
 public class StatementProcedure extends StatementDMQL {
@@ -64,11 +65,15 @@ public class StatementProcedure extends StatementDMQL {
     /**
      * Constructor for CALL statements for expressions.
      */
-    StatementProcedure(Session session, Expression expression,
-                       CompileContext compileContext) {
+    StatementProcedure(
+            Session session,
+            Expression expression,
+            CompileContext compileContext) {
 
-        super(StatementTypes.CALL, StatementTypes.X_SQL_DATA,
-              session.getCurrentSchemaHsqlName());
+        super(
+            StatementTypes.CALL,
+            StatementTypes.X_SQL_DATA,
+            session.getCurrentSchemaHsqlName());
 
         statementReturnType = StatementTypes.RETURN_RESULT;
 
@@ -99,11 +104,16 @@ public class StatementProcedure extends StatementDMQL {
     /**
      * Constructor for CALL statements for procedures.
      */
-    StatementProcedure(Session session, Routine procedure,
-                       Expression[] arguments, CompileContext compileContext) {
+    StatementProcedure(
+            Session session,
+            Routine procedure,
+            Expression[] arguments,
+            CompileContext compileContext) {
 
-        super(StatementTypes.CALL, StatementTypes.X_SQL_DATA,
-              session.getCurrentSchemaHsqlName());
+        super(
+            StatementTypes.CALL,
+            StatementTypes.X_SQL_DATA,
+            session.getCurrentSchemaHsqlName());
 
         if (procedure.maxDynamicResults > 0) {
             statementReturnType = StatementTypes.RETURN_ANY;
@@ -124,8 +134,9 @@ public class StatementProcedure extends StatementDMQL {
 
     Result getResult(Session session) {
 
-        Result result = expression == null ? getProcedureResult(session)
-                                           : getExpressionResult(session);
+        Result result = expression == null
+                        ? getProcedureResult(session)
+                        : getExpressionResult(session);
 
         result.setStatementType(statementReturnType);
 
@@ -134,26 +145,7 @@ public class StatementProcedure extends StatementDMQL {
 
     Result getProcedureResult(Session session) {
 
-        Object[] data = ValuePool.emptyObjectArray;
-        int      argLength;
-
-        if (procedure.isPSM()) {
-            argLength = arguments.length;
-
-            if (procedure.getMaxDynamicResults() > 0) {
-                argLength++;
-            }
-        } else {
-            argLength = procedure.javaMethod.getParameterTypes().length;
-
-            if (procedure.javaMethodWithConnection) {
-                argLength--;
-            }
-        }
-
-        if (argLength > 0) {
-            data = new Object[argLength];
-        }
+        Object[] data = getArgsArray();
 
         for (int i = 0; i < arguments.length; i++) {
             Expression e = arguments[i];
@@ -162,8 +154,10 @@ public class StatementProcedure extends StatementDMQL {
                 Type   targetType = procedure.getParameter(i).getDataType();
                 Object value      = e.getValue(session);
 
-                data[i] = targetType.convertToType(session, value,
-                                                   e.getDataType());
+                data[i] = targetType.convertToType(
+                    session,
+                    value,
+                    e.getDataType());
             }
         }
 
@@ -219,10 +213,10 @@ public class StatementProcedure extends StatementDMQL {
 
         Result r = result;
 
-        result =
-            Result.newCallResponse(getParametersMetaData().getParameterTypes(),
-                                   id,
-                                   session.sessionContext.dynamicArguments);
+        result = Result.newCallResponse(
+            getParametersMetaData().getParameterTypes(),
+            id,
+            session.sessionContext.dynamicArguments);
 
         if (procedure.returnsTable()) {
             result.addChainedResult(r);
@@ -235,6 +229,32 @@ public class StatementProcedure extends StatementDMQL {
         return result;
     }
 
+    private Object[] getArgsArray() {
+
+        Object[] data = ValuePool.emptyObjectArray;
+        int      argLength;
+
+        if (procedure.isPSM()) {
+            argLength = arguments.length;
+
+            if (procedure.getMaxDynamicResults() > 0) {
+                argLength++;
+            }
+        } else {
+            argLength = procedure.javaMethod.getParameterTypes().length;
+
+            if (procedure.javaMethodWithConnection) {
+                argLength--;
+            }
+        }
+
+        if (argLength > 0) {
+            data = new Object[argLength];
+        }
+
+        return data;
+    }
+
     Result executePSMProcedure(Session session) {
 
         int variableCount = procedure.getVariableCount();
@@ -303,17 +323,17 @@ public class StatementProcedure extends StatementDMQL {
 
     TableDerived[] getSubqueries(Session session) {
 
-        OrderedHashSet subQueries = null;
+        OrderedHashSet<TableDerived> subQueries = null;
 
         if (expression != null) {
-            subQueries = expression.collectAllSubqueries(subQueries);
+            subQueries = expression.collectAllSubqueries(null);
         }
 
         for (int i = 0; i < arguments.length; i++) {
             subQueries = arguments[i].collectAllSubqueries(subQueries);
         }
 
-        if (subQueries == null || subQueries.size() == 0) {
+        if (subQueries == null || subQueries.isEmpty()) {
             return TableDerived.emptyArray;
         }
 
@@ -356,9 +376,11 @@ public class StatementProcedure extends StatementDMQL {
                 // return value has a void return type, a result set
                 // is described whose single column is of type NULL
                 ResultMetaData md = ResultMetaData.newResultMetaData(1);
-                ColumnBase column =
-                    new ColumnBase(null, null, null,
-                                   StatementDMQL.RETURN_COLUMN_NAME);
+                ColumnBase column = new ColumnBase(
+                    null,
+                    null,
+                    null,
+                    StatementDMQL.RETURN_COLUMN_NAME);
 
                 column.setType(expression.getDataType());
 
@@ -370,9 +392,11 @@ public class StatementProcedure extends StatementDMQL {
 
                 return md;
             }
+
             default :
-                throw Error.runtimeError(ErrorCode.U_S0500,
-                                         "StatementProcedure");
+                throw Error.runtimeError(
+                    ErrorCode.U_S0500,
+                    "StatementProcedure");
         }
     }
 
@@ -394,7 +418,7 @@ public class StatementProcedure extends StatementDMQL {
         return meta;
     }
 
-    void collectTableNamesForRead(OrderedHashSet set) {
+    void collectTableNamesForRead(OrderedHashSet<HsqlName> set) {
 
         if (expression == null) {
             set.addAll(procedure.getTableNamesForRead());
@@ -411,8 +435,7 @@ public class StatementProcedure extends StatementDMQL {
         }
     }
 
-    void collectTableNamesForWrite(OrderedHashSet set) {
-
+    void collectTableNamesForWrite(OrderedHashSet<HsqlName> set) {
         if (expression == null) {
             set.addAll(procedure.getTableNamesForWrite());
         }
