@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,7 +48,7 @@ import org.hsqldb.types.Type;
  * Table with data derived from a query expression.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.1
+ * @version 2.7.4
  * @since 1.9.0
  */
 public class TableDerived extends Table {
@@ -90,8 +90,12 @@ public class TableDerived extends Table {
     /**
      * For named sunbqueries.
      */
-    public TableDerived(Database database, HsqlName name, int type,
-                        HsqlName[] colNames, Type[] colTypes) {
+    public TableDerived(
+            Database database,
+            HsqlName name,
+            int type,
+            HsqlName[] colNames,
+            Type[] colTypes) {
 
         this(database, name, type);
 
@@ -107,9 +111,13 @@ public class TableDerived extends Table {
         createPrimaryKey(null, null, false);
     }
 
-    public TableDerived(Database database, HsqlName name, int type,
-                        Type[] columnTypes, OrderedHashMap columnList,
-                        int[] pkColumns) {
+    public TableDerived(
+            Database database,
+            HsqlName name,
+            int type,
+            Type[] columnTypes,
+            OrderedHashMap<String, ColumnSchema> columnList,
+            int[] pkColumns) {
 
         this(database, name, type);
 
@@ -120,9 +128,14 @@ public class TableDerived extends Table {
         createPrimaryKey(null, pkColumns, true);
     }
 
-    public TableDerived(Database database, HsqlName name, int type,
-                        QueryExpression queryExpression,
-                        Expression dataExpression, int opType, int depth) {
+    public TableDerived(
+            Database database,
+            HsqlName name,
+            int type,
+            QueryExpression queryExpression,
+            Expression dataExpression,
+            int opType,
+            int depth) {
 
         super(database, name, type);
 
@@ -172,8 +185,9 @@ public class TableDerived extends Table {
         }
     }
 
-    public TableDerived newDerivedTable(Session session,
-                                        CompileContext baseContext) {
+    public TableDerived newDerivedTable(
+            Session session,
+            CompileContext baseContext) {
 
         TableDerived td = this;
 
@@ -186,9 +200,10 @@ public class TableDerived extends Table {
 
             td = p.XreadSubqueryTableBody(tableName, OpTypes.TABLE_SUBQUERY);
 
-            td.queryExpression.resolve(session,
-                                       p.compileContext.getOuterRanges(),
-                                       null);
+            td.queryExpression.resolve(
+                session,
+                p.compileContext.getOuterRanges(),
+                null);
 
             td.columnList   = columnList;
             td.columnCount  = columnList.size();
@@ -202,7 +217,7 @@ public class TableDerived extends Table {
         return td;
     }
 
-    public int getId() {
+    public long getId() {
         return 0;
     }
 
@@ -220,8 +235,7 @@ public class TableDerived extends Table {
             return false;
         }
 
-        return queryExpression == null ? false
-                                       : queryExpression.isInsertable();
+        return queryExpression != null && queryExpression.isInsertable();
     }
 
     public boolean isUpdatable() {
@@ -230,8 +244,7 @@ public class TableDerived extends Table {
             return false;
         }
 
-        return queryExpression == null ? false
-                                       : queryExpression.isUpdatable();
+        return queryExpression != null && queryExpression.isUpdatable();
     }
 
     public int[] getUpdatableColumns() {
@@ -271,15 +284,15 @@ public class TableDerived extends Table {
     }
 
     public Table getBaseTable() {
-        return queryExpression == null ? this
-                                       : queryExpression.getBaseTable();
+        return queryExpression == null
+               ? this
+               : queryExpression.getBaseTable();
     }
 
     public int[] getBaseTableColumnMap() {
-
-        return queryExpression == null ? null
-                                       : queryExpression
-                                           .getBaseTableColumnMap();
+        return queryExpression == null
+               ? null
+               : queryExpression.getBaseTableColumnMap();
     }
 
     public QueryExpression getQueryExpression() {
@@ -320,10 +333,11 @@ public class TableDerived extends Table {
                 throw Error.error(ErrorCode.X_42593);
             }
 
-            OrderedHashMap newColumnList = new OrderedHashMap();
+            OrderedHashMap<String, ColumnSchema> newColumnList =
+                new OrderedHashMap<>();
 
             for (int i = 0; i < columnCount; i++) {
-                ColumnSchema col = (ColumnSchema) columnList.get(i);
+                ColumnSchema col = columnList.get(i);
 
                 col.setName(columns[i]);
                 newColumnList.add(columns[i].name, col);
@@ -350,8 +364,9 @@ public class TableDerived extends Table {
             ArrayUtil.fillSequence(cols);
         }
 
-        int[] pkcols = uniqueRows ? cols
-                                  : null;
+        int[] pkcols = uniqueRows
+                       ? cols
+                       : null;
 
         createPrimaryKey(null, pkcols, false);
 
@@ -433,7 +448,6 @@ public class TableDerived extends Table {
     }
 
     public void materialiseCorrelated(Session session) {
-
         if (isCorrelated()) {
             materialise(session);
         }
@@ -444,11 +458,7 @@ public class TableDerived extends Table {
         if (canRecompile && queryExpression instanceof QuerySpecification) {
             QuerySpecification qs = (QuerySpecification) queryExpression;
 
-            if (qs.isAggregated || qs.isGrouped || qs.isOrderSensitive) {
-                return false;
-            } else {
-                return true;
-            }
+            return !qs.isAggregated && !qs.isGrouped && !qs.isOrderSensitive;
         }
 
         return false;
@@ -472,7 +482,6 @@ public class TableDerived extends Table {
     }
 
     public Object getValue(Session session) {
-
         Object[] data = getValues(session);
 
         return data[0];
@@ -480,7 +489,8 @@ public class TableDerived extends Table {
 
     public RowSetNavigatorData getNavigator(Session session) {
 
-        RowSetNavigatorData navigator = new RowSetNavigatorDataTable(session,
+        RowSetNavigatorData navigator = new RowSetNavigatorDataTable(
+            session,
             this);
 
         return navigator;
