@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2023, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,11 +39,11 @@ import org.hsqldb.persist.PersistentStore;
  * Manages rows involved in transactions
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.2
+ * @version 2.7.3
  * @since 2.0.0
  */
 public class TransactionManager2PL extends TransactionManagerCommon
-implements TransactionManager {
+        implements TransactionManager {
 
     public TransactionManager2PL(Database db) {
 
@@ -86,7 +86,6 @@ implements TransactionManager {
     }
 
     public boolean prepareCommitActions(Session session) {
-
         session.actionSCN = getNextSystemChangeNumber();
 
         return true;
@@ -110,7 +109,7 @@ implements TransactionManager {
             endTransaction(session);
 
             for (int i = 0; i < limit; i++) {
-                RowAction action = (RowAction) session.rowActionList.get(i);
+                RowAction action = session.rowActionList.get(i);
 
                 action.commit(session);
             }
@@ -146,6 +145,8 @@ implements TransactionManager {
             session.isTransaction = false;
 
             endTransactionTPL(session);
+
+            session.sessionData.newLobFloor = SessionData.noLobFloor;
         } finally {
             writeLock.unlock();
         }
@@ -154,7 +155,7 @@ implements TransactionManager {
     public void rollbackSavepoint(Session session, int index) {
 
         long timestamp = session.sessionContext.savepointTimestamps.get(index);
-        Integer oi = (Integer) session.sessionContext.savepoints.get(index);
+        Integer oi     = session.sessionContext.savepoints.get(index);
         int     start  = oi.intValue();
 
         while (session.sessionContext.savepoints.size() > index + 1) {
@@ -184,9 +185,10 @@ implements TransactionManager {
         }
 
         for (int i = limit - 1; i >= start; i--) {
-            RowAction action = (RowAction) session.rowActionList.get(i);
+            RowAction action = session.rowActionList.get(i);
 
-            if (action == null || action.type == RowActionBase.ACTION_NONE
+            if (action == null
+                    || action.type == RowActionBase.ACTION_NONE
                     || action.type == RowActionBase.ACTION_DELETE_FINAL) {
                 continue;
             }
@@ -211,15 +213,22 @@ implements TransactionManager {
         session.rowActionList.setSize(start);
     }
 
-    public RowAction addDeleteAction(Session session, Table table,
-                                     PersistentStore store, Row row,
-                                     int[] changedColumns) {
+    public RowAction addDeleteAction(
+            Session session,
+            Table table,
+            PersistentStore store,
+            Row row,
+            int[] changedColumns) {
 
         RowAction action;
 
         synchronized (row) {
-            action = RowAction.addDeleteAction(session, table, store, row,
-                                               changedColumns);
+            action = RowAction.addDeleteAction(
+                session,
+                table,
+                store,
+                row,
+                changedColumns);
         }
 
         store.delete(session, row);
@@ -235,19 +244,24 @@ implements TransactionManager {
         return action;
     }
 
-    public void addInsertAction(Session session, Table table,
-                                PersistentStore store, Row row,
-                                int[] changedColumns) {
+    public void addInsertAction(
+            Session session,
+            Table table,
+            PersistentStore store,
+            Row row,
+            int[] changedColumns) {
 
         RowAction action = row.rowAction;
 
         if (action == null) {
+
 /*
             System.out.println("null insert action " + session + " "
                                + session.actionTimestamp);
 */
-            throw Error.runtimeError(ErrorCode.GENERAL_ERROR,
-                                     "null insert action ");
+            throw Error.runtimeError(
+                ErrorCode.GENERAL_ERROR,
+                "null insert action ");
         }
 
         store.indexRow(session, row);
@@ -262,15 +276,14 @@ implements TransactionManager {
     }
 
     public void beginTransaction(Session session) {
-
         if (!session.isTransaction) {
             beginTransactionCommon(session);
         }
     }
 
     /**
-     * add session to the end of queue when a transaction starts
-     * (depending on isolation mode)
+     * allow session to execute the statement or put it in wait for
+     * other sessions to commit (depending on isolation mode)
      */
     public void beginAction(Session session, Statement cs) {
 
@@ -293,8 +306,8 @@ implements TransactionManager {
                 if (session.tempSet.isEmpty()) {
                     lockTablesTPL(session, cs);
 
-                    // we don't set other sessions that would now be waiting for this one too
-                    // next lock release will do it
+                    // we don't set other sessions that would now be waiting for this one too,
+                    // the next lock release will do it
                 } else {
                     setWaitingSessionTPL(session);
                 }
@@ -309,6 +322,7 @@ implements TransactionManager {
     }
 
     public void beginActionResume(Session session) {
+
         Statement cs = session.sessionContext.currentStatement;
 
         cs = updateCurrentStatement(session, cs);
@@ -327,13 +341,15 @@ implements TransactionManager {
 
     public void removeTransactionInfo(long id) {}
 
-    public void resetSession(Session session, Session targetSession,
-                             long statementTimestamp, int mode) {
+    public void resetSession(
+            Session session,
+            Session targetSession,
+            long statementTimestamp,
+            int mode) {
         super.resetSession(session, targetSession, statementTimestamp, mode);
     }
 
     private void endTransaction(Session session) {
-
         if (session.isTransaction) {
             transactionCount.decrementAndGet();
         }
