@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2023, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,7 +50,7 @@ import org.hsqldb.lib.OrderedHashSet;
  * Shared code for TransactionManager classes
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.2
+ * @version 2.7.3
  * @since 2.0.0
  */
 class TransactionManagerCommon {
@@ -76,8 +76,9 @@ class TransactionManagerCommon {
     AtomicInteger transactionCount = new AtomicInteger();
 
     //
-    HashMap           tableWriteLocks = new HashMap();
-    MultiValueHashMap tableReadLocks  = new MultiValueHashMap();
+    HashMap<HsqlName, Session> tableWriteLocks = new HashMap<>();
+    MultiValueHashMap<HsqlName, Session> tableReadLocks =
+        new MultiValueHashMap<>();
 
     /**
      * Normally false. When SET DATABASE TRANSACTION CONTROL is used to change
@@ -115,58 +116,60 @@ class TransactionManagerCommon {
             switch (mode) {
 
                 case TransactionManager.MVCC : {
-                    TransactionManagerMVCC txMan =
-                        new TransactionManagerMVCC(database);
+                    TransactionManagerMVCC txMan = new TransactionManagerMVCC(
+                        database);
 
                     txMan.liveTransactionSCNs.addLast(session.transactionSCN);
 
                     txMan.catalogWriteSession = session;
                     txMan.isLockedMode        = true;
 
-                    OrderedHashSet set = session.waitingSessions;
+                    OrderedHashSet<Session> set = session.waitingSessions;
 
                     for (int i = 0; i < set.size(); i++) {
-                        Session current = (Session) set.get(i);
+                        Session current = set.get(i);
 
                         current.waitedSessions.add(session);
                     }
 
                     manager = txMan;
-
                     break;
                 }
+
                 case TransactionManager.MVLOCKS : {
                     manager = new TransactionManagerMV2PL(database);
 
-                    manager.liveTransactionSCNs.addLast(
-                        session.transactionSCN);
+                    manager.liveTransactionSCNs.addLast(session.transactionSCN);
 
-                    OrderedHashSet set = session.waitingSessions;
+                    OrderedHashSet<Session> set = session.waitingSessions;
 
                     for (int i = 0; i < set.size(); i++) {
-                        Session current = (Session) set.get(i);
+                        Session current = set.get(i);
 
                         current.waitedSessions.clear();
                     }
 
                     break;
                 }
+
                 case TransactionManager.LOCKS : {
                     manager = new TransactionManager2PL(database);
 
-                    OrderedHashSet set = session.waitingSessions;
+                    OrderedHashSet<Session> set = session.waitingSessions;
 
                     for (int i = 0; i < set.size(); i++) {
-                        Session current = (Session) set.get(i);
+                        Session current = set.get(i);
 
                         current.waitedSessions.clear();
                     }
 
                     break;
                 }
+
                 default :
-                    throw Error.runtimeError(ErrorCode.U_S0500,
-                                             "TransactionManagerCommon");
+                    throw Error.runtimeError(
+                        ErrorCode.U_S0500,
+                        "TransactionManagerCommon");
             }
 
             manager.systemChangeNumber.set(systemChangeNumber.get());
@@ -196,7 +199,7 @@ class TransactionManagerCommon {
         long lastActionTimestamp = session.actionSCN;
 
         for (int i = 0; i < limit; i++) {
-            RowAction action = (RowAction) session.rowActionList.get(i);
+            RowAction action = session.rowActionList.get(i);
 
             if (action.type == RowActionBase.ACTION_NONE) {
                 continue;
@@ -213,13 +216,17 @@ class TransactionManagerCommon {
                 switch (type) {
 
                     case RowActionBase.ACTION_INSERT :
-                        session.sessionData.adjustLobUsageCount(action.table,
-                                row.getData(), 1);
+                        session.sessionData.adjustLobUsageCount(
+                            action.table,
+                            row.getData(),
+                            1);
                         break;
 
                     case RowActionBase.ACTION_DELETE :
-                        session.sessionData.adjustLobUsageCount(action.table,
-                                row.getData(), -1);
+                        session.sessionData.adjustLobUsageCount(
+                            action.table,
+                            row.getData(),
+                            -1);
                         break;
 
                     case RowActionBase.ACTION_INSERT_DELETE :
@@ -232,11 +239,13 @@ class TransactionManagerCommon {
 
         if (newLimit > limit) {
             for (int i = limit; i < newLimit; i++) {
-                RowAction lobAction = (RowAction) session.rowActionList.get(i);
+                RowAction lobAction = session.rowActionList.get(i);
 
                 lobAction.commit(session);
             }
         }
+
+        session.sessionData.newLobFloor = SessionData.noLobFloor;
     }
 
     final Statement updateCurrentStatement(Session session, Statement cs) {
@@ -261,7 +270,7 @@ class TransactionManagerCommon {
         boolean writeCommit = false;
 
         for (int i = 0; i < limit; i++) {
-            RowAction action = (RowAction) session.rowActionList.get(i);
+            RowAction action = session.rowActionList.get(i);
 
             if (action.type == RowActionBase.ACTION_NONE) {
                 continue;
@@ -303,7 +312,11 @@ class TransactionManagerCommon {
         }
     }
 
-    final void finaliseRows(Session session, Object[] list, int start, int limit) {
+    final void finaliseRows(
+            Session session,
+            Object[] list,
+            int start,
+            int limit) {
 
         for (int i = start; i < limit; i++) {
             RowAction action = (RowAction) list[i];
@@ -315,11 +328,14 @@ class TransactionManagerCommon {
     /**
      * merge a transaction committed at a given timestamp.
      */
-    final void mergeTransaction(Object[] list, int start, int limit,
-                          long timestamp) {
+    final void mergeTransaction(
+            RowAction[] list,
+            int start,
+            int limit,
+            long timestamp) {
 
         for (int i = start; i < limit; i++) {
-            RowAction rowact = (RowAction) list[i];
+            RowAction rowact = list[i];
 
             rowact.mergeToTimestamp(timestamp);
         }
@@ -332,12 +348,14 @@ class TransactionManagerCommon {
         return systemChangeNumber.incrementAndGet();
     }
 
-    final static boolean checkDeadlock(Session session, OrderedHashSet newWaits) {
+    static boolean checkDeadlock(
+            Session session,
+            OrderedHashSet<Session> newWaits) {
 
         int size = session.waitingSessions.size();
 
         for (int i = 0; i < size; i++) {
-            Session current = (Session) session.waitingSessions.get(i);
+            Session current = session.waitingSessions.get(i);
 
             if (newWaits.contains(current)) {
                 return false;
@@ -356,7 +374,7 @@ class TransactionManagerCommon {
         int size = session.waitingSessions.size();
 
         for (int i = 0; i < size; i++) {
-            Session current = (Session) session.waitingSessions.get(i);
+            Session current = session.waitingSessions.get(i);
 
             if (current == other) {
                 return false;
@@ -372,8 +390,8 @@ class TransactionManagerCommon {
 
     final void getTransactionSessions(Session session) {
 
-        OrderedHashSet set      = session.tempSet;
-        Session[]      sessions = database.sessionManager.getAllSessions();
+        OrderedHashSet<Session> set = session.tempSet;
+        Session[] sessions          = database.sessionManager.getAllSessions();
 
         for (int i = 0; i < sessions.length; i++) {
             long timestamp = sessions[i].transactionSCN;
@@ -386,8 +404,8 @@ class TransactionManagerCommon {
 
     final void getTransactionAndPreSessions(Session session) {
 
-        OrderedHashSet set      = session.tempSet;
-        Session[]      sessions = database.sessionManager.getAllSessions();
+        OrderedHashSet<Session> set = session.tempSet;
+        Session[] sessions          = database.sessionManager.getAllSessions();
 
         set.clear();
 
@@ -407,8 +425,7 @@ class TransactionManagerCommon {
     final void endActionTPL(Session session) {
 
         if (session.isolationLevel == SessionInterface.TX_REPEATABLE_READ
-                || session.isolationLevel
-                   == SessionInterface.TX_SERIALIZABLE) {
+                || session.isolationLevel == SessionInterface.TX_SERIALIZABLE) {
             return;
         }
 
@@ -446,7 +463,6 @@ class TransactionManagerCommon {
             for (int i = 0; i < readLocks.length; i++) {
                 if (tableWriteLocks.get(readLocks[i]) != session) {
                     canUnlock = true;
-
                     break;
                 }
             }
@@ -458,11 +474,10 @@ class TransactionManagerCommon {
             canUnlock = false;
 
             for (int i = 0; i < waitingCount; i++) {
-                Session current = (Session) session.waitingSessions.get(i);
+                Session current = session.waitingSessions.get(i);
 
                 if (current.abortTransaction) {
                     canUnlock = true;
-
                     break;
                 }
 
@@ -471,14 +486,12 @@ class TransactionManagerCommon {
 
                 if (current.sessionContext.invalidStatement) {
                     canUnlock = true;
-
                     break;
                 }
 
-                if (ArrayUtil.containsAny(
-                        readLocks, currentStatement.getTableNamesForWrite())) {
+                if (ArrayUtil.containsAny(readLocks,
+                                          currentStatement.getTableNamesForWrite())) {
                     canUnlock = true;
-
                     break;
                 }
             }
@@ -513,20 +526,22 @@ class TransactionManagerCommon {
         final int waitingCount = session.waitingSessions.size();
 
         for (int i = 0; i < waitingCount; i++) {
-            Session current = (Session) session.waitingSessions.get(i);
+            Session current = session.waitingSessions.get(i);
 
             current.tempUnlocked = false;
 
             long count = current.latch.getCount();
 
             if (count == 1) {
-                boolean canProceed = setWaitedSessionsTPL(current,
+                boolean canProceed = setWaitedSessionsTPL(
+                    current,
                     current.sessionContext.currentStatement);
 
                 if (canProceed) {
                     if (current.tempSet.isEmpty()) {
-                        lockTablesTPL(current,
-                                      current.sessionContext.currentStatement);
+                        lockTablesTPL(
+                            current,
+                            current.sessionContext.currentStatement);
 
                         current.tempUnlocked = true;
                     }
@@ -535,7 +550,7 @@ class TransactionManagerCommon {
         }
 
         for (int i = 0; i < waitingCount; i++) {
-            Session current = (Session) session.waitingSessions.get(i);
+            Session current = session.waitingSessions.get(i);
 
             if (current.tempUnlocked) {
 
@@ -546,8 +561,9 @@ class TransactionManagerCommon {
             } else {
 
                 // this can introduce additional waits for the sessions
-                setWaitedSessionsTPL(current,
-                                     current.sessionContext.currentStatement);
+                setWaitedSessionsTPL(
+                    current,
+                    current.sessionContext.currentStatement);
             }
         }
     }
@@ -557,23 +573,23 @@ class TransactionManagerCommon {
         final int waitingCount = session.waitingSessions.size();
 
         for (int i = 0; i < waitingCount; i++) {
-            Session current     = (Session) session.waitingSessions.get(i);
+            Session current     = session.waitingSessions.get(i);
             boolean monitorCode = false;
 
             if (monitorCode) {
                 if (!current.abortTransaction && current.tempSet.isEmpty()) {
 
                     // test code valid only for top level statements
-                    boolean hasLocks =
-                        hasLocks(current,
-                                 current.sessionContext.currentStatement);
+                    boolean hasLocks = hasLocks(
+                        current,
+                        current.sessionContext.currentStatement);
 
                     if (!hasLocks) {
                         System.out.println("tx graph");
 
-                        hasLocks =
-                            hasLocks(current,
-                                     current.sessionContext.currentStatement);
+                        hasLocks = hasLocks(
+                            current,
+                            current.sessionContext.currentStatement);
                     }
                 }
             }
@@ -594,23 +610,23 @@ class TransactionManagerCommon {
         final int waitingCount = session.tempSet.size();
 
         for (int i = 0; i < waitingCount; i++) {
-            Session current     = (Session) session.tempSet.get(i);
+            Session current     = session.tempSet.get(i);
             boolean monitorCode = false;
 
             if (monitorCode) {
                 if (!current.abortTransaction && current.tempSet.isEmpty()) {
 
                     // test code valid for top level statements
-                    boolean hasLocks =
-                        hasLocks(current,
-                                 current.sessionContext.currentStatement);
+                    boolean hasLocks = hasLocks(
+                        current,
+                        current.sessionContext.currentStatement);
 
                     if (!hasLocks) {
                         System.out.println("tx graph");
 
-                        hasLocks =
-                            hasLocks(current,
-                                     current.sessionContext.currentStatement);
+                        hasLocks = hasLocks(
+                            current,
+                            current.sessionContext.currentStatement);
                     }
                 }
             }
@@ -646,16 +662,16 @@ class TransactionManagerCommon {
                 continue;
             }
 
-            Session holder = (Session) tableWriteLocks.get(name);
+            Session holder = tableWriteLocks.get(name);
 
             if (holder != null && holder != session) {
                 session.tempSet.add(holder);
             }
 
-            Iterator it = tableReadLocks.getValuesIterator(name);
+            Iterator<Session> it = tableReadLocks.getValuesIterator(name);
 
             while (it.hasNext()) {
-                holder = (Session) it.next();
+                holder = it.next();
 
                 if (holder != session) {
                     session.tempSet.add(holder);
@@ -678,7 +694,7 @@ class TransactionManagerCommon {
                 continue;
             }
 
-            Session holder = (Session) tableWriteLocks.get(name);
+            Session holder = tableWriteLocks.get(name);
 
             if (holder != null && holder != session) {
                 session.tempSet.add(holder);
@@ -710,7 +726,7 @@ class TransactionManagerCommon {
         }
 
         for (int i = 0; i < count; i++) {
-            Session current = (Session) session.tempSet.get(i);
+            Session current = session.tempSet.get(i);
 
             current.waitingSessions.add(session);
         }
@@ -758,10 +774,10 @@ class TransactionManagerCommon {
 
     final void unlockTablesTPL(Session session) {
 
-        Iterator it = tableWriteLocks.values().iterator();
+        Iterator<Session> it = tableWriteLocks.values().iterator();
 
         while (it.hasNext()) {
-            Session s = (Session) it.next();
+            Session s = it.next();
 
             if (s == session) {
                 it.remove();
@@ -771,7 +787,7 @@ class TransactionManagerCommon {
         it = tableReadLocks.values().iterator();
 
         while (it.hasNext()) {
-            Session s = (Session) it.next();
+            Session s = it.next();
 
             if (s == session) {
                 it.remove();
@@ -780,7 +796,6 @@ class TransactionManagerCommon {
     }
 
     final void unlockReadTablesTPL(Session session, HsqlName[] locks) {
-
         for (int i = 0; i < locks.length; i++) {
             tableReadLocks.remove(locks[i], session);
         }
@@ -801,16 +816,16 @@ class TransactionManagerCommon {
                 continue;
             }
 
-            Session holder = (Session) tableWriteLocks.get(name);
+            Session holder = tableWriteLocks.get(name);
 
             if (holder != null && holder != session) {
                 return false;
             }
 
-            Iterator it = tableReadLocks.getValuesIterator(name);
+            Iterator<Session> it = tableReadLocks.getValuesIterator(name);
 
             while (it.hasNext()) {
-                holder = (Session) it.next();
+                holder = it.next();
 
                 if (holder != session) {
                     return false;
@@ -827,7 +842,7 @@ class TransactionManagerCommon {
                 continue;
             }
 
-            Session holder = (Session) tableWriteLocks.get(name);
+            Session holder = tableWriteLocks.get(name);
 
             if (holder != null && holder != session) {
                 return false;
@@ -849,7 +864,7 @@ class TransactionManagerCommon {
     /**
      * Return an array of all row actions sorted by System Change No.
      */
-   final RowAction[] getRowActionList() {
+    final RowAction[] getRowActionList() {
 
         writeLock.lock();
 
@@ -879,9 +894,8 @@ class TransactionManagerCommon {
                     int tSize = sessions[i].getTransactionSize();
 
                     if (tIndex[i] < tSize) {
-                        RowAction current =
-                            (RowAction) sessions[i].rowActionList.get(
-                                tIndex[i]);
+                        RowAction current = sessions[i].rowActionList.get(
+                            tIndex[i]);
 
                         if (current.actionSCN < minChangeNo) {
                             minChangeNo  = current.actionSCN;
@@ -896,14 +910,13 @@ class TransactionManagerCommon {
                     break;
                 }
 
-                HsqlArrayList currentList =
+                HsqlArrayList<RowAction> currentList =
                     sessions[sessionIndex].rowActionList;
 
-                for (; tIndex[sessionIndex] < currentList.size(); ) {
-                    RowAction current =
-                        (RowAction) currentList.get(tIndex[sessionIndex]);
+                while (tIndex[sessionIndex] < currentList.size()) {
+                    RowAction current = currentList.get(tIndex[sessionIndex]);
 
-                    // if the next change no is in this session, continue adding
+                    // if the next change not is in this session, continue adding
                     if (current.actionSCN == minChangeNo + 1) {
                         minChangeNo++;
                     }
@@ -924,8 +937,11 @@ class TransactionManagerCommon {
         }
     }
 
-    void resetSession(Session session, Session targetSession,
-                      long statementTimestamp, int mode) {
+    void resetSession(
+            Session session,
+            Session targetSession,
+            long statementTimestamp,
+            int mode) {
 
         writeLock.lock();
 
@@ -940,6 +956,7 @@ class TransactionManagerCommon {
                     if (!targetSession.isInMidTransaction()) {
                         targetSession.sessionData.closeAllNavigators();
                     }
+
                     break;
 
                 case TransactionManager.resetSessionTables :
@@ -948,9 +965,9 @@ class TransactionManagerCommon {
                     }
 
                     if (!targetSession.isInMidTransaction()) {
-                        targetSession.sessionData.persistentStoreCollection
-                            .clearAllTables();
+                        targetSession.sessionData.persistentStoreCollection.clearAllTables();
                     }
+
                     break;
 
                 case TransactionManager.resetSessionResetAll :
@@ -961,6 +978,7 @@ class TransactionManagerCommon {
                     if (!targetSession.isInMidTransaction()) {
                         targetSession.resetSession();
                     }
+
                     break;
 
                 case TransactionManager.resetSessionRollback :
@@ -975,11 +993,11 @@ class TransactionManagerCommon {
                             targetSession.rollbackNoCheck(true);
                         }
                     }
+
                     break;
 
                 case TransactionManager.resetSessionStatement :
-                    if (statementTimestamp
-                            != targetSession.statementStartSCN) {
+                    if (statementTimestamp != targetSession.statementStartSCN) {
                         break;
                     }
 
@@ -992,6 +1010,7 @@ class TransactionManagerCommon {
                             targetSession.latch.setCount(0);
                         }
                     }
+
                     break;
 
                 case TransactionManager.resetSessionClose :
@@ -1003,6 +1022,7 @@ class TransactionManagerCommon {
                         targetSession.rollbackNoCheck(true);
                         targetSession.close();
                     }
+
                     break;
             }
         } finally {
@@ -1012,10 +1032,10 @@ class TransactionManagerCommon {
 
     final void prepareReset(Session session) {
 
-        OrderedHashSet waitedSessions = session.waitedSessions;
+        OrderedHashSet<Session> waitedSessions = session.waitedSessions;
 
         for (int i = 0; i < waitedSessions.size(); i++) {
-            Session current = (Session) waitedSessions.get(i);
+            Session current = waitedSessions.get(i);
 
             current.waitingSessions.remove(session);
         }
