@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,7 +45,7 @@ import org.hsqldb.lib.OrderedHashSet;
  *
  * @author leptipre@users
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.1
+ * @version 2.7.3
  * @since 1.7.0
  */
 public class View extends TableDerived {
@@ -55,14 +55,10 @@ public class View extends TableDerived {
     //
     private HsqlName[] columnNames;
 
-    /**
-     * Names of SCHEMA objects referenced in VIEW
-     */
-    private OrderedHashSet schemaObjectNames;
+    /** Names of SCHEMA objects referenced in VIEW */
+    private OrderedHashSet<HsqlName> schemaObjectNames;
 
-    /**
-     * check option
-     */
+    /** check option */
     private int checkOption;
 
     //
@@ -85,21 +81,19 @@ public class View extends TableDerived {
         return SchemaObject.VIEW;
     }
 
-    public OrderedHashSet getReferences() {
+    public OrderedHashSet<HsqlName> getReferences() {
         return schemaObjectNames;
     }
 
-    public OrderedHashSet getComponents() {
-        return null;
-    }
-
     /**
      * Compiles the query expression and sets up the columns.
      */
     public void compile(Session session, SchemaObject parentObject) {
 
-        ParserDQL p = new ParserDQL(session, new Scanner(session, statement),
-                                    null);
+        ParserDQL p = new ParserDQL(
+            session,
+            new Scanner(session, statement),
+            null);
 
         p.isViewDefinition = true;
 
@@ -121,7 +115,9 @@ public class View extends TableDerived {
             }
 
             TableUtil.setColumnsInSchemaTable(
-                this, columnNames, queryExpression.getColumnTypes());
+                this,
+                columnNames,
+                queryExpression.getColumnTypes());
         }
 
         //
@@ -149,10 +145,13 @@ public class View extends TableDerived {
 
         StringBuilder sb = new StringBuilder(128);
 
-        sb.append(Tokens.T_CREATE).append(' ').append(Tokens.T_VIEW);
-        sb.append(' ');
-        sb.append(getName().getSchemaQualifiedStatementName()).append(' ');
-        sb.append('(');
+        sb.append(Tokens.T_CREATE)
+          .append(' ')
+          .append(Tokens.T_VIEW)
+          .append(' ')
+          .append(getName().getSchemaQualifiedStatementName())
+          .append(' ')
+          .append('(');
 
         int count = getColumnCount();
 
@@ -164,8 +163,11 @@ public class View extends TableDerived {
             }
         }
 
-        sb.append(')').append(' ').append(Tokens.T_AS).append(' ');
-        sb.append(getStatement());
+        sb.append(')')
+          .append(' ')
+          .append(Tokens.T_AS)
+          .append(' ')
+          .append(getStatement());
 
         return sb.toString();
     }
@@ -187,13 +189,11 @@ public class View extends TableDerived {
     }
 
     public boolean isInsertable() {
-        return isTriggerInsertable ? false
-                                   : super.isInsertable();
+        return !isTriggerInsertable && super.isInsertable();
     }
 
     public boolean isUpdatable() {
-        return isTriggerUpdatable ? false
-                                  : super.isUpdatable();
+        return !isTriggerUpdatable && super.isUpdatable();
     }
 
     void addTrigger(TriggerDef td, HsqlName otherName) {
@@ -276,8 +276,9 @@ public class View extends TableDerived {
         statement = sql;
     }
 
-    public TableDerived newDerivedTable(Session session,
-                                        CompileContext baseContext) {
+    public TableDerived newDerivedTable(
+            Session session,
+            CompileContext baseContext) {
 
         TableDerived td;
         ParserDQL    p = new ParserDQL(session, new Scanner(), baseContext);
