@@ -48,7 +48,7 @@ import org.hsqldb.cmdline.sqltool.Token;
 import org.hsqldb.cmdline.libclone.FrameworkLogger;
 import org.hsqldb.cmdline.utilclone.RCData;
 
-/* $Id: SqlTool.java 6559 2022-06-12 15:53:31Z fredt $ */
+/* $Id: SqlTool.java 6632 2022-11-20 21:35:32Z unsaved $ */
 
 /**
  * A command-line JDBC SQL tool supporting both interactive and
@@ -70,7 +70,7 @@ import org.hsqldb.cmdline.utilclone.RCData;
  * @see #main(String[])
  * @see #objectMain(String[])
  * @see SqlFile
- * @version $Revision: 6559 $, $Date: 2022-06-12 16:53:31 +0100 (Sun, 12 Jun 2022) $
+ * @version $Revision: 6632 $, $Date: 2022-11-20 21:35:32 +0000 (Sun, 20 Nov 2022) $
  * @author Blaine Simpson (blaine dot simpson at admc dot com)
  */
 public class SqlTool {
@@ -79,7 +79,7 @@ public class SqlTool {
     public static final String DEFAULT_RCFILE =
         System.getProperty("user.home") + "/sqltool.rc";
     // N.b. the following are static!
-    private static final String revString = "$Revision: 6559 $";
+    private static final String revString = "$Revision: 6632 $";
     private static final int revStringLength = revString.length();
     @SuppressWarnings("ConstantConditions")
     private static final String  revnum =
@@ -582,7 +582,7 @@ public class SqlTool {
                 }
 
                 while (i + 1 < arg.length) try {
-                    scriptFiles[scriptIndex] =
+                    scriptFiles[scriptIndex++] =
                       SqlFile.URL_WITH_PROTO_RE.matcher(arg[++i]).matches() ?
                         new URL(arg[i]) :
                         new URL("file", null, arg[i]);
