@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -54,7 +54,7 @@ import org.hsqldb.persist.PersistentStore;
  * DatabaseInformation implementations. <p>
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.3
  * @since 1.7.2
  */
 public class DatabaseInformation {
@@ -73,9 +73,9 @@ public class DatabaseInformation {
     static final int SYSTEM_TYPEINFO          = 10;
     static final int SYSTEM_UDTATTRIBUTES     = 11;
     static final int SYSTEM_UDTS              = 12;
-    static final int SYSTEM_USERS             = 13;    //-- ref in SqlFile only
-    static final int SYSTEM_VERSIONCOLUMNS    = 14;    //-- returns autogenerated columns
-    static final int SYSTEM_SEQUENCES = 15;            //-- same as SEQUENCES
+    static final int SYSTEM_USERS             = 13;    // ref in SqlFile only
+    static final int SYSTEM_VERSIONCOLUMNS    = 14;    // autogenerated columns
+    static final int SYSTEM_SEQUENCES         = 15;    // same as SEQUENCES
 
     // HSQLDB-specific
     static final int SYSTEM_CACHEINFO             = 16;
@@ -172,123 +172,123 @@ public class DatabaseInformation {
 
     /** system table names strictly in order of their ids */
     static final String[] sysTableNames = {
-        "SYSTEM_BESTROWIDENTIFIER",                              //
-        "SYSTEM_COLUMNS",                                        //
-        "SYSTEM_CROSSREFERENCE",                                 //
-        "SYSTEM_INDEXINFO",                                      //
-        "SYSTEM_PRIMARYKEYS",                                    //
-        "SYSTEM_PROCEDURECOLUMNS",                               //
-        "SYSTEM_PROCEDURES",                                     //
-        "SYSTEM_SCHEMAS",                                        //
-        "SYSTEM_TABLES",                                         //
-        "SYSTEM_TABLETYPES",                                     //
-        "SYSTEM_TYPEINFO",                                       //
-        "SYSTEM_UDTATTRIBUTES",                                           //
-        "SYSTEM_UDTS",                                           //
-        "SYSTEM_USERS",                                          //
-        "SYSTEM_VERSIONCOLUMNS",                                 //
-        "SYSTEM_SEQUENCES",                                      //
+        "SYSTEM_BESTROWIDENTIFIER",    //
+        "SYSTEM_COLUMNS",              //
+        "SYSTEM_CROSSREFERENCE",       //
+        "SYSTEM_INDEXINFO",            //
+        "SYSTEM_PRIMARYKEYS",          //
+        "SYSTEM_PROCEDURECOLUMNS",     //
+        "SYSTEM_PROCEDURES",           //
+        "SYSTEM_SCHEMAS",              //
+        "SYSTEM_TABLES",               //
+        "SYSTEM_TABLETYPES",           //
+        "SYSTEM_TYPEINFO",             //
+        "SYSTEM_UDTATTRIBUTES",        //
+        "SYSTEM_UDTS",                 //
+        "SYSTEM_USERS",                //
+        "SYSTEM_VERSIONCOLUMNS",       //
+        "SYSTEM_SEQUENCES",            //
 
         // HSQLDB-specific
-        "SYSTEM_CACHEINFO",                                      //
-        "SYSTEM_COLUMN_SEQUENCE_USAGE",                          //
-        "SYSTEM_COMMENTS",                                       //
-        "SYSTEM_CONNECTION_PROPERTIES",                          //
-        "SYSTEM_INDEXSTATS",                                     //
-        "SYSTEM_KEY_INDEX_USAGE",                                //
-        "SYSTEM_PROPERTIES",                                     //
-        "SYSTEM_SESSIONINFO",                                    //
-        "SYSTEM_SESSIONS",                                       //
-        "SYSTEM_TABLESTATS",                                     //
-        "SYSTEM_TEXTTABLES",                                     //
-        "SYSTEM_SYNONYMS",                                       //
+        "SYSTEM_CACHEINFO",                //
+        "SYSTEM_COLUMN_SEQUENCE_USAGE",    //
+        "SYSTEM_COMMENTS",                 //
+        "SYSTEM_CONNECTION_PROPERTIES",    //
+        "SYSTEM_INDEXSTATS",               //
+        "SYSTEM_KEY_INDEX_USAGE",          //
+        "SYSTEM_PROPERTIES",               //
+        "SYSTEM_SESSIONINFO",              //
+        "SYSTEM_SESSIONS",                 //
+        "SYSTEM_TABLESTATS",               //
+        "SYSTEM_TEXTTABLES",               //
+        "SYSTEM_SYNONYMS",                 //
 
         // SQL 200n
-        "ADMINISTRABLE_ROLE_AUTHORIZATIONS",                     //
-        "APPLICABLE_ROLES",                                      //
-        "ASSERTIONS",                                            //
-        "AUTHORIZATIONS",                                        //
-        "CHARACTER_SETS",                                        //
-        "CHECK_CONSTRAINT_ROUTINE_USAGE",                        //
-        "CHECK_CONSTRAINTS",                                     //
-        "COLLATIONS",                                            //
-        "COLUMN_COLUMN_USAGE",                                   //
-        "COLUMN_DOMAIN_USAGE",                                   //
-        "COLUMN_PRIVILEGES",                                     //
-        "COLUMN_UDT_USAGE",                                      //
-        "COLUMNS",                                               //
-        "CONSTRAINT_COLUMN_USAGE",                               //
-        "CONSTRAINT_PERIOD_USAGE",                               //
-        "CONSTRAINT_TABLE_USAGE",                                //
-        "DATA_TYPE_PRIVILEGES",                                  //
-        "DOMAIN_CONSTRAINTS",                                    //
-        "DOMAINS",                                               //
-        "ELEMENT_TYPES",                                         //
-        "ENABLED_ROLES",                                         //
-        "INFORMATION_SCHEMA_CATALOG_NAME",                       //
-        "JAR_JAR_USAGE",                                         //
-        "JARS",                                                  //
-        "KEY_COLUMN_USAGE",                                      //
-        "KEY_PERIOD_USAGE",                                      //
-        "METHOD_SPECIFICATIONS",                                 //
-        "MODULE_COLUMN_USAGE",                                   //
-        "MODULE_PRIVILEGES",                                     //
-        "MODULE_TABLE_USAGE",                                    //
-        "MODULES",                                               //
-        "PARAMETERS",                                            //
-        "PERIODS",                                               //
-        "REFERENTIAL_CONSTRAINTS",                               //
-        "ROLE_AUTHORIZATION_DESCRIPTORS",                        //
-        "ROLE_COLUMN_GRANTS",                                    //
-        "ROLE_MODULE_GRANTS",                                    //
-        "ROLE_ROUTINE_GRANTS",                                   //
-        "ROLE_TABLE_GRANTS",                                     //
-        "ROLE_UDT_GRANTS",                                       //
-        "ROLE_USAGE_GRANTS",                                     //
-        "ROUTINE_COLUMN_USAGE",                                  //
-        "ROUTINE_JAR_USAGE",                                     //
-        "ROUTINE_PERIOD_USAGE",                                  //
-        "ROUTINE_PRIVILEGES",                                    //
-        "ROUTINE_ROUTINE_USAGE",                                 //
-        "ROUTINE_SEQUENCE_USAGE",                                //
-        "ROUTINE_TABLE_USAGE",                                   //
-        "ROUTINES",                                              //
-        "SCHEMATA",                                              //
-        "SEQUENCES",                                             //
-        "SQL_FEATURES",                                          //
-        "SQL_IMPLEMENTATION_INFO",                               //
-        "SQL_PACKAGES",                                          //
-        "SQL_PARTS",                                             //
-        "SQL_SIZING",                                            //
-        "SQL_SIZING_PROFILES",                                   //
-        "TABLE_CONSTRAINTS",                                     //
-        "TABLE_PRIVILEGES",                                      //
-        "TABLES",                                                //
-        "TRANSLATIONS",                                          //
-        "TRIGGER_COLUMN_USAGE",                                  //
-        "TRIGGER_PERIOD_USAGE",                                  //
-        "TRIGGER_ROUTINE_USAGE",                                 //
-        "TRIGGER_SEQUENCE_USAGE",                                //
-        "TRIGGER_TABLE_USAGE",                                   //
-        "TRIGGERED_UPDATE_COLUMNS",                              //
-        "TRIGGERS",                                              //
-        "TYPE_JAR_USAGE",                                        //
-        "UDT_PRIVILEGES",                                        //
-        "USAGE_PRIVILEGES",                                      //
-        "USER_DEFINED_TYPES",                                    //
-        "VIEW_COLUMN_USAGE",                                     //
-        "VIEW_PERIOD_USAGE",                                     //
-        "VIEW_ROUTINE_USAGE",                                    //
-        "VIEW_TABLE_USAGE",                                      //
-        "VIEWS",                                                 //
+        "ADMINISTRABLE_ROLE_AUTHORIZATIONS",    //
+        "APPLICABLE_ROLES",                     //
+        "ASSERTIONS",                           //
+        "AUTHORIZATIONS",                       //
+        "CHARACTER_SETS",                       //
+        "CHECK_CONSTRAINT_ROUTINE_USAGE",       //
+        "CHECK_CONSTRAINTS",                    //
+        "COLLATIONS",                           //
+        "COLUMN_COLUMN_USAGE",                  //
+        "COLUMN_DOMAIN_USAGE",                  //
+        "COLUMN_PRIVILEGES",                    //
+        "COLUMN_UDT_USAGE",                     //
+        "COLUMNS",                              //
+        "CONSTRAINT_COLUMN_USAGE",              //
+        "CONSTRAINT_PERIOD_USAGE",              //
+        "CONSTRAINT_TABLE_USAGE",               //
+        "DATA_TYPE_PRIVILEGES",                 //
+        "DOMAIN_CONSTRAINTS",                   //
+        "DOMAINS",                              //
+        "ELEMENT_TYPES",                        //
+        "ENABLED_ROLES",                        //
+        "INFORMATION_SCHEMA_CATALOG_NAME",      //
+        "JAR_JAR_USAGE",                        //
+        "JARS",                                 //
+        "KEY_COLUMN_USAGE",                     //
+        "KEY_PERIOD_USAGE",                     //
+        "METHOD_SPECIFICATIONS",                //
+        "MODULE_COLUMN_USAGE",                  //
+        "MODULE_PRIVILEGES",                    //
+        "MODULE_TABLE_USAGE",                   //
+        "MODULES",                              //
+        "PARAMETERS",                           //
+        "PERIODS",                              //
+        "REFERENTIAL_CONSTRAINTS",              //
+        "ROLE_AUTHORIZATION_DESCRIPTORS",       //
+        "ROLE_COLUMN_GRANTS",                   //
+        "ROLE_MODULE_GRANTS",                   //
+        "ROLE_ROUTINE_GRANTS",                  //
+        "ROLE_TABLE_GRANTS",                    //
+        "ROLE_UDT_GRANTS",                      //
+        "ROLE_USAGE_GRANTS",                    //
+        "ROUTINE_COLUMN_USAGE",                 //
+        "ROUTINE_JAR_USAGE",                    //
+        "ROUTINE_PERIOD_USAGE",                 //
+        "ROUTINE_PRIVILEGES",                   //
+        "ROUTINE_ROUTINE_USAGE",                //
+        "ROUTINE_SEQUENCE_USAGE",               //
+        "ROUTINE_TABLE_USAGE",                  //
+        "ROUTINES",                             //
+        "SCHEMATA",                             //
+        "SEQUENCES",                            //
+        "SQL_FEATURES",                         //
+        "SQL_IMPLEMENTATION_INFO",              //
+        "SQL_PACKAGES",                         //
+        "SQL_PARTS",                            //
+        "SQL_SIZING",                           //
+        "SQL_SIZING_PROFILES",                  //
+        "TABLE_CONSTRAINTS",                    //
+        "TABLE_PRIVILEGES",                     //
+        "TABLES",                               //
+        "TRANSLATIONS",                         //
+        "TRIGGER_COLUMN_USAGE",                 //
+        "TRIGGER_PERIOD_USAGE",                 //
+        "TRIGGER_ROUTINE_USAGE",                //
+        "TRIGGER_SEQUENCE_USAGE",               //
+        "TRIGGER_TABLE_USAGE",                  //
+        "TRIGGERED_UPDATE_COLUMNS",             //
+        "TRIGGERS",                             //
+        "TYPE_JAR_USAGE",                       //
+        "UDT_PRIVILEGES",                       //
+        "USAGE_PRIVILEGES",                     //
+        "USER_DEFINED_TYPES",                   //
+        "VIEW_COLUMN_USAGE",                    //
+        "VIEW_PERIOD_USAGE",                    //
+        "VIEW_ROUTINE_USAGE",                   //
+        "VIEW_TABLE_USAGE",                     //
+        "VIEWS",                                //
     };
 
     /** Map: table name : table id */
-    static final IntValueHashMap sysTableNamesMap;
+    static final IntValueHashMap<String> sysTableNamesMap;
 
     static {
         synchronized (DatabaseInformation.class) {
-            sysTableNamesMap = new IntValueHashMap(107);
+            sysTableNamesMap = new IntValueHashMap<>(107);
 
             for (int i = 0; i < sysTableNames.length; i++) {
                 sysTableNamesMap.put(sysTableNames[i], i);
@@ -339,7 +339,8 @@ public class DatabaseInformation {
 
             return (DatabaseInformation) ctor.newInstance(ctorParms);
         } catch (Exception e) {
-            e.printStackTrace();
+
+            // e.printStackTrace();
         }
 
         return new DatabaseInformation(db);
@@ -369,12 +370,12 @@ public class DatabaseInformation {
     /**
      * Retrieves a table with the specified name whose content may depend on
      * the execution context indicated by the session argument as well as the
-     * current value of <code>withContent</code>. <p>
+     * current value of {@code withContent}. <p>
      *
      * @param session the context in which to produce the table
      * @param name the name of the table to produce
      * @return a table corresponding to the name and session arguments, or
-     *      <code>null</code> if there is no such table to be produced
+     *      {@code null} if there is no such table to be produced
      */
     public Table getSystemTable(Session session, String name) {
         return null;
@@ -383,8 +384,7 @@ public class DatabaseInformation {
     /**
      * Sets the store for the given session, populates the store if necessary.
      */
-    public void setStore(Session session, Table table,
-                         PersistentStore store) {}
+    public void setStore(Session session, Table table, PersistentStore store) {}
 
     /**
      * Switches this table producer between producing empty (surrogate)
