@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,6 +36,7 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.Reader;
 import java.io.Writer;
+
 import java.sql.Clob;
 import java.sql.SQLException;
 import java.sql.SQLFeatureNotSupportedException;
@@ -52,23 +53,23 @@ import org.hsqldb.types.ClobInputStream;
  * Instances of this class are returned by calls to ResultSet methods.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.1
+ * @version 2.7.4
  * @since HSQLDB 1.9.0
  */
 public class JDBCClobClient implements Clob {
 
     /**
-     * Retrieves the <code>CLOB</code> value designated by this
-     * <code>Clob</code> object as an ascii stream.
+     * Retrieves the {@code CLOB} value designated by this
+     * {@code Clob} object as an ascii stream.
      *
      * The ascii stream consists of the low ordre bytes of UTF-16 characters
      * in the clob. The question mark character is returnd for UTF-16 characters
      * beyond the range of 8-bit ASCII.
      *
-     * @return a <code>java.io.InputStream</code> object containing the
-     *   <code>CLOB</code> data
+     * @return a {@code java.io.InputStream} object containing the
+     *   {@code CLOB} data
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
     public synchronized InputStream getAsciiStream() throws SQLException {
 
@@ -77,7 +78,6 @@ public class JDBCClobClient implements Clob {
         return new InputStream() {
 
             private Reader reader = clob.getCharacterStream(session);
-
             public int read() throws IOException {
 
                 int c = reader.read();
@@ -96,7 +96,6 @@ public class JDBCClobClient implements Clob {
 
                 return c;
             }
-
             public int read(byte[] b, int off, int len) throws IOException {
 
                 if (b == null) {
@@ -133,11 +132,11 @@ public class JDBCClobClient implements Clob {
                     bytesRead++;
                 }
 
-                return bytesRead == 0 ? -1 : bytesRead;
+                return bytesRead == 0
+                       ? -1
+                       : bytesRead;
             }
-
             public void close() throws IOException {
-
                 try {
                     reader.close();
                 } catch (Exception ex) {}
@@ -146,36 +145,37 @@ public class JDBCClobClient implements Clob {
     }
 
     /**
-     * Retrieves the <code>CLOB</code> value designated by this
-     * <code>Clob</code> object as a <code>java.io.Reader</code> object (or
+     * Retrieves the {@code CLOB} value designated by this
+     * {@code Clob} object as a {@code java.io.Reader} object (or
      * as a stream of characters).
      *
-     * @return a <code>java.io.Reader</code> object containing the
-     *   <code>CLOB</code> data
+     * @return a {@code java.io.Reader} object containing the
+     *   {@code CLOB} data
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
     public synchronized Reader getCharacterStream() throws SQLException {
-
         checkClosed();
 
         return new ClobInputStream(session, clob, 0, length());
     }
 
     /**
-     * Retrieves a copy of the specified substring in the <code>CLOB</code>
-     * value designated by this <code>Clob</code> object.
+     * Retrieves a copy of the specified substring in the {@code CLOB}
+     * value designated by this {@code Clob} object.
      *
      * @param pos the first character of the substring to be extracted. The
      *   first character is at position 1.
      * @param length the number of consecutive characters to be copied
-     * @return a <code>String</code> that is the specified substring in the
-     *   <code>CLOB</code> value designated by this <code>Clob</code> object
+     * @return a {@code String} that is the specified substring in the
+     *   {@code CLOB} value designated by this {@code Clob} object
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
-    public synchronized String getSubString(long pos,
-            int length) throws SQLException {
+    public synchronized String getSubString(
+            long pos,
+            int length)
+            throws SQLException {
 
         checkClosed();
 
@@ -191,12 +191,12 @@ public class JDBCClobClient implements Clob {
     }
 
     /**
-     * Retrieves the number of characters in the <code>CLOB</code> value
-     * designated by this <code>Clob</code> object.
+     * Retrieves the number of characters in the {@code CLOB} value
+     * designated by this {@code Clob} object.
      *
-     * @return length of the <code>CLOB</code> in characters
+     * @return length of the {@code CLOB} in characters
      * @throws SQLException if there is an error accessing the length of the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
     public synchronized long length() throws SQLException {
 
@@ -211,8 +211,8 @@ public class JDBCClobClient implements Clob {
 
     /**
      * Retrieves the character position at which the specified substring
-     * <code>searchstr</code> appears in the SQL <code>CLOB</code> value
-     * represented by this <code>Clob</code> object.
+     * {@code searchstr} appears in the SQL {@code CLOB} value
+     * represented by this {@code Clob} object.
      *
      * @param searchstr the substring for which to search
      * @param start the position at which to begin searching; the first
@@ -220,10 +220,12 @@ public class JDBCClobClient implements Clob {
      * @return the position at which the substring appears or -1 if it is
      *   not present; the first position is 1
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
-    public synchronized long position(String searchstr,
-                                      long start) throws SQLException {
+    public synchronized long position(
+            String searchstr,
+            long start)
+            throws SQLException {
 
         checkClosed();
 
@@ -240,19 +242,21 @@ public class JDBCClobClient implements Clob {
 
     /**
      * Retrieves the character position at which the specified
-     * <code>Clob</code> object <code>searchstr</code> appears in this
-     * <code>Clob</code> object.
+     * {@code Clob} object {@code searchstr} appears in this
+     * {@code Clob} object.
      *
-     * @param searchstr the <code>Clob</code> object for which to search
+     * @param searchstr the {@code Clob} object for which to search
      * @param start the position at which to begin searching; the first
      *   position is 1
-     * @return the position at which the <code>Clob</code> object appears or
+     * @return the position at which the {@code Clob} object appears or
      *   -1 if it is not present; the first position is 1
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
-    public synchronized long position(Clob searchstr,
-                                      long start) throws SQLException {
+    public synchronized long position(
+            Clob searchstr,
+            long start)
+            throws SQLException {
 
         checkClosed();
 
@@ -274,35 +278,35 @@ public class JDBCClobClient implements Clob {
             throw JDBCUtil.outOfRangeArgument();
         }
 
-        return position(searchstr.getSubString(1, (int) searchstr.length()),
-                        start);
+        return position(
+            searchstr.getSubString(1, (int) searchstr.length()),
+            start);
     }
 
     /**
      * Retrieves a stream to be used to write Ascii characters to the
-     * <code>CLOB</code> value that this <code>Clob</code> object represents,
-     * starting at position <code>pos</code>.
+     * {@code CLOB} value that this {@code Clob} object represents,
+     * starting at position {@code pos}.
      *
      * The bytes written to the OutputStream are stored verbatim in the clob as
      * the low order bytes of UTF-16 characters.
      *
      * @param pos the position at which to start writing to this
-     *   <code>CLOB</code> object
+     *   {@code CLOB} object
      * @return the stream to which ASCII encoded characters can be written
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
-    public synchronized OutputStream setAsciiStream(final long pos)
-    throws SQLException {
+    public synchronized OutputStream setAsciiStream(
+            final long pos)
+            throws SQLException {
 
         return new OutputStream() {
 
             Writer writer = setCharacterStream(pos);
-
             public void write(int b) throws IOException {
                 writer.write(b & 0xff);
             }
-
             public void write(byte[] b, int off, int len) throws IOException {
 
                 if (b == null) {
@@ -325,7 +329,6 @@ public class JDBCClobClient implements Clob {
 
                 writer.write(charArray, 0, len);
             }
-
             public void close() throws IOException {
                 writer.close();
             }
@@ -334,17 +337,18 @@ public class JDBCClobClient implements Clob {
 
     /**
      * Retrieves a stream to be used to write a stream of Unicode characters
-     * to the <code>CLOB</code> value that this <code>Clob</code> object
-     * represents, at position <code>pos</code>.
+     * to the {@code CLOB} value that this {@code Clob} object
+     * represents, at position {@code pos}.
      *
      * @param pos the position at which to start writing to the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      * @return a stream to which Unicode encoded characters can be written
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
-    public synchronized Writer setCharacterStream(final long pos)
-    throws SQLException {
+    public synchronized Writer setCharacterStream(
+            final long pos)
+            throws SQLException {
 
         checkClosed();
 
@@ -362,28 +366,26 @@ public class JDBCClobClient implements Clob {
 
             private long    m_clobPosition = pos - 1;
             private boolean m_closed;
-
-            public void write(char[] cbuf, int off,
-                              int len) throws IOException {
+            public void write(
+                    char[] cbuf,
+                    int off,
+                    int len)
+                    throws IOException {
 
                 checkClosed();
                 clob.setChars(session, m_clobPosition, cbuf, off, len);
 
                 m_clobPosition += len;
             }
-
             public void flush() throws IOException {
 
                 // no-op
             }
-
             @Override
             public void close() throws IOException {
                 m_closed = true;
             }
-
             private void checkClosed() throws IOException {
-
                 if (m_closed || JDBCClobClient.this.isClosed()) {
                     throw new IOException("The stream is closed");
                 }
@@ -392,42 +394,48 @@ public class JDBCClobClient implements Clob {
     }
 
     /**
-     * Writes the given Java <code>String</code> to the <code>CLOB</code>
-     * value that this <code>Clob</code> object designates at the position
-     * <code>pos</code>.
+     * Writes the given Java {@code String} to the {@code CLOB}
+     * value that this {@code Clob} object designates at the position
+     * {@code pos}.
      *
      * @param pos the position at which to start writing to the
-     *   <code>CLOB</code> value that this <code>Clob</code> object
+     *   {@code CLOB} value that this {@code Clob} object
      *   represents
-     * @param str the string to be written to the <code>CLOB</code> value
-     *   that this <code>Clob</code> designates
+     * @param str the string to be written to the {@code CLOB} value
+     *   that this {@code Clob} designates
      * @return the number of characters written
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
-    public synchronized int setString(long pos,
-                                      String str) throws SQLException {
+    public synchronized int setString(
+            long pos,
+            String str)
+            throws SQLException {
         return setString(pos, str, 0, str.length());
     }
 
     /**
-     * Writes <code>len</code> characters of <code>str</code>, starting at
-     * character <code>offset</code>, to the <code>CLOB</code> value that
-     * this <code>Clob</code> represents.
+     * Writes {@code len} characters of {@code str}, starting at
+     * character {@code offset}, to the {@code CLOB} value that
+     * this {@code Clob} represents.
      *
      * @param pos the position at which to start writing to this
-     *   <code>CLOB</code> object
-     * @param str the string to be written to the <code>CLOB</code> value
-     *   that this <code>Clob</code> object represents
-     * @param offset the offset into <code>str</code> to start reading the
+     *   {@code CLOB} object
+     * @param str the string to be written to the {@code CLOB} value
+     *   that this {@code Clob} object represents
+     * @param offset the offset into {@code str} to start reading the
      *   characters to be written
      * @param len the number of characters to be written
      * @return the number of characters written
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
-    public synchronized int setString(long pos, String str, int offset,
-                                      int len) throws SQLException {
+    public synchronized int setString(
+            long pos,
+            String str,
+            int offset,
+            int len)
+            throws SQLException {
 
         checkClosed();
 
@@ -457,13 +465,13 @@ public class JDBCClobClient implements Clob {
     }
 
     /**
-     * Truncates the <code>CLOB</code> value that this <code>Clob</code>
-     * designates to have a length of <code>len</code> characters.
+     * Truncates the {@code CLOB} value that this {@code Clob}
+     * designates to have a length of {@code len} characters.
      *
-     * @param len the length, in bytes, to which the <code>CLOB</code> value
+     * @param len the length, in bytes, to which the {@code CLOB} value
      *   should be truncated
      * @throws SQLException if there is an error accessing the
-     *   <code>CLOB</code> value
+     *   {@code CLOB} value
      */
     public synchronized void truncate(long len) throws SQLException {
 
@@ -483,47 +491,48 @@ public class JDBCClobClient implements Clob {
     //------------------------- JDBC 4.0 -----------------------------------
 
     /**
-     * This method frees the <code>Clob</code> object and releases the resources
-     * that it holds.  The object is invalid once the <code>free</code> method
+     * This method frees the {@code Clob} object and releases the resources
+     * that it holds.  The object is invalid once the {@code free} method
      * is called.
      * <p>
-     * After <code>free</code> has been called, any attempt to invoke a
-     * method other than <code>free</code> will result in a <code>SQLException</code>
-     * being thrown.  If <code>free</code> is called multiple times, the subsequent
-     * calls to <code>free</code> are treated as a no-op.
-     * <p>
+     * After {@code free} has been called, any attempt to invoke a
+     * method other than {@code free} will result in a {@code SQLException}
+     * being thrown.  If {@code free} is called multiple times, the subsequent
+     * calls to {@code free} are treated as a no-op.
+     *
      * @throws SQLException if an error occurs releasing
      * the Clob's resources
      *
-     * @exception SQLFeatureNotSupportedException if the JDBC driver does not support
+     * @throws SQLFeatureNotSupportedException if the JDBC driver does not support
      * this method
      * @since JDK 1.6, HSQLDB 2.0
      */
     public synchronized void free() throws SQLException {
-
         isClosed = true;
         clob     = null;
         session  = null;
     }
 
     /**
-     * Returns a <code>Reader</code> object that contains a partial <code>Clob</code> value, starting
+     * Returns a {@code Reader} object that contains a partial {@code Clob} value, starting
      * with the character specified by pos, which is length characters in length.
      *
      * @param pos the offset to the first character of the partial value to
      * be retrieved.  The first character in the Clob is at position 1.
      * @param length the length in characters of the partial value to be retrieved.
-     * @return <code>Reader</code> through which the partial <code>Clob</code> value can be read.
+     * @return {@code Reader} through which the partial {@code Clob} value can be read.
      * @throws SQLException if pos is less than 1 or if pos is greater than the number of
-     * characters in the <code>Clob</code> or if pos + length is greater than the number of
-     * characters in the <code>Clob</code>
+     * characters in the {@code Clob} or if pos + length is greater than the number of
+     * characters in the {@code Clob}
      *
-     * @exception SQLFeatureNotSupportedException if the JDBC driver does not support
+     * @throws SQLFeatureNotSupportedException if the JDBC driver does not support
      * this method
      * @since JDK 1.6, HSQLDB 2.0
      */
-    public synchronized Reader getCharacterStream(long pos,
-            long length) throws SQLException {
+    public synchronized Reader getCharacterStream(
+            long pos,
+            long length)
+            throws SQLException {
 
         checkClosed();
 
@@ -566,7 +575,6 @@ public class JDBCClobClient implements Clob {
     }
 
     public synchronized void setWritable(JDBCResultSet result, int index) {
-
         isWritable = true;
         resultSet  = result;
         colIndex   = index;
@@ -593,17 +601,20 @@ public class JDBCClobClient implements Clob {
 
         resultSet.preparedStatement.parameterValues[colIndex] = clob;
         resultSet.preparedStatement.parameterSet[colIndex]    = true;
+        resultSet.isRowUpdated                                = true;
     }
 
     private void checkClosed() throws SQLException {
-
         if (isClosed) {
             throw JDBCUtil.sqlException(ErrorCode.X_0F502);
         }
     }
 
     static boolean isInLimits(long fullLength, long pos, long len) {
-        return fullLength >= 0 && pos >= 0 && len >= 0
+
+        return fullLength >= 0
+               && pos >= 0
+               && len >= 0
                && pos <= fullLength - len;
     }
 }
