@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,17 +32,21 @@
 package org.hsqldb.jdbc;
 
 import java.io.PrintWriter;
+
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.SQLFeatureNotSupportedException;
 import java.sql.Wrapper;
+
 import java.util.Arrays;
 import java.util.Properties;
 import java.util.concurrent.atomic.AtomicIntegerArray;
+
 import javax.naming.NamingException;
 import javax.naming.Reference;
 import javax.naming.Referenceable;
 import javax.naming.StringRefAddr;
+
 import javax.sql.ConnectionEvent;
 import javax.sql.ConnectionEventListener;
 import javax.sql.DataSource;
@@ -59,7 +63,7 @@ import org.hsqldb.jdbc.pool.JDBCPooledDataSource;
  *
  * <!-- start Release-specific documentation -->
  * <div class="ReleaseSpecificDocumentation">
- * <h1>HSQLDB-Specific Information:</h1> <p>
+ * <p class="rshead">HSQLDB-Specific Information:</p>
  *
  * A connection pool for HyperSQL connections. This implementation of
  * {@link javax.sql.DataSource DataSource} is dedicated to HyperSQL and
@@ -68,17 +72,17 @@ import org.hsqldb.jdbc.pool.JDBCPooledDataSource;
  *
  * The methods of the parent class,
  * {@link JDBCCommonDataSource} are used to specify the database URL, user,
- * password, and / or connection properties.<p>
+ * password, and / or connection properties.
  *
  * </div>
  * <!-- end Release-specific documentation -->
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.3.4
- * @since 2.2.9
+ * @version 2.7.3
+ * @since HSQLDB 2.2.9
  */
 @SuppressWarnings("serial")
-public class JDBCPool implements DataSource,
-                   Referenceable, ConnectionEventListener,
+public class JDBCPool
+        implements DataSource, Referenceable, ConnectionEventListener,
                    StatementEventListener, Wrapper {
 
     /**
@@ -86,13 +90,13 @@ public class JDBCPool implements DataSource,
      * set.
      *
      * @return  a connection to the data source
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public Connection getConnection() throws SQLException {
 
         int retries = 300;
 
-        if (source.loginTimeout != 0){
+        if (source.loginTimeout != 0) {
             retries = source.loginTimeout * 10;
         }
 
@@ -102,19 +106,22 @@ public class JDBCPool implements DataSource,
 
         for (int count = 0; count < retries; count++) {
             for (int i = 0; i < states.length(); i++) {
-                if (states.compareAndSet(i, RefState.available,
-                                        RefState.allocated)) {
+                if (states.compareAndSet(i,
+                                         RefState.available,
+                                         RefState.allocated)) {
                     return connections[i].getConnection();
                 }
 
-                if (states.compareAndSet(i, RefState.empty,
-                                        RefState.allocated)) {
+                if (states.compareAndSet(i,
+                                         RefState.empty,
+                                         RefState.allocated)) {
                     try {
                         JDBCPooledConnection connection =
                             (JDBCPooledConnection) source.getPooledConnection();
 
                         connection.addConnectionEventListener(this);
                         connection.addStatementEventListener(this);
+
                         connections[i] = connection;
 
                         return connections[i].getConnection();
@@ -145,9 +152,11 @@ public class JDBCPool implements DataSource,
      *  being made
      * @param password the user's password
      * @return  a connection to the data source
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
-    public Connection getConnection(String username, String password)
+    public Connection getConnection(
+            String username,
+            String password)
             throws SQLException {
 
         String user = getUser();
@@ -156,7 +165,7 @@ public class JDBCPool implements DataSource,
             throw JDBCUtil.nullArgument();
         }
 
-        if ( user == null) {
+        if (user == null) {
             setUser(username);
             setPassword(password);
         } else if (!user.equals(username)) {
@@ -177,9 +186,9 @@ public class JDBCPool implements DataSource,
      * or a proxy for the receiver. If the receiver is a wrapper
      * and the wrapped object implements the interface then the result is the
      * wrapped object or a proxy for the wrapped object. Otherwise return the
-     * result of calling <code>unwrap</code> recursively on the wrapped object
+     * result of calling {@code unwrap} recursively on the wrapped object
      * or a proxy for that result. If the receiver is not a
-     * wrapper and does not implement the interface, then an <code>SQLException</code> is thrown.
+     * wrapper and does not implement the interface, then an {@code SQLException} is thrown.
      *
      * @param iface A Class defining an interface that the result must implement.
      * @return an object that implements the interface. May be a proxy for the actual implementing object.
@@ -187,7 +196,8 @@ public class JDBCPool implements DataSource,
      * @since JDK 1.6, HSQLDB 2.0
      */
     @SuppressWarnings("unchecked")
-    public <T>T unwrap(java.lang.Class<T> iface) throws java.sql.SQLException {
+    public <T> T unwrap(java.lang.Class<T> iface) throws java.sql.SQLException {
+
         if (isWrapperFor(iface)) {
             return (T) this;
         }
@@ -198,11 +208,11 @@ public class JDBCPool implements DataSource,
     /**
      * Returns true if this either implements the interface argument or is directly or indirectly a wrapper
      * for an object that does. Returns false otherwise. If this implements the interface then return true,
-     * else if this is a wrapper then return the result of recursively calling <code>isWrapperFor</code> on the wrapped
+     * else if this is a wrapper then return the result of recursively calling {@code isWrapperFor} on the wrapped
      * object. If this does not implement the interface and is not a wrapper, return false.
-     * This method should be implemented as a low-cost operation compared to <code>unwrap</code> so that
-     * callers can use this method to avoid expensive <code>unwrap</code> calls that may fail. If this method
-     * returns true then calling <code>unwrap</code> with the same argument should succeed.
+     * This method should be implemented as a low-cost operation compared to {@code unwrap} so that
+     * callers can use this method to avoid expensive {@code unwrap} calls that may fail. If this method
+     * returns true then calling {@code unwrap} with the same argument should succeed.
      *
      * @param iface a Class defining an interface.
      * @return true if this implements the interface or directly or indirectly wraps an object that does.
@@ -210,7 +220,8 @@ public class JDBCPool implements DataSource,
      * for an object with the given interface.
      * @since JDK 1.6, HSQLDB 2.0
      */
-    public boolean isWrapperFor(java.lang.Class<?> iface)
+    public boolean isWrapperFor(
+            java.lang.Class<?> iface)
             throws java.sql.SQLException {
         return ((iface != null) && iface.isAssignableFrom(this.getClass()));
     }
@@ -219,43 +230,50 @@ public class JDBCPool implements DataSource,
      * Retrieves the Reference of this object.
      *
      * @return The non-null Reference of this object.
-     * @exception NamingException If a naming exception was encountered
+     * @throws NamingException If a naming exception was encountered
      *          while retrieving the reference.
      */
     public Reference getReference() throws NamingException {
+
         String    cname = "org.hsqldb.jdbc.JDBCDataSourceFactory";
         Reference ref   = new Reference(getClass().getName(), cname, null);
 
         ref.add(new StringRefAddr("database", source.getDatabase()));
         ref.add(new StringRefAddr("user", source.getUser()));
         ref.add(new StringRefAddr("password", source.password));
-        ref.add(new StringRefAddr("loginTimeout",
-                                  Integer.toString(source.loginTimeout)));
-        ref.add(new StringRefAddr("poolSize", Integer.toString(connections.length)));
+        ref.add(
+            new StringRefAddr("loginTimeout",
+                              Integer.toString(source.loginTimeout)));
+        ref.add(
+            new StringRefAddr("poolSize",
+                              Integer.toString(connections.length)));
 
         return ref;
     }
 
     // ------------------------ event listener ------------------------
     public void connectionClosed(ConnectionEvent event) {
+
         PooledConnection connection = (PooledConnection) event.getSource();
 
         for (int i = 0; i < connections.length; i++) {
             if (connections[i] == connection) {
                 states.set(i, RefState.available);
-
                 break;
             }
         }
     }
 
     public void connectionErrorOccurred(ConnectionEvent event) {
+
         PooledConnection connection = (PooledConnection) event.getSource();
 
         for (int i = 0; i < connections.length; i++) {
             if (connections[i] == connection) {
                 states.set(i, RefState.allocated);
+
                 connections[i] = null;
+
                 states.set(i, RefState.empty);
                 break;
             }
@@ -266,10 +284,10 @@ public class JDBCPool implements DataSource,
 
     public void statementErrorOccurred(StatementEvent event) {}
 
-
     // ------------------------ event listener ------------------------
+
     /**
-     * <p>Retrieves the log writer for this <code>DataSource</code>
+     * <p>Retrieves the log writer for this {@code DataSource}
      * object.
      *
      * <p>The log writer is a character output stream to which all logging
@@ -278,14 +296,14 @@ public class JDBCPool implements DataSource,
      * object, messages printed by methods of other objects manufactured
      * by this object, and so on.  Messages printed to a data source
      * specific log writer are not printed to the log writer associated
-     * with the <code>java.sql.DriverManager</code> class.  When a
-     * <code>DataSource</code> object is
+     * with the {@code java.sql.DriverManager} class.  When a
+     * {@code DataSource} object is
      * created, the log writer is initially null; in other words, the
      * default is for logging to be disabled.
      *
      * @return the log writer for this data source or null if
      *        logging is disabled
-     * @exception java.sql.SQLException if a database access error occurs
+     * @throws java.sql.SQLException if a database access error occurs
      * @see #setLogWriter
      * @since 1.4
      */
@@ -294,8 +312,8 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * <p>Sets the log writer for this <code>DataSource</code>
-     * object to the given <code>java.io.PrintWriter</code> object.
+     * <p>Sets the log writer for this {@code DataSource}
+     * object to the given {@code java.io.PrintWriter} object.
      *
      * <p>The log writer is a character output stream to which all logging
      * and tracing messages for this data source will be
@@ -303,13 +321,13 @@ public class JDBCPool implements DataSource,
      * object, messages printed by methods of other objects manufactured
      * by this object, and so on.  Messages printed to a data source-
      * specific log writer are not printed to the log writer associated
-     * with the <code>java.sql.DriverManager</code> class. When a
-     * <code>DataSource</code> object is created the log writer is
+     * with the {@code java.sql.DriverManager} class. When a
+     * {@code DataSource} object is created the log writer is
      * initially null; in other words, the default is for logging to be
      * disabled.
      *
      * @param out the new log writer; to disable logging, set to null
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      * @see #getLogWriter
      * @since 1.4
      */
@@ -322,11 +340,11 @@ public class JDBCPool implements DataSource,
      * while attempting to connect to a database.  A value of zero
      * specifies that the timeout is the default system timeout
      * if there is one; otherwise, it specifies that there is no timeout.
-     * When a <code>DataSource</code> object is created, the login timeout is
+     * When a {@code DataSource} object is created, the login timeout is
      * initially zero.
      *
      * @param seconds the data source login time limit
-     * @exception SQLException if a database access error occurs.
+     * @throws SQLException if a database access error occurs.
      * @see #getLoginTimeout
      * @since 1.4
      */
@@ -339,11 +357,11 @@ public class JDBCPool implements DataSource,
      * while attempting to connect to a database.  A value of zero
      * means that the timeout is the default system timeout
      * if there is one; otherwise, it means that there is no timeout.
-     * When a <code>DataSource</code> object is created, the login timeout is
+     * When a {@code DataSource} object is created, the login timeout is
      * initially zero.
      *
      * @return the data source login time limit
-     * @exception SQLException if a database access error occurs.
+     * @throws SQLException if a database access error occurs.
      * @see #setLoginTimeout
      * @since 1.4
      */
@@ -354,7 +372,7 @@ public class JDBCPool implements DataSource,
     // ------------------------ custom public methods ------------------------
 
     /**
-     * Retrieves the description of the data source. <p>
+     * Retrieves the description of the data source.
      *
      * @return the description
      */
@@ -363,7 +381,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Retrieves the name of the data source. <p>
+     * Retrieves the name of the data source.
      *
      * @return the description
      */
@@ -390,7 +408,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Retrieves the jdbc database connection url attribute. <p>
+     * Retrieves the jdbc database connection url attribute.
      *
      * @return the jdbc database connection url attribute
      */
@@ -399,7 +417,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Retrieves the jdbc database connection url attribute. <p>
+     * Retrieves the jdbc database connection url attribute.
      *
      * @return the jdbc database connection url attribute
      */
@@ -408,7 +426,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Retrieves the user name for the connection. <p>
+     * Retrieves the user name for the connection.
      *
      * @return the username for the connection
      */
@@ -417,7 +435,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Synonym for setUrl(String). <p>
+     * Synonym for setUrl(String).
      *
      * @param databaseName the new value for the attribute
      */
@@ -426,7 +444,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Synonym for setUrl(String). <p>
+     * Synonym for setUrl(String).
      *
      * @param database the new value for the attribute
      */
@@ -435,7 +453,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Sets the jdbc database URL. <p>
+     * Sets the jdbc database URL.
      *
      * @param url the new value of this object's jdbc database connection
      *      url attribute
@@ -445,7 +463,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Sets the jdbc database URL. <p>
+     * Sets the jdbc database URL.
      *
      * @param url the new value of this object's jdbc database connection
      *      url attribute
@@ -455,7 +473,7 @@ public class JDBCPool implements DataSource,
     }
 
     /**
-     * Sets the password for the user name.
+     * Sets the password for the username.
      *
      * @param password the password
      */
@@ -494,12 +512,12 @@ public class JDBCPool implements DataSource,
      * In the worst case, this may be the root Logger.
      *
      * @return the parent Logger for this data source
-     * @throws SQLFeatureNotSupportedException if the data source does not use <code>java.util.logging</code>.
-     * @since JDK 1.7 M11 2010/09/10 (b123), HSQLDB 2.2.9
+     * @throws SQLFeatureNotSupportedException if the data source does not use {@code java.util.logging}.
+     * @since JDK 1.7, HSQLDB 2.2.9
      */
     public java.util.logging.Logger getParentLogger()
-    throws java.sql.SQLFeatureNotSupportedException {
-        throw (java.sql.SQLFeatureNotSupportedException) JDBCUtil.notSupported();
+            throws java.sql.SQLFeatureNotSupportedException {
+        throw(java.sql.SQLFeatureNotSupportedException) JDBCUtil.notSupported();
     }
 
     // ------------------------ custom public methods ------------------------
@@ -519,9 +537,10 @@ public class JDBCPool implements DataSource,
      * @param size int maximum size of the pool
      */
     public JDBCPool(int size) {
-        source = new JDBCPooledDataSource();
+        source      = new JDBCPooledDataSource();
         connections = new JDBCPooledConnection[size];
-        states = new AtomicIntegerArray(size);    }
+        states      = new AtomicIntegerArray(size);
+    }
 
     /**
      * Closes the pool immediately. Waits the given number of seconds before
@@ -532,9 +551,10 @@ public class JDBCPool implements DataSource,
      */
     public void close(int wait) throws SQLException {
 
-        if (wait <0 || wait > 60) {
+        if (wait < 0 || wait > 60) {
             throw JDBCUtil.outOfRangeArgument();
         }
+
         if (closed) {
             return;
         }
@@ -553,16 +573,17 @@ public class JDBCPool implements DataSource,
 
         Arrays.fill(connections, null);
     }
+
     // ------------------------ internal ------------------------
     interface RefState {
+
         int empty     = 0;
         int available = 1;
         int allocated = 2;
     }
 
-
-    AtomicIntegerArray       states;
-    JDBCPooledConnection[]   connections;
-    JDBCPooledDataSource     source;
-    volatile boolean         closed;
+    AtomicIntegerArray     states;
+    JDBCPooledConnection[] connections;
+    JDBCPooledDataSource   source;
+    volatile boolean       closed;
 }
