@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,28 +40,22 @@ import org.hsqldb.types.IntervalType;
 import org.hsqldb.types.Type;
 import org.hsqldb.types.Types;
 
-/* $Id: JDBCResultSetMetaData.java 6492 2022-04-21 07:30:40Z fredt $ */
-
 // fredt@users    - 20040412 - removed DITypeInfo dependencies
 // campbell-burnet@users - 200404xx - removed unused imports;refinement for better
 //                             usability of getColumnDisplaySize;
 //                             javadoc updates
 // campbell-burnet@users - 20051207 - patch 1.8.0.x initial JDBC 4.0 support work
-// campbell-burnet@users - 20060522 - doc   1.9.0 full synch up to Mustang Build 84
+// campbell-burnet@users - 20060522 - doc   1.9.0 full synch up to JAVA 1.6 (Mustang) Build 84
 // fredt@users - 1.9.0 usage of types and new ResultMetadata and ColumnMetaData
 // Revision 1.15  2006/07/12 12:29:42  boucherb
-// patch 1.9.0
-// - full synch up to Mustang b90
-// - minor update to toString
 
 /**
- * <!-- start generic documentation -->
  * An object that can be used to get information about the types
- * and properties of the columns in a <code>ResultSet</code> object.
- * The following code fragment creates the <code>ResultSet</code> object rs,
- * creates the <code>ResultSetMetaData</code> object rsmd, and uses rsmd
+ * and properties of the columns in a {@code ResultSet} object.
+ * The following code fragment creates the {@code ResultSet} object rs,
+ * creates the {@code ResultSetMetaData} object rsmd, and uses rsmd
  * to find out how many columns rs has and whether the first column in rs
- * can be used in a <code>WHERE</code> clause.
+ * can be used in a {@code WHERE} clause.
  * <PRE>
  *
  *     ResultSet rs = stmt.executeQuery("SELECT a, b, c FROM TABLE2");
@@ -70,11 +64,10 @@ import org.hsqldb.types.Types;
  *     boolean b = rsmd.isSearchable(1);
  *
  * </PRE>
- * <!-- end generic documentation -->
  *
  * <!-- start Release-specific documentation -->
  * <div class="ReleaseSpecificDocumentation">
- * <h1>HSQLDB-Specific Information:</h1> <p>
+ * <p class="rshead">HSQLDB-Specific Information:</p>
  *
  * HSQLDB supports a subset of the {@code ResultSetMetaData} interface.<p>
  *
@@ -90,13 +83,13 @@ import org.hsqldb.types.Types;
  * speed, accuracy, jar-footprint and retention of JDBC resources. <p>
  *
  * (fredt@users) <br>
- * (campbell-burnet@users)<p>
+ * (campbell-burnet@users)
  * </div>
  * <!-- end release-specific documentation -->
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.2.6
+ * @version 2.7.3
  * @see JDBCStatement#executeQuery
  * @see JDBCStatement#getResultSet
  * @see java.sql.ResultSetMetaData
@@ -104,26 +97,21 @@ import org.hsqldb.types.Types;
 public class JDBCResultSetMetaData implements ResultSetMetaData {
 
     /**
-     * <!-- start generic documentation -->
-     * Returns the number of columns in this <code>ResultSet</code> object.
+     * Returns the number of columns in this {@code ResultSet} object.
      *
-     * <!-- end generic documentation -->
      * @return the number of columns
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public int getColumnCount() throws SQLException {
         return resultMetaData.getColumnCount();
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates whether the designated column is automatically numbered.
-     * <p>(JDBC4 deleted:)[, thus read-only.]
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 2.0 fully supports SQL Standard features T174 and T176 that
      * define identity column support.
@@ -141,30 +129,27 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      *
      * Simply, an auto-increment column is one that guarantees it has a
      * autogenerated value after a successful insert or update operation,
-     * even if no value is supplied, or DEFAULT is specified.<p>
+     * even if no value is supplied, or DEFAULT is specified.
      *
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return <code>true</code> if so; <code>false</code> otherwise
-     * @exception SQLException if a database access error occurs
+     * @return {@code true} if so; {@code false} otherwise
+     * @throws SQLException if a database access error occurs
      */
     public boolean isAutoIncrement(int column) throws SQLException {
-
         checkColumn(column);
 
         return resultMetaData.columns[--column].isIdentity();
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates whether a column's case matters.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 1.7.1 did not report this value accurately.  <p>
      *
@@ -173,14 +158,14 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * This method returns true for any column whose data type is a character
      * type, with the exception of VARCHAR_IGNORECASE for which it returns
      * false. It also returns false for any column whose data type is a
-     * not a character data type. <p>
+     * not a character data type.
      *
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return <code>true</code> if so; <code>false</code> otherwise
-     * @exception SQLException if a database access error occurs
+     * @return {@code true} if so; {@code false} otherwise
+     * @throws SQLException if a database access error occurs
      */
     public boolean isCaseSensitive(int column) throws SQLException {
 
@@ -196,13 +181,11 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates whether the designated column can be used in a where clause.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 2.0 handles this differently from previous versions. <p>
      *
@@ -213,34 +196,31 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return <code>true</code> if so; <code>false</code> otherwise
-     * @exception SQLException if a database access error occurs
+     * @return {@code true} if so; {@code false} otherwise
+     * @throws SQLException if a database access error occurs
      */
     public boolean isSearchable(int column) throws SQLException {
-
         checkColumn(column);
 
         return resultMetaData.columns[--column].isSearchable();
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates whether the designated column is a cash value.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 2.0 fully supports this feature and returns true for
-     * NUMERIC and DECIMAL columns. <p>
+     * NUMERIC and DECIMAL columns.
      *
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return <code>true</code> if so; <code>false</code> otherwise
-     * @exception SQLException if a database access error occurs
+     * @return {@code true} if so; {@code false} otherwise
+     * @throws SQLException if a database access error occurs
      */
     public boolean isCurrency(int column) throws SQLException {
 
@@ -249,17 +229,16 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
         Type type = translateType(resultMetaData.columnTypes[--column]);
 
         return (type.typeCode == Types.SQL_DECIMAL
-                || type.typeCode == Types.SQL_NUMERIC) && type.scale > 0;
+                || type.typeCode == Types.SQL_NUMERIC)
+               && type.scale > 0;
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates the nullability of values in the designated column.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 2.2 fully supports this feature.  <p>
      *
@@ -279,34 +258,31 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return the nullability status of the given column; one of <code>columnNoNulls</code>,
-     *          <code>columnNullable</code> or <code>columnNullableUnknown</code>
-     * @exception SQLException if a database access error occurs
+     * @return the nullability status of the given column; one of {@code columnNoNulls},
+     *          {@code columnNullable} or {@code columnNullableUnknown}
+     * @throws SQLException if a database access error occurs
      */
     public int isNullable(int column) throws SQLException {
-
         checkColumn(column);
 
         return resultMetaData.columns[--column].getNullability();
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates whether values in the designated column are signed numbers.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
-     * HSQLDB 2.0 fully supports this feature.  <p>
+     * HSQLDB 2.0 fully supports this feature.
      *
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return <code>true</code> if so; <code>false</code> otherwise
-     * @exception SQLException if a database access error occurs
+     * @return {@code true} if so; {@code false} otherwise
+     * @throws SQLException if a database access error occurs
      */
     public boolean isSigned(int column) throws SQLException {
 
@@ -318,13 +294,11 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates the designated column's normal maximum width in characters.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 2.0 fully supports this feature.  <p>
      *
@@ -348,7 +322,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      *           32766 (0x7FFE) (tested usable/accepted by most tools and
      *           compatible with assumptions made by java.io read/write
      *           UTF) when the system property is not defined or is not
-     *           accessible, due to security constraints. <p>
+     *           accessible, due to security constraints.
      *
      *      </ul>
      *
@@ -376,7 +350,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      *     The maximum length/precision, respectively, as reported by
      *     DatabaseMetaData.getTypeInfo(), when applicable.  If the maximum
      *     display size is unknown, unknowable or inapplicable, then zero is
-     *     returned. <p>
+     *     returned.
      *
      * </ol>
      *
@@ -386,7 +360,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * @param column the first column is 1, the second is 2, ...
      * @return the normal maximum number of characters allowed as the width
      *          of the designated column
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public int getColumnDisplaySize(int column) throws SQLException {
 
@@ -398,17 +372,15 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * <!-- start generic documentation -->
      * Gets the designated column's suggested title for use in printouts and
-     * displays. (JDBC4 clarification:) The suggested title is usually specified by the SQL <code>AS</code>
-     * clause.  If a SQL <code>AS</code> is not specified, the value returned from
-     * <code>getColumnLabel</code> will be the same as the value returned by the
-     * <code>getColumnName</code> method.
-     * <!-- end generic documentation -->
+     * displays. The suggested title is usually specified by the SQL {@code AS}
+     * clause.  If a SQL {@code AS} is not specified, the value returned from
+     * {@code getColumnLabel} will be the same as the value returned by the
+     * {@code getColumnName} method.
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * In HSQLDB, a {@code ResultSet} column label is determined using the
      * following order of precedence:
@@ -417,14 +389,14 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * <LI>The label (alias) specified in the generating query.</LI>
      * <LI>The name of the underlying column, if no label is specified.<br>
      * <LI>C1, C2, etc. for computed columns that have no label.</LI>
-     * </OL> <p>
+     * </OL>
      *
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
      * @return the suggested column title
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public String getColumnLabel(int column) throws SQLException {
 
@@ -440,13 +412,11 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * <!-- start generic documentation -->
      * Get the designated column's name.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * In HSQLDB, a ResultSet column name is determined using the following
      * order of precedence:
@@ -458,16 +428,16 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * <LI>C1, C2, etc. for computed columns that have no label.</LI>
      * </OL> <p>
      *
-     * If the <code>jdbc.get_column_name</code> property of the JDBC Connection
+     * If the {@code jdbc.get_column_name} property of the JDBC Connection
      * has been set to false, this method returns the same value as
-     * {@link #getColumnLabel(int)}.<p>
+     * {@link #getColumnLabel(int)}.
      *
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
      * @return column name
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public String getColumnName(int column) throws SQLException {
 
@@ -483,18 +453,17 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
 
         String label = resultMetaData.columnLabels[column];
 
-        return label == null ? resultMetaData.columns[column].getNameString()
-                             : label;
+        return label == null
+               ? resultMetaData.columns[column].getNameString()
+               : label;
     }
 
     /**
-     * <!-- start generic documentation -->
      * Get the designated column's table's schema.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * Since 1.8.0.x, HSQLDB implements standard SQL SCHEMA support;
      * this method returns the actual schema of the column's table.
@@ -504,7 +473,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      *
      * @param column the first column is 1, the second is 2, ...
      * @return schema name or "" if not applicable
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public String getSchemaName(int column) throws SQLException {
 
@@ -512,66 +481,63 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
 
         String name = resultMetaData.columns[--column].getSchemaNameString();
 
-        return name == null ? ""
-                            : name;
+        return name == null
+               ? ""
+               : name;
     }
 
     /**
-     * <!-- start generic documentation -->
-     * (JDBC4 clarification:)
      * Get the designated column's specified column size.
      * For numeric data, this is the maximum precision.  For character data, this is the [maximum] length in characters.
      * For datetime datatypes, this is the [maximum] length in characters of the String representation (assuming the
      * maximum allowed precision of the fractional seconds component). For binary data, this is the [maximum] length in bytes.  For the ROWID datatype,
-     * this is the length in bytes[, as returned by the implementation-specific java.sql.RowId.getBytes() method]. 0 is returned for data types where the
+     * this is the length in bytes. 0 is returned for data types where the
      * column size is not applicable.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 2.0 reports the correct length or precision for
      * all columns. For DOUBLE, the binary precision of 64 is returned, while
-     * for other numeric types the decimal precision is returned.<p>
+     * for other numeric types the decimal precision is returned.
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
      * @return precision
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public int getPrecision(int column) throws SQLException {
 
         checkColumn(column);
 
         // type in columnTypes overrides column type
-        Type type      = translateType(resultMetaData.columnTypes[--column]);
+        Type type = translateType(resultMetaData.columnTypes[--column]);
+
         return type.getJDBCPrecision();
     }
 
     /**
-     * <!-- start generic documentation -->
      * Gets the designated column's number of digits to right of the decimal point.
      * 0 is returned for data types where the scale is not applicable.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 2.0 reports the correct scale for all columns.<p>
      *
      * For datetime and interval types such as Timestamp or Time, the
      * fractional second precision is reported.<p>
      *
-     * The reported scale for INTEGER, BIGINT and DOUBLE is 0<p>
+     * The reported scale for INTEGER, BIGINT and DOUBLE is 0.
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
      * @return scale
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public int getScale(int column) throws SQLException {
 
@@ -583,13 +549,11 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * <!-- start generic documentation -->
      * Gets the designated column's table name.
      *
-     * <!-- end generic documentation -->
      * @param column the first column is 1, the second is 2, ...
      * @return table name or "" if not applicable
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public String getTableName(int column) throws SQLException {
 
@@ -597,18 +561,17 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
 
         String name = resultMetaData.columns[--column].getTableNameString();
 
-        return name == null ? ""
-                            : name;
+        return name == null
+               ? ""
+               : name;
     }
 
     /**
-     * <!-- start generic documentation -->
      * Gets the designated column's table's catalog name.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * From 2.0, HSQLDB returns the name of the catalog. The default name is
      * PUBLIC.
@@ -622,7 +585,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * <p>
      *
      * For greater detail, see discussion at:
-     * {@link JDBCDatabaseMetaData}. <p>
+     * {@link JDBCDatabaseMetaData}.
      *
      * </div>
      * <!-- end release-specific documentation -->
@@ -630,7 +593,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * @param column the first column is 1, the second is 2, ...
      * @return the name of the catalog for the table in which the given column
      *          appears or "" if not applicable
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public String getCatalogName(int column) throws SQLException {
 
@@ -638,22 +601,21 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
 
         String name = resultMetaData.columns[--column].getCatalogNameString();
 
-        return name == null ? ""
-                            : name;
+        return name == null
+               ? ""
+               : name;
     }
 
     /**
-     * <!-- start generic documentation -->
      * Retrieves the designated column's SQL type.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * This reports the SQL type code of the column. For time and timestamp
      * types that are WITH TIME ZONE, the values as the SQL Standard CLI
-     * codes.<p>
+     * codes.
      *
      * </div>
      * <!-- end release-specific documentation -->
@@ -661,7 +623,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      *
      * @param column the first column is 1, the second is 2, ...
      * @return SQL type from java.sql.Types
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      * @see java.sql.Types
      */
     public int getColumnType(int column) throws SQLException {
@@ -674,14 +636,12 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * <!-- start generic documentation -->
      * Retrieves the designated column's database-specific type name.
-     * <!-- end generic documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
      * @return type name used by the database. If the column type is
      * a user-defined type, then a fully-qualified type name is returned.
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      */
     public String getColumnTypeName(int column) throws SQLException {
 
@@ -693,49 +653,44 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates whether the designated column is definitely not writable.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * From 2.0 this method returns true if the ResultSet is not updatable
-     * or the column in question is not updatable.<p>
+     * or the column in question is not updatable.
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return <code>true</code> if so; <code>false</code> otherwise
-     * @exception SQLException if a database access error occurs
+     * @return {@code true} if so; {@code false} otherwise
+     * @throws SQLException if a database access error occurs
      */
     public boolean isReadOnly(int column) throws SQLException {
-
         checkColumn(column);
 
         return !resultMetaData.columns[--column].isWriteable();
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates whether it is possible for a write on the designated column to
      * succeed.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * From 2.0 this method returns false if the ResultSet is not updatable
-     * or the column in question is not updatable.<p>
+     * or the column in question is not updatable.
      *
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return <code>true</code> if so; <code>false</code> otherwise
-     * @exception SQLException if a database access error occurs
+     * @return {@code true} if so; {@code false} otherwise
+     * @throws SQLException if a database access error occurs
      */
     public boolean isWritable(int column) throws SQLException {
 
@@ -746,23 +701,21 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * <!-- start generic documentation -->
      * Indicates whether a write on the designated column will definitely succeed.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * From 2.0 this method returns false if the ResultSet is not updatable
-     * or the column in question is not updatable.<p>
+     * or the column in question is not updatable.
      *
      * </div>
      * <!-- end release-specific documentation -->
      *
      * @param column the first column is 1, the second is 2, ...
-     * @return <code>true</code> if so; <code>false</code> otherwise
-     * @exception SQLException if a database access error occurs
+     * @return {@code true} if so; {@code false} otherwise
+     * @throws SQLException if a database access error occurs
      */
     public boolean isDefinitelyWritable(int column) throws SQLException {
 
@@ -775,17 +728,15 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     //--------------------------JDBC 2.0-----------------------------------
 
     /**
-     * <!-- start generic documentation -->
      * <p>Returns the fully-qualified name of the Java class whose instances
-     * are manufactured if the method <code>ResultSet.getObject</code>
+     * are manufactured if the method {@code ResultSet.getObject}
      * is called to retrieve a value
-     * from the column.  <code>ResultSet.getObject</code> may return a subclass of the
+     * from the column.  {@code ResultSet.getObject} may return a subclass of the
      * class returned by this method.
-     * <!-- end generic documentation -->
      *
      * <!-- start Release-specific documentation -->
      * <div class="ReleaseSpecificDocumentation">
-     * <h1>HSQLDB-Specific Information:</h1> <p>
+     * <p class="rshead">HSQLDB-Specific Information:</p>
      *
      * HSQLDB 2.0 fully supports this feature.<p>
      *
@@ -798,9 +749,9 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * @param column the first column is 1, the second is 2, ...
      * @return the fully-qualified name of the class in the Java programming
      *         language that would be used by the method
-     * <code>ResultSet.getObject</code> to retrieve the value in the specified
+     * {@code ResultSet.getObject} to retrieve the value in the specified
      * column. This is the class name used for custom mapping.
-     * @exception SQLException if a database access error occurs
+     * @throws SQLException if a database access error occurs
      * @since JDK 1.2
      */
     public String getColumnClassName(int column) throws SQLException {
@@ -823,9 +774,9 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * or a proxy for the receiver. If the receiver is a wrapper
      * and the wrapped object implements the interface then the result is the
      * wrapped object or a proxy for the wrapped object. Otherwise return the
-     * result of calling <code>unwrap</code> recursively on the wrapped object
+     * result of calling {@code unwrap} recursively on the wrapped object
      * or a proxy for that result. If the receiver is not a
-     * wrapper and does not implement the interface, then an <code>SQLException</code> is thrown.
+     * wrapper and does not implement the interface, then an {@code SQLException} is thrown.
      *
      * @param iface A Class defining an interface that the result must implement.
      * @return an object that implements the interface. May be a proxy for the actual implementing object.
@@ -833,7 +784,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * @since JDK 1.6
      */
     @SuppressWarnings("unchecked")
-    public <T>T unwrap(java.lang.Class<T> iface) throws java.sql.SQLException {
+    public <T> T unwrap(java.lang.Class<T> iface) throws java.sql.SQLException {
 
         if (isWrapperFor(iface)) {
             return (T) this;
@@ -845,11 +796,11 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     /**
      * Returns true if this either implements the interface argument or is directly or indirectly a wrapper
      * for an object that does. Returns false otherwise. If this implements the interface then return true,
-     * else if this is a wrapper then return the result of recursively calling <code>isWrapperFor</code> on the wrapped
+     * else if this is a wrapper then return the result of recursively calling {@code isWrapperFor} on the wrapped
      * object. If this does not implement the interface and is not a wrapper, return false.
-     * This method should be implemented as a low-cost operation compared to <code>unwrap</code> so that
-     * callers can use this method to avoid expensive <code>unwrap</code> calls that may fail. If this method
-     * returns true then calling <code>unwrap</code> with the same argument should succeed.
+     * This method should be implemented as a low-cost operation compared to {@code unwrap} so that
+     * callers can use this method to avoid expensive {@code unwrap} calls that may fail. If this method
+     * returns true then calling {@code unwrap} with the same argument should succeed.
      *
      * @param iface a Class defining an interface.
      * @return true if this implements the interface or directly or indirectly wraps an object that does.
@@ -858,7 +809,8 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      * @since JDK 1.6
      */
     public boolean isWrapperFor(
-            java.lang.Class<?> iface) throws java.sql.SQLException {
+            java.lang.Class<?> iface)
+            throws java.sql.SQLException {
         return (iface != null && iface.isAssignableFrom(this.getClass()));
     }
 
@@ -881,9 +833,12 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
      *        JDBCResultSetMetaData object
      * @throws SQLException if a database access error occurs
      */
-    JDBCResultSetMetaData(ResultMetaData meta, boolean isUpdatable,
-                          boolean isInsertable,
-                          JDBCConnection conn) throws SQLException {
+    JDBCResultSetMetaData(
+            ResultMetaData meta,
+            boolean isUpdatable,
+            boolean isInsertable,
+            JDBCConnection conn)
+            throws SQLException {
         init(meta, conn);
     }
 
@@ -916,7 +871,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     }
 
     /**
-     * Performs an internal check for column index validity. <p>
+     * Performs an internal check for column index validity.
      *
      * @param column index of column to check
      * @throws SQLException when this object's parent ResultSet has
@@ -925,8 +880,9 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
     private void checkColumn(int column) throws SQLException {
 
         if (column < 1 || column > columnCount) {
-            throw JDBCUtil.sqlException(ErrorCode.JDBC_COLUMN_NOT_FOUND,
-                                    String.valueOf(column));
+            throw JDBCUtil.sqlException(
+                ErrorCode.JDBC_COLUMN_NOT_FOUND,
+                String.valueOf(column));
         }
     }
 
@@ -968,6 +924,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
 
             return sb.toString();
         }
+
         sb.append('[');
 
         for (int i = 0; i < columnCount; i++) {
@@ -984,6 +941,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
                 sb.append(' ');
             }
         }
+
         sb.append('\n');
         sb.append(']');
 
@@ -1014,8 +972,7 @@ public class JDBCResultSetMetaData implements ResultSetMetaData {
             meta.scale                = getScale(i);
             meta.schemaName           = getSchemaName(i);
             meta.tableName            = getTableName(i);
-        } catch (SQLException e) {
-        }
+        } catch (SQLException e) {}
 
         return meta;
     }
