@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,43 +35,40 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.StringConverter;
 
 import java.io.IOException;
+
 import java.sql.RowId;
 import java.sql.SQLException;
+
 import java.util.Arrays;
 
-/* $Id: JDBCRowId.java 6492 2022-04-21 07:30:40Z fredt $ */
-
-//campbell-burnet@users 20060522 - doc 1.8.1 full synch up to Mustang Build 84
-
 /**
- *
  * The representation (mapping) in the Java programming language of an SQL ROWID
  * value. An SQL ROWID is a built-in type, a value of which can be thought of as
  * an address  for its identified row in a database table. Whether that address
  * is logical or, in any  respects, physical is determined by its originating data
  * source.
  * <p>
- * Methods in the interfaces <code>ResultSet</code>, <code>CallableStatement</code>,
- * and <code>PreparedStatement</code>, such as <code>getRowId</code> and <code>setRowId</code>
- * allow a programmer to access a SQL <code>ROWID</code>  value. The <code>RowId</code>
+ * Methods in the interfaces {@code ResultSet}, {@code CallableStatement},
+ * and {@code PreparedStatement}, such as {@code getRowId} and {@code setRowId}
+ * allow a programmer to access a SQL {@code ROWID}  value. The {@code RowId}
  * interface provides a method
- * for representing the value of the <code>ROWID</code> as a byte array or as a
- * <code>String</code>.
+ * for representing the value of the {@code ROWID} as a byte array or as a
+ * {@code String}.
  * <p>
- * The method <code>getRowIdLifetime</code> in the interface <code>DatabaseMetaData</code>,
+ * The method {@code getRowIdLifetime} in the interface {@code DatabaseMetaData},
  * can be used
- * to determine if a <code>RowId</code> object remains valid for the duration of the transaction in
- * which  the <code>RowId</code> was created, the duration of the session in which
- * the <code>RowId</code> was created,
+ * to determine if a {@code RowId} object remains valid for the duration of the transaction in
+ * which  the {@code RowId} was created, the duration of the session in which
+ * the {@code RowId} was created,
  * or, effectively, for as long as its identified row is not deleted. In addition
  * to specifying the duration of its valid lifetime outside its originating data
- * source, <code>getRowIdLifetime</code> specifies the duration of a <code>ROWID</code>
+ * source, {@code getRowIdLifetime} specifies the duration of a {@code ROWID}
  * value's valid lifetime
  * within its originating data source. In this, it differs from a large object,
  * because there is no limit on the valid lifetime of a large  object within its
  * originating data source.
  * <p>
- * All methods on the <code>RowId</code> interface must be fully implemented if the
+ * All methods on the {@code RowId} interface must be fully implemented if the
  * JDBC driver supports the data type.
  *
  * @see java.sql.DatabaseMetaData
@@ -104,12 +101,13 @@ public final class JDBCRowId implements RowId {
         if (id == null) {
             throw JDBCUtil.nullArgument("id");
         }
+
         this.id = id;
     }
 
     /**
      * Constructs a new JDBCRowId instance whose internal octet sequence
-     * is a copy of the octet sequence of the given RowId object. <p>
+     * is a copy of the octet sequence of the given RowId object.
      *
      * @param id the octet sequence representing the Rowid value
      * @throws SQLException if the argument is null
@@ -120,7 +118,7 @@ public final class JDBCRowId implements RowId {
 
     /**
      * Constructs a new JDBCRowId instance whose internal octet sequence
-     * is that represented by the given hexadecimal character sequence. <p>
+     * is that represented by the given hexadecimal character sequence.
      * @param hex the hexadecimal character sequence from which to derive
      *        the internal octet sequence
      * @throws java.sql.SQLException if the argument is null or is not a valid
@@ -135,21 +133,22 @@ public final class JDBCRowId implements RowId {
         try {
             this.id = StringConverter.hexStringToByteArray(hex);
         } catch (IOException e) {
-            throw JDBCUtil.sqlException(ErrorCode.JDBC_INVALID_ARGUMENT,
-                                    "hex: " + e);
+            throw JDBCUtil.sqlException(
+                ErrorCode.JDBC_INVALID_ARGUMENT,
+                "hex: " + e);
 
             // .illegalHexadecimalCharacterSequenceArgumentException("hex", e);
         }
     }
 
     /**
-     * Compares this <code>RowId</code> to the specified object. The result is
-     * <code>true</code> if and only if the argument is not null and is a RowId
+     * Compares this {@code RowId} to the specified object. The result is
+     * {@code true} if and only if the argument is not null and is a RowId
      * object that represents the same ROWID as  this object.
      * <p>
      * It is important
-     * to consider both the origin and the valid lifetime of a <code>RowId</code>
-     * when comparing it to another <code>RowId</code>. If both are valid, and
+     * to consider both the origin and the valid lifetime of a {@code RowId}
+     * when comparing it to another {@code RowId}. If both are valid, and
      * both are from the same table on the same data source, then if they are equal
      * they identify
      * the same row; if one or more is no longer guaranteed to be valid, or if
@@ -157,9 +156,9 @@ public final class JDBCRowId implements RowId {
      * same data source, they  may be equal but still
      * not identify the same row.
      *
-     * @param obj the <code>Object</code> to compare this <code>RowId</code> object
+     * @param obj the {@code Object} to compare this {@code RowId} object
      *     against.
-     * @return true if the <code>RowId</code>s are equal; false otherwise
+     * @return true if the {@code RowId}s are equal; false otherwise
      * @since JDK 1.6, HSQLDB 2.0
      */
     public boolean equals(Object obj) {
@@ -168,8 +167,8 @@ public final class JDBCRowId implements RowId {
     }
 
     /**
-     * Returns an array of bytes representing the value of the SQL <code>ROWID</code>
-     * designated by this <code>java.sql.RowId</code> object.
+     * Returns an array of bytes representing the value of the SQL {@code ROWID}
+     * designated by this {@code java.sql.RowId} object.
      *
      * @return an array of bytes, whose length is determined by the driver supplying
      *     the connection, representing the value of the ROWID designated by this
@@ -181,27 +180,27 @@ public final class JDBCRowId implements RowId {
 
     /**
      * Returns a String representing the value of the SQL ROWID designated by this
-     * <code>java.sql.RowId</code> object.
+     * {@code java.sql.RowId} object.
      * <p>
-     * Like <code>java.sql.Date.toString()</code>
-     * returns the contents of its DATE as the <code>String</code> "2004-03-17"
-     * rather than as  DATE literal in SQL (which would have been the <code>String</code>
+     * Like {@code java.sql.Date.toString()}
+     * returns the contents of its DATE as the {@code String} "2004-03-17"
+     * rather than as  DATE literal in SQL (which would have been the {@code String}
      * DATE "2004-03-17"), toString()
      * returns the contents of its ROWID in a form specific to the driver supplying
-     * the connection, and possibly not as a <code>ROWID</code> literal.
+     * the connection, and possibly not as a {@code ROWID} literal.
      *
      * @return a String whose format is determined by the driver supplying the
-     *     connection, representing the value of the <code>ROWID</code> designated
-     *     by this <code>java.sql.RowId</code>  object.
+     *     connection, representing the value of the {@code ROWID} designated
+     *     by this {@code java.sql.RowId}  object.
      */
     public String toString() {
         return StringConverter.byteArrayToHexString(id);
     }
 
     /**
-     * Returns a hash code value of this <code>RowId</code> object.
+     * Returns a hash code value of this {@code RowId} object.
      *
-     * @return a hash code for the <code>RowId</code>
+     * @return a hash code for the {@code RowId}
      */
     public int hashCode() {
 
