@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -30,15 +30,16 @@
 
 
 package org.hsqldb.jdbc.pool;
+
 import java.sql.Connection;
 import java.sql.SQLException;
+
 import javax.sql.XAConnection;
+
 import javax.transaction.xa.XAResource;
 
 import org.hsqldb.jdbc.JDBCConnection;
 
-// @(#)$Id: JDBCXAConnection.java 6266 2021-01-25 16:08:06Z fredt $
-
 /**
  * Subclass of JDBCPooledConnection implements the XAConnection interface.
  * For use by global transaction service managers.<p>
@@ -55,13 +56,16 @@ import org.hsqldb.jdbc.JDBCConnection;
  * @author Fred Toussi (fredt at users.sourceforge.net)
  * @see javax.sql.XAConnection
  */
-public class JDBCXAConnection extends JDBCPooledConnection implements XAConnection {
+public class JDBCXAConnection extends JDBCPooledConnection
+        implements XAConnection {
 
     JDBCXAResource xaResource;
 
-    public JDBCXAConnection(JDBCXADataSource dataSource, JDBCConnection connection) {
-
+    public JDBCXAConnection(
+            JDBCXADataSource dataSource,
+            JDBCConnection connection) {
         super(connection);
+
         xaResource = new JDBCXAResource(dataSource, connection);
     }
 
