@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,9 @@
 package org.hsqldb.jdbc.pool;
 
 import java.io.Serializable;
+
 import java.sql.SQLException;
+
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -42,9 +44,11 @@ import javax.naming.NamingException;
 import javax.naming.Reference;
 import javax.naming.Referenceable;
 import javax.naming.StringRefAddr;
+
 import javax.sql.CommonDataSource;
 import javax.sql.XAConnection;
 import javax.sql.XADataSource;
+
 import javax.transaction.xa.Xid;
 
 import org.hsqldb.error.Error;
@@ -54,8 +58,6 @@ import org.hsqldb.jdbc.JDBCConnection;
 import org.hsqldb.jdbc.JDBCDriver;
 import org.hsqldb.jdbc.JDBCUtil;
 
-// @(#)$Id: JDBCXADataSource.java 6266 2021-01-25 16:08:06Z fredt $
-
 /**
  * Connection factory for JDBCXAConnections.
  * For use by XA data source factories, not by end users.<p>
@@ -64,16 +66,16 @@ import org.hsqldb.jdbc.JDBCUtil;
  * instances of this class.<p>
  *
  * The methods of the superclass, {@link org.hsqldb.jdbc.JDBCCommonDataSource},
- * are used for settings the HyperSQL server and user.<p>
+ * are used for settings the HyperSQL server and user.
  *
  * @version 2.3.3
- * @since 2.0.0
+ * @since HSQLDB 2.0.0
  * @author Blaine Simpson (blaine dot simpson at admc dot com)
  * @see javax.sql.XADataSource
  * @see org.hsqldb.jdbc.pool.JDBCXAConnection
  */
 public class JDBCXADataSource extends JDBCCommonDataSource
-implements XADataSource, Serializable, Referenceable, CommonDataSource {
+        implements XADataSource, Serializable, Referenceable, CommonDataSource {
 
     /**
      * Get new XAConnection connection, to be managed by a connection manager.
@@ -83,14 +85,16 @@ implements XADataSource, Serializable, Referenceable, CommonDataSource {
     public XAConnection getXAConnection() throws SQLException {
 
         // Comment out before public release:
+
 /*
         System.err.print("Executing " + getClass().getName()
                          + ".getXAConnection()...");
 */
 
         // Use JDBCDriver directly so there is no need to register with DriverManager
-        JDBCConnection connection =
-            (JDBCConnection) JDBCDriver.getConnection(url, connectionProps);
+        JDBCConnection connection = (JDBCConnection) JDBCDriver.getConnection(
+            url,
+            connectionProps);
         JDBCXAConnection xaConnection = new JDBCXAConnection(this, connection);
 
         return xaConnection;
@@ -108,8 +112,10 @@ implements XADataSource, Serializable, Referenceable, CommonDataSource {
      *                  for this JDBCXADataSource.
      * @throws SQLException on error
      */
-    public XAConnection getXAConnection(String user,
-                                        String password) throws SQLException {
+    public XAConnection getXAConnection(
+            String user,
+            String password)
+            throws SQLException {
 
         if (user == null || password == null) {
             throw JDBCUtil.nullArgument();
@@ -126,7 +132,7 @@ implements XADataSource, Serializable, Referenceable, CommonDataSource {
      * Retrieves the Reference of this object.
      *
      * @return The non-null javax.naming.Reference of this object.
-     * @exception NamingException If a naming exception was encountered
+     * @throws NamingException If a naming exception was encountered
      *          while retrieving the reference.
      */
     public Reference getReference() throws NamingException {
@@ -137,14 +143,15 @@ implements XADataSource, Serializable, Referenceable, CommonDataSource {
         ref.add(new StringRefAddr("database", getDatabase()));
         ref.add(new StringRefAddr("user", getUser()));
         ref.add(new StringRefAddr("password", password));
-        ref.add(new StringRefAddr("loginTimeout",
-                                  Integer.toString(loginTimeout)));
+        ref.add(
+            new StringRefAddr("loginTimeout", Integer.toString(loginTimeout)));
 
         return ref;
     }
 
     // ------------------------ internal implementation ------------------------
-    private HashMap                resources = new HashMap();
+    private HashMap<Xid, JDBCXAResource> resources = new HashMap<Xid,
+        JDBCXAResource>();
     private ReentrantReadWriteLock lock = new ReentrantReadWriteLock(true);
 
     public void addResource(Xid xid, JDBCXAResource xaResource) {
@@ -168,7 +175,7 @@ implements XADataSource, Serializable, Referenceable, CommonDataSource {
         lock.writeLock().lock();
 
         try {
-            return (JDBCXAResource) resources.remove(xid);
+            return resources.remove(xid);
         } finally {
             lock.writeLock().unlock();
         }
@@ -187,14 +194,14 @@ implements XADataSource, Serializable, Referenceable, CommonDataSource {
         lock.writeLock().lock();
 
         try {
-            Iterator it = resources.keySet().iterator();
-            Xid      curXid;
-            HashSet  preparedSet = new HashSet();
+            Iterator<Xid> it = resources.keySet().iterator();
+            Xid           curXid;
+            HashSet<Xid>  preparedSet = new HashSet<Xid>();
 
             while (it.hasNext()) {
-                curXid = (Xid) it.next();
+                curXid = it.next();
 
-                if (((JDBCXAResource) resources.get(curXid)).state
+                if ((resources.get(curXid)).state
                         == JDBCXAResource.XA_STATE_PREPARED) {
                     preparedSet.add(curXid);
                 }
@@ -224,7 +231,7 @@ implements XADataSource, Serializable, Referenceable, CommonDataSource {
         lock.readLock().lock();
 
         try {
-            return (JDBCXAResource) resources.get(xid);
+            return resources.get(xid);
         } finally {
             lock.readLock().unlock();
         }
