@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,27 +32,30 @@
 package org.hsqldb.lib;
 
 import java.lang.reflect.Array;
+
 import java.util.Arrays;
 
 /**
  * Collection of static methods for operations on arrays
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.1
+ * @version 2.7.4
  * @since 1.7.2
  */
 public final class ArrayUtil {
 
-    public static final int              CLASS_CODE_BYTE    = 'B';
-    public static final int              CLASS_CODE_CHAR    = 'C';
-    public static final int              CLASS_CODE_DOUBLE  = 'D';
-    public static final int              CLASS_CODE_FLOAT   = 'F';
-    public static final int              CLASS_CODE_INT     = 'I';
-    public static final int              CLASS_CODE_LONG    = 'J';
-    public static final int              CLASS_CODE_OBJECT  = 'L';
-    public static final int              CLASS_CODE_SHORT   = 'S';
-    public static final int              CLASS_CODE_BOOLEAN = 'Z';
-    private static final IntValueHashMap classCodeMap = new IntValueHashMap(16);
+    public static final int CLASS_CODE_BYTE    = 'B';
+    public static final int CLASS_CODE_CHAR    = 'C';
+    public static final int CLASS_CODE_DOUBLE  = 'D';
+    public static final int CLASS_CODE_FLOAT   = 'F';
+    public static final int CLASS_CODE_INT     = 'I';
+    public static final int CLASS_CODE_LONG    = 'J';
+    public static final int CLASS_CODE_OBJECT  = 'L';
+    public static final int CLASS_CODE_SHORT   = 'S';
+    public static final int CLASS_CODE_BOOLEAN = 'Z';
+    private static final IntValueHashMap<Class> classCodeMap =
+        new IntValueHashMap<>(
+            16);
 
     static {
         classCodeMap.put(byte.class, ArrayUtil.CLASS_CODE_BYTE);
@@ -98,64 +101,63 @@ public final class ArrayUtil {
                 byte[] array = (byte[]) data;
 
                 Arrays.fill(array, from, to, (byte) 0);
-
-                return;
+                break;
             }
+
             case ArrayUtil.CLASS_CODE_CHAR : {
                 char[] array = (char[]) data;
 
                 Arrays.fill(array, from, to, (char) 0);
-
-                return;
+                break;
             }
+
             case ArrayUtil.CLASS_CODE_SHORT : {
                 short[] array = (short[]) data;
 
                 Arrays.fill(array, from, to, (short) 0);
-
-                return;
+                break;
             }
+
             case ArrayUtil.CLASS_CODE_INT : {
                 int[] array = (int[]) data;
 
                 Arrays.fill(array, from, to, 0);
-
-                return;
+                break;
             }
+
             case ArrayUtil.CLASS_CODE_LONG : {
                 long[] array = (long[]) data;
 
                 Arrays.fill(array, from, to, 0L);
-
-                return;
+                break;
             }
+
             case ArrayUtil.CLASS_CODE_FLOAT : {
                 float[] array = (float[]) data;
 
                 Arrays.fill(array, from, to, 0);
-
-                return;
+                break;
             }
+
             case ArrayUtil.CLASS_CODE_DOUBLE : {
                 double[] array = (double[]) data;
 
                 Arrays.fill(array, from, to, 0);
-
-                return;
+                break;
             }
+
             case ArrayUtil.CLASS_CODE_BOOLEAN : {
                 boolean[] array = (boolean[]) data;
 
                 Arrays.fill(array, from, to, false);
-
-                return;
+                break;
             }
+
             default : {
                 Object[] array = (Object[]) data;
 
                 Arrays.fill(array, from, to, null);
-
-                return;
+                break;
             }
         }
     }
@@ -170,8 +172,12 @@ public final class ArrayUtil {
      * @param index point at which to add or remove elements
      * @param count number of elements to add or remove
      */
-    public static void adjustArray(int type, Object array, int usedElements,
-                                   int index, int count) {
+    public static void adjustArray(
+            int type,
+            Object array,
+            int usedElements,
+            int index,
+            int count) {
 
         if (index >= usedElements || count == 0) {
             return;
@@ -318,6 +324,7 @@ public final class ArrayUtil {
 
         return -1;
     }
+
     /**
      * Finds the first element of the array that is not equal to the given value.
      *
@@ -414,8 +421,10 @@ public final class ArrayUtil {
      * @param count int
      * @return boolean
      */
-    public static boolean haveEqualArrays(Object[] arra, Object[] arrb,
-                                          int count) {
+    public static boolean haveEqualArrays(
+            Object[] arra,
+            Object[] arrb,
+            int count) {
 
         if (count > arra.length || count > arrb.length) {
             return false;
@@ -447,6 +456,13 @@ public final class ArrayUtil {
             return false;
         }
 
+        if (arra.length > arrb.length) {
+            int[] temp = arra;
+
+            arra = arrb;
+            arrb = temp;
+        }
+
         for (int i = 0; i < arra.length; i++) {
             int c = arra[i];
 
@@ -481,7 +497,7 @@ public final class ArrayUtil {
      *
      * @param arra int[] first column indexes
      * @param arrb int[] second column indexes
-     * @return int[] common indexes or <code>null</code> if there is no overlap.
+     * @return int[] common indexes or {@code null} if there is no overlap.
      */
     public static int[] commonElements(int[] arra, int[] arrb) {
 
@@ -519,17 +535,23 @@ public final class ArrayUtil {
      *
      * @param arrb int[] second array of column indexes
      *
-     * @return int number of elements shared by <code>arra</code> and <code>arrb</code>
+     * @return int number of elements shared by {@code arra} and {@code arrb}
      */
     public static int countCommonElements(int[] arra, int[] arrb) {
 
         int k = 0;
 
+        if (arra.length > arrb.length) {
+            int[] temp = arra;
+
+            arra = arrb;
+            arrb = temp;
+        }
+
         for (int i = 0; i < arra.length; i++) {
             for (int j = 0; j < arrb.length; j++) {
                 if (arra[i] == arrb[j]) {
                     k++;
-
                     break;
                 }
             }
@@ -538,8 +560,10 @@ public final class ArrayUtil {
         return k;
     }
 
-    public static int countCommonElements(Object[] arra, int alen,
-                                          Object[] arrb) {
+    public static int countCommonElements(
+            Object[] arra,
+            int alen,
+            Object[] arrb) {
 
         int k = 0;
 
@@ -547,7 +571,6 @@ public final class ArrayUtil {
             for (int j = 0; j < arrb.length; j++) {
                 if (arra[i] == arrb[j]) {
                     k++;
-
                     break;
                 }
             }
@@ -694,7 +717,7 @@ public final class ArrayUtil {
      */
     public static int[] union(int[] arra, int[] arrb) {
 
-        int commonSize  = ArrayUtil.countCommonElements(arra, arrb);
+        int commonSize = ArrayUtil.countCommonElements(arra, arrb);
 
         if (commonSize == arrb.length) {
             return arra;
@@ -708,18 +731,18 @@ public final class ArrayUtil {
         int[] arrn    = Arrays.copyOf(arra, newSize);
         int   pos     = arra.length;
 
-            mainloop:
-            for (int i = 0; i < arrb.length; i++) {
-                for (int j = 0; j < arra.length; j++) {
-                    if (arrb[i] == arra[j]) {
-                        continue mainloop;
-                    }
+        mainloop:
+        for (int i = 0; i < arrb.length; i++) {
+            for (int j = 0; j < arra.length; j++) {
+                if (arrb[i] == arra[j]) {
+                    continue mainloop;
                 }
-
-                arrn[pos++] = arrb[i];
             }
 
-            return arrn;
+            arrn[pos++] = arrb[i];
+        }
+
+        return arrn;
     }
 
     /**
@@ -730,17 +753,16 @@ public final class ArrayUtil {
      * @return int[]
      */
     public static int[] concat(int[] arra, int[] arrb) {
-        int newSize = arra.length + arrb.length;
 
-        int[] arrn = Arrays.copyOf(arra, newSize);
-        int   pos  = arra.length;
+        int   newSize = arra.length + arrb.length;
+        int[] arrn    = Arrays.copyOf(arra, newSize);
+        int   pos     = arra.length;
 
         for (int i = 0; i < arrb.length; i++) {
             arrn[pos++] = arrb[i];
         }
 
         return arrn;
-
     }
 
     /**
@@ -786,8 +808,11 @@ public final class ArrayUtil {
      * @param byteSet byte[]
      * @return int
      */
-    public static int findNotIn(byte[] arra, int start, int limit,
-                                byte[] byteSet) {
+    public static int findNotIn(
+            byte[] arra,
+            int start,
+            int limit,
+            byte[] byteSet) {
 
         mainloop:
         for (int k = start; k < limit; k++) {
@@ -813,8 +838,11 @@ public final class ArrayUtil {
      * @param byteSet byte[]
      * @return int
      */
-    public static int findIn(byte[] arra, int start, int limit,
-                             byte[] byteSet) {
+    public static int findIn(
+            byte[] arra,
+            int start,
+            int limit,
+            byte[] byteSet) {
 
         for (int k = start; k < limit; k++) {
             for (int i = 0; i < byteSet.length; i++) {
@@ -901,7 +929,8 @@ public final class ArrayUtil {
      * @param arrb boolean[]
      * @return int
      */
-    public static int countStartIntIndexesInBooleanArray(int[] arra,
+    public static int countStartIntIndexesInBooleanArray(
+            int[] arra,
             boolean[] arrb) {
 
         int k = 0;
@@ -918,7 +947,6 @@ public final class ArrayUtil {
     }
 
     public static void orBooleanArray(boolean[] source, boolean[] dest) {
-
         for (int i = 0; i < dest.length; i++) {
             dest[i] |= source[i];
         }
@@ -934,7 +962,8 @@ public final class ArrayUtil {
      * @param arrb boolean[]
      * @return boolean
      */
-    public static boolean areAllIntIndexesAsBooleanArray(int[] arra,
+    public static boolean areAllIntIndexesAsBooleanArray(
+            int[] arra,
             boolean[] arrb) {
 
         for (int i = 0; i < arra.length; i++) {
@@ -948,7 +977,8 @@ public final class ArrayUtil {
         return arra.length == countTrueElements(arrb);
     }
 
-    public static boolean areAllIntIndexesInBooleanArray(int[] arra,
+    public static boolean areAllIntIndexesInBooleanArray(
+            int[] arra,
             boolean[] arrb) {
 
         for (int i = 0; i < arra.length; i++) {
@@ -962,7 +992,8 @@ public final class ArrayUtil {
         return true;
     }
 
-    public static boolean isAnyIntIndexInBooleanArray(int[] arra,
+    public static boolean isAnyIntIndexInBooleanArray(
+            int[] arra,
             boolean[] arrb) {
 
         for (int i = 0; i < arra.length; i++) {
@@ -982,7 +1013,8 @@ public final class ArrayUtil {
      * @param arrb boolean[]
      * @return boolean
      */
-    public static boolean containsAllTrueElements(boolean[] arra,
+    public static boolean containsAllTrueElements(
+            boolean[] arra,
             boolean[] arrb) {
 
         for (int i = 0; i < arra.length; i++) {
@@ -1069,8 +1101,10 @@ public final class ArrayUtil {
      * @param arrb byte[]
      * @return int
      */
-    public static int countStartElementsAt(byte[] arra, int start,
-                                           byte[] arrb) {
+    public static int countStartElementsAt(
+            byte[] arra,
+            int start,
+            byte[] arrb) {
 
         int k = 0;
 
@@ -1079,7 +1113,6 @@ public final class ArrayUtil {
             for (int j = 0; j < arrb.length; j++) {
                 if (arra[i] == arrb[j]) {
                     k++;
-
                     continue mainloop;
                 }
             }
@@ -1112,7 +1145,9 @@ public final class ArrayUtil {
      * @param arrb byte[]
      * @return int
      */
-    public static int countNonStartElementsAt(byte[] arra, int start,
+    public static int countNonStartElementsAt(
+            byte[] arra,
+            int start,
             byte[] arrb) {
 
         int k = 0;
@@ -1146,9 +1181,14 @@ public final class ArrayUtil {
      * @param destLength int
      * @return int
      */
-    public static int copyBytes(long sourceOffset, byte[] source,
-                                int sourceOff, int sourceLength,
-                                long destOffset, byte[] dest, int destLength) {
+    public static int copyBytes(
+            long sourceOffset,
+            byte[] source,
+            int sourceOff,
+            int sourceLength,
+            long destOffset,
+            byte[] dest,
+            int destLength) {
 
         if (sourceOff >= source.length) {
             return 0;
@@ -1186,8 +1226,12 @@ public final class ArrayUtil {
             sourceLength = destLength - (int) destIndex;
         }
 
-        System.arraycopy(source, (int) sourceIndex, dest, (int) destIndex,
-                         sourceLength);
+        System.arraycopy(
+            source,
+            (int) sourceIndex,
+            dest,
+            (int) destIndex,
+            sourceLength);
 
         return sourceLength;
     }
@@ -1201,8 +1245,7 @@ public final class ArrayUtil {
      * @param destOffset int
      * @return byte[]
      */
-    public static byte[] copyBytes(byte[] source, byte[] dest,
-                                   int destOffset) {
+    public static byte[] copyBytes(byte[] source, byte[] dest, int destOffset) {
 
         if (source.length + destOffset > dest.length) {
             byte[] newDest = new byte[source.length + destOffset];
@@ -1228,34 +1271,42 @@ public final class ArrayUtil {
         System.arraycopy(source, 0, dest, 0, count);
     }
 
-    public static void copyMoveSegment(Object source, Object dest, int size,
-                                       int index, int segmentSize,
-                                       int destIndex) {
+    public static void copyMoveSegment(
+            Object source,
+            Object dest,
+            int size,
+            int index,
+            int segmentSize,
+            int destIndex) {
 
         boolean forward   = index < destIndex;
-        int     sliceSize = forward ? index
-                                    : destIndex;
+        int     sliceSize = forward
+                            ? index
+                            : destIndex;
 
         System.arraycopy(source, 0, dest, 0, sliceSize);
 
-        sliceSize = forward ? size - destIndex - segmentSize
-                            : size - index - segmentSize;
+        sliceSize = forward
+                    ? size - destIndex - segmentSize
+                    : size - index - segmentSize;
 
-        int sliceIndex = forward ? destIndex + segmentSize
-                                 : index + segmentSize;
+        int sliceIndex = forward
+                         ? destIndex + segmentSize
+                         : index + segmentSize;
 
         System.arraycopy(source, sliceIndex, dest, sliceIndex, sliceSize);
         System.arraycopy(source, index, dest, destIndex, segmentSize);
 
         sliceSize  = Math.abs(index - destIndex);
-        sliceIndex = forward ? index + segmentSize
-                             : destIndex;
+        sliceIndex = forward
+                     ? index + segmentSize
+                     : destIndex;
 
-        int targetSliceIndex = forward ? index
-                                       : destIndex + segmentSize;
+        int targetSliceIndex = forward
+                               ? index
+                               : destIndex + segmentSize;
 
-        System.arraycopy(source, sliceIndex, dest, targetSliceIndex,
-                         sliceSize);
+        System.arraycopy(source, sliceIndex, dest, targetSliceIndex, sliceSize);
     }
 
     /**
@@ -1323,7 +1374,7 @@ public final class ArrayUtil {
     }
 
     /**
-     * Fills the int array with a value
+     * Fills the int array with a value.
      *
      * @param array int[]
      * @param value int
@@ -1338,7 +1389,7 @@ public final class ArrayUtil {
     }
 
     /**
-     * Fills the double array with a value
+     * Fills the double array with a value.
      *
      * @param array double[]
      * @param value double
@@ -1376,8 +1427,9 @@ public final class ArrayUtil {
     public static Object duplicateArray(Object source) {
 
         int size = Array.getLength(source);
-        Object newarray =
-            Array.newInstance(source.getClass().getComponentType(), size);
+        Object newarray = Array.newInstance(
+            source.getClass().getComponentType(),
+            size);
 
         System.arraycopy(source, 0, newarray, 0, size);
 
@@ -1401,8 +1453,9 @@ public final class ArrayUtil {
             return source;
         }
 
-        Object newarray =
-            Array.newInstance(source.getClass().getComponentType(), newsize);
+        Object newarray = Array.newInstance(
+            source.getClass().getComponentType(),
+            newsize);
 
         if (oldsize < newsize) {
             newsize = oldsize;
@@ -1424,8 +1477,9 @@ public final class ArrayUtil {
      */
     public static Object resizeArray(Object source, int newsize) {
 
-        Object newarray =
-            Array.newInstance(source.getClass().getComponentType(), newsize);
+        Object newarray = Array.newInstance(
+            source.getClass().getComponentType(),
+            newsize);
         int oldsize = Array.getLength(source);
 
         if (oldsize < newsize) {
@@ -1469,12 +1523,16 @@ public final class ArrayUtil {
      * @param adjust int
      * @return Object
      */
-    public static Object toAdjustedArray(Object source, Object addition,
-                                         int colindex, int adjust) {
+    public static Object toAdjustedArray(
+            Object source,
+            Object addition,
+            int colindex,
+            int adjust) {
 
         int newsize = Array.getLength(source) + adjust;
-        Object newarray =
-            Array.newInstance(source.getClass().getComponentType(), newsize);
+        Object newarray = Array.newInstance(
+            source.getClass().getComponentType(),
+            newsize);
 
         copyAdjustArray(source, newarray, addition, colindex, adjust);
 
@@ -1482,7 +1540,35 @@ public final class ArrayUtil {
     }
 
     /**
-     * Copies elements of source to dest. If adjust is -1 the element at
+     * Returns an array containing the elements of source except any
+     * element shared with the other.
+     *
+     * @param source int[]
+     * @param other int[]
+     * @return int[]
+     */
+    public static int[] except(int[] source, int[] other) {
+
+        int newsize = source.length - countCommonElements(source, other);
+
+        if (newsize == source.length) {
+            return source;
+        }
+
+        int[] newarray = new int[newsize];
+
+        for (int i = 0, j = 0; i < source.length; i++) {
+            if (find(other, source[i]) < 0) {
+                newarray[j++] = source[i];
+            }
+        }
+
+        return newarray;
+    }
+
+    /**
+     * For arrays of Objects or primitives.
+     * Copies array elements of source to dest. If adjust is -1 the element at
      * colindex is not copied. If adjust is +1 that element is filled with the
      * Object addition. All the rest of the elements in source are shifted left
      * or right accordingly when they are copied. If adjust is 0 the addition is
@@ -1496,9 +1582,12 @@ public final class ArrayUtil {
      * @param colindex int
      * @param adjust int
      */
-    public static void copyAdjustArray(Object source, Object dest,
-                                       Object addition, int colindex,
-                                       int adjust) {
+    public static void copyAdjustArray(
+            Object source,
+            Object dest,
+            Object addition,
+            int colindex,
+            int adjust) {
 
         int length = Array.getLength(source);
 
@@ -1516,15 +1605,23 @@ public final class ArrayUtil {
             Array.set(dest, colindex, addition);
 
             if (endcount > 0) {
-                System.arraycopy(source, colindex + 1, dest, colindex + 1,
-                                 endcount);
+                System.arraycopy(
+                    source,
+                    colindex + 1,
+                    dest,
+                    colindex + 1,
+                    endcount);
             }
         } else if (adjust < 0) {
             int endcount = length - colindex - 1;
 
             if (endcount > 0) {
-                System.arraycopy(source, colindex + 1, dest, colindex,
-                                 endcount);
+                System.arraycopy(
+                    source,
+                    colindex + 1,
+                    dest,
+                    colindex,
+                    endcount);
             }
         } else {
             int endcount = length - colindex;
@@ -1532,16 +1629,20 @@ public final class ArrayUtil {
             Array.set(dest, colindex, addition);
 
             if (endcount > 0) {
-                System.arraycopy(source, colindex, dest, colindex + 1,
-                                 endcount);
+                System.arraycopy(
+                    source,
+                    colindex,
+                    dest,
+                    colindex + 1,
+                    endcount);
             }
         }
     }
 
     /**
      * Similar to single slot adjusted copy, with multiple slots added or
-     * removed. The colindex array is the ordered lists the slots to be added or
-     * removed. The adjust argument can be {-1, +1) for remove or add. No checks
+     * removed. The colindex array is the ordered list of the slots to be added or
+     * removed. The adjust argument can be {-1, +1} for remove or add. No checks
      * are performed on array sizes and no exception is thrown if they are not
      * consistent with the other arguments.
      *
@@ -1550,8 +1651,11 @@ public final class ArrayUtil {
      * @param colindex int[]
      * @param adjust int
      */
-    public static void copyAdjustArray(Object[] source, Object[] dest,
-                                       int[] colindex, int adjust) {
+    public static void copyAdjustArray(
+            Object[] source,
+            Object[] dest,
+            int[] colindex,
+            int adjust) {
 
         if (adjust == 0) {
             System.arraycopy(source, 0, dest, 0, source.length);
@@ -1561,7 +1665,6 @@ public final class ArrayUtil {
 
         for (int i = 0, j = 0, counter = 0;
                 i < source.length && j < dest.length; i++, j++) {
-
             if (counter < colindex.length) {
                 int adjustPos = colindex[counter];
 
@@ -1602,7 +1705,9 @@ public final class ArrayUtil {
      * @param  adjust +1, 0 or -1
      * @return new, adjusted array
      */
-    public static int[] toAdjustedColumnArray(int[] colarr, int colindex,
+    public static int[] toAdjustedColumnArray(
+            int[] colarr,
+            int colindex,
             int adjust) {
 
         if (colarr == null) {
@@ -1657,7 +1762,9 @@ public final class ArrayUtil {
      * @param adjust int
      * @return int[]
      */
-    public static int[] toAdjustedColumnArray(int[] colarr, int[] colindex,
+    public static int[] toAdjustedColumnArray(
+            int[] colarr,
+            int[] colindex,
             int adjust) {
 
         if (colarr == null) {
@@ -1667,9 +1774,7 @@ public final class ArrayUtil {
         int[] intarr = new int[colarr.length];
 
         if (adjust == 0) {
-            for (int i = 0; i < colarr.length; i++) {
-                intarr[i] = colarr[i];
-            }
+            System.arraycopy(colarr, 0, intarr, 0, colarr.length);
         } else if (adjust < 0) {
             for (int i = 0; i < colarr.length; i++) {
                 int count = countSmallerElements(colindex, colarr[i]);
@@ -1688,87 +1793,75 @@ public final class ArrayUtil {
     }
 
     /**
-     *  Copies some elements of row into newRow by using columnMap as
-     *  the list of indexes into row. <p>
+     *  Copies some elements of source into target by using columnMap as
+     *  the list of indexes into source. <p>
      *
-     *  columnMap and newRow are of equal length and are normally
-     *  shorter than row. <p>
+     *  columnMap and target are normally of equal length and
+     *  shorter than source.
      *
-     *  @param row the source array
-     *  @param columnMap the list of indexes into row
-     *  @param newRow the destination array
+     *  @param source the source array
+     *  @param columnMap the list of indexes into source
+     *  @param target the destination array
      */
-    public static void projectRow(Object[] row, int[] columnMap,
-                                  Object[] newRow) {
+    public static void projectRow(
+            Object[] source,
+            int[] columnMap,
+            Object[] target) {
 
         for (int i = 0; i < columnMap.length; i++) {
-            newRow[i] = row[columnMap[i]];
+            if (columnMap[i] >= 0) {
+                target[i] = source[columnMap[i]];
+            }
         }
     }
 
-    public static void projectRow(int[] row, int[] columnMap, int[] newRow) {
+    public static void projectRow(int[] source, int[] columnMap, int[] target) {
 
         for (int i = 0; i < columnMap.length; i++) {
-            newRow[i] = row[columnMap[i]];
+            if (columnMap[i] >= 0) {
+                target[i] = source[columnMap[i]];
+            }
         }
     }
 
     /**
-     *  As above but copies in reverse direction. <p>
+     *  As above but copies in reverse direction.
      *
-     *  @param row the target array
+     *  @param target the target array
      *  @param columnMap the list of indexes into row
-     *  @param newRow the source array
+     *  @param source the source array
      */
-    public static void projectRowReverse(Object[] row, int[] columnMap,
-                                         Object[] newRow) {
+    public static void projectRowReverse(
+            Object[] target,
+            int[] columnMap,
+            Object[] source) {
 
         for (int i = 0; i < columnMap.length; i++) {
-            row[columnMap[i]] = newRow[i];
+            if (columnMap[i] >= 0) {
+                target[columnMap[i]] = source[i];
+            }
         }
     }
 
-/*
-    public static void copyColumnValues(int[] row, int[] colindex,
-                                        int[] colobject) {
-
-        for (int i = 0; i < colindex.length; i++) {
-            colobject[i] = row[colindex[i]];
-        }
-    }
-
-    public static void copyColumnValues(boolean[] row, int[] colindex,
-                                        boolean[] colobject) {
-
-        for (int i = 0; i < colindex.length; i++) {
-            colobject[i] = row[colindex[i]];
-        }
-    }
-
-    public static void copyColumnValues(byte[] row, int[] colindex,
-                                        byte[] colobject) {
-
-        for (int i = 0; i < colindex.length; i++) {
-            colobject[i] = row[colindex[i]];
-        }
-    }
-*/
-    public static void projectMap(int[] mainMap, int[] subMap,
-                                  int[] newSubMap) {
+    public static void projectMap(
+            int[] mainMap,
+            int[] subMap,
+            int[] newSubMap) {
 
         for (int i = 0; i < subMap.length; i++) {
             for (int j = 0; j < mainMap.length; j++) {
                 if (subMap[i] == mainMap[j]) {
                     newSubMap[i] = j;
-
                     break;
                 }
             }
         }
     }
 
-    public static void reorderMaps(int[] mainMap, int[] firstMap,
-                                   int[] secondMap) {
+    public static void reorderMaps(
+            int[] mainMap,
+            int[] firstMap,
+            int[] secondMap) {
 
         for (int i = 0; i < mainMap.length; i++) {
             for (int j = i; j < firstMap.length; j++) {
@@ -1780,7 +1873,6 @@ public final class ArrayUtil {
                     temp         = secondMap[i];
                     secondMap[i] = secondMap[j];
                     secondMap[j] = temp;
-
                     break;
                 }
             }
@@ -1788,7 +1880,6 @@ public final class ArrayUtil {
     }
 
     public static void fillSequence(int[] colindex) {
-
         for (int i = 0; i < colindex.length; i++) {
             colindex[i] = i;
         }
@@ -1836,7 +1927,8 @@ public final class ArrayUtil {
      */
     public static boolean isInSortedArray(char ch, char[] array) {
 
-        if (array.length == 0 || ch < array[0]
+        if (array.length == 0
+                || ch < array[0]
                 || ch > array[array.length - 1]) {
             return false;
         }
@@ -1957,7 +2049,7 @@ public final class ArrayUtil {
     }
 
     /**
-     * converts two longs to a byte[]
+     * converts two longs to a byte[16]
      *
      * @param hi long
      * @param lo long
@@ -2014,8 +2106,13 @@ public final class ArrayUtil {
         return compare(a, 0, a.length, b, 0, b.length);
     }
 
-    public static int compare(byte[] a, int aOffset, int aLength, byte[] b,
-                              int bOffset, int bLength) {
+    public static int compare(
+            byte[] a,
+            int aOffset,
+            int aLength,
+            byte[] b,
+            int bOffset,
+            int bLength) {
 
         int length = aLength;
 
@@ -2029,16 +2126,18 @@ public final class ArrayUtil {
             }
 
             return (((int) a[aOffset + i]) & 0xff)
-                   > (((int) b[bOffset + i]) & 0xff) ? 1
-                                                     : -1;
+                   > (((int) b[bOffset + i]) & 0xff)
+                   ? 1
+                   : -1;
         }
 
         if (aLength == bLength) {
             return 0;
         }
 
-        return aLength < bLength ? -1
-                                 : 1;
+        return aLength < bLength
+               ? -1
+               : 1;
     }
 
     /**
