@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,6 +39,7 @@ import java.io.FilenameFilter;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+
 import java.util.Random;
 
 import org.hsqldb.lib.java.JavaSystem;
@@ -66,16 +67,18 @@ public class FileUtil implements FileAccess {
     }
 
     public static FileAccess getFileAccess(boolean isResource) {
-        return isResource ? fileAccessRes
-                          : fileUtil;
+        return isResource
+               ? fileAccessRes
+               : fileUtil;
     }
 
     public boolean isStreamElement(String elementName) {
         return new File(elementName).exists();
     }
 
-    public InputStream openInputStreamElement(String streamName)
-    throws IOException {
+    public InputStream openInputStreamElement(
+            String streamName)
+            throws IOException {
 
         try {
             return new FileInputStream(streamName);
@@ -101,8 +104,10 @@ public class FileUtil implements FileAccess {
         return renameWithOverwrite(oldName, newName);
     }
 
-    public boolean renameElementOrCopy(String oldName, String newName,
-                                       EventLogInterface logger) {
+    public boolean renameElementOrCopy(
+            String oldName,
+            String newName,
+            EventLogInterface logger) {
 
         if (renameWithOverwrite(oldName, newName)) {
             return true;
@@ -120,7 +125,8 @@ public class FileUtil implements FileAccess {
         } catch (IOException e) {
             String message = String.format(
                 "Platform does not allow renaming files and failed to copy file contents from %s to %s",
-                oldName, newName);
+                oldName,
+                newName);
 
             logger.logSevereEvent(message, e);
 
@@ -144,26 +150,30 @@ public class FileUtil implements FileAccess {
         }
 
         if (!delete(oldName)) {
-            logger.logWarningEvent("Failed to delete renamed file " + oldName,
-                                   null);
+            logger.logWarningEvent(
+                "Failed to delete renamed file " + oldName,
+                null);
         }
 
         String message = String.format(
             "Platform does not allow renaming files. Copied file from %s to %s instead",
-            oldName, newName);
+            oldName,
+            newName);
 
         logger.logDetailEvent(message);
 
         return true;
     }
 
-    public OutputStream openOutputStreamElement(String streamName)
-    throws IOException {
+    public OutputStream openOutputStreamElement(
+            String streamName)
+            throws IOException {
         return new FileOutputStream(streamName, false);
     }
 
-    public OutputStream openOutputStreamElementAppend(String streamName)
-    throws IOException {
+    public OutputStream openOutputStreamElementAppend(
+            String streamName)
+            throws IOException {
         return new FileOutputStream(streamName, true);
     }
 
@@ -176,13 +186,12 @@ public class FileUtil implements FileAccess {
     // even if, unlike for File.getCanonicalPath(), (new File("a")).exists() or
     // (new File("A")).exits(), regardless of the hosting system's
     // file path case sensitivity policy.
-    public final boolean fsIsIgnoreCase =
-        (new File("A")).equals(new File("a"));
+    public final boolean fsIsIgnoreCase = (new File("A")).equals(new File("a"));
 
     // posix separator normalized to File.separator?
     // CHECKME: is this true for every file system under Java?
-    public final boolean fsNormalizesPosixSeparator =
-        (new File("/")).getPath().endsWith(File.separator);
+    public final boolean fsNormalizesPosixSeparator = (new File("/")).getPath()
+            .endsWith(File.separator);
 
     // for JDK 1.1 createTempFile
     final Random random = new Random(System.currentTimeMillis());
@@ -232,8 +241,9 @@ public class FileUtil implements FileAccess {
             return false;
         }
 
-        return resource ? null != cla.getResource(fileName)
-                        : FileUtil.getFileUtil().exists(fileName);
+        return resource
+               ? null != cla.getResource(fileName)
+               : FileUtil.getFileUtil().exists(fileName);
     }
 
     /**
@@ -377,8 +387,9 @@ public class FileUtil implements FileAccess {
         }
     }
 
-    public FileAccess.FileSync getFileSync(java.io.OutputStream os)
-    throws IOException {
+    public FileAccess.FileSync getFileSync(
+            java.io.OutputStream os)
+            throws IOException {
         return new FileSync((FileOutputStream) os);
     }
 
@@ -408,7 +419,7 @@ public class FileUtil implements FileAccess {
     public static boolean deleteOrRenameDatabaseFiles(String dbNamePath) {
 
         DatabaseFilenameFilter filter = new DatabaseFilenameFilter(dbNamePath);
-        File[] fileList = filter.getExistingFileListInDirectory();
+        File[] fileList               = filter.getExistingFileListInDirectory();
 
         for (int i = 0; i < fileList.length; i++) {
             fileList[i].delete();
@@ -458,7 +469,6 @@ public class FileUtil implements FileAccess {
      * @return File[]
      */
     public static File[] getDatabaseFileList(String dbNamePath) {
-
         DatabaseFilenameFilter filter = new DatabaseFilenameFilter(dbNamePath);
 
         return filter.getExistingFileListInDirectory();
@@ -474,7 +484,8 @@ public class FileUtil implements FileAccess {
      */
     public static File[] getDatabaseMainFileList(String dbNamePath) {
 
-        DatabaseFilenameFilter filter = new DatabaseFilenameFilter(dbNamePath,
+        DatabaseFilenameFilter filter = new DatabaseFilenameFilter(
+            dbNamePath,
             false);
 
         return filter.getExistingFileListInDirectory();
@@ -484,9 +495,12 @@ public class FileUtil implements FileAccess {
 
     public static String newDiscardFileName(String filename) {
 
+        String ts = Integer.toHexString((int) System.currentTimeMillis());
         String timestamp = StringUtil.toPaddedString(
-            Integer.toHexString((int) System.currentTimeMillis()),
-            discardSuffixLength - 1, '0', true);
+            ts,
+            discardSuffixLength - 1,
+            '0',
+            true);
         String discardName = filename + "." + timestamp + ".old";
 
         return discardName;
@@ -494,12 +508,10 @@ public class FileUtil implements FileAccess {
 
     static class DatabaseFilenameFilter implements FilenameFilter {
 
-        String[]        suffixes      = new String[] {
+        String[]        suffixes = new String[] {
             ".backup", ".properties", ".script", ".data", ".log", ".lobs"
         };
-        String[]        extraSuffixes = new String[] {
-            ".lck", ".sql.log", ".app.log"
-        };
+        String[] extraSuffixes = new String[]{ ".lck", ".sql.log", ".app.log" };
         private String  dbName;
         private File    parent;
         private File    canonicalFile;
@@ -535,8 +547,8 @@ public class FileUtil implements FileAccess {
 
         public File[] getExistingMainFileSetList() {
 
-            File[]        fileList = getCompleteMainFileSetList();
-            HsqlArrayList list     = new HsqlArrayList();
+            File[]              fileList = getCompleteMainFileSetList();
+            HsqlArrayList<File> list     = new HsqlArrayList<>();
 
             for (int i = 0; i < fileList.length; i++) {
                 if (fileList[i].exists()) {
@@ -555,8 +567,9 @@ public class FileUtil implements FileAccess {
 
             File[] list = parent.listFiles(this);
 
-            return list == null ? new File[]{}
-                                : list;
+            return list == null
+                   ? new File[]{}
+                   : list;
         }
 
         /**
