@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -70,7 +70,7 @@ public class HsqlTaskQueue {
         taskRunnerThread = null;
     }
 
-    protected final HsqlDeque<Runnable> queue = new HsqlDeque<Runnable>();
+    protected final HsqlDeque<Runnable> queue = new HsqlDeque<>();
 
     protected class TaskRunner implements Runnable {
 
