@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -59,7 +59,7 @@ class HsqlThreadFactory implements ThreadFactory {
 
     /**
      * Constructs a new HsqlThreadFactory whose retrieved threads come from the
-     * specified ThreadFactory object or from this factory implementation, if'
+     * specified ThreadFactory object or from this factory implementation, if
      * the specified implementation is null.
      *
      * @param f the factory implementation this factory uses
@@ -74,8 +74,9 @@ class HsqlThreadFactory implements ThreadFactory {
      * @return the requested thread instance
      */
     public Thread newThread(Runnable r) {
-        return factory == this ? new Thread(r)
-                               : factory.newThread(r);
+        return factory == this
+               ? new Thread(r)
+               : factory.newThread(r);
     }
 
     /**
@@ -92,8 +93,9 @@ class HsqlThreadFactory implements ThreadFactory {
         ThreadFactory old;
 
         old     = factory;
-        factory = (f == null) ? this
-                              : f;
+        factory = (f == null)
+                  ? this
+                  : f;
 
         return old;
     }
