@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -92,8 +92,9 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      *      by this class will be used.
      */
     public HsqlTimer(final ThreadFactory threadFactory) {
-        this.threadFactory = (threadFactory == null) ? this
-                                                     : threadFactory;
+        this.threadFactory = (threadFactory == null)
+                             ? this
+                             : threadFactory;
     }
 
     /**
@@ -108,9 +109,11 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
         final long awhen = ((Task) a).getNextScheduled();
         final long bwhen = ((Task) b).getNextScheduled();
 
-        return (awhen < bwhen) ? -1
-                               : (awhen == bwhen) ? 0
-                                                  : 1;
+        return (awhen < bwhen)
+               ? -1
+               : (awhen == bwhen)
+                 ? 0
+                 : 1;
     }
 
     /**
@@ -156,8 +159,8 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
         if (this.isShutdown) {
             throw new IllegalStateException("isShutdown==true");
         } else if (this.taskRunnerThread == null) {
-            this.taskRunnerThread =
-                this.threadFactory.newThread(this.taskRunner);
+            this.taskRunnerThread = this.threadFactory.newThread(
+                this.taskRunner);
 
             this.taskRunnerThread.start();
         } else {
@@ -174,9 +177,10 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @return opaque reference to the internal task
      * @throws IllegalArgumentException if runnable is null
      */
-    public Object scheduleAfter(final long delay,
-                                final Runnable runnable)
-                                throws IllegalArgumentException {
+    public Object scheduleAfter(
+            final long delay,
+            final Runnable runnable)
+            throws IllegalArgumentException {
 
         if (runnable == null) {
             throw new IllegalArgumentException("runnable == null");
@@ -194,9 +198,10 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @return opaque reference to the internal task
      * @throws IllegalArgumentException if date or runnable is null
      */
-    public Object scheduleAt(final Date date,
-                             final Runnable runnable)
-                             throws IllegalArgumentException {
+    public Object scheduleAt(
+            final Date date,
+            final Runnable runnable)
+            throws IllegalArgumentException {
 
         if (date == null) {
             throw new IllegalArgumentException("date == null");
@@ -219,10 +224,12 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @throws IllegalArgumentException if date or runnable is null, or
      *      period is {@code <= 0}
      */
-    public Object schedulePeriodicallyAt(final Date date, final long period,
-                                         final Runnable runnable,
-                                         final boolean relative)
-                                         throws IllegalArgumentException {
+    public Object schedulePeriodicallyAt(
+            final Date date,
+            final long period,
+            final Runnable runnable,
+            final boolean relative)
+            throws IllegalArgumentException {
 
         if (date == null) {
             throw new IllegalArgumentException("date == null");
@@ -246,9 +253,12 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @param runnable the Runnable to execute.
      * @throws IllegalArgumentException if runnable is null or period is {@code <= 0}
      */
-    public Object schedulePeriodicallyAfter(final long delay,
-            final long period, final Runnable runnable,
-            final boolean relative) throws IllegalArgumentException {
+    public Object schedulePeriodicallyAfter(
+            final long delay,
+            final long period,
+            final Runnable runnable,
+            final boolean relative)
+            throws IllegalArgumentException {
 
         if (period <= 0) {
             throw new IllegalArgumentException("period <= 0");
@@ -319,7 +329,6 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @param task a task reference
      */
     public static void cancel(final Object task) {
-
         if (task instanceof Task) {
             ((Task) task).cancel();
         }
@@ -332,8 +341,9 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @return true if referenced task is cancelled
      */
     public static boolean isCancelled(final Object task) {
-        return (task instanceof Task) ? ((Task) task).isCancelled()
-                                      : true;
+        return (task instanceof Task)
+               ? ((Task) task).isCancelled()
+               : true;
     }
 
     /**
@@ -380,8 +390,9 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @return true if the task is scheduled for periodic execution
      */
     public static boolean isPeriodic(final Object task) {
-        return (task instanceof Task) ? (((Task) task).period > 0)
-                                      : false;
+        return (task instanceof Task)
+               ? (((Task) task).period > 0)
+               : false;
     }
 
     /**
@@ -397,8 +408,9 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
             final Task ltask = (Task) task;
             final long last  = ltask.getLastScheduled();
 
-            return (last == 0) ? null
-                               : new Date(last);
+            return (last == 0)
+                   ? null
+                   : new Date(last);
         } else {
             return null;
         }
@@ -424,8 +436,9 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @param period the new period
      */
     public static Object setPeriod(final Object task, final long period) {
-        return (task instanceof Task) ? ((Task) task).setPeriod(period)
-                                      : task;
+        return (task instanceof Task)
+               ? ((Task) task).setPeriod(period)
+               : task;
     }
 
     /**
@@ -439,11 +452,13 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
 
         if (task instanceof Task) {
             final Task ltask = (Task) task;
-            final long next  = ltask.isCancelled() ? 0
-                                                   : ltask.getNextScheduled();
+            final long next  = ltask.isCancelled()
+                               ? 0
+                               : ltask.getNextScheduled();
 
-            return next == 0 ? null
-                             : new Date(next);
+            return next == 0
+                   ? null
+                   : new Date(next);
         } else {
             return null;
         }
@@ -459,8 +474,11 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @param relative if true, use fixed rate else use fixed delay scheduling
      * @return an opaque reference to the internal task
      */
-    Task addTask(final long first, final Runnable runnable,
-                           final long period, boolean relative) {
+    Task addTask(
+            final long first,
+            final Runnable runnable,
+            final long period,
+            boolean relative) {
 
         if (this.isShutdown) {
             throw new IllegalStateException("shutdown");
@@ -525,7 +543,6 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
                         // at most until the time when the peeked task is
                         // next supposed to execute
                         this.taskQueue.park(wait);
-
                         continue;           // to top of loop
                     } else {
                         this.taskQueue.removeTask();
@@ -579,7 +596,6 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * @return System.currentTimeMillis()
      */
     static long now() {
-
         nowCount++;
 
         return System.currentTimeMillis();
@@ -683,7 +699,7 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
          * Scheduling policy flag. <p>
          *
          * When true, scheduling is fixed rate (as opposed to fixed delay),
-         * and schedule updates are calculated relative to when the task was
+         * and schedule updates are calculated relative to when the task
          * was last run rather than a fixed delay starting from the current
          * wall-clock time provided by System.currentTimeMillis().  <p>
          *
@@ -701,7 +717,10 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
          * @param period the periodicity of execution
          * @param relative if true, use fixed rate scheduling else fixed delay
          */
-        Task(final long first, final Runnable runnable, final long period,
+        Task(
+                final long first,
+                final Runnable runnable,
+                final long period,
                 final boolean relative) {
 
             this.next     = first;
@@ -734,7 +753,6 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
          * @return true if cancelled, else false
          */
         boolean isCancelled() {
-
             synchronized (cancel_mutex) {
                 return cancelled;
             }
@@ -801,8 +819,11 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
             } else {
                 this.cancel();
 
-                return HsqlTimer.this.addTask(now(), this.runnable, newPeriod,
-                                              this.relative);
+                return HsqlTimer.this.addTask(
+                    now(),
+                    this.runnable,
+                    newPeriod,
+                    this.relative);
             }
         }
     }
@@ -813,7 +834,7 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
      * Provides extensions to facilitate and simplify implementing
      * timer functionality.
      */
-    protected static class TaskQueue extends HsqlArrayHeap {
+    protected static class TaskQueue extends HsqlArrayHeap<Task> {
 
         /**
          * Constructs a new TaskQueue with the specified initial capacity and
@@ -823,7 +844,7 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
          * @param oc The ObjectComparator this queue uses to maintain its
          *      Heap invariant.
          */
-        TaskQueue(final int capacity, final Comparator oc) {
+        TaskQueue(final int capacity, final Comparator<Task> oc) {
             super(capacity, oc);
         }
 
@@ -876,15 +897,14 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
          *    interrupted the current thread.  The <i>interrupted status</i> of
          *    the current thread is cleared when this exception is thrown.
          */
-        synchronized void park(final long timeout)
-        throws InterruptedException {
+        synchronized void park(final long timeout) throws InterruptedException {
             this.wait(timeout);
         }
 
         /**
          * Retrieves the head of this queue, without removing it. <p>
          *
-         * This method has the side-effect of removing tasks from the
+         * This method has the side effect of removing tasks from the
          * head of this queue until a non-cancelled task is encountered
          * or this queue is empty. <p>
          *
@@ -940,7 +960,7 @@ public final class HsqlTimer implements Comparator, ThreadFactory {
         Task removeTask() {
 
             // System.out.println("removing task...");
-            return (Task) super.remove();
+            return super.remove();
         }
 
         /**
