@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -62,8 +62,10 @@ public final class InOutUtil {
      * @throws IOException on failure
      * @return int
      */
-    public static int readLine(InputStream in,
-                               OutputStream out) throws IOException {
+    public static int readLine(
+            InputStream in,
+            OutputStream out)
+            throws IOException {
 
         int count = 0;
 
@@ -87,7 +89,7 @@ public final class InOutUtil {
     }
 
     /**
-     * Retrieves the serialized form of the specified <code>Object</code> as an
+     * Retrieves the serialized form of the specified {@code Object} as an
      * array of bytes.
      *
      * @param s the Object to serialize
@@ -106,15 +108,17 @@ public final class InOutUtil {
 
     /**
      * Deserializes the specified byte array to an
-     * <code>Object</code> instance.
+     * {@code Object} instance.
      *
      * @return the Object resulting from deserializing the specified array of bytes
      * @param ba the byte array to deserialize to an Object
      * @throws IOException on failure
      * @throws ClassNotFoundException if not found
      */
-    public static Serializable deserialize(byte[] ba)
-    throws IOException, ClassNotFoundException {
+    public static Serializable deserialize(
+            byte[] ba)
+            throws IOException,
+                   ClassNotFoundException {
 
         HsqlByteArrayInputStream bi = new HsqlByteArrayInputStream(ba);
         ObjectInputStream        is = new ObjectInputStream(bi);
@@ -133,11 +137,16 @@ public final class InOutUtil {
      * @throws IOException on failure
      * @return long
      */
-    public static long copy(final InputStream inputStream,
-                            final OutputStream outputStream)
-                            throws IOException {
-        return copy(inputStream, outputStream, DEFAULT_COPY_AMOUNT,
-                    DEFAULT_COPY_BUFFER_SIZE);
+    public static long copy(
+            final InputStream inputStream,
+            final OutputStream outputStream)
+            throws IOException {
+
+        return copy(
+            inputStream,
+            outputStream,
+            DEFAULT_COPY_AMOUNT,
+            DEFAULT_COPY_BUFFER_SIZE);
     }
 
     /**
@@ -149,15 +158,21 @@ public final class InOutUtil {
      * @throws IOException on failure
      * @return long
      */
-    public static long copy(final InputStream inputStream,
-                            final OutputStream outputStream,
-                            final long amount) throws IOException {
-        return copy(inputStream, outputStream, amount,
-                    DEFAULT_COPY_BUFFER_SIZE);
+    public static long copy(
+            final InputStream inputStream,
+            final OutputStream outputStream,
+            final long amount)
+            throws IOException {
+
+        return copy(
+            inputStream,
+            outputStream,
+            amount,
+            DEFAULT_COPY_BUFFER_SIZE);
     }
 
     /**
-     * the specified <code>amount</code> from the given input stream to the
+     * the specified {@code amount} from the given input stream to the
      * given output stream, using a buffer of the given size.
      *
      * @param inputStream from which to source bytes
@@ -167,10 +182,12 @@ public final class InOutUtil {
      * @return the number of bytes <i>actually</i> transferred.
      * @throws IOException if any, thrown by either of the given stream objects
      */
-    public static long copy(final InputStream inputStream,
-                            final OutputStream outputStream,
-                            final long amount,
-                            final int bufferSize) throws IOException {
+    public static long copy(
+            final InputStream inputStream,
+            final OutputStream outputStream,
+            final long amount,
+            final int bufferSize)
+            throws IOException {
 
         //
         int maxBytesToRead = (int) Math.min(bufferSize, amount);
@@ -183,8 +200,9 @@ public final class InOutUtil {
         int  bytesRead;
 
         while ((bytesCopied < amount)
-                && -1 != (bytesRead = inputStream.read(buffer, 0,
-                    maxBytesToRead))) {
+                && -1 != (bytesRead = inputStream.read(buffer,
+                        0,
+                        maxBytesToRead))) {
 
             //
             outputStream.write(buffer, 0, bytesRead);
@@ -216,10 +234,16 @@ public final class InOutUtil {
      * @throws IOException on failure
      * @return long
      */
-    public static long copy(final Reader reader,
-                            final Writer writer) throws IOException {
-        return copy(reader, writer, DEFAULT_COPY_AMOUNT,
-                    DEFAULT_COPY_BUFFER_SIZE);
+    public static long copy(
+            final Reader reader,
+            final Writer writer)
+            throws IOException {
+
+        return copy(
+            reader,
+            writer,
+            DEFAULT_COPY_AMOUNT,
+            DEFAULT_COPY_BUFFER_SIZE);
     }
 
     /**
@@ -231,13 +255,16 @@ public final class InOutUtil {
      * @throws IOException on failure
      * @return long
      */
-    public static long copy(final Reader reader, final Writer writer,
-                            final long amount) throws IOException {
+    public static long copy(
+            final Reader reader,
+            final Writer writer,
+            final long amount)
+            throws IOException {
         return copy(reader, writer, amount, DEFAULT_COPY_BUFFER_SIZE);
     }
 
     /**
-     * the specified <code>amount</code> from the given input stream to the
+     * the specified {@code amount} from the given input stream to the
      * given output stream, using a buffer of the given size.
      *
      * @param reader from which to source characters
@@ -247,9 +274,12 @@ public final class InOutUtil {
      * @return the number of characters <i>actually</i> transferred.
      * @throws IOException if any, thrown by either of the given stream objects
      */
-    public static long copy(final Reader reader, final Writer writer,
-                            final long amount,
-                            final int bufferSize) throws IOException {
+    public static long copy(
+            final Reader reader,
+            final Writer writer,
+            final long amount,
+            final int bufferSize)
+            throws IOException {
 
         //
         int maxCharsToRead = (int) Math.min(bufferSize, amount);
@@ -262,8 +292,7 @@ public final class InOutUtil {
         int  charsRead;
 
         while ((charsCopied < amount)
-                && -1 != (charsRead = reader.read(buffer, 0,
-                    maxCharsToRead))) {
+                && -1 != (charsRead = reader.read(buffer, 0, maxCharsToRead))) {
 
             //
             writer.write(buffer, 0, charsRead);
