@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,6 +35,8 @@ import java.io.IOException;
 import java.io.InputStream;
 
 /**
+ * A wrapper for a java.io.InputStream object.
+ *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
  * @version 2.2.9
  * @since 2.2.8
@@ -61,8 +63,9 @@ public class InputStreamWrapper implements InputStreamInterface {
             if (limitSize == -1) {
                 return -1;
             } else {
-                throw new IOException("stream not reached the end"
-                                      + fetchedSize + " " + limitSize);
+                throw new IOException(
+                    "stream not reached the end" + fetchedSize + " "
+                    + limitSize);
             }
         }
 
@@ -91,8 +94,9 @@ public class InputStreamWrapper implements InputStreamInterface {
             if (limitSize == -1) {
                 return -1;
             } else {
-                throw new IOException("stream not reached the end"
-                                      + fetchedSize + " " + limitSize);
+                throw new IOException(
+                    "stream not reached the end" + fetchedSize + " "
+                    + limitSize);
             }
         }
 
