@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,10 +34,10 @@ package org.hsqldb.lib;
 import org.hsqldb.map.BaseHashMap;
 
 /**
- * A Map of int primitives to Object values.<p>
+ * A Map of int primitives to Object values.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.0
+ * @version 2.7.3
  * @since 1.7.2
  */
 public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
@@ -51,17 +51,20 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
     }
 
     public IntKeyHashMap(int initialCapacity) throws IllegalArgumentException {
-        super(initialCapacity, BaseHashMap.intKeyOrValue,
-              BaseHashMap.objectKeyOrValue, false);
+
+        super(
+            initialCapacity,
+            BaseHashMap.intKeyOrValue,
+            BaseHashMap.objectKeyOrValue,
+            false);
     }
 
     public boolean containsKey(Object key) {
 
         if (key instanceof Integer) {
-
             int intKey = ((Integer) key).intValue();
 
-            return containsKey(intKey);
+            return containsIntKey(intKey);
         }
 
         if (key == null) {
@@ -72,27 +75,22 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
     }
 
     public boolean containsKey(int key) {
-        return super.containsKey(key);
+        return super.containsIntKey(key);
     }
 
     public boolean containsValue(Object value) {
         return super.containsValue(value);
     }
 
-    public V get(Object key) {
-
-        if (key instanceof Integer) {
-
-            int intKey = ((Integer) key).intValue();
-
-            return get(intKey);
-        }
+    public V get(Integer key) {
 
         if (key == null) {
             throw new NullPointerException();
         }
 
-        return null;
+        int intKey = key.intValue();
+
+        return get(intKey);
     }
 
     public V get(int key) {
@@ -112,7 +110,7 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
             throw new NullPointerException();
         }
 
-        int intKey = ((Integer) key).intValue();
+        int intKey = key.intValue();
 
         return put(intKey, value);
     }
@@ -122,8 +120,8 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
     }
 
     public V remove(Object key) {
-        if (key instanceof Integer) {
 
+        if (key instanceof Integer) {
             int intKey = ((Integer) key).intValue();
 
             return remove(intKey);
@@ -140,30 +138,14 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
         return (V) super.remove(key, 0, null, null, false, false);
     }
 
-    public void putAll(Map<? extends Integer, ? extends V> other) {
-        Iterator<? extends Integer> it = other.keySet().iterator();
+    public void putAll(IntKeyHashMap<V> other) {
 
-        while (it.hasNext()) {
-            Integer key = it.next();
-
-            if (key == null) {
-                continue;
-            }
-
-            int intKey = key.intValue();
-
-            put(intKey, (V) other.get(key));
-        }
-    }
-
-    public void putAll(IntKeyHashMap other) {
-
-        PrimitiveIterator it = (PrimitiveIterator) other.keySet().iterator();
+        Iterator<Integer> it = other.keySet().iterator();
 
         while (it.hasNext()) {
             int key = it.nextInt();
 
-            put(key, (V) other.get(key));
+            put(key, other.get(key));
         }
     }
 
@@ -172,7 +154,6 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
     }
 
     public Object[] valuesToArray() {
-
         return toArray(false);
     }
 
@@ -180,6 +161,14 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
         return toArray(array, false);
     }
 
+    public int[] getKeyArray() {
+        return intKeyTable;
+    }
+
+    public Object[] getValueArray() {
+        return objectValueTable;
+    }
+
     public Set<Integer> keySet() {
 
         if (keySet == null) {
@@ -199,6 +188,7 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
     }
 
     public Set<Entry<Integer, V>> entrySet() {
+
         if (entries == null) {
             entries = new EntrySet();
         }
@@ -206,7 +196,9 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
         return entries;
     }
 
-    private class EntrySet extends AbstractReadOnlyCollection<Map.Entry<Integer, V>> implements Set<Map.Entry<Integer, V>> {
+    private class EntrySet
+            extends AbstractReadOnlyCollection<Map.Entry<Integer, V>>
+            implements Set<Map.Entry<Integer, V>> {
 
         public Iterator<Entry<Integer, V>> iterator() {
             return IntKeyHashMap.this.new EntrySetIterator();
@@ -221,23 +213,25 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
         }
     }
 
-    private class EntrySetIterator extends BaseHashIterator{
+    private class EntrySetIterator extends BaseHashIterator {
 
         EntrySetIterator() {
             super(true);
         }
 
         public Entry<Integer, V> next() {
-            Integer key   = super.nextInt();
-            V value       = (V) objectValueTable[lookup];
 
-            return new MapEntry(key, value);
+            Integer key   = super.nextInt();
+            V       value = (V) objectValueTable[lookup];
+
+            return new MapEntry<>(key, value);
         }
     }
 
-    private class KeySet<Integer> extends AbstractReadOnlyCollection<Integer> implements Set<Integer> {
+    private class KeySet extends AbstractReadOnlyCollection<Integer>
+            implements Set<Integer> {
 
-        public PrimitiveIterator<Integer> iterator() {
+        public Iterator<Integer> iterator() {
             return IntKeyHashMap.this.new BaseHashIterator(true);
         }
 
@@ -250,7 +244,7 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
         }
     }
 
-    private class Values<V> extends AbstractReadOnlyCollection<V> {
+    private class Values extends AbstractReadOnlyCollection<V> {
 
         public Iterator<V> iterator() {
             return IntKeyHashMap.this.new BaseHashIterator(false);
@@ -263,13 +257,5 @@ public class IntKeyHashMap<V> extends BaseHashMap implements Map<Integer, V> {
         public boolean isEmpty() {
             return size() == 0;
         }
-
-        public Object[] toArray() {
-            return IntKeyHashMap.this.toArray(false);
-        }
-
-        public <T> T[] toArray(T[] array) {
-            return IntKeyHashMap.this.toArray(array, false);
-        }
     }
 }
