@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,36 +36,40 @@ import java.util.NoSuchElementException;
 import org.hsqldb.map.BaseHashMap;
 
 /**
- * A Map of int primitive keys to long primitive values.<p>
+ * A Map of int primitive keys to long primitive values.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
  * @version 2.6.0
  * @since 1.7.2
  */
-public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer, Long> {
+public class IntKeyLongValueHashMap extends BaseHashMap
+        implements Map<Integer, Long> {
 
     private Set<Integer>              keySet;
     private Collection<Long>          values;
     private Set<Entry<Integer, Long>> entries;
 
-
     public IntKeyLongValueHashMap() {
         this(8);
     }
 
-    public IntKeyLongValueHashMap(int initialCapacity) throws
-        IllegalArgumentException {
-        super(initialCapacity, BaseHashMap.intKeyOrValue,
-              BaseHashMap.longKeyOrValue, false);
+    public IntKeyLongValueHashMap(
+            int initialCapacity)
+            throws IllegalArgumentException {
+
+        super(
+            initialCapacity,
+            BaseHashMap.intKeyOrValue,
+            BaseHashMap.longKeyOrValue,
+            false);
     }
 
     public boolean containsKey(Object key) {
 
         if (key instanceof Integer) {
-
             int intKey = ((Integer) key).intValue();
 
-            return super.containsKey(intKey);
+            return super.containsIntKey(intKey);
         }
 
         if (key == null) {
@@ -76,12 +80,12 @@ public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer,
     }
 
     public boolean containsKey(int key) {
-        return super.containsKey(key);
+        return super.containsIntKey(key);
     }
 
     public boolean containsValue(Object value) {
-        if (value instanceof Long) {
 
+        if (value instanceof Long) {
             long longValue = ((Long) value).longValue();
 
             return super.containsValue(longValue);
@@ -94,29 +98,25 @@ public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer,
         return false;
     }
 
-    public boolean containsValue(int value) {
+    public boolean containsValue(long value) {
         return super.containsValue(value);
     }
 
-    public Long get(Object key) {
-
-        if (key instanceof Integer) {
-
-            int intKey = ((Integer) key).intValue();
-
-            try {
-                long longVal = get(intKey);
-
-                return Long.valueOf(longVal);
-            } catch (NoSuchElementException e) {
-                return null;
-            }
-        }
+    public Long get(Integer key) {
 
         if (key == null) {
             throw new NullPointerException();
         }
 
+        int intKey = key.intValue();
+        int lookup = getLookup(intKey);
+
+        if (lookup != -1) {
+            long longValue = longValueTable[lookup];
+
+            return Long.valueOf(longValue);
+        }
+
         return null;
     }
 
@@ -182,11 +182,11 @@ public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer,
     }
 
     public Long remove(Object key) {
-        if (key instanceof Integer) {
 
+        if (key instanceof Integer) {
             int intKey = ((Integer) key).intValue();
 
-            return (Long)super.remove(intKey, 0, null, null, false, false);
+            return (Long) super.remove(intKey, 0, null, null, false, false);
         }
 
         if (key == null) {
@@ -197,39 +197,23 @@ public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer,
     }
 
     public boolean remove(int key) {
+        Long value = (Long) super.remove(key, 0, null, null, false, false);
 
-        Long value = (Long)super.remove(key, 0, null, null, false, false);
-
-        return value == null ? false : true;
+        return value != null;
     }
 
-    public void putAll(Map<? extends Integer, ? extends Long> other) {
+    public void putAll(IntKeyLongValueHashMap other) {
 
-        Iterator<? extends Integer> it = other.keySet().iterator();
+        Iterator<Integer> it = other.keySet().iterator();
 
         while (it.hasNext()) {
-            Integer key = it.next();
-            int intKey = key.intValue();
-            Long value = other.get(key);
-            long longValue = value.longValue();
+            int  intKey    = it.nextInt();
+            long longValue = other.get(intKey);
 
             put(intKey, longValue);
         }
     }
 
-    public void putAll(IntKeyIntValueHashMap other) {
-
-        PrimitiveIterator it = (PrimitiveIterator) other.keySet().iterator();
-
-        while (it.hasNext()) {
-
-            int intKey = it.nextInt();
-            int intValue = other.get(intKey);
-
-            put(intKey, intValue);
-        }
-    }
-
     public int[] keysToArray(int[] array) {
         return toIntArray(array, true);
     }
@@ -239,6 +223,7 @@ public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer,
     }
 
     public Set<Integer> keySet() {
+
         if (keySet == null) {
             keySet = new KeySet();
         }
@@ -256,6 +241,7 @@ public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer,
     }
 
     public Set<Map.Entry<Integer, Long>> entrySet() {
+
         if (entries == null) {
             entries = new EntrySet();
         }
@@ -263,7 +249,9 @@ public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer,
         return entries;
     }
 
-    private class EntrySet extends AbstractReadOnlyCollection<Map.Entry<Integer, Long>> implements Set<Map.Entry<Integer, Long>> {
+    private class EntrySet
+            extends AbstractReadOnlyCollection<Map.Entry<Integer, Long>>
+            implements Set<Map.Entry<Integer, Long>> {
 
         public Iterator<Map.Entry<Integer, Long>> iterator() {
             return IntKeyLongValueHashMap.this.new EntrySetIterator();
@@ -278,21 +266,23 @@ public class IntKeyLongValueHashMap extends BaseHashMap implements Map<Integer,
         }
     }
 
-    private class EntrySetIterator extends BaseHashIterator{
+    private class EntrySetIterator extends BaseHashIterator {
 
         EntrySetIterator() {
             super(true);
         }
 
         public Entry<Integer, Long> next() {
+
             Integer key   = super.nextInt();
             Long    value = longValueTable[lookup];
 
-            return new MapEntry(key, value);
+            return new MapEntry<>(key, value);
         }
     }
 
-    private class KeySet extends AbstractReadOnlyCollection<Integer> implements Set<Integer> {
+    private class KeySet extends AbstractReadOnlyCollection<Integer>
+            implements Set<Integer> {
 
         public PrimitiveIterator<Integer> iterator() {
             return IntKeyLongValueHashMap.this.new BaseHashIterator(true);
