@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -87,7 +87,6 @@ public class LongDeque {
     }
 
     public long get(int i) throws IndexOutOfBoundsException {
-
         int index = getInternalIndex(i);
 
         return list[index];
@@ -238,8 +237,12 @@ public class LongDeque {
                 firstindex = 0;
             }
         } else if (target > firstindex) {
-            System.arraycopy(list, firstindex, list, firstindex + 1,
-                             target - firstindex);
+            System.arraycopy(
+                list,
+                firstindex,
+                list,
+                firstindex + 1,
+                target - firstindex);
 
             list[firstindex] = 0;
 
@@ -249,8 +252,12 @@ public class LongDeque {
                 firstindex = 0;
             }
         } else {
-            System.arraycopy(list, target + 1, list, target,
-                             endindex - target - 1);
+            System.arraycopy(
+                list,
+                target + 1,
+                list,
+                target,
+                endindex - target - 1);
 
             endindex--;
 
@@ -288,14 +295,12 @@ public class LongDeque {
     }
 
     public void toArray(int[] array) {
-
         for (int i = 0; i < elementCount; i++) {
             array[i] = (int) get(i);
         }
     }
 
     public void toArray(long[] array) {
-
         for (int i = 0; i < elementCount; i++) {
             array[i] = get(i);
         }
@@ -335,8 +340,12 @@ public class LongDeque {
 
         long[] newList = new long[list.length * 2];
 
-        System.arraycopy(list, firstindex, newList, firstindex,
-                         list.length - firstindex);
+        System.arraycopy(
+            list,
+            firstindex,
+            newList,
+            firstindex,
+            list.length - firstindex);
 
         if (endindex <= firstindex) {
             System.arraycopy(list, 0, newList, list.length, endindex);
