@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,7 +38,7 @@ package org.hsqldb.lib;
  * This class does not store null elements.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.3
  * @since 1.9.0
  */
 public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
@@ -61,40 +61,36 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
         this.isList = true;
     }
 
-    public OrderedHashSet(Object[] valueList) {
+    public OrderedHashSet(E[] valueList) {
+
         this(valueList.length);
 
         for (int i = 0; i < valueList.length; i++) {
-            add((E) valueList[i]);
+            add(valueList[i]);
         }
     }
 
-    public boolean remove(Object key) {
+    public boolean remove(E key) {
 
         if (key == null) {
             throw new NullPointerException();
         }
 
-        return (Boolean) super.remove(0, 0, key, null, false, true);
+        return (boolean) super.remove(0, 0, key, null, false, true);
     }
 
     public E remove(int index) {
 
         checkRange(index);
 
-        E key = (E)objectKeyTable[index];
+        E key = (E) objectKeyTable[index];
 
         super.remove(0, 0, key, null, false, true);
 
         return key;
     }
 
-    public void removeEntry(int index) throws IndexOutOfBoundsException {
-        remove(index);
-    }
-
-    public boolean insert(int index,
-                          E key) throws IndexOutOfBoundsException {
+    public boolean insert(int index, E key) throws IndexOutOfBoundsException {
 
         if (index < 0 || index > size()) {
             throw new IndexOutOfBoundsException();
@@ -112,6 +108,7 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
     }
 
     public E set(int index, E key) {
+
         if (key == null) {
             throw new NullPointerException();
         }
@@ -125,13 +122,13 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
         E oldKey = (E) objectKeyTable[index];
 
         super.remove(0, 0, oldKey, null, false, false);
-
         add(key);
 
         return oldKey;
     }
 
     public void add(int index, E key) {
+
         boolean result = insert(index, key);
 
         if (!result) {
@@ -140,7 +137,6 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
     }
 
     public E get(int index) {
-
         checkRange(index);
 
         return (E) objectKeyTable[index];
@@ -148,6 +144,7 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
 
     public Object[] toArray() {
         Object[] array = new Object[size()];
+
         return toArray(array);
     }
 
@@ -206,7 +203,7 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
         int count = 0;
 
         for (int i = 0, size = size(); i < size; i++) {
-            if (other.contains((E) objectKeyTable[i])) {
+            if (other.contains(objectKeyTable[i])) {
                 count++;
             }
         }
@@ -214,15 +211,21 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
         return count;
     }
 
-    public static <E> OrderedHashSet<E> addAll(OrderedHashSet<E> first,
-                                        OrderedHashSet<E> second) {
+    /**
+     * add all elements of second to first.
+     * if second is null return first (which can be null),
+     * else if first is null return a new set and add the elements of second
+     */
+    public static <E> OrderedHashSet<E> addAll(
+            OrderedHashSet<E> first,
+            OrderedHashSet<E> second) {
 
         if (second == null) {
             return first;
         }
 
         if (first == null) {
-            first = new OrderedHashSet<E>();
+            first = new OrderedHashSet<>();
         }
 
         first.addAll(second);
@@ -230,6 +233,11 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
         return first;
     }
 
+    /**
+     * add value to first.
+     * if value is null return first (which can be null),
+     * else if first is null return a new set and add the value
+     */
     public static <E> OrderedHashSet<E> add(OrderedHashSet<E> first, E value) {
 
         if (value == null) {
@@ -237,7 +245,7 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
         }
 
         if (first == null) {
-            first = new OrderedHashSet<E>();
+            first = new OrderedHashSet<>();
         }
 
         first.add(value);
@@ -246,7 +254,6 @@ public class OrderedHashSet<E> extends HashSet<E> implements List<E>, Set<E> {
     }
 
     private void checkRange(int i) {
-
         if (i < 0 || i >= size()) {
             throw new IndexOutOfBoundsException();
         }
