@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,7 @@ package org.hsqldb.lib;
 import java.io.IOException;
 import java.io.InputStream;
 import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.Locale;
@@ -44,7 +45,7 @@ import java.util.ResourceBundle;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-/* $Id: RefCapablePropertyResourceBundle.java 6513 2022-05-18 03:25:20Z unsaved $ */
+/* $Id: RefCapablePropertyResourceBundle.java 6697 2024-03-12 22:56:35Z fredt $ */
 
 /**
  * Just like PropertyResourceBundle, except keys mapped to nothing in the
@@ -81,32 +82,32 @@ import java.util.regex.Pattern;
  * <P>
  * REFERENCED FILE DIRECTORY is a directory named with the base name of the
  * properties file, and in the same parent directory.  So, the referenced
- * file directory <CODE>/a/b/c/greentea</CODE> is used to hold all reference
- * files for properties files <CODE>/a/b/c/greentea_en_us.properties</CODE>,
- * <CODE>/a/b/c/greentea_de.properties</CODE>,
- * <CODE>/a/b/c/greentea.properties</CODE>, etc.
+ * file directory {@code /a/b/c/greentea} is used to hold all reference
+ * files for properties files {@code /a/b/c/greentea_en_us.properties},
+ * {@code /a/b/c/greentea_de.properties},
+ * {@code /a/b/c/greentea.properties}, etc.
  * (BTW, according to ResourceBundle rules, this resource should be looked
  * up with name "a.b.c.greentea", not "/a/b/c..." or "a/b/c").
  * REFERENCED FILES themselves all have the base name of the property key,
  * with locale appendages exactly as the <i>referring</i> properties files
- * has, plus the suffix <CODE>.text</CODE>.
+ * has, plus the suffix {@code .text}.
  * <P>
  * So, if we have the following line in
- * <CODE>/a/b/c/greentea_de.properties</CODE>:
+ * {@code /a/b/c/greentea_de.properties}:
  * <PRE>
  *     1: eins
  * </PRE>
  * then you <b>must</b> have a reference text file
- * <CODE>/a/b/c/greentea/1_de.properties</CODE>:
+ * {@code /a/b/c/greentea/1_de.properties}:
  * <P>
  * In reference text files,
  * sequences of "\r", "\n" and "\r\n" are all translated to the line
- * delimiter for your platform (System property <CODE>line.separator</CODE>).
+ * delimiter for your platform (System property {@code line.separator}).
  * If one of those sequences exists at the very end of the file, it will be
  * eliminated (so, if you really want getString() to end with a line delimiter,
  * end your file with two of them).
  * (The file itself is never modified-- I'm talking about the value returned
- * by <CODE>getString(String)</CODE>).
+ * by {@code getString(String)}).
  * <P>
  * To prevent throwing at runtime due to unset variables, use a wrapper class
  * like SqltoolRB (use SqltoolRB.java as a template).
@@ -158,7 +159,7 @@ public class RefCapablePropertyResourceBundle {
     private String language, country, variant;
     static private Map<ResourceBundle, RefCapablePropertyResourceBundle>
             allBundles =
-            new HashMap<ResourceBundle, RefCapablePropertyResourceBundle>();
+            new HashMap<>();
     public static final String LS = System.getProperty("line.separator");
     private Pattern sysPropVarPattern = Pattern.compile(
             "(?s)\\Q${\\E([^}]+?)(?:\\Q:+\\E([^}]+))?\\Q}");
@@ -489,7 +490,7 @@ public class RefCapablePropertyResourceBundle {
         }
 
         try {
-            return new String(ba, Charset.forName("ISO-8859-1"));
+            return new String(ba, StandardCharsets.ISO_8859_1);
         } catch (Throwable re) {
             throw new MissingResourceException(
                 "Value for key '" + key + "' too big to convert to String.  "
