@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -32,6 +32,7 @@
 package org.hsqldb.map;
 
 import java.lang.reflect.Array;
+
 import java.util.Arrays;
 import java.util.NoSuchElementException;
 import java.util.concurrent.atomic.AtomicInteger;
@@ -50,7 +51,7 @@ import org.hsqldb.lib.PrimitiveIterator;
  * Special getOrAddXXX() methods are used for object maps in some subclasses.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.0
+ * @version 2.7.4
  * @since 1.7.2
  */
 public class BaseHashMap {
@@ -93,7 +94,6 @@ public class BaseHashMap {
     protected boolean isLongValue;
     protected boolean isObjectValue;
     protected boolean isMultiValue;
-    protected boolean isTwoObjectValue;
     protected boolean isList;
     protected boolean isAccessCount;
     protected boolean isLastAccessCount;
@@ -116,6 +116,7 @@ public class BaseHashMap {
     protected AtomicInteger accessCount;
     protected int[]         accessTable;
     protected Object[]      objectValueTable2;
+    protected Object[]      objectValueTable3;
 
     //
     protected final float      loadFactor;
@@ -146,9 +147,12 @@ public class BaseHashMap {
     public static final int      ACCESS_MAX = Integer.MAX_VALUE - (1 << 20);
     public static final Object[] emptyObjectArray = new Object[]{};
 
-    protected BaseHashMap(int initialCapacity, int keyType, int valueType,
-                          boolean hasAccessCount)
-                          throws IllegalArgumentException {
+    protected BaseHashMap(
+            int initialCapacity,
+            int keyType,
+            int valueType,
+            boolean hasAccessCount)
+            throws IllegalArgumentException {
 
         if (initialCapacity <= 0) {
             throw new IllegalArgumentException();
@@ -157,7 +161,8 @@ public class BaseHashMap {
         if (initialCapacity < 4) {
             initialCapacity = 4;
         } else {
-            initialCapacity = (int) ArrayUtil.getBinaryNormalisedCeiling(initialCapacity);
+            initialCapacity = (int) ArrayUtil.getBinaryNormalisedCeiling(
+                initialCapacity);
         }
 
         this.loadFactor      = 1;    // can use any value if necessary
@@ -289,8 +294,9 @@ public class BaseHashMap {
     protected PrimitiveIterator getMultiValuesIterator(Object key) {
 
         int lookup = getLookup(key);
-        ValueCollectionIterator valuesIterator =
-            new ValueCollectionIterator(key, lookup);
+        ValueCollectionIterator valuesIterator = new ValueCollectionIterator(
+            key,
+            lookup);
 
         return valuesIterator;
     }
@@ -331,7 +337,6 @@ public class BaseHashMap {
         for (int index = 0; index < hashIndex.hashTable.length; ) {
             if (hashIndex.hashTable[index] < 0) {
                 index++;
-
                 continue;
             }
 
@@ -343,7 +348,6 @@ public class BaseHashMap {
 
             if (lookup < 0) {
                 index++;
-
                 continue;
             }
 
@@ -362,10 +366,13 @@ public class BaseHashMap {
      *
      * returns existing Object value if any or null
      *
-     * returns
+     * for SETs, returns TRUE or FALSE
      */
-    protected Object addOrUpdate(long longKey, long longValue,
-                                 Object objectKey, Object objectValue) {
+    protected Object addOrUpdate(
+            long longKey,
+            long longValue,
+            Object objectKey,
+            Object objectValue) {
 
         int hash;
 
@@ -386,8 +393,7 @@ public class BaseHashMap {
         boolean matched     = false;
 
         for (; lookup >= 0;
-                lastLookup = lookup,
-                lookup = hashIndex.getNextLookup(lookup)) {
+                lastLookup = lookup, lookup = hashIndex.getNextLookup(lookup)) {
             if (isObjectKey) {
                 matched = comparator.equals(objectKeyTable[lookup], objectKey);
             } else if (isIntKey) {
@@ -523,9 +529,13 @@ public class BaseHashMap {
      *
      * returns existing Object value if any (or Object key if this is a set)
      */
-    protected Object remove(long longKey, long longValue, Object objectKey,
-                            Object objectValue, boolean matchValue,
-                            boolean removeRow) {
+    protected Object remove(
+            long longKey,
+            long longValue,
+            Object objectKey,
+            Object objectValue,
+            boolean matchValue,
+            boolean removeRow) {
 
         int hash;
 
@@ -545,8 +555,7 @@ public class BaseHashMap {
         Object returnValue = null;
 
         for (; lookup >= 0;
-                lastLookup = lookup,
-                lookup = hashIndex.getNextLookup(lookup)) {
+                lastLookup = lookup, lookup = hashIndex.getNextLookup(lookup)) {
             boolean matched = false;
 
             if (isObjectKey) {
@@ -561,7 +570,8 @@ public class BaseHashMap {
                 if (matchValue) {
                     if (isObjectValue) {
                         matched = ObjectComparator.defaultComparator.equals(
-                            objectValueTable[lookup], objectValue);
+                            objectValueTable[lookup],
+                            objectValue);
                     } else if (isIntValue) {
                         matched = intValueTable[lookup] == longValue;
                     } else if (isLongKey) {
@@ -650,8 +660,11 @@ public class BaseHashMap {
      * Single method for adding key / values in multi-value maps.
      * Values for each key are clustered.
      */
-    protected boolean addMultiVal(long longKey, long longValue,
-                                  Object objectKey, Object objectValue) {
+    protected boolean addMultiVal(
+            long longKey,
+            long longValue,
+            Object objectKey,
+            Object objectValue) {
 
         int hash;
 
@@ -672,8 +685,7 @@ public class BaseHashMap {
         boolean matched    = false;
 
         for (; lookup >= 0;
-                lastLookup = lookup,
-                lookup = hashIndex.getNextLookup(lookup)) {
+                lastLookup = lookup, lookup = hashIndex.getNextLookup(lookup)) {
             if (isObjectKey) {
                 matched = comparator.equals(objectKeyTable[lookup], objectKey);
             } else if (isIntKey) {
@@ -694,7 +706,8 @@ public class BaseHashMap {
 
             if (isObjectValue) {
                 matched = ObjectComparator.defaultComparator.equals(
-                    objectValueTable[lookup], objectValue);
+                    objectValueTable[lookup],
+                    objectValue);
             } else if (isIntValue) {
                 matched = longValue == intValueTable[lookup];
             } else if (isLongValue) {
@@ -767,9 +780,12 @@ public class BaseHashMap {
     /**
      * Single method for removing key / values in multi-value maps.
      */
-    protected Object removeMultiVal(long longKey, long longValue,
-                                    Object objectKey, Object objectValue,
-                                    boolean matchValue) {
+    protected Object removeMultiVal(
+            long longKey,
+            long longValue,
+            Object objectKey,
+            Object objectValue,
+            boolean matchValue) {
 
         if (objectKey == null) {
             return null;
@@ -783,9 +799,8 @@ public class BaseHashMap {
         Object returnValue = null;
 
         for (; lookup >= 0;
-                lastLookup = lookup,
-                lookup = hashIndex.getNextLookup(lookup)) {
-            boolean matched = false;
+                lastLookup = lookup, lookup = hashIndex.getNextLookup(lookup)) {
+            boolean matched;
 
             if (isObjectKey) {
                 matched = comparator.equals(objectKeyTable[lookup], objectKey);
@@ -802,7 +817,8 @@ public class BaseHashMap {
 
                 if (matchValue) {
                     matched = ObjectComparator.defaultComparator.equals(
-                        objectValueTable[lookup], objectValue);
+                        objectValueTable[lookup],
+                        objectValue);
 
                     if (matched) {
                         objectKeyTable[lookup]   = null;
@@ -816,8 +832,6 @@ public class BaseHashMap {
                         hashIndex.unlinkNode(index, lastLookup, lookup);
 
                         return returnValue;
-                    } else {
-                        continue;
                     }
                 } else {
                     objectKeyTable[lookup]   = null;
@@ -866,8 +880,7 @@ public class BaseHashMap {
         Object returnValue = null;
 
         for (; lookup >= 0;
-                lastLookup = lookup,
-                lookup = hashIndex.getNextLookup(lookup)) {
+                lastLookup = lookup, lookup = hashIndex.getNextLookup(lookup)) {
             if (!comparator.equals(objectKeyTable[lookup], objectKey)) {
                 continue;
             }
@@ -901,8 +914,10 @@ public class BaseHashMap {
      * For object sets using long key attribute of object for equality and
      * hash. Used in org.hsqldb.persist.Cache
      */
-    protected Object addOrRemoveObject(long longKey, Object object,
-                                       boolean remove) {
+    protected Object addOrRemoveObject(
+            long longKey,
+            Object object,
+            boolean remove) {
 
         int    hash        = (int) (longKey >>> 32 ^ longKey);
         int    index       = hashIndex.getHashIndex(hash);
@@ -911,11 +926,9 @@ public class BaseHashMap {
         Object returnValue = null;
 
         for (; lookup >= 0;
-                lastLookup = lookup,
-                lookup = hashIndex.getNextLookup(lookup)) {
+                lastLookup = lookup, lookup = hashIndex.getNextLookup(lookup)) {
             if (comparator.longKey(objectKeyTable[lookup]) == longKey) {
                 returnValue = objectKeyTable[lookup];
-
                 break;
             }
         }
@@ -1011,16 +1024,18 @@ public class BaseHashMap {
             return;
         }
 
-        hashIndex.reset((int) (newCapacity * loadFactor), newCapacity);
+        hashIndex.reset(newCapacity, newCapacity);
 
         hasZeroKey           = false;
         zeroKeyIndex         = -1;
         zeroOrNullValueCount = 0;
-        threshold    = newCapacity;
+        threshold            = newCapacity;
 
         for (int lookup = -1;
-                (lookup = nextLookup(lookup, limitLookup, oldZeroKey, oldZeroKeyIndex))
-                < limitLookup; ) {
+                (lookup = nextLookup(lookup,
+                                     limitLookup,
+                                     oldZeroKey,
+                                     oldZeroKeyIndex)) < limitLookup; ) {
             long   longKey     = 0;
             long   longValue   = 0;
             Object objectKey   = null;
@@ -1061,61 +1076,77 @@ public class BaseHashMap {
      */
     private void resizeElementArrays(int dataLength, int newLength) {
 
-        Object temp;
-        int    usedLength = newLength > dataLength ? dataLength
-                                                   : newLength;
+        int usedLength = newLength > dataLength
+                         ? dataLength
+                         : newLength;
 
         if (isIntKey) {
-            temp        = intKeyTable;
+            int[] temp = intKeyTable;
+
             intKeyTable = new int[newLength];
 
             System.arraycopy(temp, 0, intKeyTable, 0, usedLength);
         }
 
         if (isIntValue) {
-            temp          = intValueTable;
+            int[] temp = intValueTable;
+
             intValueTable = new int[newLength];
 
             System.arraycopy(temp, 0, intValueTable, 0, usedLength);
         }
 
         if (isLongKey) {
-            temp         = longKeyTable;
+            long[] temp = longKeyTable;
+
             longKeyTable = new long[newLength];
 
             System.arraycopy(temp, 0, longKeyTable, 0, usedLength);
         }
 
         if (isLongValue) {
-            temp           = longValueTable;
+            long[] temp = longValueTable;
+
             longValueTable = new long[newLength];
 
             System.arraycopy(temp, 0, longValueTable, 0, usedLength);
         }
 
         if (objectKeyTable != null) {
-            temp           = objectKeyTable;
+            Object[] temp = objectKeyTable;
+
             objectKeyTable = new Object[newLength];
 
             System.arraycopy(temp, 0, objectKeyTable, 0, usedLength);
         }
 
         if (isObjectValue) {
-            temp             = objectValueTable;
+            Object[] temp = objectValueTable;
+
             objectValueTable = new Object[newLength];
 
             System.arraycopy(temp, 0, objectValueTable, 0, usedLength);
         }
 
         if (objectValueTable2 != null) {
-            temp              = objectValueTable2;
+            Object[] temp = objectValueTable2;
+
             objectValueTable2 = new Object[newLength];
 
             System.arraycopy(temp, 0, objectValueTable2, 0, usedLength);
         }
 
+        if (objectValueTable3 != null) {
+            Object[] temp = objectValueTable3;
+
+            objectValueTable3 = new Object[newLength];
+
+            System.arraycopy(temp, 0, objectValueTable3, 0, usedLength);
+        }
+
         if (accessTable != null) {
-            temp        = accessTable;
+            int[] temp = accessTable;
+
             accessTable = new int[newLength];
 
             System.arraycopy(temp, 0, accessTable, 0, usedLength);
@@ -1149,6 +1180,10 @@ public class BaseHashMap {
             Arrays.fill(objectValueTable2, from, to, null);
         }
 
+        if (objectValueTable3 != null) {
+            Arrays.fill(objectValueTable3, from, to, null);
+        }
+
         if (accessTable != null) {
             Arrays.fill(accessTable, from, to, 0);
         }
@@ -1160,69 +1195,114 @@ public class BaseHashMap {
     void removeFromElementArrays(int size, int lookup) {
 
         if (isIntKey) {
-            Object array = intKeyTable;
+            int[] array = intKeyTable;
 
-            System.arraycopy(array, lookup + 1, array, lookup,
-                             size - lookup - 1);
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
 
             intKeyTable[size - 1] = 0;
         } else if (isLongKey) {
-            Object array = longKeyTable;
+            long[] array = longKeyTable;
 
-            System.arraycopy(array, lookup + 1, array, lookup,
-                             size - lookup - 1);
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
 
             longKeyTable[size - 1] = 0;
         }
 
         if (objectKeyTable != null) {
-            Object array = objectKeyTable;
+            Object[] array = objectKeyTable;
 
-            System.arraycopy(array, lookup + 1, array, lookup,
-                             size - lookup - 1);
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
 
             objectKeyTable[size - 1] = null;
         }
 
         if (isIntValue) {
-            Object array = intValueTable;
+            int[] array = intValueTable;
 
-            System.arraycopy(array, lookup + 1, array, lookup,
-                             size - lookup - 1);
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
 
             intValueTable[size - 1] = 0;
         } else if (isLongValue) {
-            Object array = longValueTable;
+            long[] array = longValueTable;
 
-            System.arraycopy(array, lookup + 1, array, lookup,
-                             size - lookup - 1);
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
 
             longValueTable[size - 1] = 0;
         }
 
         if (isObjectValue) {
-            Object array = objectValueTable;
+            Object[] array = objectValueTable;
 
-            System.arraycopy(array, lookup + 1, array, lookup,
-                             size - lookup - 1);
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
 
             objectValueTable[size - 1] = null;
         }
 
         if (objectValueTable2 != null) {
-            Object array = objectValueTable2;
+            Object[] array = objectValueTable2;
 
-            System.arraycopy(array, lookup + 1, array, lookup,
-                             size - lookup - 1);
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
 
             objectValueTable2[size - 1] = null;
         }
 
-        if (accessTable != null) {
-            Object array = accessTable;
+        if (objectValueTable3 != null) {
+            Object[] array = objectValueTable3;
 
-            System.arraycopy(array, lookup + 1, array, lookup,
-                             size - lookup - 1);
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
+
+            objectValueTable3[size - 1] = null;
+        }
+
+        if (accessTable != null) {
+            int[] array = accessTable;
+
+            System.arraycopy(
+                array,
+                lookup + 1,
+                array,
+                lookup,
+                size - lookup - 1);
 
             accessTable[size - 1] = 0;
         }
@@ -1234,13 +1314,13 @@ public class BaseHashMap {
     void insertIntoElementArrays(int size, int lookup) {
 
         if (isIntKey) {
-            Object array = intKeyTable;
+            int[] array = intKeyTable;
 
             System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
 
             intKeyTable[lookup] = 0;
         } else if (isLongKey) {
-            Object array = longKeyTable;
+            long[] array = longKeyTable;
 
             System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
 
@@ -1248,7 +1328,7 @@ public class BaseHashMap {
         }
 
         if (objectKeyTable != null) {
-            Object array = objectKeyTable;
+            Object[] array = objectKeyTable;
 
             System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
 
@@ -1256,13 +1336,13 @@ public class BaseHashMap {
         }
 
         if (isIntValue) {
-            Object array = intValueTable;
+            int[] array = intValueTable;
 
             System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
 
             intValueTable[lookup] = 0;
         } else if (isLongValue) {
-            Object array = longValueTable;
+            long[] array = longValueTable;
 
             System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
 
@@ -1270,7 +1350,7 @@ public class BaseHashMap {
         }
 
         if (isObjectValue) {
-            Object array = objectValueTable;
+            Object[] array = objectValueTable;
 
             System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
 
@@ -1278,15 +1358,23 @@ public class BaseHashMap {
         }
 
         if (objectValueTable2 != null) {
-            Object array = objectValueTable2;
+            Object[] array = objectValueTable2;
 
             System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
 
             objectValueTable2[lookup] = null;
         }
 
+        if (objectValueTable3 != null) {
+            Object[] array = objectValueTable3;
+
+            System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
+
+            objectValueTable3[lookup] = null;
+        }
+
         if (accessTable != null) {
-            Object array = accessTable;
+            int[] array = accessTable;
 
             System.arraycopy(array, lookup, array, lookup + 1, size - lookup);
 
@@ -1298,8 +1386,11 @@ public class BaseHashMap {
      * find the next lookup in the key/value tables with an entry
      * allows the use of old limit and zero int key attributes
      */
-    int nextLookup(int lookup, int limitLookup, boolean hasZeroKey,
-                   int zeroKeyIndex) {
+    int nextLookup(
+            int lookup,
+            int limitLookup,
+            boolean hasZeroKey,
+            int zeroKeyIndex) {
 
         for (++lookup; lookup < limitLookup; lookup++) {
             if (isObjectKey) {
@@ -1417,8 +1508,14 @@ public class BaseHashMap {
      * access count. Always return at least accessMin + 1
      */
     protected int getAccessCountCeiling(int count, int margin) {
-        return ArrayCounter.rank(accessTable, hashIndex.newNodePointer, count,
-                                 accessMin, accessCount.get(), margin);
+
+        return ArrayCounter.rank(
+            accessTable,
+            hashIndex.newNodePointer,
+            count,
+            accessMin,
+            accessCount.get(),
+            margin);
     }
 
     /**
@@ -1511,7 +1608,7 @@ public class BaseHashMap {
         return hashIndex.elementCount == 0;
     }
 
-    protected boolean containsKey(Object key) {
+    protected final boolean containsObjectKey(Object key) {
 
         if (key == null) {
             return false;
@@ -1523,11 +1620,10 @@ public class BaseHashMap {
 
         int lookup = getLookup(key, comparator.hashCode(key));
 
-        return lookup == -1 ? false
-                            : true;
+        return lookup != -1;
     }
 
-    protected boolean containsKey(int key) {
+    protected final boolean containsIntKey(int key) {
 
         if (hashIndex.elementCount == 0) {
             return false;
@@ -1535,11 +1631,10 @@ public class BaseHashMap {
 
         int lookup = getLookup(key);
 
-        return lookup == -1 ? false
-                            : true;
+        return lookup != -1;
     }
 
-    protected boolean containsKey(long key) {
+    protected final boolean containsLongKey(long key) {
 
         if (hashIndex.elementCount == 0) {
             return false;
@@ -1547,8 +1642,7 @@ public class BaseHashMap {
 
         int lookup = getLookup(key);
 
-        return lookup == -1 ? false
-                            : true;
+        return lookup != -1;
     }
 
     protected boolean containsValue(Object value) {
@@ -1623,24 +1717,23 @@ public class BaseHashMap {
     }
 
     protected Object[] toArray(boolean keys) {
-
         Object[] array = new Object[size()];
 
         return toArray(array, keys);
     }
 
-
     protected <T> T[] multiValueKeysToArray(T[] array) {
 
         int size = this.multiValueKeyCount();
+
         if (array.length < size) {
-            array = (T[]) Array.newInstance(array.getClass().getComponentType(),
+            array = (T[]) Array.newInstance(
+                array.getClass().getComponentType(),
                 size);
         }
 
-        PrimitiveIterator it = new MultiValueKeyIterator();
-
-        int index = 0;
+        PrimitiveIterator it    = new MultiValueKeyIterator();
+        int               index = 0;
 
         while (it.hasNext()) {
             array[index] = (T) it.next();
@@ -1651,18 +1744,19 @@ public class BaseHashMap {
         return array;
     }
 
-
     protected <T> T[] toArray(T[] array, boolean keys) {
 
         if (array.length < size()) {
-            array = (T[]) Array.newInstance(array.getClass().getComponentType(),
+            array = (T[]) Array.newInstance(
+                array.getClass().getComponentType(),
                 size());
         }
 
-        int limit = hashIndex.getNewNodePointer();
-        int index = 0;
-        Object[] table = keys ? objectKeyTable :
-                                objectValueTable;
+        int      limit = hashIndex.getNewNodePointer();
+        int      index = 0;
+        Object[] table = keys
+                         ? objectKeyTable
+                         : objectValueTable;
 
         for (int i = 0; i < limit; i++) {
             T o = (T) table[i];
@@ -1747,18 +1841,6 @@ public class BaseHashMap {
 
             return value;
         }
-
-        public int nextInt() throws NoSuchElementException {
-            throw new NoSuchElementException("Hash Iterator");
-        }
-
-        public long nextLong() throws NoSuchElementException {
-            throw new NoSuchElementException("Hash Iterator");
-        }
-
-        public void remove() throws NoSuchElementException {
-            throw new NoSuchElementException("Hash Iterator");
-        }
     }
 
     protected class MultiValueKeyIterator implements PrimitiveIterator {
@@ -1769,7 +1851,6 @@ public class BaseHashMap {
         Object  oldKey;
 
         public MultiValueKeyIterator() {
-
             if (hashIndex.elementCount > 0) {
                 toNextLookup();
             }
@@ -1777,10 +1858,9 @@ public class BaseHashMap {
 
         private void toNextLookup() {
 
-            for (; index < hashIndex.hashTable.length; ) {
+            while (index < hashIndex.hashTable.length) {
                 if (hashIndex.hashTable[index] < 0) {
                     index++;
-
                     continue;
                 }
 
@@ -1792,7 +1872,6 @@ public class BaseHashMap {
 
                 if (lookup < 0) {
                     index++;
-
                     continue;
                 }
 
@@ -1832,7 +1911,6 @@ public class BaseHashMap {
         }
 
         public void remove() throws NoSuchElementException {
-
             removeMultiVal(0, 0, oldKey, null, false);
 
             oldKey = null;
@@ -1853,9 +1931,7 @@ public class BaseHashMap {
         /**
          * default is iterator for values
          */
-        public BaseHashIterator() {
-
-        }
+        public BaseHashIterator() {}
 
         public BaseHashIterator(boolean keys) {
 
@@ -1867,7 +1943,6 @@ public class BaseHashMap {
         }
 
         public void reset() {
-
             this.lookup  = -1;
             this.counter = 0;
             this.removed = false;
@@ -1913,7 +1988,7 @@ public class BaseHashMap {
         public int nextInt() throws NoSuchElementException {
 
             if ((keys && !isIntKey) || (!keys && !isIntValue)) {
-                throw new NoSuchElementException("Hash Iterator");
+                throw new UnsupportedOperationException("Hash Iterator");
             }
 
             removed = false;
@@ -1936,7 +2011,7 @@ public class BaseHashMap {
         public long nextLong() throws NoSuchElementException {
 
             if ((keys && !isLongKey) || (!keys && !isLongValue)) {
-                throw new NoSuchElementException("Hash Iterator");
+                throw new UnsupportedOperationException("Hash Iterator");
             }
 
             removed = false;
@@ -1946,8 +2021,9 @@ public class BaseHashMap {
 
                 lookup = nextLookup(lookup);
 
-                return keys ? longKeyTable[lookup]
-                            : longValueTable[lookup];
+                return keys
+                       ? longKeyTable[lookup]
+                       : longValueTable[lookup];
             }
 
             throw new NoSuchElementException("Hash Iterator");
@@ -1965,18 +2041,37 @@ public class BaseHashMap {
 
             if (BaseHashMap.this.isObjectKey) {
                 if (isMultiValue) {
-                    removeMultiVal(0, 0, objectKeyTable[lookup],
-                                   objectValueTable[lookup], true);
+                    removeMultiVal(
+                        0,
+                        0,
+                        objectKeyTable[lookup],
+                        objectValueTable[lookup],
+                        true);
                 } else {
-                    BaseHashMap.this.remove(0, 0, objectKeyTable[lookup],
-                                            null, false, true);
+                    BaseHashMap.this.remove(
+                        0,
+                        0,
+                        objectKeyTable[lookup],
+                        null,
+                        false,
+                        true);
                 }
             } else if (isIntKey) {
-                BaseHashMap.this.remove(intKeyTable[lookup], 0, null, null,
-                                        false, true);
+                BaseHashMap.this.remove(
+                    intKeyTable[lookup],
+                    0,
+                    null,
+                    null,
+                    false,
+                    true);
             } else {
-                BaseHashMap.this.remove(longKeyTable[lookup], 0, null, null,
-                                        false, true);
+                BaseHashMap.this.remove(
+                    longKeyTable[lookup],
+                    0,
+                    null,
+                    null,
+                    false,
+                    true);
             }
 
             if (isList) {
@@ -2049,6 +2144,10 @@ public class BaseHashMap {
             copy.objectValueTable2 = objectValueTable2.clone();
         }
 
+        if (objectValueTable3 != null) {
+            copy.objectValueTable3 = objectValueTable3.clone();
+        }
+
         return copy;
     }
 
