@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,7 +45,7 @@ import org.hsqldb.rowio.RowOutputInterface;
  * object retrieval.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.7.4
  * @since 1.9.0
  */
 public abstract class RowSetNavigator implements RangeIterator {
@@ -58,7 +58,6 @@ public abstract class RowSetNavigator implements RangeIterator {
     int              mode;
     int              currentPos = -1;
     int              rangePosition;
-    boolean          hadNext;
     boolean          isClosed;
 
     /**
@@ -100,11 +99,6 @@ public abstract class RowSetNavigator implements RangeIterator {
      */
     public abstract void add(Object[] data);
 
-    /**
-     * Add row to the end
-     */
-    public abstract boolean addRow(Row row);
-
     /**
      * Remove current row
      */
@@ -123,7 +117,7 @@ public abstract class RowSetNavigator implements RangeIterator {
     public abstract void clear();
 
     /**
-     * Remove any resourses and invalidate
+     * Remove any resources and invalidate
      */
     public abstract void release();
 
@@ -152,15 +146,11 @@ public abstract class RowSetNavigator implements RangeIterator {
         if (hasNext()) {
             currentPos++;
 
-            hadNext = true;
-
             return true;
         } else if (size != 0) {
             currentPos = size;
         }
 
-        hadNext = false;
-
         return false;
     }
 
@@ -172,8 +162,8 @@ public abstract class RowSetNavigator implements RangeIterator {
         throw Error.runtimeError(ErrorCode.U_S0500, "RowSetNavigator");
     }
 
-    public boolean hadNext() {
-        return hadNext;
+    public Object[] getData(long rowId) {
+        throw Error.runtimeError(ErrorCode.U_S0500, "RowSetNavigator");
     }
 
     public boolean beforeFirst() {
@@ -199,7 +189,6 @@ public abstract class RowSetNavigator implements RangeIterator {
     }
 
     public boolean first() {
-
         beforeFirst();
 
         return next();
@@ -229,14 +218,10 @@ public abstract class RowSetNavigator implements RangeIterator {
     /**
      * Uses similar semantics to java.sql.ResultSet except this is 0 based.
      * When position is 0 or positive, it is from the start; when negative,
-     * it is from end
+     * it means beforeFirst()
      */
     public boolean absolute(int position) {
 
-        if (position < 0) {
-            position += size;
-        }
-
         if (position < 0) {
             beforeFirst();
 
@@ -257,7 +242,7 @@ public abstract class RowSetNavigator implements RangeIterator {
             beforeFirst();
         }
 
-        // go to the tagget row;
+        // go to the target row;
         while (position > currentPos) {
             next();
         }
