@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,7 +45,7 @@ import org.hsqldb.rowio.RowOutputInterface;
  * a server-side row set.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.0
+ * @version 2.7.4
  * @since 1.9.0
  */
 public class RowSetNavigatorClient extends RowSetNavigator {
@@ -68,8 +68,10 @@ public class RowSetNavigatorClient extends RowSetNavigator {
         table = new Object[blockSize][];
     }
 
-    public RowSetNavigatorClient(RowSetNavigator source, int offset,
-                                 int blockSize) {
+    public RowSetNavigatorClient(
+            RowSetNavigator source,
+            int offset,
+            int blockSize) {
 
         this.size          = source.size;
         this.baseBlockSize = blockSize;
@@ -83,8 +85,6 @@ public class RowSetNavigatorClient extends RowSetNavigator {
 
             source.next();
         }
-
-        source.beforeFirst();
     }
 
     /**
@@ -95,8 +95,17 @@ public class RowSetNavigatorClient extends RowSetNavigator {
         this.size  = table.length;
     }
 
-    public void setData(int index, Object[] data) {
-        table[index] = data;
+    public void setData(int pos, Object[] data) {
+
+        if (pos < 0 || pos >= size || pos >= currentOffset + table.length) {
+            return;
+        }
+
+        if (pos < currentOffset) {
+            return;
+        }
+
+        table[pos - currentOffset] = data;
     }
 
     public Object[] getData(int index) {
@@ -104,7 +113,7 @@ public class RowSetNavigatorClient extends RowSetNavigator {
     }
 
     /**
-     * Returns the current row object. Type of object is implementation defined.
+     * Returns the current row data.
      */
     public Object[] getCurrent() {
 
@@ -112,8 +121,11 @@ public class RowSetNavigatorClient extends RowSetNavigator {
             return null;
         }
 
-        if (currentPos >= currentOffset + table.length) {
-            getBlock(currentOffset + table.length);
+        if (currentPos >= currentOffset + table.length
+                || currentPos < currentOffset) {
+            int newOffset = (currentPos / baseBlockSize) * baseBlockSize;
+
+            getBlock(newOffset);
         }
 
         return table[currentPos - currentOffset];
@@ -128,8 +140,12 @@ public class RowSetNavigatorClient extends RowSetNavigator {
      */
     public void removeCurrent() {
 
-        System.arraycopy(table, currentPos + 1, table, currentPos,
-                         size - currentPos - 1);
+        System.arraycopy(
+            table,
+            currentPos + 1,
+            table,
+            currentPos,
+            size - currentPos - 1);
 
         table[size - 1] = null;
 
@@ -146,10 +162,6 @@ public class RowSetNavigatorClient extends RowSetNavigator {
         size++;
     }
 
-    public boolean addRow(Row row) {
-        throw Error.runtimeError(ErrorCode.U_S0500, "RowSetNavigatorClient");
-    }
-
     public void clear() {
 
         setData(emptyTable);
@@ -169,10 +181,6 @@ public class RowSetNavigatorClient extends RowSetNavigator {
 
     public boolean absolute(int position) {
 
-        if (position < 0) {
-            position += size;
-        }
-
         if (position < 0) {
             beforeFirst();
 
@@ -214,8 +222,12 @@ public class RowSetNavigatorClient extends RowSetNavigator {
         for (int i = 0; i < size; i++) {
             Object[] data = table[i];
 
-            out.writeData(meta.getColumnCount(), meta.columnTypes, data, null,
-                          null);
+            out.writeData(
+                meta.getColumnCount(),
+                meta.columnTypes,
+                data,
+                null,
+                null);
         }
     }
 
@@ -251,8 +263,12 @@ public class RowSetNavigatorClient extends RowSetNavigator {
         for (int i = 0; i < limit; i++) {
             Object[] data = table[i];
 
-            out.writeData(meta.getColumnCount(), meta.columnTypes, data, null,
-                          null);
+            out.writeData(
+                meta.getExtendedColumnCount(),
+                meta.columnTypes,
+                data,
+                null,
+                null);
         }
     }
 
@@ -262,19 +278,24 @@ public class RowSetNavigatorClient extends RowSetNavigator {
     void getBlock(int offset) {
 
         try {
-            RowSetNavigatorClient source = session.getRows(id, offset,
+            RowSetNavigatorClient source = session.getRows(
+                id,
+                offset,
                 baseBlockSize);
 
             table         = source.table;
             currentOffset = source.currentOffset;
-        } catch (HsqlException e) {}
+        } catch (HsqlException e) {
+            throw e;
+        }
     }
 
     private void ensureCapacity() {
 
         if (size == table.length) {
-            int        newSize  = size == 0 ? 4
-                                            : size * 2;
+            int        newSize  = size == 0
+                                  ? 4
+                                  : size * 2;
             Object[][] newTable = new Object[newSize][];
 
             System.arraycopy(table, 0, newTable, 0, size);
