@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -44,6 +44,7 @@ import org.hsqldb.error.ErrorCode;
 import org.hsqldb.index.Index;
 import org.hsqldb.lib.ArraySort;
 import org.hsqldb.lib.ArrayUtil;
+import org.hsqldb.lib.List;
 import org.hsqldb.lib.LongKeyHashMap;
 import org.hsqldb.result.ResultMetaData;
 import org.hsqldb.rowio.RowInputInterface;
@@ -53,11 +54,11 @@ import org.hsqldb.rowio.RowOutputInterface;
  * Implementation of RowSetNavigator for result sets.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.6.1
+ * @version 2.7.4
  * @since 1.9.0
  */
 public class RowSetNavigatorData extends RowSetNavigator
-implements Comparator<Object[]> {
+        implements Comparator<Object[]> {
 
     public static final Object[][] emptyTable = new Object[0][];
 
@@ -79,16 +80,17 @@ implements Comparator<Object[]> {
     Index orderIndex;
     Index groupIndex;
     Index idIndex;
+    Index rowNumIndex;
 
     //
     final SortAndSlice sortAndSlice;
 
     //
     TreeMap<Object[], Integer> groupMap;
-    LongKeyHashMap             idMap;
+    LongKeyHashMap<Object[]>   idMap;
 
     RowSetNavigatorData(Session session, SortAndSlice sortAndSlice) {
-        this.session = session;
+        this.session      = session;
         this.sortAndSlice = sortAndSlice;
     }
 
@@ -102,19 +104,21 @@ implements Comparator<Object[]> {
         fullIndex          = select.fullIndex;
         orderIndex         = select.orderIndex;
         sortAndSlice       = select.sortAndSlice;
+        idIndex            = select.idIndex;
 
         if (select.isGrouped) {
             mainIndex = select.groupIndex;
-            groupMap    = new TreeMap<Object[], Integer>(this);
+            groupMap  = new TreeMap<>(this);
         }
 
-        if (select.idIndex != null) {
-            idMap = new LongKeyHashMap();
+        if (idIndex != null) {
+            idMap = new LongKeyHashMap<>();
         }
     }
 
-    public RowSetNavigatorData(Session session,
-                               QueryExpression queryExpression) {
+    public RowSetNavigatorData(
+            Session session,
+            QueryExpression queryExpression) {
 
         this.session       = session;
         mainIndex          = queryExpression.mainIndex;
@@ -136,6 +140,18 @@ implements Comparator<Object[]> {
         }
     }
 
+    public RowSetNavigatorData(Session session, List<Object[]> list) {
+
+        this.session = session;
+        sortAndSlice = SortAndSlice.noSort;
+
+        setCapacity(list.size());
+
+        for (int i = 0; i < list.size(); i++) {
+            add(list.get(i));
+        }
+    }
+
     public void sortFull() {
 
         mainIndex = fullIndex;
@@ -176,7 +192,8 @@ implements Comparator<Object[]> {
         }
 
         if (idMap != null) {
-            Long id = (Long) data[visibleColumnCount];
+            Long id =
+                (Long) data[visibleColumnCount + ResultMetaData.SysOffsets.rowId];
 
             idMap.put(id.longValue(), data);
         }
@@ -197,32 +214,38 @@ implements Comparator<Object[]> {
         currentPos = pos;
     }
 
-    public boolean addRow(Row row) {
-        throw Error.runtimeError(ErrorCode.U_S0500, "RowSetNavigatorData");
+    public void updateData(long oldRowId, Object[] newData) {
+
+        if (idMap == null) {
+            throw Error.runtimeError(ErrorCode.U_S0500, "RowSetNavigatorData");
+        }
+
+        Object[] oldData = idMap.get(oldRowId);
+        long newId =
+            (Long) newData[visibleColumnCount + ResultMetaData.SysOffsets.rowId];
+
+        idMap.remove(oldRowId);
+        idMap.put(newId, oldData);
+        ArrayUtil.copyArray(newData, oldData, newData.length);
     }
 
-    public void update(Object[] oldData, Object[] newData) {
+    public void updateData(Object[] oldData, Object[] newData) {
 
-        // noop
+        // no op
     }
 
     void addAdjusted(Object[] data, int[] columnMap) {
-
         data = projectData(data, columnMap);
 
         add(data);
     }
 
-    void insertAdjusted(Object[] data, int[] columnMap) {
-        data = projectData(data, columnMap);
-        insert(data);
-    }
-
     Object[] projectData(Object[] data, int[] columnMap) {
 
         if (columnMap == null) {
-            data = (Object[]) ArrayUtil.resizeArrayIfDifferent(data,
-                    visibleColumnCount);
+            data = (Object[]) ArrayUtil.resizeArrayIfDifferent(
+                data,
+                visibleColumnCount);
         } else {
             Object[] newData = new Object[visibleColumnCount];
 
@@ -240,16 +263,28 @@ implements Comparator<Object[]> {
     void insert(Object[] data) {
 
         ensureCapacity();
-        System.arraycopy(dataTable, currentPos, dataTable, currentPos + 1,
-                         size - currentPos);
+        System.arraycopy(
+            dataTable,
+            currentPos,
+            dataTable,
+            currentPos + 1,
+            size - currentPos);
 
         dataTable[currentPos] = data;
 
         size++;
     }
 
-    public Object[][] getDataTable() {
-        return dataTable;
+    public Object[][] removeDataTable() {
+
+        Object[][] table = dataTable;
+
+        dataTable = emptyTable;
+        size      = 0;
+
+        reset();
+
+        return table;
     }
 
     public void release() {
@@ -271,7 +306,7 @@ implements Comparator<Object[]> {
     }
 
     public void resetRowMap() {
-        groupMap = new TreeMap(this);
+        groupMap = new TreeMap<>(this);
     }
 
     public boolean absolute(int position) {
@@ -291,19 +326,18 @@ implements Comparator<Object[]> {
         throw Error.runtimeError(ErrorCode.U_S0500, "RowSetNavigatorData");
     }
 
-    public Object[] getNextRowData() {
-        return next() ? getCurrent()
-                      : null;
-    }
-
     public boolean next() {
         return super.next();
     }
 
     public void removeCurrent() {
 
-        System.arraycopy(dataTable, currentPos + 1, dataTable, currentPos,
-                         size - currentPos - 1);
+        System.arraycopy(
+            dataTable,
+            currentPos + 1,
+            dataTable,
+            currentPos,
+            size - currentPos - 1);
 
         dataTable[size - 1] = null;
 
@@ -313,8 +347,12 @@ implements Comparator<Object[]> {
 
     public void removeRange(int start, int rows) {
 
-        ArrayUtil.adjustArray(ArrayUtil.CLASS_CODE_OBJECT, dataTable, size,
-                              start, -rows);
+        ArrayUtil.adjustArray(
+            ArrayUtil.CLASS_CODE_OBJECT,
+            dataTable,
+            size,
+            start,
+            -rows);
 
         if (currentPos >= start + rows) {
             currentPos -= rows;
@@ -346,15 +384,19 @@ implements Comparator<Object[]> {
         while (next()) {
             Object[] data = getCurrent();
 
-            out.writeData(meta.getExtendedColumnCount(), meta.columnTypes,
-                          data, null, null);
+            out.writeData(
+                meta.getExtendedColumnCount(),
+                meta.columnTypes,
+                data,
+                null,
+                null);
         }
 
         reset();
     }
 
     public Object[] getData(long rowId) {
-        return (Object[]) idMap.get(rowId);
+        return idMap.get(rowId);
     }
 
     public void copy(RowIterator other, int[] rightColumnIndexes) {
@@ -378,8 +420,12 @@ implements Comparator<Object[]> {
         while (other.next()) {
             currentData = other.getCurrent();
 
-            int position = ArraySort.searchFirst(dataTable, 0, size,
-                                                 currentData, this);
+            int position = ArraySort.searchFirst(
+                dataTable,
+                0,
+                size,
+                currentData,
+                this);
 
             if (position < 0) {
                 position   = -position - 1;
@@ -437,11 +483,12 @@ implements Comparator<Object[]> {
 
         while (next()) {
             Object[] currentData = getCurrent();
-            boolean newGroup =
-                compareData == null
-                || fullIndex.compareRowNonUnique(
-                    (Session) session, currentData, compareData,
-                    visibleColumnCount) != 0;
+            boolean newGroup = compareData == null
+                               || fullIndex.compareRowNonUnique(
+                                   (Session) session,
+                                   currentData,
+                                   compareData,
+                                   visibleColumnCount) != 0;
 
             if (newGroup) {
                 compareData = currentData;
@@ -451,9 +498,10 @@ implements Comparator<Object[]> {
             if (it.next()) {
                 otherData = it.getCurrent();
 
-                if (fullIndex.compareRowNonUnique(
-                        (Session) session, currentData, otherData,
-                        visibleColumnCount) == 0) {
+                if (fullIndex.compareRowNonUnique((Session) session,
+                                                  currentData,
+                                                  otherData,
+                                                  visibleColumnCount) == 0) {
                     continue;
                 }
             }
@@ -511,11 +559,12 @@ implements Comparator<Object[]> {
 
         while (next()) {
             Object[] currentData = getCurrent();
-            boolean newGroup =
-                compareData == null
-                || fullIndex.compareRowNonUnique(
-                    (Session) session, currentData, compareData,
-                    fullIndex.getColumnCount()) != 0;
+            boolean newGroup = compareData == null
+                               || fullIndex.compareRowNonUnique(
+                                   (Session) session,
+                                   currentData,
+                                   compareData,
+                                   fullIndex.getColumnCount()) != 0;
 
             if (newGroup) {
                 compareData = currentData;
@@ -525,9 +574,10 @@ implements Comparator<Object[]> {
             if (it.next()) {
                 otherData = it.getCurrent();
 
-                if (fullIndex.compareRowNonUnique(
-                        (Session) session, currentData, otherData,
-                        fullIndex.getColumnCount()) == 0) {
+                if (fullIndex.compareRowNonUnique((Session) session,
+                                                  currentData,
+                                                  otherData,
+                                                  fullIndex.getColumnCount()) == 0) {
                     removeCurrent();
                 }
             }
@@ -551,8 +601,9 @@ implements Comparator<Object[]> {
             }
 
             if (lastRowData != null
-                    && fullIndex.compareRow(
-                        (Session) session, lastRowData, currentData) == 0) {
+                    && fullIndex.compareRow((Session) session,
+                                            lastRowData,
+                                            currentData) == 0) {
                 return false;
             } else {
                 lastRowData = currentData;
@@ -576,12 +627,12 @@ implements Comparator<Object[]> {
             if (lastRowData == null) {
                 lastRowPos  = currentPos;
                 lastRowData = currentData;
-
                 continue;
             }
 
-            if (fullIndex.compareRow(
-                    (Session) session, lastRowData, currentData) != 0) {
+            if (fullIndex.compareRow((Session) session,
+                                     lastRowData,
+                                     currentData) != 0) {
                 lastRowPos++;
 
                 lastRowData           = currentData;
@@ -612,8 +663,9 @@ implements Comparator<Object[]> {
 
         if ((long) limitstart + limitcount < size) {
             reset();
-            removeRange(limitstart + limitcount,
-                        size - limitstart - limitcount);
+            removeRange(
+                limitstart + limitcount,
+                size - limitstart - limitcount);
         }
 
         removeRange(0, limitstart);
@@ -675,7 +727,6 @@ implements Comparator<Object[]> {
     }
 
     boolean containsRow(Object[] data) {
-
         int position = ArraySort.searchFirst(dataTable, 0, size, data, this);
 
         return position >= 0;
@@ -703,7 +754,6 @@ implements Comparator<Object[]> {
     }
 
     private void setCapacity(int newSize) {
-
         if (size > dataTable.length) {
             dataTable = new Object[newSize][];
         }
@@ -712,8 +762,9 @@ implements Comparator<Object[]> {
     private void ensureCapacity() {
 
         if (size == dataTable.length) {
-            int        newSize  = size == 0 ? 4
-                                            : size * 2;
+            int        newSize  = size == 0
+                                  ? 4
+                                  : size * 2;
             Object[][] newTable = new Object[newSize][];
 
             System.arraycopy(dataTable, 0, newTable, 0, size);
