@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -42,11 +42,13 @@ import org.hsqldb.types.Type;
 
 /*
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.0
+ * @version 2.7.4
  * @since 2.2.7
  */
 public interface RowSetNavigatorDataChange extends RangeIterator {
 
+    int getMainRowCount();
+
     int getSize();
 
     int getRowPosition();
@@ -57,16 +59,28 @@ public interface RowSetNavigatorDataChange extends RangeIterator {
 
     int[] getCurrentChangedColumns();
 
-    void write(RowOutputInterface out, ResultMetaData meta) throws IOException;
+    default void setCurrentChangedColumns(int[] colMap) {}
 
-    void read(RowInputInterface in, ResultMetaData meta) throws IOException;
+    default void write(RowOutputInterface out, ResultMetaData meta) {}
+
+    default void read(RowInputInterface in, ResultMetaData meta) {}
 
     void endMainDataSet();
 
     boolean addRow(Row row);
 
-    Object[] addRow(Session session, Row row, Object[] data, Type[] types,
-                    int[] columnMap);
+    Object[] addRow(
+            Session session,
+            Row row,
+            Object[] data,
+            Type[] types,
+            int[] columnMap);
+
+    default void addUpdatedRow(Row row) {}
+
+    default Row getUpdatedRow() {
+        return null;
+    }
 
     boolean addUpdate(Row row, Object[] data, int[] columnMap);
 
