@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,9 +37,6 @@ import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayUtil;
 import org.hsqldb.lib.OrderedLongKeyHashMap;
-import org.hsqldb.result.ResultMetaData;
-import org.hsqldb.rowio.RowInputInterface;
-import org.hsqldb.rowio.RowOutputInterface;
 import org.hsqldb.types.Type;
 
 /*
@@ -47,22 +44,24 @@ import org.hsqldb.types.Type;
  * operations.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.5.0
+ * @version 2.7.4
  * @since 1.9.0
  */
 public class RowSetNavigatorDataChangeMemory
-implements RowSetNavigatorDataChange {
+        implements RowSetNavigatorDataChange {
 
     public static final RowSetNavigatorDataChangeMemory emptyRowSet =
-        new RowSetNavigatorDataChangeMemory(null);
-    int                   size;
-    int                   currentPos = -1;
-    OrderedLongKeyHashMap list;
-    Session               session;
+        new RowSetNavigatorDataChangeMemory(
+            null);
+    int                        size;
+    int                        mainRowCount;
+    int                        currentPos = -1;
+    OrderedLongKeyHashMap<Row> list;
+    Session                    session;
 
     public RowSetNavigatorDataChangeMemory(Session session) {
         this.session = session;
-        list         = new OrderedLongKeyHashMap(64, true);
+        list         = new OrderedLongKeyHashMap<>(64, true);
     }
 
     public void release() {
@@ -73,6 +72,10 @@ implements RowSetNavigatorDataChange {
         size = 0;
     }
 
+    public int getMainRowCount() {
+        return mainRowCount;
+    }
+
     public int getSize() {
         return size;
     }
@@ -95,14 +98,13 @@ implements RowSetNavigatorDataChange {
     }
 
     public boolean beforeFirst() {
-
         currentPos = -1;
 
         return true;
     }
 
     public Row getCurrentRow() {
-        return (Row) list.getValueAt(currentPos);
+        return list.getValueAt(currentPos);
     }
 
     public Object[] getCurrentChangedData() {
@@ -113,12 +115,13 @@ implements RowSetNavigatorDataChange {
         return (int[]) list.getThirdValueAt(currentPos);
     }
 
-    // reading and writing
-    public void write(RowOutputInterface out, ResultMetaData meta) {}
+    public void setCurrentChangedColumns(int[] colMap) {
+        list.setThirdValueAt(currentPos, colMap);
+    }
 
-    public void read(RowInputInterface in, ResultMetaData meta) {}
-
-    public void endMainDataSet() {}
+    public void endMainDataSet() {
+        mainRowCount = size;
+    }
 
     public boolean addRow(Row row) {
 
@@ -146,6 +149,17 @@ implements RowSetNavigatorDataChange {
         }
     }
 
+    /**
+     * for single-row update of scrollable ResultSet
+     */
+    public void addUpdatedRow(Row row) {
+        list.setFourthValueAt(currentPos, row);
+    }
+
+    public Row getUpdatedRow() {
+        return (Row) list.getFourthValueAt(currentPos);
+    }
+
     public boolean addUpdate(Row row, Object[] data, int[] columnMap) {
 
         int lookup = list.getLookup(row.getId());
@@ -160,8 +174,12 @@ implements RowSetNavigatorDataChange {
         return true;
     }
 
-    public Object[] addRow(Session session, Row row, Object[] data,
-                           Type[] types, int[] columnMap) {
+    public Object[] addRow(
+            Session session,
+            Row row,
+            Object[] data,
+            Type[] types,
+            int[] columnMap) {
 
         long rowId  = row.getId();
         int  lookup = list.getLookup(rowId);
@@ -175,12 +193,11 @@ implements RowSetNavigatorDataChange {
 
             return data;
         } else {
-            Object[] rowData = ((Row) list.getValueAt(lookup)).getData();
-            Object[] currentData =
-                (Object[]) list.getSecondValueAt(lookup);
+            Object[] rowData     = list.getValueAt(lookup).getData();
+            Object[] currentData = (Object[]) list.getSecondValueAt(lookup);
 
             if (currentData == null) {
-                if (session.database.sqlEnforceTDCD) {
+                if (session.database.sqlEnforceTDCD && lookup >= mainRowCount) {
                     throw Error.error(ErrorCode.X_27000);
                 } else {
                     return null;
@@ -191,8 +208,9 @@ implements RowSetNavigatorDataChange {
                 int j = columnMap[i];
 
                 if (types[j].compare(session, data[j], currentData[j]) != 0) {
-                    if (types[j].compare(session, rowData[j], currentData[j])
-                            != 0) {
+                    if (types[j].compare(session,
+                                         rowData[j],
+                                         currentData[j]) != 0) {
                         if (session.database.sqlEnforceTDCU) {
                             throw Error.error(ErrorCode.X_27000);
                         }
@@ -237,7 +255,7 @@ implements RowSetNavigatorDataChange {
 
         outerloop:
         for (int i = 0; i < size; i++) {
-            Row oldRow = (Row) list.getValueAt(i);
+            Row oldRow = list.getValueAt(i);
 
             if (oldRow.getTable() != row.getTable()) {
                 continue;
@@ -249,8 +267,7 @@ implements RowSetNavigatorDataChange {
             for (int j = 0; j < keys.length; j++) {
                 int pos = keys[j];
 
-                if (types[pos].compare(session, rowData[pos], data[pos])
-                        != 0) {
+                if (types[pos].compare(session, rowData[pos], data[pos]) != 0) {
                     continue outerloop;
                 }
             }
@@ -320,13 +337,11 @@ implements RowSetNavigatorDataChange {
         }
 
         public Object[] getCurrent() {
-            return RowSetNavigatorDataChangeMemory.this
-                .getCurrentChangedData();
+            return RowSetNavigatorDataChangeMemory.this.getCurrentChangedData();
         }
 
         public Object getField(int col) {
-            return RowSetNavigatorDataChangeMemory.this
-                .getCurrentChangedData()[col];
+            return RowSetNavigatorDataChangeMemory.this.getCurrentChangedData()[col];
         }
 
         public void setCurrent(Object[] data) {}
