@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -49,7 +49,7 @@ import org.hsqldb.rowio.RowOutputInterface;
  * Implementation of RowSetNavigator using a table as the data store.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.4
  * @since 1.9.0
  */
 public class RowSetNavigatorDataTable extends RowSetNavigatorData {
@@ -57,34 +57,38 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
     public TableBase       table;
     public PersistentStore store;
     RowIterator            iterator;
-    Row                    currentRow;
+    int                    iteratorPos = -1;
     Object[]               tempRowData;
 
-    public RowSetNavigatorDataTable(Session session,
-                                    QuerySpecification select) {
+    public RowSetNavigatorDataTable(
+            Session session,
+            QuerySpecification select) {
 
         super(session, select.sortAndSlice);
 
         rangePosition      = select.resultRangePosition;
         visibleColumnCount = select.indexLimitVisible;
         table              = select.resultTable.duplicate();
-        store = session.sessionData.getNewResultRowStore(table,
-                !select.isAggregated);
-        table.store       = store;
-        isAggregate       = select.isAggregated;
-        isSimpleAggregate = select.isAggregated && !select.isGrouped;
-        reindexTable      = select.isGrouped;
-        mainIndex         = select.mainIndex;
-        fullIndex         = select.fullIndex;
-        orderIndex        = select.orderIndex;
-        groupIndex        = select.groupIndex;
-        idIndex           = select.idIndex;
-        tempRowData       = new Object[1];
+        store = session.sessionData.getNewResultRowStore(
+            table,
+            !select.isAggregated);
+        table.store        = store;
+        isAggregate        = select.isAggregated;
+        isSimpleAggregate  = select.isAggregated && !select.isGrouped;
+        reindexTable       = select.isGrouped;
+        mainIndex          = select.mainIndex;
+        fullIndex          = select.fullIndex;
+        orderIndex         = select.orderIndex;
+        groupIndex         = select.groupIndex;
+        idIndex            = select.idIndex;
+        rowNumIndex        = select.rowNumIndex;
+        tempRowData        = new Object[1];
     }
 
-    public RowSetNavigatorDataTable(Session session,
-                                    QuerySpecification select,
-                                    RowSetNavigatorData navigator) {
+    public RowSetNavigatorDataTable(
+            Session session,
+            QuerySpecification select,
+            RowSetNavigatorData navigator) {
 
         this(session, select);
 
@@ -95,8 +99,9 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
         }
     }
 
-    public RowSetNavigatorDataTable(Session session,
-                                    QueryExpression queryExpression) {
+    public RowSetNavigatorDataTable(
+            Session session,
+            QueryExpression queryExpression) {
 
         super(session, queryExpression.sortAndSlice);
 
@@ -142,10 +147,6 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
             mainIndex = orderIndex;
 
-            if (iterator != null) {
-                iterator.release();
-            }
-
             reset();
         }
     }
@@ -170,7 +171,9 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
                 data = d;
             }
 
-            Row row = (Row) store.getNewCachedObject((Session) session, data,
+            Row row = (Row) store.getNewCachedObject(
+                (Session) session,
+                data,
                 false);
 
             store.indexRow((Session) session, row);
@@ -183,8 +186,9 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
         try {
             if (columnMap == null) {
-                data = (Object[]) ArrayUtil.resizeArrayIfDifferent(data,
-                        visibleColumnCount);
+                data = (Object[]) ArrayUtil.resizeArrayIfDifferent(
+                    data,
+                    visibleColumnCount);
             } else {
                 Object[] newData = new Object[visibleColumnCount];
 
@@ -197,13 +201,45 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
         } catch (HsqlException e) {}
     }
 
-    public void update(Object[] oldData, Object[] newData) {
+    /**
+     * Used when updating results via JDBC ResultSet methods.
+     * The instance iterator is reset as it may become invalid after a row is
+     * removed.
+     */
+    public void updateData(long oldRowId, Object[] newData) {
+
+        tempRowData[0] = oldRowId;
+
+        RowIterator it = idIndex.findFirstRow(
+            (Session) session,
+            store,
+            tempRowData,
+            idIndex.getDefaultColumnMap());
+
+        if (it.next()) {
+            it.removeCurrent();
+            it.release();
+
+            size--;
+
+            add(newData);
+        }
+
+        resetIterator();
+    }
+
+    /**
+     * Used while building grouped results.
+     */
+    public void updateData(Object[] oldData, Object[] newData) {
 
         if (isSimpleAggregate) {
             return;
         }
 
-        RowIterator it = groupIndex.findFirstRow((Session) session, store,
+        RowIterator it = groupIndex.findFirstRow(
+            (Session) session,
+            store,
             oldData);
 
         if (it.next()) {
@@ -217,38 +253,97 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
     }
 
     public boolean absolute(int position) {
-        return super.absolute(position);
-    }
 
-    public Object[] getCurrent() {
-        return currentRow.getData();
-    }
+        if (position < 0) {
+            position += size;
+        }
 
-    public Row getCurrentRow() {
-        return currentRow;
-    }
+        if (position < 0) {
+            beforeFirst();
 
-    public boolean next() {
-
-        boolean result = super.next();
-
-        if (!result) {
             return false;
         }
 
-        iterator.next();
+        if (position >= size) {
+            afterLast();
 
-        currentRow = iterator.getCurrentRow();
+            return false;
+        }
 
-        return result;
+        if (size == 0) {
+            return false;
+        }
+
+        currentPos = position;
+
+        return true;
+    }
+
+    private boolean toCurrentRow() {
+
+        if (rowNumIndex == mainIndex) {
+            tempRowData[0] = (long) currentPos;
+            iterator = rowNumIndex.findFirstRow(
+                (Session) session,
+                store,
+                tempRowData,
+                rowNumIndex.getDefaultColumnMap());
+
+            iterator.next();
+
+            iteratorPos = currentPos;
+        } else {
+            if (iteratorPos > currentPos) {
+                resetIterator();
+            }
+
+            while (iteratorPos < currentPos) {
+                iterator.next();
+
+                iteratorPos++;
+            }
+        }
+
+        return true;
+    }
+
+    public Object[] getCurrent() {
+
+        if (currentPos < 0 || currentPos >= size) {
+            return null;
+        }
+
+        if (currentPos != iteratorPos) {
+            toCurrentRow();
+        }
+
+        return iterator.getCurrent();
+    }
+
+    public Row getCurrentRow() {
+
+        if (currentPos < 0 || currentPos >= size) {
+            return null;
+        }
+
+        if (currentPos != iteratorPos) {
+            toCurrentRow();
+        }
+
+        return iterator.getCurrentRow();
+    }
+
+    public boolean next() {
+        return super.next();
     }
 
     public void removeCurrent() {
 
+        Row currentRow = getCurrentRow();
+
         if (currentRow != null) {
             iterator.removeCurrent();
-
-            currentRow = null;
+            iterator.next();
 
             currentPos--;
             size--;
@@ -256,14 +351,18 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
     }
 
     public void reset() {
-
         super.reset();
+        resetIterator();
+    }
+
+    void resetIterator() {
 
         if (iterator != null) {
             iterator.release();
         }
 
         iterator = mainIndex.firstRow((Session) session, store, null, 0, null);
+        iteratorPos = -1;
     }
 
     public void release() {
@@ -304,20 +403,26 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
         while (next()) {
             Object[] data = getCurrent();
 
-            out.writeData(meta.getExtendedColumnCount(), meta.columnTypes,
-                          data, null, null);
+            out.writeData(
+                meta.getExtendedColumnCount(),
+                meta.columnTypes,
+                data,
+                null,
+                null);
         }
 
         reset();
     }
 
-    public Object[] getData(Long rowId) {
+    public Object[] getData(long rowId) {
 
         tempRowData[0] = rowId;
 
-        RowIterator it = idIndex.findFirstRow((Session) session, store,
-                                              tempRowData,
-                                              idIndex.getDefaultColumnMap());
+        RowIterator it = idIndex.findFirstRow(
+            (Session) session,
+            store,
+            tempRowData,
+            idIndex.getDefaultColumnMap());
 
         it.next();
 
@@ -347,9 +452,9 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             RowIterator it = findFirstRow(currentData);
 
             if (!it.next()) {
-                currentData =
-                    (Object[]) ArrayUtil.resizeArrayIfDifferent(currentData,
-                        colCount);
+                currentData = (Object[]) ArrayUtil.resizeArrayIfDifferent(
+                    currentData,
+                    colCount);
 
                 add(currentData);
             }
@@ -391,11 +496,12 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
         while (next()) {
             Object[] currentData = getCurrent();
-            boolean newGroup =
-                compareData == null
-                || fullIndex.compareRowNonUnique(
-                    (Session) session, currentData, compareData,
-                    fullIndex.getColumnCount()) != 0;
+            boolean newGroup = compareData == null
+                               || fullIndex.compareRowNonUnique(
+                                   (Session) session,
+                                   currentData,
+                                   compareData,
+                                   fullIndex.getColumnCount()) != 0;
 
             if (newGroup) {
                 compareData = currentData;
@@ -405,9 +511,10 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             if (it.next()) {
                 otherData = it.getCurrent();
 
-                if (fullIndex.compareRowNonUnique(
-                        (Session) session, currentData, otherData,
-                        fullIndex.getColumnCount()) == 0) {
+                if (fullIndex.compareRowNonUnique((Session) session,
+                                                  currentData,
+                                                  otherData,
+                                                  fullIndex.getColumnCount()) == 0) {
                     continue;
                 }
             }
@@ -465,11 +572,12 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
         while (next()) {
             Object[] currentData = getCurrent();
-            boolean newGroup =
-                compareData == null
-                || fullIndex.compareRowNonUnique(
-                    (Session) session, currentData, compareData,
-                    fullIndex.getColumnCount()) != 0;
+            boolean newGroup = compareData == null
+                               || fullIndex.compareRowNonUnique(
+                                   (Session) session,
+                                   currentData,
+                                   compareData,
+                                   fullIndex.getColumnCount()) != 0;
 
             if (newGroup) {
                 compareData = currentData;
@@ -479,9 +587,10 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             if (it.next()) {
                 otherData = it.getCurrent();
 
-                if (fullIndex.compareRowNonUnique(
-                        (Session) session, currentData, otherData,
-                        fullIndex.getColumnCount()) == 0) {
+                if (fullIndex.compareRowNonUnique((Session) session,
+                                                  currentData,
+                                                  otherData,
+                                                  fullIndex.getColumnCount()) == 0) {
                     removeCurrent();
                 }
             }
@@ -504,8 +613,9 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             }
 
             if (lastRowData != null
-                    && fullIndex.compareRow(
-                        (Session) session, lastRowData, currentData) == 0) {
+                    && fullIndex.compareRow((Session) session,
+                                            lastRowData,
+                                            currentData) == 0) {
                 return false;
             } else {
                 lastRowData = currentData;
@@ -525,8 +635,9 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             Object[] currentData = getCurrent();
 
             if (lastRowData != null
-                    && fullIndex.compareRow(
-                        (Session) session, lastRowData, currentData) == 0) {
+                    && fullIndex.compareRow((Session) session,
+                                            lastRowData,
+                                            currentData) == 0) {
                 removeCurrent();
             } else {
                 lastRowData = currentData;
@@ -600,7 +711,9 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
             return simpleAggregateData;
         }
 
-        RowIterator it = groupIndex.findFirstRow((Session) session, store,
+        RowIterator it = groupIndex.findFirstRow(
+            (Session) session,
+            store,
             data);
 
         if (it.next()) {
@@ -618,9 +731,8 @@ public class RowSetNavigatorDataTable extends RowSetNavigatorData {
 
     boolean containsRow(Object[] data) {
 
-        RowIterator it = mainIndex.findFirstRow((Session) session, store,
-            data);
-        boolean result = it.next();
+        RowIterator it = mainIndex.findFirstRow((Session) session, store, data);
+        boolean     result = it.next();
 
         it.release();
 
