@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -76,8 +76,11 @@ public class Cache extends BaseHashMap {
 
     Cache(DataFileCache dfc) {
 
-        super(dfc.capacity(), BaseHashMap.objectKeyOrValue,
-              BaseHashMap.noKeyOrValue, true);
+        super(
+            dfc.capacity(),
+            BaseHashMap.objectKeyOrValue,
+            BaseHashMap.noKeyOrValue,
+            true);
 
         maxCapacity      = dfc.capacity();
         dataFileCache    = dfc;
@@ -90,8 +93,9 @@ public class Cache extends BaseHashMap {
         updateAccess     = dfc instanceof TextCache;
         comparator       = rowComparator;
         reserveCount = dfc instanceof TextCache
-                       || dfc instanceof DataFileCacheSession ? 0
-                                                              : 8;
+                       || dfc instanceof DataFileCacheSession
+                       ? 0
+                       : 8;
     }
 
     long getTotalCachedBlockSize() {
@@ -126,12 +130,13 @@ public class Cache extends BaseHashMap {
         if (preparePut(storageSize)) {
             putNoCheck(row);
         } else {
-            long value = size() + reserveCount >= capacity ? capacity
-                                                           : bytesCapacity
-                                                             / 1024L;
+            long value = size() + reserveCount >= capacity
+                         ? capacity
+                         : bytesCapacity / 1024L;
 
-            throw Error.error(ErrorCode.DATA_CACHE_IS_FULL,
-                              String.valueOf(value));
+            throw Error.error(
+                ErrorCode.DATA_CACHE_IS_FULL,
+                String.valueOf(value));
         }
     }
 
@@ -145,8 +150,9 @@ public class Cache extends BaseHashMap {
         preparePut(storageSize);
 
         if (size() >= capacity) {
-            throw Error.error(ErrorCode.DATA_CACHE_IS_FULL,
-                              String.valueOf(capacity));
+            throw Error.error(
+                ErrorCode.DATA_CACHE_IS_FULL,
+                String.valueOf(capacity));
         }
 
         putNoCheck(row);
@@ -204,9 +210,10 @@ public class Cache extends BaseHashMap {
         Object existing = addOrRemoveObject(row.getPos(), row, false);
 
         if (existing != null) {
-            dataFileCache.logSevereEvent("existing object in Cache.put() "
-                                         + row.getPos() + " "
-                                         + row.getStorageSize(), null);
+            dataFileCache.logSevereEvent(
+                "existing object in Cache.put() " + row.getPos() + " "
+                + row.getStorageSize(),
+                null);
         }
 
         row.setInMemory(true);
@@ -327,13 +334,15 @@ public class Cache extends BaseHashMap {
 
         int savecount    = 0;
         int removeCount  = size() / 2;
-        int accessTarget = all ? accessCount.get() + 1
-                               : getAccessCountCeiling(removeCount,
-                                   removeCount / 8);
+        int accessTarget = all
+                           ? accessCount.get() + 1
+                           : getAccessCountCeiling(
+                               removeCount,
+                               removeCount / 8);
 
         objectIterator.reset();
 
-        for (; objectIterator.hasNext(); ) {
+        while (objectIterator.hasNext()) {
             CachedObject row = (CachedObject) objectIterator.next();
 
             synchronized (row) {
@@ -376,7 +385,7 @@ public class Cache extends BaseHashMap {
 
         objectIterator.reset();
 
-        for (; objectIterator.hasNext(); ) {
+        while (objectIterator.hasNext()) {
             CachedObject row = (CachedObject) objectIterator.next();
 
             synchronized (row) {
@@ -412,7 +421,7 @@ public class Cache extends BaseHashMap {
 
         objectIterator.reset();
 
-        for (; objectIterator.hasNext(); ) {
+        while (objectIterator.hasNext()) {
             if (savecount == rowTable.length) {
                 saveRows(savecount);
 
@@ -434,20 +443,22 @@ public class Cache extends BaseHashMap {
     void logSaveRowsEvent(int saveCount, long storageSize, long startTime) {
 
         long          time = saveAllTimer.elapsedTime();
-        StringBuilder sb   = new StringBuilder();
+        StringBuilder sb   = new StringBuilder(128);
 
-        sb.append("cache save rows total [count,time] ");
-        sb.append(saveRowCount + saveCount);
-        sb.append(',').append(time).append(' ');
-        sb.append("operation [count,time,size]").append(saveCount).append(',');
-        sb.append(time - startTime).append(',');
-        sb.append(storageSize).append(' ');
-
-//
-        sb.append("tx-ts ");
-        sb.append(dataFileCache.database.txManager.getSystemChangeNumber());
-
-//
+        sb.append("cache save rows total [count,time] ")
+          .append(saveRowCount + saveCount)
+          .append(',')
+          .append(time)
+          .append(' ')
+          .append("operation [count,time,size]")
+          .append(saveCount)
+          .append(',')
+          .append(time - startTime)
+          .append(',')
+          .append(storageSize)
+          .append(' ')
+          .append("tx-ts ")
+          .append(dataFileCache.database.txManager.getSystemChangeNumber());
         dataFileCache.logDetailEvent(sb.toString());
     }
 
@@ -455,14 +466,12 @@ public class Cache extends BaseHashMap {
      * clears out the memory cache
      */
     public void clear() {
-
         super.clear();
 
         cacheBytesLength = 0;
     }
 
-    public Iterator getIterator() {
-
+    public Iterator<CachedObject> getIterator() {
         objectIterator.reset();
 
         return objectIterator;
@@ -473,7 +482,8 @@ public class Cache extends BaseHashMap {
     }
 
     static final class CachedObjectComparator
-    implements Comparator<CachedObject>, ObjectComparator<CachedObject> {
+            implements Comparator<CachedObject>,
+                       ObjectComparator<CachedObject> {
 
         static final int COMPARE_LAST_ACCESS = 0;
         static final int COMPARE_POSITION    = 1;
@@ -508,9 +518,11 @@ public class Cache extends BaseHashMap {
                     return 0;
             }
 
-            return diff == 0 ? 0
-                             : diff > 0 ? 1
-                                        : -1;
+            return diff == 0
+                   ? 0
+                   : diff > 0
+                     ? 1
+                     : -1;
         }
 
         public boolean equals(CachedObject a, CachedObject b) {
