@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -112,8 +112,9 @@ public abstract class CachedObjectBase implements CachedObject {
             keepCount++;
         } else {
             if (keepCount == 0) {
-                throw Error.runtimeError(ErrorCode.U_S0500,
-                                         "CachedObjectBase - keep count");
+                throw Error.runtimeError(
+                    ErrorCode.U_S0500,
+                    "CachedObjectBase - keep count");
             }
 
             keepCount--;
