@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -62,8 +62,11 @@ public interface DataSpaceManager {
 
     void freeTableSpace(int spaceId);
 
-    void freeTableSpace(int spaceId, LongLookup spaceList, long offset,
-                        long limit);
+    void freeTableSpace(
+            int spaceId,
+            LongLookup spaceList,
+            long offset,
+            long limit);
 
     long getLostBlocksSize();
 
