@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2023, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -47,7 +47,7 @@ import org.hsqldb.types.Collation;
  * Manages a .properties file for a database.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.2
+ * @version 2.7.4
  * @since 1.7.0
  */
 public class HsqlDatabaseProperties extends HsqlProperties {
@@ -58,8 +58,9 @@ public class HsqlDatabaseProperties extends HsqlProperties {
         "textdb.allow_full_path";
     public static final String hsqldb_reconfig_logging =
         "hsqldb.reconfig_logging";
-    public static String methodClassNames;
-    private static final HashSet accessibleJavaMethodNames = new HashSet();
+    private static final HashSet<String> accessibleJavaMethodNames =
+        new HashSet<>();
+    public static String   methodClassNames;
     private static boolean allowFullPath;
 
     static {
@@ -67,7 +68,6 @@ public class HsqlDatabaseProperties extends HsqlProperties {
             methodClassNames = System.getProperty(hsqldb_method_class_names);
 
             if (methodClassNames != null) {
-
                 String[] names = StringUtil.split(methodClassNames, ";");
 
                 for (int i = 0; i < names.length; i++) {
@@ -110,10 +110,10 @@ public class HsqlDatabaseProperties extends HsqlProperties {
             return true;
         }
 
-        Iterator it = accessibleJavaMethodNames.iterator();
+        Iterator<String> it = accessibleJavaMethodNames.iterator();
 
         while (it.hasNext()) {
-            String className = (String) it.next();
+            String className = it.next();
             int    limit     = className.lastIndexOf(".*");
 
             if (limit < 1) {
@@ -150,20 +150,23 @@ public class HsqlDatabaseProperties extends HsqlProperties {
     private static final String MODIFIED_NO_NEW       = "no-new-files";
 
     // allowed property metadata
-    private static final HashMap<String, PropertyMeta> dbMeta = new HashMap(128);
-    private static final HashMap<String, PropertyMeta> textMeta = new HashMap(16);
-    private static final HashSet<String>               excludedMeta = new HashSet();
-    private static final HashMap<String, PropertyMeta> urlUserConnMeta = new HashMap();
+    private static final HashMap<String, PropertyMeta> dbMeta = new HashMap<>(
+        128);
+    private static final HashMap<String, PropertyMeta> textMeta = new HashMap<>(
+        16);
+    private static final HashSet<String> excludedMeta = new HashSet<>();
+    private static final HashMap<String, PropertyMeta> urlUserConnMeta =
+        new HashMap<>();
 
     // versions
     public static final String VERSION_STRING_1_8_0 = "1.8.0";
     public static final String PRODUCT_NAME         = "HSQL Database Engine";
-
-    public static final String THIS_VERSION      = "2.7.2";
-    public static final String THIS_FULL_VERSION = "2.7.2";
-    public static final int    MAJOR             = 2,
-                               MINOR             = 7,
-                               REVISION          = 2;
+    public static final String THIS_VERSION         = "2.7.4";
+    public static final String THIS_FULL_VERSION    = "2.7.4";
+    public static final int
+        MAJOR                                       = 2,
+        MINOR                                       = 7,
+        REVISION                                    = 4;
 
     /**
      * system properties supported by HSQLDB
@@ -210,15 +213,15 @@ public class HsqlDatabaseProperties extends HsqlProperties {
     public static final String url_crypt_lobs     = "crypt_lobs";
 
     //
-    public static final String hsqldb_tx       = "hsqldb.tx";
-    public static final String hsqldb_tx_level = "hsqldb.tx_level";
+    public static final String hsqldb_tx              = "hsqldb.tx";
+    public static final String hsqldb_tx_level        = "hsqldb.tx_level";
     public static final String hsqldb_tx_conflict_rollback =
         "hsqldb.tx_conflict_rollback";
     public static final String hsqldb_tx_interrupt_rollback =
         "hsqldb.tx_interrupt_rollback";
-    public static final String hsqldb_applog         = "hsqldb.applog";
-    public static final String hsqldb_extlog         = "hsqldb.extlog";
-    public static final String hsqldb_sqllog         = "hsqldb.sqllog";
+    public static final String hsqldb_applog          = "hsqldb.applog";
+    public static final String hsqldb_extlog          = "hsqldb.extlog";
+    public static final String hsqldb_sqllog          = "hsqldb.sqllog";
     public static final String hsqldb_lob_file_scale = "hsqldb.lob_file_scale";
     public static final String hsqldb_lob_file_compressed =
         "hsqldb.lob_compressed";
@@ -241,32 +244,32 @@ public class HsqlDatabaseProperties extends HsqlProperties {
     public static final String hsqldb_temp_directory = "hsqldb.temp_directory";
     public static final String hsqldb_result_max_memory_rows =
         "hsqldb.result_max_memory_rows";
-    public static final String hsqldb_write_delay = "hsqldb.write_delay";
+    public static final String hsqldb_write_delay     = "hsqldb.write_delay";
     public static final String hsqldb_write_delay_millis =
         "hsqldb.write_delay_millis";
     public static final String hsqldb_full_log_replay =
         "hsqldb.full_log_replay";
-    public static final String hsqldb_large_data  = "hsqldb.large_data";
-    public static final String hsqldb_files_space = "hsqldb.files_space";
-    public static final String hsqldb_digest      = "hsqldb.digest";
+    public static final String hsqldb_large_data      = "hsqldb.large_data";
+    public static final String hsqldb_files_space     = "hsqldb.files_space";
+    public static final String hsqldb_digest          = "hsqldb.digest";
 
     //
     public static final String jdbc_translate_tti_types =
         "jdbc.translate_tti_types";
 
     //
-    public static final String sql_restrict_exec       = "sql.restrict_exec";
-    public static final String sql_ref_integrity       = "sql.ref_integrity";
+    public static final String sql_restrict_exec     = "sql.restrict_exec";
+    public static final String sql_ref_integrity     = "sql.ref_integrity";
     public static final String sql_compare_in_locale = "sql.compare_in_locale";
-    public static final String sql_enforce_size        = "sql.enforce_size";
+    public static final String sql_enforce_size      = "sql.enforce_size";
     public static final String sql_enforce_strict_size =
         "sql.enforce_strict_size";    // synonym for sql_enforce_size
     public static final String sql_enforce_refs      = "sql.enforce_refs";
     public static final String sql_enforce_names     = "sql.enforce_names";
     public static final String sql_regular_names     = "sql.regular_names";
     public static final String sql_enforce_types     = "sql.enforce_types";
-    public static final String sql_enforce_tdcd = "sql.enforce_tdc_delete";
-    public static final String sql_enforce_tdcu = "sql.enforce_tdc_update";
+    public static final String sql_enforce_tdcd      = "sql.enforce_tdc_delete";
+    public static final String sql_enforce_tdcu      = "sql.enforce_tdc_update";
     public static final String sql_char_literal      = "sql.char_literal";
     public static final String sql_concat_nulls      = "sql.concat_nulls";
     public static final String sql_nulls_first       = "sql.nulls_first";
@@ -291,7 +294,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
     public static final String sql_lowercase_ident   = "sql.lowercase_ident";
 
     //
-    public static final String textdb_cache_scale = "textdb.cache_scale";
+    public static final String textdb_cache_scale  = "textdb.cache_scale";
     public static final String textdb_cache_size_scale =
         "textdb.cache_size_scale";
     public static final String textdb_cache_rows   = "textdb.cache_rows";
@@ -371,8 +374,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
 
         // string defaults for protected props
         dbMeta.put(hsqldb_version, newMeta(hsqldb_version, FILES_PROP, null));
-        dbMeta.put(hsqldb_modified,
-                   newMeta(hsqldb_modified, FILES_PROP, null));
+        dbMeta.put(hsqldb_modified, newMeta(hsqldb_modified, FILES_PROP, null));
         dbMeta.put(hsqldb_cache_version,
                    newMeta(hsqldb_cache_version, FILES_PROP, null));
 
@@ -383,13 +385,16 @@ public class HsqlDatabaseProperties extends HsqlProperties {
                    newMeta(hsqldb_files_readonly, FILES_PROP, false));
 
         // string defaults for user defined props
-        dbMeta.put(hsqldb_tx, newMeta(hsqldb_tx, SQL_PROP, "LOCKS"));
+        dbMeta.put(hsqldb_tx, newMeta(hsqldb_tx, SQL_PROP, "LOCKS",
+                new String[] {"LOCKS", "MVLOCKS", "MVCC"}));
         dbMeta.put(hsqldb_tx_level,
-                   newMeta(hsqldb_tx_level, SQL_PROP, "READ_COMMITTED"));
+                   newMeta(hsqldb_tx_level, SQL_PROP, "READ_COMMITTED",
+                           new String[] {"READ_COMMITTED", "SERIALIZABLE"}));
         dbMeta.put(hsqldb_temp_directory,
                    newMeta(hsqldb_temp_directory, DB_PROP, null));
         dbMeta.put(hsqldb_default_table_type,
-                   newMeta(hsqldb_default_table_type, SQL_PROP, "MEMORY"));
+                   newMeta(hsqldb_default_table_type, SQL_PROP, "MEMORY",
+                           new String[] {"MEMORY", "CACHED"}));
         dbMeta.put(hsqldb_digest, newMeta(hsqldb_digest, DB_PROP, "MD5"));
         dbMeta.put(sql_live_object, newMeta(sql_live_object, DB_PROP, false));
         dbMeta.put(tx_timestamp, newMeta(tx_timestamp, DB_PROP, 0));
@@ -427,22 +432,16 @@ public class HsqlDatabaseProperties extends HsqlProperties {
                    newMeta(sql_enforce_refs, SQL_PROP, false));
 
         // char padding to size and exception if data is too long
-        dbMeta.put(sql_enforce_size,
-                   newMeta(sql_enforce_size, SQL_PROP, true));
+        dbMeta.put(sql_enforce_size, newMeta(sql_enforce_size, SQL_PROP, true));
         dbMeta.put(sql_enforce_types,
                    newMeta(sql_enforce_types, SQL_PROP, false));
-        dbMeta.put(sql_enforce_tdcd,
-                   newMeta(sql_enforce_tdcd, SQL_PROP, true));
-        dbMeta.put(sql_enforce_tdcu,
-                   newMeta(sql_enforce_tdcu, SQL_PROP, true));
-        dbMeta.put(sql_char_literal,
-                   newMeta(sql_char_literal, SQL_PROP, true));
-        dbMeta.put(sql_concat_nulls,
-                   newMeta(sql_concat_nulls, SQL_PROP, true));
+        dbMeta.put(sql_enforce_tdcd, newMeta(sql_enforce_tdcd, SQL_PROP, true));
+        dbMeta.put(sql_enforce_tdcu, newMeta(sql_enforce_tdcu, SQL_PROP, true));
+        dbMeta.put(sql_char_literal, newMeta(sql_char_literal, SQL_PROP, true));
+        dbMeta.put(sql_concat_nulls, newMeta(sql_concat_nulls, SQL_PROP, true));
         dbMeta.put(sql_nulls_first, newMeta(sql_nulls_first, SQL_PROP, true));
         dbMeta.put(sql_nulls_order, newMeta(sql_nulls_order, SQL_PROP, true));
-        dbMeta.put(sql_unique_nulls,
-                   newMeta(sql_unique_nulls, SQL_PROP, true));
+        dbMeta.put(sql_unique_nulls, newMeta(sql_unique_nulls, SQL_PROP, true));
         dbMeta.put(sql_convert_trunc,
                    newMeta(sql_convert_trunc, SQL_PROP, true));
         dbMeta.put(sql_trunc_trailing,
@@ -505,15 +504,15 @@ public class HsqlDatabaseProperties extends HsqlProperties {
                    newMeta(runtime_gc_interval, DB_PROP, 0, 0, 1000000));
         dbMeta.put(hsqldb_cache_size,
                    newMeta(hsqldb_cache_size, DB_PROP, 10000, 100,
-                           4 * 1024 * 1024));
+                           16 * 1024 * 1024));
         dbMeta.put(hsqldb_cache_rows,
                    newMeta(hsqldb_cache_rows, DB_PROP, 50000, 100,
-                           4 * 1024 * 1024));
+                           16 * 1024 * 1024));
         dbMeta.put(hsqldb_cache_free_count,
                    newMeta(hsqldb_cache_free_count, DB_PROP, 512, 0, 4096));
         dbMeta.put(hsqldb_result_max_memory_rows,
                    newMeta(hsqldb_result_max_memory_rows, DB_PROP, 0, 0,
-                           4 * 1024 * 1024));
+                           16 * 1024 * 1024));
         dbMeta.put(hsqldb_nio_max_size,
                    newMeta(hsqldb_nio_max_size, DB_PROP, 256, 64, 262144));
         dbMeta.put(hsqldb_min_reuse,
@@ -553,10 +552,11 @@ public class HsqlDatabaseProperties extends HsqlProperties {
         try {
             exists = super.load();
         } catch (Throwable t) {
-            throw Error.error(t, ErrorCode.FILE_IO_ERROR,
-                              ErrorCode.M_LOAD_SAVE_PROPERTIES, new String[] {
-                t.toString(), fileName
-            });
+            throw Error.error(
+                t,
+                ErrorCode.FILE_IO_ERROR,
+                ErrorCode.M_LOAD_SAVE_PROPERTIES,
+                new String[]{ t.toString(), fileName });
         }
 
         if (!exists) {
@@ -566,7 +566,8 @@ public class HsqlDatabaseProperties extends HsqlProperties {
         filterLoadedProperties();
 
         String version = getStringProperty(hsqldb_version);
-        int    check = version.substring(0, 5).compareTo(VERSION_STRING_1_8_0);
+        int    check   = version.substring(0, 5)
+                                .compareTo(VERSION_STRING_1_8_0);
 
         // do not open early version databases
         if (check < 0) {
@@ -592,14 +593,17 @@ public class HsqlDatabaseProperties extends HsqlProperties {
 
     public void save() {
 
-        if (!database.getType().isFileBased() || database.isFilesReadOnly()
+        if (!database.getType().isFileBased()
+                || database.isFilesReadOnly()
                 || database.isFilesInJar()) {
             return;
         }
 
         try {
-            HsqlProperties props = new HsqlProperties(database.getPath(),
-                database.logger.getFileAccess(), false);
+            HsqlProperties props = new HsqlProperties(
+                database.getPath(),
+                database.logger.getFileAccess(),
+                false);
 
             if (getIntegerProperty(hsqldb_script_format) == 3) {
                 props.setProperty(hsqldb_script_format, 3);
@@ -611,15 +615,18 @@ public class HsqlDatabaseProperties extends HsqlProperties {
                 Long.toString(database.logger.getFilesTimestamp()));
             props.setProperty(hsqldb_modified, getProperty(hsqldb_modified));
             props.save(fileName + ".properties" + ".new");
-            fa.renameElementOrCopy(fileName + ".properties" + ".new",
-                                   fileName + ".properties", database.logger);
+            fa.renameElementOrCopy(
+                fileName + ".properties" + ".new",
+                fileName + ".properties",
+                database.logger);
         } catch (Throwable t) {
             database.logger.logSevereEvent("save failed", t);
 
-            throw Error.error(t, ErrorCode.FILE_IO_ERROR,
-                              ErrorCode.M_LOAD_SAVE_PROPERTIES, new String[] {
-                t.toString(), fileName
-            });
+            throw Error.error(
+                t,
+                ErrorCode.FILE_IO_ERROR,
+                ErrorCode.M_LOAD_SAVE_PROPERTIES,
+                new String[]{ t.toString(), fileName });
         }
     }
 
@@ -631,7 +638,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
             stringProps.setProperty(sql_enforce_size, val);
         }
 
-        Enumeration en = stringProps.propertyNames();
+        Enumeration<?> en = stringProps.propertyNames();
 
         while (en.hasMoreElements()) {
             String  key    = (String) en.nextElement();
@@ -664,7 +671,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
 
         strict = p.isPropertyTrue(url_check_props, false);
 
-        for (Enumeration e = p.propertyNames(); e.hasMoreElements(); ) {
+        for (Enumeration<?> e = p.propertyNames(); e.hasMoreElements(); ) {
             String       propertyName  = (String) e.nextElement();
             String       propertyValue = p.getProperty(propertyName);
             boolean      valid         = false;
@@ -674,7 +681,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
 
             if (meta != null) {
                 if (meta.propType == DB_PROP || meta.propType == SQL_PROP) {
-                    valid = true;
+                    valid    = true;
                     error = validateProperty(propertyName, propertyValue, meta);
                     validVal = error == null;
                 }
@@ -683,23 +690,27 @@ public class HsqlDatabaseProperties extends HsqlProperties {
             if (propertyName.startsWith("sql.")
                     || propertyName.startsWith("hsqldb.")
                     || propertyName.startsWith("textdb.")) {
-                if (strict && !valid) {
-                    throw Error.error(ErrorCode.X_42555, propertyName);
-                }
+                if (strict) {
+                    if (!valid) {
+                        throw Error.error(ErrorCode.X_42555, propertyName);
+                    }
 
-                if (strict && !validVal) {
-                    throw Error.error(ErrorCode.X_42556, error);
+                    if (!validVal) {
+                        throw Error.error(ErrorCode.X_42556, error);
+                    }
                 }
             }
         }
 
-        for (Enumeration e = p.propertyNames(); e.hasMoreElements(); ) {
+        for (Enumeration<?> e = p.propertyNames(); e.hasMoreElements(); ) {
             String       propertyName = (String) e.nextElement();
             PropertyMeta meta         = dbMeta.get(propertyName);
 
             if (meta != null) {
                 if (meta.propType == DB_PROP || meta.propType == SQL_PROP) {
-                    setDatabaseProperty(propertyName, p.getProperty(propertyName));
+                    setDatabaseProperty(
+                        propertyName,
+                        p.getProperty(propertyName));
                 }
             }
         }
@@ -707,17 +718,15 @@ public class HsqlDatabaseProperties extends HsqlProperties {
 
     public static Iterator<PropertyMeta> getUserDefinedProperties() {
 
-        return new Iterator() {
+        return new Iterator<PropertyMeta>() {
 
             Iterator<PropertyMeta> it = dbMeta.values().iterator();
-            PropertyMeta current;
-            boolean      b = filterToNext();
-
+            PropertyMeta           current;
+            boolean                b = filterToNext();
             public boolean hasNext() {
                 return current != null;
             }
-
-            public Object next() {
+            public PropertyMeta next() {
 
                 PropertyMeta value = current;
 
@@ -725,17 +734,6 @@ public class HsqlDatabaseProperties extends HsqlProperties {
 
                 return value;
             }
-
-            public int nextInt() {
-                return 0;
-            }
-
-            public long nextLong() {
-                return 0L;
-            }
-
-            public void remove() {}
-
             private boolean filterToNext() {
 
                 while (it.hasNext()) {
@@ -794,8 +792,9 @@ public class HsqlDatabaseProperties extends HsqlProperties {
                 break;
 
             default :
-                throw Error.runtimeError(ErrorCode.U_S0500,
-                                         "HsqlDatabaseProperties");
+                throw Error.runtimeError(
+                    ErrorCode.U_S0500,
+                    "HsqlDatabaseProperties");
         }
 
         stringProps.put(hsqldb_modified, value);
@@ -984,9 +983,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
             if (meta.propValues != null) {
                 int[] values = meta.propValues;
 
-                if (ArrayUtil.find(values, number) == -1) {
-                    return false;
-                }
+                return ArrayUtil.find(values, number) >= 0;
             }
 
             return true;
@@ -1002,11 +999,7 @@ public class HsqlDatabaseProperties extends HsqlProperties {
     public String getClientPropertiesAsString() {
 
         if (isPropertyTrue(jdbc_translate_tti_types)) {
-            StringBuilder sb = new StringBuilder(jdbc_translate_tti_types);
-
-            sb.append('=').append(true);
-
-            return sb.toString();
+            return jdbc_translate_tti_types + '=' + true;
         }
 
         return "";
@@ -1014,10 +1007,10 @@ public class HsqlDatabaseProperties extends HsqlProperties {
 
     public boolean isVersion18() {
 
-        String version =
-            getProperty(HsqlDatabaseProperties.hsqldb_cache_version,
-                        THIS_VERSION);
+        String version = getProperty(
+            HsqlDatabaseProperties.hsqldb_cache_version,
+            THIS_VERSION);
 
-        return version.substring(0, 4).equals("1.7.");
+        return version.startsWith("1.7.");
     }
 }
