@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -90,9 +90,12 @@ final class RAFile implements RandomAccessInterface {
      * seekPosition is the position in seek() calls or after reading or writing
      * realPosition is the file position
      */
-    static RandomAccessInterface newScaledRAFile(Database database,
-            String name, boolean readonly,
-            int type) throws FileNotFoundException, IOException {
+    static RandomAccessInterface newScaledRAFile(
+            Database database,
+            String name,
+            boolean readonly,
+            int type)
+            throws IOException {
 
         if (type == DATA_FILE_JAR) {
             return new RAFileInJar(name);
@@ -105,26 +108,31 @@ final class RAFile implements RandomAccessInterface {
             long         length = fi.length();
 
             if (length > database.logger.propNioMaxSize) {
-                return new RAFile(database.logger, name, readonly, true,
-                                  false);
+                return new RAFile(database.logger, name, readonly, true, false);
             }
 
             return new RAFileHybrid(database, name, readonly);
         }
     }
 
-    RAFile(EventLogInterface logger, String name, boolean readonly,
+    RAFile(
+            EventLogInterface logger,
+            String name,
+            boolean readonly,
             boolean extendLengthToBlock,
-            boolean commitOnChange) throws FileNotFoundException, IOException {
+            boolean commitOnChange)
+            throws IOException {
 
         this.logger       = logger;
         this.fileName     = name;
         this.readOnly     = readonly;
         this.extendLength = extendLengthToBlock;
 
-        String accessMode = readonly ? "r"
-                                     : commitOnChange ? "rws"
-                                                      : "rw";
+        String accessMode = readonly
+                            ? "r"
+                            : commitOnChange
+                              ? "rws"
+                              : "rw";
 
         this.file      = new RandomAccessFile(name, accessMode);
         buffer         = new byte[bufferSize];
@@ -175,8 +183,9 @@ final class RAFile implements RandomAccessInterface {
             bufferOffset = filePos;
         } catch (IOException e) {
             resetPointer();
-            logger.logWarningEvent("Read Error " + filePos + " " + readLength,
-                                   e);
+            logger.logWarningEvent(
+                "Read Error " + filePos + " " + readLength,
+                e);
 
             throw e;
         }
@@ -294,14 +303,12 @@ final class RAFile implements RandomAccessInterface {
     }
 
     public void writeInt(int i) throws IOException {
-
         vbao.reset();
         vbao.writeInt(i);
         write(valueBuffer, 0, 4);
     }
 
     public void writeLong(long i) throws IOException {
-
         vbao.reset();
         vbao.writeLong(i);
         write(valueBuffer, 0, 8);
@@ -364,8 +371,14 @@ final class RAFile implements RandomAccessInterface {
 
     private int writeToBuffer(byte[] b, int off, int len) {
 
-        int count = ArrayUtil.copyBytes(seekPosition - off, b, off, len,
-                                        bufferOffset, buffer, buffer.length);
+        int count = ArrayUtil.copyBytes(
+            seekPosition - off,
+            b,
+            off,
+            len,
+            bufferOffset,
+            buffer,
+            buffer.length);
 
         return count;
     }
@@ -388,8 +401,9 @@ final class RAFile implements RandomAccessInterface {
             scaleUp = 12;
         }
 
-        position = ArrayUtil.getBinaryNormalisedCeiling(position,
-                bufferScale + scaleUp);
+        position = ArrayUtil.getBinaryNormalisedCeiling(
+            position,
+            bufferScale + scaleUp);
 
         return position;
     }
@@ -422,7 +436,7 @@ final class RAFile implements RandomAccessInterface {
         try {
             seekPosition = 0;
             fileLength   = length();
-            bufferOffset = -buffer.length; // invalid buffer
+            bufferOffset = -buffer.length;    // invalid buffer
         } catch (Throwable e) {}
     }
 }
