@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -63,23 +63,23 @@ import org.hsqldb.types.Type;
  * Base implementation of PersistentStore for different table types.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.3
  * @since 1.9.0
  */
 public abstract class RowStoreAVL implements PersistentStore {
 
-    Database              database;
-    TableSpaceManager     tableSpace;
-    Index[]               indexList    = Index.emptyArray;
-    CachedObject[]        accessorList = CachedObject.emptyArray;
-    TableBase             table;
-    long                  baseElementCount;
-    AtomicLong            elementCount = new AtomicLong();
-    long                  storageSize;
-    boolean[]             nullsList;
-    double[][]            searchCost;
-    boolean               isSchemaStore;
-    public LongKeyHashMap rowActionMap;
+    Database                         database;
+    TableSpaceManager                tableSpace;
+    Index[]                          indexList    = Index.emptyArray;
+    CachedObject[]                   accessorList = CachedObject.emptyArray;
+    TableBase                        table;
+    long                             baseElementCount;
+    AtomicLong                       elementCount = new AtomicLong();
+    long                             storageSize;
+    boolean[]                        nullsList;
+    double[][]                       searchCost;
+    boolean                          isSchemaStore;
+    public LongKeyHashMap<RowAction> rowActionMap;
 
     //
     ReadWriteLock lock;
@@ -133,8 +133,11 @@ public abstract class RowStoreAVL implements PersistentStore {
         return true;
     }
 
-    public boolean canRead(Session session, CachedObject object, int mode,
-                           int[] colMap) {
+    public boolean canRead(
+            Session session,
+            CachedObject object,
+            int mode,
+            int[] colMap) {
 
         RowAction action = ((Row) object).rowAction;
 
@@ -142,7 +145,7 @@ public abstract class RowStoreAVL implements PersistentStore {
             return true;
         }
 
-        return action.canRead(session, mode);
+        return action.canRead(session, mode, colMap);
     }
 
     public abstract CachedObject get(RowInputInterface in);
@@ -159,8 +162,10 @@ public abstract class RowStoreAVL implements PersistentStore {
         throw Error.runtimeError(ErrorCode.U_S0500, "RowStoreAVL");
     }
 
-    public abstract CachedObject getNewCachedObject(Session session,
-            Object object, boolean tx);
+    public abstract CachedObject getNewCachedObject(
+            Session session,
+            Object object,
+            boolean tx);
 
     public abstract void removeAll();
 
@@ -168,12 +173,13 @@ public abstract class RowStoreAVL implements PersistentStore {
 
     public abstract void commitPersistence(CachedObject object);
 
-    public RowAction addDeleteActionToRow(Session session, Row row,
-                                          int[] colMap, boolean isMV) {
-
+    public RowAction addDeleteActionToRow(
+            Session session,
+            Row row,
+            int[] colMap,
+            boolean isMV) {
         synchronized (row) {
-            return RowAction.addDeleteAction(session, table, this, row,
-                                             colMap);
+            return RowAction.addDeleteAction(session, table, this, row, colMap);
         }
     }
 
@@ -310,11 +316,17 @@ public abstract class RowStoreAVL implements PersistentStore {
         }
     }
 
-    public abstract void commitRow(Session session, Row row, int changeAction,
-                                   int txModel);
+    public abstract void commitRow(
+            Session session,
+            Row row,
+            int changeAction,
+            int txModel);
 
-    public abstract void rollbackRow(Session session, Row row,
-                                     int changeAction, int txModel);
+    public abstract void rollbackRow(
+            Session session,
+            Row row,
+            int changeAction,
+            int txModel);
 
     public abstract void postCommitAction(Session session, RowAction action);
 
@@ -351,7 +363,6 @@ public abstract class RowStoreAVL implements PersistentStore {
         for (int i = 0; i < indexList.length; i++) {
             if (indexList[i].isClustered()) {
                 index = indexList[i];
-
                 break;
             }
         }
@@ -407,8 +418,11 @@ public abstract class RowStoreAVL implements PersistentStore {
                 }
             }
 
-            Index[] tempKeys = (Index[]) ArrayUtil.toAdjustedArray(indexList,
-                null, position, 1);
+            Index[] tempKeys = (Index[]) ArrayUtil.toAdjustedArray(
+                indexList,
+                null,
+                position,
+                1);
 
             tempKeys[position] = keys[position];
 
@@ -424,8 +438,11 @@ public abstract class RowStoreAVL implements PersistentStore {
             }
         }
 
-        accessorList = (CachedObject[]) ArrayUtil.toAdjustedArray(accessorList,
-                null, position, diff);
+        accessorList = (CachedObject[]) ArrayUtil.toAdjustedArray(
+            accessorList,
+            null,
+            position,
+            diff);
         indexList = keys;
 
         try {
@@ -446,8 +463,11 @@ public abstract class RowStoreAVL implements PersistentStore {
         return indexList;
     }
 
-    public double searchCost(Session session, Index index, int count,
-                             int opType) {
+    public double searchCost(
+            Session session,
+            Index index,
+            int count,
+            int opType) {
 
         if (count == 0) {
             return elementCount.get();
@@ -469,8 +489,9 @@ public abstract class RowStoreAVL implements PersistentStore {
             }
 
             if (searchCost[position] == null) {
-                searchCost[position] = indexList[position].searchCost(session,
-                        this);
+                searchCost[position] = indexList[position].searchCost(
+                    session,
+                    this);
             }
 
             return searchCost[index.getPosition()][count - 1];
@@ -541,8 +562,11 @@ public abstract class RowStoreAVL implements PersistentStore {
      * The colIndex argument is the indexes of the columns that were
      * removed, type modified or added. The adjust argument is {-1 | 0 | +1}.
      */
-    public final void moveData(Session session, PersistentStore other,
-                               int[] colIndex, int adjust) {
+    public final void moveData(
+            Session session,
+            PersistentStore other,
+            int[] colIndex,
+            int adjust) {
 
         try {
             Table       table = (Table) this.table;
@@ -557,23 +581,24 @@ public abstract class RowStoreAVL implements PersistentStore {
 
                 for (int i = 0; i < colIndex.length; i++) {
                     if (adjust == 0) {
-                        Type oldtype =
-                            other.getTable().getColumnTypes()[colIndex[i]];
-                        Type newtype =
-                            this.table.getColumnTypes()[colIndex[i]];
+                        Type oldtype = other.getTable()
+                                            .getColumnTypes()[colIndex[i]];
+                        Type newtype = this.table.getColumnTypes()[colIndex[i]];
                         Object oldvalue = olddata[colIndex[i]];
-                        Object value = newtype.convertToType(session,
-                                                             oldvalue,
-                                                             oldtype);
+                        Object value = newtype.convertToType(
+                            session,
+                            oldvalue,
+                            oldtype);
 
                         data[colIndex[i]] = value;
 
                         table.systemSetIdentityColumn(session, data);
                     } else if (adjust > 0) {
                         ColumnSchema column = table.getColumn(colIndex[i]);
-                        Object value =
-                            table.getColumnDefaultOrGeneratedValue(session,
-                                column, data);
+                        Object value = table.getColumnDefaultOrGeneratedValue(
+                            session,
+                            column,
+                            data);
 
                         data[colIndex[i]] = value;
 
@@ -609,8 +634,9 @@ public abstract class RowStoreAVL implements PersistentStore {
                         LobData  oldvalue = (LobData) olddata[colIndex[0]];
 
                         if (oldvalue != null) {
-                            session.sessionData.adjustLobUsageCount(oldvalue,
-                                    -1);
+                            session.sessionData.adjustLobUsageCount(
+                                oldvalue,
+                                -1);
                         }
                     }
                 }
@@ -671,10 +697,9 @@ public abstract class RowStoreAVL implements PersistentStore {
         IndexStats[] indexStats = new IndexStats[accessorList.length];
 
         for (int i = 0; i < indexList.length; i++) {
-            IndexAVL index = (IndexAVL) indexList[i];
-            NodeAVL  node  = (NodeAVL) accessorList[i];
-            IndexAVLProbe probe = new IndexAVLProbe(session, this, index,
-                node);
+            IndexAVL      index = (IndexAVL) indexList[i];
+            NodeAVL       node  = (NodeAVL) accessorList[i];
+            IndexAVLProbe probe = new IndexAVLProbe(session, this, index, node);
 
             probe.probe();
 
@@ -714,8 +739,10 @@ public abstract class RowStoreAVL implements PersistentStore {
         it.release();
     }
 
-    boolean insertIndexNodes(Session session, Index primaryIndex,
-                             Index newIndex) {
+    boolean insertIndexNodes(
+            Session session,
+            Index primaryIndex,
+            Index newIndex) {
 
         writeLock();
 
