@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -41,12 +41,14 @@ import org.hsqldb.ColumnBase;
 import org.hsqldb.HsqlException;
 import org.hsqldb.Session;
 import org.hsqldb.SessionInterface;
+import org.hsqldb.SessionInterface.AttributePos;
 import org.hsqldb.SqlInvariants;
 import org.hsqldb.Statement;
 import org.hsqldb.error.Error;
 import org.hsqldb.error.ErrorCode;
 import org.hsqldb.lib.ArrayUtil;
 import org.hsqldb.lib.DataOutputStream;
+import org.hsqldb.lib.List;
 import org.hsqldb.map.ValuePool;
 import org.hsqldb.navigator.RowSetNavigator;
 import org.hsqldb.navigator.RowSetNavigatorClient;
@@ -69,7 +71,7 @@ import org.hsqldb.types.Type;
  *
  * @author Campbell Burnet (campbell-burnet@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.4
  * @since 1.9.0
  */
 public class Result {
@@ -84,29 +86,33 @@ public class Result {
         Charset.getDefaultInstance();
         Collation.getDefaultInstance();
 
-        sessionAttributesMetaData =
-            ResultMetaData.newResultMetaData(SessionInterface.INFO_LIMIT);
+        sessionAttributesMetaData = ResultMetaData.newResultMetaData(
+            AttributePos.INFO_LIMIT);
 
-        for (int i = 0; i < Session.INFO_LIMIT; i++) {
-            sessionAttributesMetaData.columns[i] = new ColumnBase(null, null,
-                    null, null);
+        for (int i = 0; i < AttributePos.INFO_LIMIT; i++) {
+            sessionAttributesMetaData.columns[i] = new ColumnBase(
+                null,
+                null,
+                null,
+                null);
         }
 
-        sessionAttributesMetaData.columns[Session.INFO_ID].setType(
+        sessionAttributesMetaData.columns[AttributePos.INFO_ID].setType(
             Type.SQL_INTEGER);
-        sessionAttributesMetaData.columns[Session.INFO_INTEGER].setType(
+        sessionAttributesMetaData.columns[AttributePos.INFO_INTEGER].setType(
             Type.SQL_INTEGER);
-        sessionAttributesMetaData.columns[Session.INFO_BOOLEAN].setType(
+        sessionAttributesMetaData.columns[AttributePos.INFO_BOOLEAN].setType(
             Type.SQL_BOOLEAN);
-        sessionAttributesMetaData.columns[Session.INFO_VARCHAR].setType(
+        sessionAttributesMetaData.columns[AttributePos.INFO_VARCHAR].setType(
             Type.SQL_VARCHAR);
         sessionAttributesMetaData.prepareData();
     }
 
     private static final ResultMetaData emptyMeta =
-        ResultMetaData.newResultMetaData(0);
-    public static final Result emptyGeneratedResult =
-        Result.newDataResult(emptyMeta);
+        ResultMetaData.newResultMetaData(
+            0);
+    public static final Result emptyGeneratedResult = Result.newDataResult(
+        emptyMeta);
     public static final Result updateZeroResult = newUpdateCountResult(0);
     public static final Result updateOneResult  = newUpdateCountResult(1);
 
@@ -205,7 +211,7 @@ public class Result {
     public static Result newResult(int type) {
 
         RowSetNavigator navigator = null;
-        Result          result    = null;
+        Result          result;
 
         switch (type) {
 
@@ -236,6 +242,7 @@ public class Result {
 
             case ResultConstants.LARGE_OBJECT_OP :
                 throw Error.runtimeError(ErrorCode.U_S0500, "Result");
+
             default :
         }
 
@@ -245,17 +252,20 @@ public class Result {
         return result;
     }
 
-    public static Result newResult(DataInputStream dataInput,
-                                   RowInputInterface in) throws IOException {
-
+    public static Result newResult(
+            DataInputStream dataInput,
+            RowInputInterface in)
+            throws IOException {
         int readMode = dataInput.readByte();
 
         return newResult(null, readMode, dataInput, in);
     }
 
-    public static Result newResult(Session session, int mode,
-                                   DataInputStream dataInput,
-                                   RowInputInterface in) {
+    public static Result newResult(
+            Session session,
+            int mode,
+            DataInputStream dataInput,
+            RowInputInterface in) {
 
         try {
             if (mode == ResultConstants.LARGE_OBJECT_OP) {
@@ -270,12 +280,11 @@ public class Result {
         }
     }
 
-    public void readAdditionalResults(SessionInterface session,
-                                      DataInputStream inputStream,
-                                      RowInputInterface in)
-                                      throws IOException {
-
-        Result currentResult = this;
+    public void readAdditionalResults(
+            SessionInterface session,
+            DataInputStream inputStream,
+            RowInputInterface in)
+            throws IOException {
 
         setSession(session);
 
@@ -286,15 +295,20 @@ public class Result {
                 return;
             }
 
-            currentResult = newResult(null, inputStream, in, addedResultMode);
+            Result currentResult = newResult(
+                null,
+                inputStream,
+                in,
+                addedResultMode);
 
             addChainedResult(currentResult);
         }
     }
 
-    public Result readLobResults(Session session,
-                                 DataInputStream inputStream)
-                                 throws IOException {
+    public Result readLobResults(
+            Session session,
+            DataInputStream inputStream)
+            throws IOException {
 
         boolean hasLob = false;
 
@@ -312,8 +326,6 @@ public class Result {
                 }
 
                 hasLob = true;
-
-                continue;
             } else if (addedResultMode == ResultConstants.NONE) {
                 break;
             } else {
@@ -328,9 +340,12 @@ public class Result {
         return Result.updateZeroResult;
     }
 
-    private static Result newResult(Session session, DataInput dataInput,
-                                    RowInputInterface in,
-                                    int mode) throws IOException {
+    private static Result newResult(
+            Session session,
+            DataInput dataInput,
+            RowInputInterface in,
+            int mode)
+            throws IOException {
 
         Result result = newResult(mode);
         int    length = dataInput.readInt();
@@ -360,12 +375,13 @@ public class Result {
                 result.rsProperties = in.readByte();
                 result.generateKeys = in.readByte();
 
-                if (result.generateKeys == ResultConstants
-                        .RETURN_GENERATED_KEYS_COL_NAMES || result
-                        .generateKeys == ResultConstants
-                        .RETURN_GENERATED_KEYS_COL_INDEXES) {
+                if (result.generateKeys
+                        == ResultConstants.RETURN_GENERATED_KEYS_COL_NAMES
+                        || result.generateKeys
+                        == ResultConstants.RETURN_GENERATED_KEYS_COL_INDEXES) {
                     result.generatedMetaData = new ResultMetaData(in);
                 }
+
                 break;
 
             case ResultConstants.CLOSE_RESULT :
@@ -385,12 +401,13 @@ public class Result {
                 result.queryTimeout        = in.readShort();
                 result.generateKeys        = in.readByte();
 
-                if (result.generateKeys == ResultConstants
-                        .RETURN_GENERATED_KEYS_COL_NAMES || result
-                        .generateKeys == ResultConstants
-                        .RETURN_GENERATED_KEYS_COL_INDEXES) {
+                if (result.generateKeys
+                        == ResultConstants.RETURN_GENERATED_KEYS_COL_NAMES
+                        || result.generateKeys
+                        == ResultConstants.RETURN_GENERATED_KEYS_COL_INDEXES) {
                     result.generatedMetaData = new ResultMetaData(in);
                 }
+
                 break;
 
             case ResultConstants.CONNECT :
@@ -445,6 +462,7 @@ public class Result {
 
                 break;
             }
+
             case ResultConstants.SETCONNECTATTR : {
                 int type = in.readInt();                        // attr type
 
@@ -465,6 +483,7 @@ public class Result {
 
                 break;
             }
+
             case ResultConstants.SQLCANCEL :
                 result.databaseID   = in.readInt();
                 result.sessionID    = in.readLong();
@@ -498,15 +517,14 @@ public class Result {
                 result.rsProperties = in.readByte();
                 result.queryTimeout = in.readShort();
 
-                Statement statement =
-                    session.statementManager.getStatement(result.statementID);
+                Statement statement = session.statementManager.getStatement(
+                    result.statementID);
 
                 if (statement == null) {
 
                     // invalid statement
                     result.mode      = ResultConstants.EXECUTE_INVALID;
                     result.valueData = ValuePool.emptyObjectArray;
-
                     break;
                 }
 
@@ -524,9 +542,9 @@ public class Result {
 
                 result.metaData  = new ResultMetaData(in);
                 result.valueData = readSimple(in, result.metaData);
-
                 break;
             }
+
             case ResultConstants.BATCHEXECRESPONSE :
             case ResultConstants.BATCHEXECUTE :
             case ResultConstants.BATCHEXECDIRECT :
@@ -538,23 +556,23 @@ public class Result {
                 result.metaData     = new ResultMetaData(in);
 
                 result.navigator.readSimple(in, result.metaData);
-
                 break;
             }
+
             case ResultConstants.PARAM_METADATA : {
                 result.metaData = new ResultMetaData(in);
 
                 result.navigator.read(in, result.metaData);
-
                 break;
             }
+
             case ResultConstants.REQUESTDATA : {
                 result.id          = in.readLong();
                 result.updateCount = in.readInt();
                 result.fetchSize   = in.readInt();
-
                 break;
             }
+
             case ResultConstants.DATAHEAD :
             case ResultConstants.DATA :
             case ResultConstants.GENERATED : {
@@ -566,17 +584,17 @@ public class Result {
                 result.navigator    = new RowSetNavigatorClient();
 
                 result.navigator.read(in, result.metaData);
-
                 break;
             }
+
             case ResultConstants.DATAROWS : {
                 result.metaData  = new ResultMetaData(in);
                 result.navigator = new RowSetNavigatorClient();
 
                 result.navigator.read(in, result.metaData);
-
                 break;
             }
+
             default :
                 throw Error.runtimeError(ErrorCode.U_S0500, "Result");
         }
@@ -623,7 +641,8 @@ public class Result {
      * For execution of SQL prepared statements.
      * The parameters are set afterwards as the Result is reused
      */
-    public static Result newPreparedExecuteRequest(Type[] types,
+    public static Result newPreparedExecuteRequest(
+            Type[] types,
             long statementId) {
 
         Result result = newResult(ResultConstants.EXECUTE);
@@ -639,8 +658,10 @@ public class Result {
      * For CALL_RESPONSE
      * For execution of SQL callable statements.
      */
-    public static Result newCallResponse(Type[] types, long statementId,
-                                         Object[] values) {
+    public static Result newCallResponse(
+            Type[] types,
+            long statementId,
+            Object[] values) {
 
         Result result = newResult(ResultConstants.CALL_RESPONSE);
 
@@ -661,7 +682,7 @@ public class Result {
 
         result.metaData  = ResultMetaData.newUpdateResultMetaData(types);
         result.id        = id;
-        result.valueData = new Object[]{};
+        result.valueData = ValuePool.emptyObjectArray;
 
         return result;
     }
@@ -678,8 +699,12 @@ public class Result {
      * For SQLEXECUTE results
      * The parameters are set by this method as the Result is reused
      */
-    public void setPreparedExecuteProperties(Object[] parameterValues,
-            int maxRows, int fetchSize, int resultProps, int timeout) {
+    public void setPreparedExecuteProperties(
+            Object[] parameterValues,
+            int maxRows,
+            int fetchSize,
+            int resultProps,
+            int timeout) {
 
         mode              = ResultConstants.EXECUTE;
         valueData         = parameterValues;
@@ -726,8 +751,10 @@ public class Result {
     /**
      * For BATCHEXERESPONSE for a BATCHEXECUTE or BATCHEXECDIRECT
      */
-    public static Result newBatchedExecuteResponse(int[] updateCounts,
-            Result generatedResult, Result e) {
+    public static Result newBatchedExecuteResponse(
+            int[] updateCounts,
+            Result generatedResult,
+            Result e) {
 
         Result result = newResult(ResultConstants.BATCHEXECRESPONSE);
 
@@ -750,14 +777,14 @@ public class Result {
     }
 
     public static Result newResetSessionRequest() {
-
-        Result result = newResult(ResultConstants.RESETSESSION);
-
-        return result;
+        return newResult(ResultConstants.RESETSESSION);
     }
 
-    public static Result newConnectionAttemptRequest(String user,
-            String password, String database, String zoneString,
+    public static Result newConnectionAttemptRequest(
+            String user,
+            String password,
+            String database,
+            String zoneString,
             int timeZoneSeconds) {
 
         Result result = newResult(ResultConstants.CONNECT);
@@ -778,9 +805,9 @@ public class Result {
         result.sessionID    = session.getId();
         result.databaseID   = session.getDatabase().getDatabaseID();
         result.databaseName = session.getDatabase().getNameString();
-        result.mainString =
-            session.getDatabase().getProperties()
-                .getClientPropertiesAsString();
+        result.mainString = session.getDatabase()
+                                   .getProperties()
+                                   .getClientPropertiesAsString();
         result.generateKeys = session.getRandomId();
 
         return result;
@@ -826,12 +853,12 @@ public class Result {
         return result;
     }
 
-    public static Result newSingleColumnStringResult(String colName,
+    public static Result newSingleColumnStringResult(
+            String colName,
             String contents) {
 
-        Result result = Result.newSingleColumnResult(colName);
-        LineNumberReader lnr =
-            new LineNumberReader(new StringReader(contents));
+        Result           result = Result.newSingleColumnResult(colName);
+        LineNumberReader lnr = new LineNumberReader(new StringReader(contents));
 
         while (true) {
             String line = null;
@@ -850,10 +877,9 @@ public class Result {
         return result;
     }
 
-    public static Result newMultiColumnResult(String[] names,
-            Type[] types) {
+    public static Result newMultiColumnResult(String[] names, Type[] types) {
 
-        Result   result = newResult(ResultConstants.DATA);
+        Result result = newResult(ResultConstants.DATA);
 
         result.metaData  = ResultMetaData.newMetaData(names, types);
         result.navigator = new RowSetNavigatorClient(8);
@@ -877,8 +903,10 @@ public class Result {
         return r;
     }
 
-    public static Result newCancelRequest(int randomId, long statementId,
-                                          String sql) {
+    public static Result newCancelRequest(
+            int randomId,
+            long statementId,
+            String sql) {
 
         Result r = newResult(ResultConstants.SQLCANCEL);
 
@@ -909,9 +937,15 @@ public class Result {
     /**
      * For both EXECDIRECT and PREPARE
      */
-    public void setPrepareOrExecuteProperties(String sql, int maxRows,
-            int fetchSize, int statementReturnType, int timeout,
-            int resultSetProperties, int keyMode, int[] generatedIndexes,
+    public void setPrepareOrExecuteProperties(
+            String sql,
+            int maxRows,
+            int fetchSize,
+            int statementReturnType,
+            int timeout,
+            int resultSetProperties,
+            int keyMode,
+            int[] generatedIndexes,
             String[] generatedNames) {
 
         mainString               = sql;
@@ -921,9 +955,9 @@ public class Result {
         queryTimeout             = timeout;
         rsProperties             = resultSetProperties;
         generateKeys             = keyMode;
-        generatedMetaData =
-            ResultMetaData.newGeneratedColumnsMetaData(generatedIndexes,
-                generatedNames);
+        generatedMetaData = ResultMetaData.newGeneratedColumnsMetaData(
+            generatedIndexes,
+            generatedNames);
     }
 
     public static Result newSetSavepointRequest(String name) {
@@ -976,9 +1010,11 @@ public class Result {
         return rsProperties;
     }
 
-    public static Result newDataHeadResult(SessionInterface session,
-                                           Result source, int offset,
-                                           int count) {
+    public static Result newDataHeadResult(
+            SessionInterface session,
+            Result source,
+            int offset,
+            int count) {
 
         if (offset + count > source.navigator.getSize()) {
             count = source.navigator.getSize() - offset;
@@ -987,8 +1023,10 @@ public class Result {
         Result result = newResult(ResultConstants.DATAHEAD);
 
         result.metaData = source.metaData;
-        result.navigator = new RowSetNavigatorClient(source.navigator, offset,
-                count);
+        result.navigator = new RowSetNavigatorClient(
+            source.navigator,
+            offset,
+            count);
 
         result.navigator.setId(source.navigator.getId());
         result.setSession(session);
@@ -999,8 +1037,10 @@ public class Result {
         return result;
     }
 
-    public static Result newDataRowsResult(Result source, int offset,
-                                           int count) {
+    public static Result newDataRowsResult(
+            Result source,
+            int offset,
+            int count) {
 
         if (offset + count > source.navigator.getSize()) {
             count = source.navigator.getSize() - offset;
@@ -1010,8 +1050,10 @@ public class Result {
 
         result.id       = source.id;
         result.metaData = source.metaData;
-        result.navigator = new RowSetNavigatorClient(source.navigator, offset,
-                count);
+        result.navigator = new RowSetNavigatorClient(
+            source.navigator,
+            offset,
+            count);
 
         return result;
     }
@@ -1035,7 +1077,7 @@ public class Result {
         result.navigator = new RowSetNavigatorClient(1);
         result.metaData  = sessionAttributesMetaData;
 
-        result.navigator.add(new Object[SessionInterface.INFO_LIMIT]);
+        result.navigator.add(new Object[AttributePos.INFO_LIMIT]);
 
         return result;
     }
@@ -1091,8 +1133,11 @@ public class Result {
         return result;
     }
 
-    public void write(SessionInterface session, DataOutputStream dataOut,
-                      RowOutputInterface rowOut) throws IOException {
+    public void write(
+            SessionInterface session,
+            DataOutputStream dataOut,
+            RowOutputInterface rowOut)
+            throws IOException {
 
         rowOut.reset();
         rowOut.writeByte(mode);
@@ -1118,11 +1163,13 @@ public class Result {
                 rowOut.writeByte(rsProperties);
                 rowOut.writeByte(generateKeys);
 
-                if (generateKeys == ResultConstants
-                        .RETURN_GENERATED_KEYS_COL_NAMES || generateKeys == ResultConstants
-                        .RETURN_GENERATED_KEYS_COL_INDEXES) {
+                if (generateKeys
+                        == ResultConstants.RETURN_GENERATED_KEYS_COL_NAMES
+                        || generateKeys
+                        == ResultConstants.RETURN_GENERATED_KEYS_COL_INDEXES) {
                     generatedMetaData.write(rowOut);
                 }
+
                 break;
 
             case ResultConstants.FREESTMT :
@@ -1142,11 +1189,13 @@ public class Result {
                 rowOut.writeShort(queryTimeout);
                 rowOut.writeByte(generateKeys);
 
-                if (generateKeys == ResultConstants
-                        .RETURN_GENERATED_KEYS_COL_NAMES || generateKeys == ResultConstants
-                        .RETURN_GENERATED_KEYS_COL_INDEXES) {
+                if (generateKeys
+                        == ResultConstants.RETURN_GENERATED_KEYS_COL_NAMES
+                        || generateKeys
+                        == ResultConstants.RETURN_GENERATED_KEYS_COL_INDEXES) {
                     generatedMetaData.write(rowOut);
                 }
+
                 break;
 
             case ResultConstants.CONNECT :
@@ -1201,6 +1250,7 @@ public class Result {
 
                 break;
             }
+
             case ResultConstants.SQLCANCEL :
                 rowOut.writeInt(databaseID);
                 rowOut.writeLong(sessionID);
@@ -1253,15 +1303,15 @@ public class Result {
                 rowOut.writeShort(queryTimeout);
                 metaData.write(rowOut);
                 navigator.writeSimple(rowOut, metaData);
-
                 break;
             }
+
             case ResultConstants.PARAM_METADATA : {
                 metaData.write(rowOut);
                 navigator.write(rowOut, metaData);
-
                 break;
             }
+
             case ResultConstants.SETCONNECTATTR : {
                 int type = getConnectionAttrType();
 
@@ -1281,13 +1331,14 @@ public class Result {
 
                 break;
             }
+
             case ResultConstants.REQUESTDATA : {
                 rowOut.writeLong(id);
                 rowOut.writeInt(updateCount);
                 rowOut.writeInt(fetchSize);
-
                 break;
             }
+
             case ResultConstants.DATAROWS :
                 metaData.write(rowOut);
                 navigator.write(rowOut, metaData);
@@ -1336,8 +1387,7 @@ public class Result {
     }
 
     public boolean isData() {
-        return mode == ResultConstants.DATA
-               || mode == ResultConstants.DATAHEAD;
+        return mode == ResultConstants.DATA || mode == ResultConstants.DATAHEAD;
     }
 
     public boolean isError() {
@@ -1458,7 +1508,6 @@ public class Result {
     }
 
     public void setSession(SessionInterface session) {
-
         if (navigator != null) {
             navigator.setSession(session);
         }
@@ -1493,8 +1542,9 @@ public class Result {
 
         mode        = ResultConstants.ENDTRAN;
         updateCount = subType;
-        mainString  = savepoint == null ? ""
-                                        : savepoint;
+        mainString  = savepoint == null
+                      ? ""
+                      : savepoint;
     }
 
     public Object[] getSingleRowData() {
@@ -1504,8 +1554,9 @@ public class Result {
 
         Object[] data = navigator.getCurrent();
 
-        data = (Object[]) ArrayUtil.resizeArrayIfDifferent(data,
-                metaData.getColumnCount());
+        data = (Object[]) ArrayUtil.resizeArrayIfDifferent(
+            data,
+            metaData.getColumnCount());
 
         return data;
     }
@@ -1609,37 +1660,41 @@ public class Result {
         lobCount   = 0;
     }
 
-    public void addRows(String[] sql) {
+    public void addRows(List<String> sqlArray) {
 
-        if (sql == null) {
+        if (sqlArray == null) {
             return;
         }
 
-        for (int i = 0; i < sql.length; i++) {
+        for (int i = 0; i < sqlArray.size(); i++) {
             String[] s = new String[1];
 
-            s[0] = sql[i];
+            s[0] = sqlArray.get(i);
 
             initialiseNavigator().add(s);
         }
     }
 
-    private static Object[] readSimple(RowInputInterface in,
-                                       ResultMetaData meta)
-                                       throws IOException {
-
+    private static Object[] readSimple(
+            RowInputInterface in,
+            ResultMetaData meta) {
         int size = in.readInt();
 
         return in.readData(meta.columnTypes);
     }
 
-    private static void writeSimple(RowOutputInterface out,
-                                    ResultMetaData meta,
-                                    Object[] data) throws IOException {
+    private static void writeSimple(
+            RowOutputInterface out,
+            ResultMetaData meta,
+            Object[] data) {
 
         out.writeInt(1);
-        out.writeData(meta.getColumnCount(), meta.columnTypes, data, null,
-                      null);
+        out.writeData(
+            meta.getColumnCount(),
+            meta.columnTypes,
+            data,
+            null,
+            null);
     }
 
 //----------- Navigation
