@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,7 @@
 
 package org.hsqldb.rowio;
 
+import org.hsqldb.ColumnSchema;
 import org.hsqldb.Row;
 import org.hsqldb.lib.HsqlByteArrayOutputStream;
 import org.hsqldb.lib.OrderedHashMap;
@@ -41,7 +42,7 @@ import org.hsqldb.types.Type;
  *
  * @author Bob Preston (sqlbob@users dot sourceforge.net)
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.4.1
+ * @version 2.7.3
  * @since 1.7.0
  */
 public interface RowOutputInterface extends Cloneable {
@@ -76,8 +77,12 @@ public interface RowOutputInterface extends Cloneable {
 
     void writeData(Row row, Type[] types);
 
-    void writeData(int l, Type[] types, Object[] data, OrderedHashMap cols,
-                   int[] primarykeys);
+    void writeData(
+            int l,
+            Type[] types,
+            Object[] data,
+            OrderedHashMap<String, ColumnSchema> cols,
+            int[] primaryKeys);
 
     int getSize(Row row);
 
