@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -53,11 +53,14 @@ public class HsqlServerFactory {
 
     private HsqlServerFactory() {}
 
-    public static HsqlSocketRequestHandler createHsqlServer(String dbFilePath,
-            boolean debugMessages, boolean silentMode) throws SQLException {
+    public static HsqlSocketRequestHandler createHsqlServer(
+            String dbFilePath,
+            boolean debugMessages,
+            boolean silentMode)
+            throws SQLException {
 
-        ServerProperties props =
-            new ServerProperties(ServerConstants.SC_PROTOCOL_HSQL);
+        ServerProperties props = new ServerProperties(
+            ServerConstants.SC_PROTOCOL_HSQL);
 
         props.setProperty("server.dbname.0", "");
         props.setProperty("server.database.0", dbFilePath);
