@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,6 +33,7 @@ package org.hsqldb.server;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
+
 import java.net.InetAddress;
 import java.net.ServerSocket;
 import java.net.Socket;
@@ -71,8 +72,9 @@ public class HsqlSocketFactory {
      * @return a new factory
      */
     public static HsqlSocketFactory getInstance(boolean tls) throws Exception {
-        return tls ? getSSLImpl()
-                   : getPlainImpl();
+        return tls
+               ? getSSLImpl()
+               : getPlainImpl();
     }
 
 // -------------------------- public instance methods --------------------------
@@ -103,8 +105,10 @@ public class HsqlSocketFactory {
      * @param address String
      * @throws Exception if a network error occurs
      */
-    public ServerSocket createServerSocket(int port,
-                                           String address) throws Exception {
+    public ServerSocket createServerSocket(
+            int port,
+            String address)
+            throws Exception {
         return new ServerSocket(port, 128, InetAddress.getByName(address));
     }
 
@@ -120,10 +124,14 @@ public class HsqlSocketFactory {
      * @param port the server port
      * @throws Exception if a network error occurs
      */
-    public Socket createSocket(Socket socket, String host,
-                               int port) throws Exception {
-        return socket == null ? new Socket(host, port)
-                              : socket;
+    public Socket createSocket(
+            Socket socket,
+            String host,
+            int port)
+            throws Exception {
+        return socket == null
+               ? new Socket(host, port)
+               : socket;
     }
 
     /**
@@ -165,8 +173,8 @@ public class HsqlSocketFactory {
 
         synchronized (HsqlSocketFactory.class) {
             if (sslImpl == null) {
-                sslImpl =
-                    newFactory("org.hsqldb.server.HsqlSocketFactorySecure");
+                sslImpl = newFactory(
+                    "org.hsqldb.server.HsqlSocketFactorySecure");
             }
         }
 
@@ -188,8 +196,9 @@ public class HsqlSocketFactory {
      * @throws Exception if a new secure socket factory cannot
      *      be constructed
      */
-    private static HsqlSocketFactory newFactory(String implClass)
-    throws Exception {
+    private static HsqlSocketFactory newFactory(
+            String implClass)
+            throws Exception {
 
         Class       clazz;
         Constructor ctor;
@@ -209,9 +218,9 @@ public class HsqlSocketFactory {
         } catch (InvocationTargetException e) {
             Throwable t = e.getTargetException();
 
-            throw (t instanceof Exception) ? ((Exception) t)
-                                           : new RuntimeException(
-                                               t.toString());
+            throw(t instanceof Exception)
+                 ? ((Exception) t)
+                 : new RuntimeException(t.toString());
         }
 
         return (HsqlSocketFactory) factory;
