@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2022, The HSQL Development Group
+ * Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -75,8 +75,10 @@ import java.io.ByteArrayInputStream;
 import java.io.DataInputStream;
 import java.io.EOFException;
 import java.io.IOException;
+
 import java.net.Socket;
 import java.net.SocketException;
+
 import java.util.concurrent.atomic.AtomicLong;
 
 import org.hsqldb.ClientConnection;
@@ -123,7 +125,7 @@ import org.hsqldb.types.Type;
  *
  * @author Blaine Simpson (unsaved@users dot sourceforge.net
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.4
  * @since 1.6.2
  */
 class ServerConnection implements Runnable {
@@ -154,7 +156,8 @@ class ServerConnection implements Runnable {
 
     static {
         int serverBundleHandle = ResourceBundleHandler.getBundleHandle(
-            "org_hsqldb_server_Server_messages", null);
+            "org_hsqldb_server_Server_messages",
+            null);
 
         if (serverBundleHandle < 0) {
             throw new RuntimeException(
@@ -164,10 +167,12 @@ class ServerConnection implements Runnable {
             // Not necessary to localize message.
         }
 
-        TEXTBANNER_PART1 = ResourceBundleHandler.getString(serverBundleHandle,
-                "textbanner.part1");
-        TEXTBANNER_PART2 = ResourceBundleHandler.getString(serverBundleHandle,
-                "textbanner.part2");
+        TEXTBANNER_PART1 = ResourceBundleHandler.getString(
+            serverBundleHandle,
+            "textbanner.part1");
+        TEXTBANNER_PART2 = ResourceBundleHandler.getString(
+            serverBundleHandle,
+            "textbanner.part2");
 
         if (TEXTBANNER_PART1 == null || TEXTBANNER_PART2 == null) {
             throw new RuntimeException(
@@ -319,7 +324,6 @@ class ServerConnection implements Runnable {
         private String clientMessage = null;
 
         public ClientFailure(String ourMessage, String clientMessage) {
-
             super(ourMessage);
 
             this.clientMessage = clientMessage;
@@ -332,11 +336,15 @@ class ServerConnection implements Runnable {
 
     private CleanExit cleanExit = new CleanExit();
 
-    private void receiveResult(int resultMode) throws CleanExit, IOException {
+    private void receiveResult(int resultMode) throws CleanExit,
+            IOException {
 
         boolean terminate = false;
-        Result resultIn = Result.newResult(session, resultMode, dataInput,
-                                           rowIn);
+        Result resultIn = Result.newResult(
+            session,
+            resultMode,
+            dataInput,
+            rowIn);
 
         resultIn.readLobResults(session, dataInput);
         server.printRequest(mThread, resultIn);
@@ -347,37 +355,36 @@ class ServerConnection implements Runnable {
 
             case ResultConstants.CONNECT : {
                 resultOut = setDatabase(resultIn);
-
                 break;
             }
+
             case ResultConstants.SQLCANCEL : {
                 resultOut = cancelStatement(resultIn);
                 terminate = true;
-
                 break;
             }
+
             case ResultConstants.DISCONNECT : {
                 resultOut = Result.updateZeroResult;
                 terminate = true;
-
                 break;
             }
+
             case ResultConstants.RESETSESSION : {
                 session.resetSession();
 
                 resultOut = Result.updateZeroResult;
-
                 break;
             }
+
             case ResultConstants.EXECUTE_INVALID : {
-                resultOut =
-                    Result.newErrorResult(Error.error(ErrorCode.X_07502));
-
+                resultOut = Result.newErrorResult(
+                    Error.error(ErrorCode.X_07502));
                 break;
             }
+
             default : {
                 resultOut = session.execute(resultIn);
-
                 break;
             }
         }
@@ -393,7 +400,8 @@ class ServerConnection implements Runnable {
 
     private OdbcPacketOutputStream outPacket = null;
 
-    private void receiveOdbcPacket(char inC) throws IOException, CleanExit {
+    private void receiveOdbcPacket(char inC) throws IOException,
+            CleanExit {
 
         /*
          * The driver's notion of the transaction state, I (no) or T (yes),
@@ -402,8 +410,8 @@ class ServerConnection implements Runnable {
          * If the user/app runs in non-autocommit mode and says to run a
          * COMMIT followed by an INSERT, the driver will handle the user/app's
          * facade of autocommittedness, and will send the server <OL>
-         *   <LI>COMMIT (which will cause us to set session.setAutoCommit(true)
-         *   <LI>BEGIN (which will cause us to set session.setAutoCommit(false)
+         *   <LI>COMMIT (which will cause us to set session.setAutoCommit(true))
+         *   <LI>BEGIN (which will cause us to set session.setAutoCommit(false))
          *   <LI>INSERT...
          * </OL>
          */
@@ -877,15 +885,13 @@ class ServerConnection implements Runnable {
 
                         // Must use "sql" directly since name is case-sensitive
                         handle = tmpStr.substring(0, tmpStr.length() - 1);
-                        odbcPs = (OdbcPreparedStatement) sessionOdbcPsMap.get(
-                            handle);
+                        odbcPs = sessionOdbcPsMap.get(handle);
 
                         if (odbcPs != null) {
                             odbcPs.close();
                         }
 
-                        portal =
-                            (StatementPortal) sessionOdbcPortalMap.get(handle);
+                        portal = sessionOdbcPortalMap.get(handle);
 
                         if (portal != null) {
                             portal.close();
@@ -1035,11 +1041,9 @@ class ServerConnection implements Runnable {
                     portal = null;
 
                     if (c == 'S') {
-                        odbcPs = (OdbcPreparedStatement) sessionOdbcPsMap.get(
-                            handle);
+                        odbcPs = sessionOdbcPsMap.get(handle);
                     } else if (c == 'P') {
-                        portal =
-                            (StatementPortal) sessionOdbcPortalMap.get(handle);
+                        portal = sessionOdbcPortalMap.get(handle);
                     } else {
                         throw new RecoverableOdbcFailure(
                             null,
@@ -1211,8 +1215,7 @@ class ServerConnection implements Runnable {
                             + "'");
                     }
 
-                    odbcPs =
-                        (OdbcPreparedStatement) sessionOdbcPsMap.get(psHandle);
+                    odbcPs = sessionOdbcPsMap.get(psHandle);
 
                     if (odbcPs == null) {
                         throw new RecoverableOdbcFailure(
@@ -1258,8 +1261,7 @@ class ServerConnection implements Runnable {
                                                + portalHandle + "'");
                     }
 
-                    portal = (StatementPortal) sessionOdbcPortalMap.get(
-                        portalHandle);
+                    portal = sessionOdbcPortalMap.get(portalHandle);
 
                     if (portal == null) {
                         throw new RecoverableOdbcFailure(
@@ -1393,15 +1395,13 @@ class ServerConnection implements Runnable {
                     portal = null;
 
                     if (c == 'S') {
-                        odbcPs = (OdbcPreparedStatement) sessionOdbcPsMap.get(
-                            handle);
+                        odbcPs = sessionOdbcPsMap.get(handle);
 
                         if (odbcPs != null) {
                             odbcPs.close();
                         }
                     } else if (c == 'P') {
-                        portal =
-                            (StatementPortal) sessionOdbcPortalMap.get(handle);
+                        portal = sessionOdbcPortalMap.get(handle);
 
                         if (portal != null) {
                             portal.close();
@@ -1622,7 +1622,6 @@ class ServerConnection implements Runnable {
      * banner.  Can't be too low or we could close a valid but slow
      * client connection.
      */
-    public static long MAX_WAIT_FOR_CLIENT_DATA   = 1000;    // ms.
     public static long CLIENT_DATA_POLLING_PERIOD = 100;     // ms.
 
     /**
@@ -1639,7 +1638,7 @@ class ServerConnection implements Runnable {
     public int handshake() throws IOException {
 
         long clientDataDeadline = new java.util.Date().getTime()
-                                  + MAX_WAIT_FOR_CLIENT_DATA;
+                                  + server.maxWaitForClientData;
 
         if (!(socket instanceof javax.net.ssl.SSLSocket)) {
 
@@ -1768,7 +1767,7 @@ class ServerConnection implements Runnable {
                 firstInt - 8);
 
         // - 4 for size of firstInt - 2 for major - 2 for minor
-        java.util.Map stringPairs = inPacket.readStringPairs();
+        java.util.Map<String, String>  stringPairs = inPacket.readStringPairs();
 
         if (server.isTrace()) {
             server.print("String Pairs from ODBC client: " + stringPairs);
@@ -1795,9 +1794,9 @@ class ServerConnection implements Runnable {
                                         "Target account not identified");
             }
 
-            String databaseName = (String) stringPairs.get("database");
+            String databaseName = stringPairs.get("database");
 
-            user = (String) stringPairs.get("user");
+            user = stringPairs.get("user");
 
             if (databaseName.equals("/")) {
 
@@ -1894,8 +1893,8 @@ class ServerConnection implements Runnable {
         dataOutput.flush();
     }
 
-    private java.util.Map sessionOdbcPsMap     = new java.util.HashMap();
-    private java.util.Map sessionOdbcPortalMap = new java.util.HashMap();
+    private java.util.Map<String, OdbcPreparedStatement> sessionOdbcPsMap = new java.util.HashMap<>();
+    private java.util.Map<String, StatementPortal> sessionOdbcPortalMap = new java.util.HashMap<>();
 
     /**
      * Read String directly from dataInput.
