@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,6 +34,7 @@ package org.hsqldb.server;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
+
 import java.util.Enumeration;
 
 import org.hsqldb.lib.HashMap;
@@ -64,10 +65,10 @@ import org.hsqldb.persist.HsqlProperties;
  * against the range.<p>
  *
  * If a set of values specified in the Meta record, then the value is checked
- * against the set.<p>
+ * against the set.
  *
  * @author Fred Toussi (fredt@users dot sourceforge.net)
- * @version 2.7.0
+ * @version 2.7.4
  * @since 1.9.0
  */
 public class ServerProperties extends HsqlProperties {
@@ -78,27 +79,28 @@ public class ServerProperties extends HsqlProperties {
     static final int SYSTEM_PROPERTY       = 2;
 
     // keys to properties
-    static final String sc_key_prefix  = "server";
-    static final String sc_key_address = "server.address";
+    static final String sc_key_prefix             = "server";
+    static final String sc_key_address            = "server.address";
     static final String sc_key_autorestart_server =
         "server.restart_on_shutdown";
-    static final String sc_key_database         = "server.database";
-    static final String sc_key_dbname           = "server.dbname";
-    static final String sc_key_no_system_exit   = "server.no_system_exit";
-    static final String sc_key_port             = "server.port";
-    static final String sc_key_http_port        = "server.port";
-    static final String sc_key_silent           = "server.silent";
-    static final String sc_key_tls              = "server.tls";
-    static final String sc_key_trace            = "server.trace";
-    static final String sc_key_web_default_page = "server.default_page";
-    static final String sc_key_web_root         = "server.root";
-    static final String sc_key_max_connections  = "server.maxconnections";
-    static final String sc_key_remote_open_db   = "server.remote_open";
-    static final String sc_key_max_databases    = "server.maxdatabases";
-    static final String sc_key_acl              = "server.acl";
-    static final String sc_key_daemon           = "server.daemon";
-    static final String sc_key_props            = "server.props";
-    static final String sc_key_system           = "system";
+    static final String sc_key_database           = "server.database";
+    static final String sc_key_dbname             = "server.dbname";
+    static final String sc_key_no_system_exit     = "server.no_system_exit";
+    static final String sc_key_port               = "server.port";
+    static final String sc_key_http_port          = "server.port";
+    static final String sc_key_silent             = "server.silent";
+    static final String sc_key_tls                = "server.tls";
+    static final String sc_key_trace              = "server.trace";
+    static final String sc_key_web_default_page   = "server.default_page";
+    static final String sc_key_web_root           = "server.root";
+    static final String sc_key_max_connections    = "server.maxconnections";
+    static final String sc_key_max_wait           = "server.max_wait";
+    static final String sc_key_remote_open_db     = "server.remote_open";
+    static final String sc_key_max_databases      = "server.maxdatabases";
+    static final String sc_key_acl                = "server.acl";
+    static final String sc_key_daemon             = "server.daemon";
+    static final String sc_key_props              = "server.props";
+    static final String sc_key_system             = "system";
 
     // web server page defaults
     static final String sc_default_web_mime = "text/html";
@@ -106,16 +108,17 @@ public class ServerProperties extends HsqlProperties {
     static final String sc_default_web_root = ".";
 
     //
-    static final HashMap<String, PropertyMeta> serverMeta = new HashMap();
-    static final OrderedHashSet prefixes = new OrderedHashSet();
+    static final HashMap<String, PropertyMeta> serverMeta = new HashMap<>();
+    static final OrderedHashSet<String>        prefixes =
+        new OrderedHashSet<>();
 
     //
     final int         protocol;
     protected boolean initialised = false;
 
     //
-    IntKeyHashMap idToAliasMap = new IntKeyHashMap();
-    IntKeyHashMap idToPathMap  = new IntKeyHashMap();
+    IntKeyHashMap<String> idToAliasMap = new IntKeyHashMap<>();
+    IntKeyHashMap<String> idToPathMap  = new IntKeyHashMap<>();
 
     public ServerProperties(int protocol, File file) throws IOException {
 
@@ -139,7 +142,6 @@ public class ServerProperties extends HsqlProperties {
     }
 
     ServerProperties(int protocol, String path, String extension) {
-
         super(path, extension);
 
         this.protocol = protocol;
@@ -151,10 +153,10 @@ public class ServerProperties extends HsqlProperties {
      */
     public void validate() {
 
-        Enumeration en = stringProps.propertyNames();
+        Enumeration<?> en = stringProps.propertyNames();
 
         while (en.hasMoreElements()) {
-            String       key      = (String) en.nextElement();
+            String       key  = (String) en.nextElement();
             PropertyMeta meta = serverMeta.get(key);
 
             if (meta == null) {
@@ -165,7 +167,6 @@ public class ServerProperties extends HsqlProperties {
                 String error = "unsupported property: " + key;
 
                 super.addError(ANY_ERROR, error);
-
                 continue;
             }
 
@@ -182,12 +183,10 @@ public class ServerProperties extends HsqlProperties {
                     if (meta.propDefaultValue == null) {
                         error = "missing value for property: " + key;
                     } else {
-                        setProperty(key,
-                                    meta.propDefaultValue.toString());
+                        setProperty(key, meta.propDefaultValue.toString());
                     }
                 } else {
-                    error = HsqlProperties.validateProperty(key, value,
-                            meta);
+                    error = HsqlProperties.validateProperty(key, value, meta);
                 }
             }
 
@@ -196,7 +195,7 @@ public class ServerProperties extends HsqlProperties {
             }
         }
 
-        Iterator it = idToAliasMap.keySet().iterator();
+        Iterator<Integer> it = idToAliasMap.keySet().iterator();
 
         while (it.hasNext()) {
             int number = it.nextInt();
@@ -222,7 +221,7 @@ public class ServerProperties extends HsqlProperties {
     PropertyMeta getPrefixedMetadata(String key) {
 
         for (int i = 0; i < prefixes.size(); i++) {
-            String prefix = (String) prefixes.get(i);
+            String prefix = prefixes.get(i);
 
             if (key.startsWith(prefix)) {
                 return serverMeta.get(prefix);
@@ -308,10 +307,11 @@ public class ServerProperties extends HsqlProperties {
         serverMeta.put(sc_key_no_system_exit, newMeta(sc_key_no_system_exit, SERVER_PROPERTY, false));
         serverMeta.put(sc_key_daemon, newMeta(sc_key_daemon, SERVER_PROPERTY, false));
         serverMeta.put(sc_key_address, newMeta(sc_key_address, SERVER_PROPERTY, null));
-        serverMeta.put(sc_key_port, newMeta(sc_key_port, 0, 9001, 0, 65535));
-        serverMeta.put(sc_key_http_port, newMeta(sc_key_http_port, 0, 80, 0, 65535));
-        serverMeta.put(sc_key_max_connections, newMeta(sc_key_max_connections, 0, 100, 1, 10000));
-        serverMeta.put(sc_key_max_databases, newMeta(sc_key_max_databases, 0, 10, 1, 1000));
+        serverMeta.put(sc_key_port, newMeta(sc_key_port, SERVER_PROPERTY, 9001, 0, 65535));
+        serverMeta.put(sc_key_http_port, newMeta(sc_key_http_port, SERVER_PROPERTY, 80, 0, 65535));
+        serverMeta.put(sc_key_max_connections, newMeta(sc_key_max_connections, SERVER_PROPERTY, 100, 1, 10000));
+        serverMeta.put(sc_key_max_wait, newMeta(sc_key_max_wait, SERVER_PROPERTY, 1000, 0, 30000));
+        serverMeta.put(sc_key_max_databases, newMeta(sc_key_max_databases, SERVER_PROPERTY, 10, 1, 1000));
 
         //
         prefixes.add(sc_key_database);
