@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -46,15 +46,7 @@ import junit.framework.TestCase;
  */
 
 // fredt@users - modified to remove dependecy on DBUnit
-public class TestGroupByHaving extends TestCase {
-
-    //------------------------------------------------------------
-    // Class variables
-    //------------------------------------------------------------
-    private static final String databaseDriver   = "org.hsqldb.jdbc.JDBCDriver";
-    private static final String databaseURL      = "jdbc:hsqldb:mem:.";
-    private static final String databaseUser     = "sa";
-    private static final String databasePassword = "";
+public class TestGroupByHaving extends TestBase {
 
     //------------------------------------------------------------
     // Instance variables
@@ -76,11 +68,6 @@ public class TestGroupByHaving extends TestCase {
     //------------------------------------------------------------
     // Class methods
     //------------------------------------------------------------
-    protected static Connection getJDBCConnection() throws SQLException {
-        return DriverManager.getConnection(databaseURL, databaseUser,
-                                           databasePassword);
-    }
-
     protected void setUp() throws Exception {
 
         super.setUp();
@@ -89,9 +76,7 @@ public class TestGroupByHaving extends TestCase {
             return;
         }
 
-        Class.forName(databaseDriver);
-
-        conn = getJDBCConnection();
+        conn = newConnection();
         stmt = conn.createStatement();
 
         // I decided not the use the "IF EXISTS" clause since it is not a
@@ -124,7 +109,7 @@ public class TestGroupByHaving extends TestCase {
         addEmployee(23, "Barbara", "Hood", 30000, 2);
     }
 
-    protected void tearDown() throws Exception {
+    protected void tearDown() {
 
         // I decided not the use the "IF EXISTS" clause since it is not a
         // SQL standard.
@@ -134,17 +119,13 @@ public class TestGroupByHaving extends TestCase {
             stmt.execute("drop table employee if exists");
         } catch (Exception x) {}
 
-        if (stmt != null) {
-            stmt.close();
+        try {
+            if (conn != null) {
+                conn.close();
+            }
+        } catch (Exception x) {}
 
-            stmt = null;
-        }
-
-        if (conn != null) {
-            conn.close();
-
-            conn = null;
-        }
+        conn = null;
 
         super.tearDown();
 
@@ -168,7 +149,7 @@ public class TestGroupByHaving extends TestCase {
     public void testAggregatedGroupBy() throws SQLException {
 
         String sql = "select avg(salary), max(id) from employee "
-                     + "group by superior_id " + "order by superior_id " + "";
+                     + "group by superior_id " + "order by superior_id ";
         Object[][] expected = new Object[][] {
             {
                 Double.valueOf(150000), Integer.valueOf(2)
@@ -196,7 +177,7 @@ public class TestGroupByHaving extends TestCase {
 
         String sql = "select avg(salary), max(id) from employee "
                      + "group by superior_id " + "having max(id) > 5 "
-                     + "order by superior_id " + "";
+                     + "order by superior_id ";
         Object[][] expected = new Object[][] {
             {
                 Double.valueOf(42500), Integer.valueOf(13)
@@ -223,7 +204,7 @@ public class TestGroupByHaving extends TestCase {
         String sql = "select avg(salary), max(id) from employee "
                      + "group by superior_id "
                      + "having superior_id is not null "
-                     + "order by superior_id " + "";
+                     + "order by superior_id ";
         Object[][] expected = new Object[][] {
             {
                 Double.valueOf(42500), Integer.valueOf(13)
@@ -247,7 +228,7 @@ public class TestGroupByHaving extends TestCase {
     public void testHavingWithoutGroupBy1() throws SQLException {
 
         String sql = "select avg(salary), max(id) from employee "
-                     + "having avg(salary) > 1000 " + "";
+                     + "having avg(salary) > 1000 ";
         Object[][] expected = new Object[][] {
             {
                 Double.valueOf(65000), Integer.valueOf(23)
@@ -269,7 +250,7 @@ public class TestGroupByHaving extends TestCase {
     public void testHavingWithoutGroupBy2() throws SQLException {
 
         String sql = "select avg(salary), max(id) from employee "
-                     + "having avg(salary) > 1000000 " + "";
+                     + "having avg(salary) > 1000000 ";
         Object[][] expected = new Object[][]{};
 
         compareResults(sql, expected, "00000");
@@ -283,7 +264,7 @@ public class TestGroupByHaving extends TestCase {
 
         String sql = "select avg(salary), max(id) from employee "
                      + "group by lastname "
-                     + "having (max(id) > 1) and (superior_id > 1) " + "";
+                     + "having (max(id) > 1) and (superior_id > 1) ";
         Object[][] expected = new Object[][]{};
 
         compareResults(sql, expected, "42573");
