@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2019, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,10 +55,6 @@ public class TestKarl {
     static final String SHUTDOWN_IMMEDIATELY = "SHUTDOWN IMMEDIATELY";
     static final String SHUTDOWN_COMPACT     = "SHUTDOWN COMPACT";
 
-    /**
-     *
-     * @param args
-     */
     public static void main(String[] args) {
 
         Connection c = null;
@@ -151,10 +147,6 @@ public class TestKarl {
         }
     }
 
-    /**
-     * @param p_connection
-     * @throws SQLException
-     */
     private static void doCreateTableTest(Connection p_connection)
     throws SQLException {
 
@@ -177,10 +169,6 @@ public class TestKarl {
         System.out.println("END INSERT INTO TESTTABLE");
     }
 
-    /**
-     * @param p_connection
-     * @throws SQLException
-     */
     private static void doUpdateInsertDeleteWaehler(Connection p_connection)
     throws SQLException {
 
@@ -217,11 +205,6 @@ public class TestKarl {
         System.out.println("END DELETE FROM WAEHLER");
     }
 
-    /**
-     * @param p_connection
-     * @param p_table
-     * @throws SQLException
-     */
     private static void printTable(Connection p_connection,
                                    String p_table) throws SQLException {
 
@@ -235,7 +218,7 @@ public class TestKarl {
             System.out.print(rs.getMetaData().getColumnLabel(i) + "\t");
         }
 
-        System.out.println("");
+        System.out.println();
 
         while (rs.next()) {
             for (int i = 1; i <= col_count; i++) {
@@ -243,17 +226,13 @@ public class TestKarl {
                 System.out.print("\t");
             }
 
-            System.out.println("");
+            System.out.println();
         }
 
         st.close();
         System.out.println("... END GET TABLE " + p_table);
     }
 
-    /**
-     * @param p_connection
-     * @throws SQLException
-     */
     private static void printMeta(Connection p_connection)
     throws SQLException {
 
@@ -270,7 +249,7 @@ public class TestKarl {
             System.out.print(rs.getMetaData().getColumnLabel(i) + "\t");
         }
 
-        System.out.println("");
+        System.out.println();
 
         while (rs.next()) {
             for (int i = 1; i <= col_count; i++) {
@@ -278,7 +257,7 @@ public class TestKarl {
                 System.out.print("\t");
             }
 
-            System.out.println("");
+            System.out.println();
         }
 
         System.out.println("END GET METADATA");
