@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2020, The HSQL Development Group
+/* Copyright (c) 2001-2021, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,7 +50,7 @@ public class TestPreparedStatements extends TestCase {
 
     private Connection con = null;
 
-    private class sqlStmt {
+    private static class sqlStmt {
 
         boolean  prepare;
         boolean  update;
@@ -310,7 +310,6 @@ public class TestPreparedStatements extends TestCase {
 
         assertTrue(result1.next());
         assertTrue(result1.next());
-
 /*
         String select2 = "SELECT name FROM testusers WHERE name IN (CAST(? AS VARCHAR(10) ARRAY))";
         PreparedStatement preparedStatement2 = con.prepareStatement(select2,
