@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -158,7 +158,7 @@ public class TestSql extends TestBase {
                 ResultSetMetaData rsmd    = rs.getMetaData();
                 String            result0 = "";
 
-                for (; rs.next(); ) {
+                while (rs.next()) {
                     for (int i = 0; i < rsmd.getColumnCount(); i++) {
                         result0 += rs.getString(i + 1) + ":";
                     }
@@ -178,7 +178,7 @@ public class TestSql extends TestBase {
                 ResultSetMetaData rsmd    = rs.getMetaData();
                 String            result0 = "";
 
-                for (; rs.next(); ) {
+                while (rs.next()) {
                     for (int i = 0; i < rsmd.getColumnCount(); i++) {
                         result0 += rs.getString(i + 1) + ":";
                     }
@@ -196,7 +196,7 @@ public class TestSql extends TestBase {
 
                 result1 = "";
 
-                for (; rs.next(); ) {
+                while (rs.next()) {
                     for (int i = 0; i < rsmd.getColumnCount(); i++) {
                         result1 += rs.getString(i + 1) + ":";
                     }
@@ -216,7 +216,7 @@ public class TestSql extends TestBase {
 
                 result2 = "";
 
-                for (; rs.next(); ) {
+                while (rs.next()) {
                     for (int i = 0; i < rsmd.getColumnCount(); i++) {
                         result2 += rs.getString(i + 1) + ":";
                     }
@@ -234,7 +234,7 @@ public class TestSql extends TestBase {
 
                 result3 = "";
 
-                for (; rs.next(); ) {
+                while (rs.next()) {
                     for (int i = 0; i < rsmd.getColumnCount(); i++) {
                         result3 += rs.getString(i + 1) + ":";
                     }
@@ -254,7 +254,7 @@ public class TestSql extends TestBase {
 
                 result4 = "";
 
-                for (; rs.next(); ) {
+                while (rs.next()) {
                     for (int i = 0; i < rsmd.getColumnCount(); i++) {
                         result4 += rs.getString(i + 1) + ":";
                     }
@@ -280,7 +280,7 @@ public class TestSql extends TestBase {
 
                 result5 = "";
 
-                for (; rs.next(); ) {
+                while (rs.next()) {
                     for (int i = 0; i < rsmd.getColumnCount(); i++) {
                         result5 += rsmd.getColumnName(i + 1) + ":"
                                    + rs.getString(i + 1) + ":";
@@ -295,7 +295,7 @@ public class TestSql extends TestBase {
                     "SELECT I, A, B, A \"aliasA\", B \"aliasB\", 1 FROM T;");
                 rsmd = rs.getMetaData();
 
-                for (; rs.next(); ) {
+                while (rs.next()) {
                     for (int i = 0; i < rsmd.getColumnCount(); i++) {
                         result5 += rsmd.getColumnLabel(i + 1) + ":"
                                    + rs.getString(i + 1) + ":";
@@ -362,7 +362,7 @@ public class TestSql extends TestBase {
         double  value    = 0;
         boolean wasEqual = false;
         String  message  = "DB operation completed";
-        String  ddl1     = "DROP TABLE t1 IF EXISTS;";
+        String  ddl1     = "DROP TABLE t1 IF EXISTS CASCADE";
         String ddl2 =
             "CREATE TABLE t1 ( d DECIMAL, f DOUBLE, l BIGINT, i INTEGER, s SMALLINT, t TINYINT, "
             + "dt DATE DEFAULT CURRENT_DATE, ti TIME DEFAULT CURRENT_TIME, ts TIMESTAMP DEFAULT CURRENT_TIMESTAMP );";
@@ -693,8 +693,8 @@ public class TestSql extends TestBase {
 
         Statement st = connection.createStatement();
 
-        st.execute("DROP TABLE t1 if exists;");
-        st.execute("DROP TABLE t2 if exists;");
+        st.execute("DROP TABLE t1 if exists cascade");
+        st.execute("DROP TABLE t2 if exists cascade");
         st.execute(
             "CREATE TABLE t1 (id int not null, v1 int, v2 int, primary key(id))");
         st.execute(
@@ -798,6 +798,9 @@ public class TestSql extends TestBase {
         try {
 
             // prepared statements
+            sStatement.execute("drop table bintest if exists cascade");
+            sStatement.execute("drop table obj if exists cascade");
+
             String s =
                 "create table bintest(id int primary key, bin varbinary(100))";
 
