@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2021, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -227,7 +227,7 @@ public class TestUtil {
 
                 startLine = sqlReader.getStartLineNumber();
 
-                if (section.size() == 0) {
+                if (section.isEmpty()) {
                     break;
                 }
 
@@ -270,7 +270,7 @@ public class TestUtil {
     static void test(Statement stat, String s, String sourceName, int line) {
 
         //maintain the interface for this method
-        HsqlArrayList section = new HsqlArrayList(new String[8], 0);
+        HsqlArrayList section = new HsqlArrayList();
 
         section.add(s);
         testSection(stat, section, sourceName, line);
@@ -551,7 +551,7 @@ abstract class ParsedSection {
 
                     lines[k] = lines[k].substring(0, endIndex);
 
-                    if (lines[k].length() == 0) {
+                    if (lines[k].isEmpty()) {
                         resEndRow = k - 1;
                     } else {
                         resEndRow = k;
@@ -808,7 +808,7 @@ class ResultSetParsedSection extends ParsedSection {
             }
 
             //iterate over the ResultSet
-            HsqlArrayList list     = new HsqlArrayList(new String[1][], 0);
+            HsqlArrayList list     = new HsqlArrayList();
             results  = aStatement.getResultSet();
             int           colCount = results.getMetaData().getColumnCount();
 
@@ -1135,9 +1135,9 @@ class WaitSection extends ParsedSection {
 
         linesArray.toArray(lines);
 
+        lines[0] = lines[0].substring(3);
         int    closeCmd = lines[0].indexOf("*/");
         String cmd      = lines[0].substring(0, closeCmd);
-
         lines[0] = lines[0].substring(closeCmd + 2).trim();
 
         String trimmed = cmd.trim();
@@ -1173,7 +1173,7 @@ class WaitSection extends ParsedSection {
 
         StringBuilder sb = new StringBuilder();
 
-        if (lines.length == 1 && lines[0].trim().length() < 1) {
+        if (lines.length == 1 && lines[0].trim().isEmpty()) {
             return null;
         }
 
@@ -1261,7 +1261,7 @@ class ProceedSection extends ParsedSection {
 
         StringBuilder sb = new StringBuilder();
 
-        if (lines.length == 1 && lines[0].trim().length() < 1) {
+        if (lines.length == 1 && lines[0].trim().isEmpty()) {
             return "";
         }
 
@@ -1392,7 +1392,7 @@ class ExceptionParsedSection extends ParsedSection {
 
         expectedState = lines[0].trim();
 
-        if (expectedState.length() < 1) {
+        if (expectedState.isEmpty()) {
             expectedState = null;
         }
 
@@ -1485,7 +1485,7 @@ class DisplaySection extends ParsedSection {
 
         StringBuilder sb = new StringBuilder();
 
-        if (lines.length == 1 && lines[0].trim().length() < 1) {
+        if (lines.length == 1 && lines[0].trim().isEmpty()) {
             return null;
         }
 
