@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -48,11 +48,15 @@ public interface ClobData extends LobData {
 
     long length(SessionInterface session);
 
-    String getSubString(SessionInterface session, final long pos,
-                        final int length);
+    String getSubString(
+            SessionInterface session,
+            final long pos,
+            final int length);
 
-    ClobData getClob(SessionInterface session, final long pos,
-                     final long length);
+    ClobData getClob(
+            SessionInterface session,
+            final long pos,
+            final long length);
 
     ClobData duplicate(SessionInterface session);
 
@@ -62,11 +66,19 @@ public interface ClobData extends LobData {
 
     void setString(SessionInterface session, long pos, String str);
 
-    void setClob(SessionInterface session, long pos, ClobData clob,
-                 long offset, long len);
+    void setClob(
+            SessionInterface session,
+            long pos,
+            ClobData clob,
+            long offset,
+            long len);
 
-    void setChars(SessionInterface session, long pos, char[] chars,
-                  int offset, int len);
+    void setChars(
+            SessionInterface session,
+            long pos,
+            char[] chars,
+            int offset,
+            int len);
 
     void setCharacterStream(SessionInterface session, long pos, Reader in);
 
