@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -64,9 +64,12 @@ class HsqldbTransferHelper extends TransferHelper {
         return (type);
     }
 
-    String fixupColumnDefRead(TransferTable t, ResultSetMetaData meta,
-                              String columnType, ResultSet columnDesc,
-                              int columnIndex) {
+    String fixupColumnDefRead(
+            TransferTable t,
+            ResultSetMetaData meta,
+            String columnType,
+            ResultSet columnDesc,
+            int columnIndex) {
 
         String CompareString = "INTEGER IDENTITY";
 
@@ -79,9 +82,12 @@ class HsqldbTransferHelper extends TransferHelper {
         return (columnType);
     }
 
-    String fixupColumnDefWrite(TransferTable t, ResultSetMetaData meta,
-                               String columnType, ResultSet columnDesc,
-                               int columnIndex) {
+    String fixupColumnDefWrite(
+            TransferTable t,
+            ResultSetMetaData meta,
+            String columnType,
+            ResultSet columnDesc,
+            int columnIndex) {
 
         if (columnType.contains("SERIAL")) {
             columnType = "INTEGER GENERATED BY DEFAULT AS IDENTITY";
@@ -90,18 +96,34 @@ class HsqldbTransferHelper extends TransferHelper {
         return (columnType);
     }
 
-    String fixupColumnDefRead(String aTableName, ResultSetMetaData meta,
-                              String columnType, ResultSet columnDesc,
-                              int columnIndex) {
-        return fixupColumnDefRead((TransferTable) null, meta, columnType,
-                                  columnDesc, columnIndex);
+    String fixupColumnDefRead(
+            String aTableName,
+            ResultSetMetaData meta,
+            String columnType,
+            ResultSet columnDesc,
+            int columnIndex) {
+
+        return fixupColumnDefRead(
+            (TransferTable) null,
+            meta,
+            columnType,
+            columnDesc,
+            columnIndex);
     }
 
-    String fixupColumnDefWrite(String aTableName, ResultSetMetaData meta,
-                               String columnType, ResultSet columnDesc,
-                               int columnIndex) {
-        return fixupColumnDefWrite((TransferTable) null, meta, columnType,
-                                   columnDesc, columnIndex);
+    String fixupColumnDefWrite(
+            String aTableName,
+            ResultSetMetaData meta,
+            String columnType,
+            ResultSet columnDesc,
+            int columnIndex) {
+
+        return fixupColumnDefWrite(
+            (TransferTable) null,
+            meta,
+            columnType,
+            columnDesc,
+            columnIndex);
     }
 
     String formatName(String t) {
