@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,9 @@ import java.io.BufferedWriter;
 import java.io.FileReader;
 import java.io.FileWriter;
 import java.io.IOException;
+
 import java.sql.SQLException;
+
 import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.NoSuchElementException;
@@ -56,8 +58,10 @@ class TransferSQLText extends DataAccessPoint {
     Hashtable           DbStmts                = null;
     protected JDBCTypes JDBCT                  = null;
 
-    TransferSQLText(String _FileName,
-                    Traceable t) throws DataAccessPointException {
+    TransferSQLText(
+            String _FileName,
+            Traceable t)
+            throws DataAccessPointException {
 
         super(t);
 
@@ -89,8 +93,11 @@ class TransferSQLText extends DataAccessPoint {
         return true;
     }
 
-    void putData(String statement, TransferResultSet r,
-                 int iMaxRows) throws DataAccessPointException {
+    void putData(
+            String statement,
+            TransferResultSet r,
+            int iMaxRows)
+            throws DataAccessPointException {
 
         int i = 0;
 
@@ -165,8 +172,9 @@ class TransferSQLText extends DataAccessPoint {
         for (int i = 0; i < len; i++) {
             int t = r.getColumnType(i + 1);
 
-            sLast = "column=" + r.getColumnName(i + 1) + " datatype="
-                    + (String) helper.getSupportedTypes().get(Integer.valueOf(t));
+            sLast = "column=" + r.getColumnName(
+                i + 1) + " datatype=" + helper.getSupportedTypes().get(
+                    Integer.valueOf(t));
 
             Object o = r.getObject(i + 1);
 
@@ -212,8 +220,9 @@ class TransferSQLText extends DataAccessPoint {
 
         columnDef.start = curPos;
 
-        if ((ColumnsDesc == null) || (ColumnsDesc.length() == 0)
-                || (curPos >= ColumnsDesc.length())) {
+        if (ColumnsDesc == null
+                || ColumnsDesc.isEmpty()
+                || curPos >= ColumnsDesc.length()) {
             return new TransferSQLText.ColumnDef();
         }
 
@@ -248,7 +257,7 @@ class TransferSQLText extends DataAccessPoint {
             columnDef.len        += nextPos;
             nextPos              = 0;
 
-            if (!columnDef.columnName.toUpperCase().equals("CONSTRAINT")) {
+            if (!columnDef.columnName.equalsIgnoreCase("CONSTRAINT")) {
                 i = 0;
 
                 for (; i < stbuff.length() && stbuff.charAt(i) == ' '; i++) {}
@@ -264,8 +273,8 @@ class TransferSQLText extends DataAccessPoint {
                     nextPos++;
                 }
 
-                columnDef.columnType = stbuff.substring(0,
-                        nextPos).toUpperCase();
+                columnDef.columnType = stbuff.substring(0, nextPos)
+                                             .toUpperCase();
                 stbuff        = stbuff.substring(nextPos);
                 columnDef.len += nextPos;
                 nextPos       = 0;
@@ -293,8 +302,10 @@ class TransferSQLText extends DataAccessPoint {
         return columnDef;
     }
 
-    String translateTypes(String CreateLine, TransferTable TTable,
-                          DataAccessPoint Dest) {
+    String translateTypes(
+            String CreateLine,
+            TransferTable TTable,
+            DataAccessPoint Dest) {
 
         String    translatedLine = "";
         JDBCTypes JDBCT          = new JDBCTypes();
@@ -318,13 +329,12 @@ class TransferSQLText extends DataAccessPoint {
             columnType = cDef.columnType;
 
             if (columnName.toUpperCase().contains("CONSTRAINT")) {
-                translatedLine +=
-                    CreateLine.substring(currentPos, currentPos + cDef.len)
-                    + ",";
+                translatedLine += CreateLine.substring(
+                    currentPos,
+                    currentPos + cDef.len) + ",";
                 currentPos += cDef.len + 1;
 
                 colnum++;
-
                 continue;
             }
 
@@ -342,8 +352,12 @@ class TransferSQLText extends DataAccessPoint {
             }
 
             try {
-                columnType = Dest.helper.fixupColumnDefWrite(TTable, null,
-                        columnType, null, colnum);
+                columnType = Dest.helper.fixupColumnDefWrite(
+                    TTable,
+                    null,
+                    columnType,
+                    null,
+                    colnum);
             } catch (SQLException SQLe) {
                 return CreateLine;
             }
@@ -354,8 +368,7 @@ class TransferSQLText extends DataAccessPoint {
             colnum++;
         } while (true);
 
-        return translatedLine.substring(0, translatedLine.length() - 1)
-               + ");";
+        return translatedLine.substring(0, translatedLine.length() - 1) + ");";
     }
 
     void parseFileForTables() throws DataAccessPointException {
@@ -390,7 +403,7 @@ class TransferSQLText extends DataAccessPoint {
                     continue;
                 }
 
-                if (!Token.toUpperCase().equals("CREATE")) {
+                if (!Token.equalsIgnoreCase("CREATE")) {
                     continue;
                 }
 
@@ -399,8 +412,12 @@ class TransferSQLText extends DataAccessPoint {
                 if (Token.equals("TABLE") || Token.equals("VIEW")) {
                     try {
                         name = Tokenizer.nextToken(" (;");
-                        relatedTable = new TransferTable(this, name, "",
-                                                         Token, tracer);
+                        relatedTable = new TransferTable(
+                            this,
+                            name,
+                            "",
+                            Token,
+                            tracer);
                         relatedTable.Stmts.bCreate      = false;
                         relatedTable.Stmts.bDelete      = false;
                         relatedTable.Stmts.bDrop        = false;
@@ -409,8 +426,9 @@ class TransferSQLText extends DataAccessPoint {
                         relatedTable.Stmts.bInsert      = false;
                         relatedTable.Stmts.bAlter       = false;
 
-                        DbStmts.put(relatedTable.Stmts.sSourceTable,
-                                    relatedTable);
+                        DbStmts.put(
+                            relatedTable.Stmts.sSourceTable,
+                            relatedTable);
                     } catch (NoSuchElementException NSE) {
                         continue;
                     }
@@ -421,9 +439,10 @@ class TransferSQLText extends DataAccessPoint {
         }
     }
 
-    void parseFileForTheRest(TransferTable TTable,
-                             DataAccessPoint Dest)
-                             throws DataAccessPointException {
+    void parseFileForTheRest(
+            TransferTable TTable,
+            DataAccessPoint Dest)
+            throws DataAccessPointException {
 
         StringTokenizer Tokenizer;
 
@@ -457,18 +476,17 @@ class TransferSQLText extends DataAccessPoint {
                     continue;
                 }
 
-                if (Token.toUpperCase().equals("INSERT")) {
+                if (Token.equalsIgnoreCase("INSERT")) {
                     try {
-                        if (!Tokenizer.nextToken().toUpperCase().equals(
-                                "INTO")) {
+                        if (!Tokenizer.nextToken().equalsIgnoreCase("INTO")) {
                             throw new DataAccessPointException(
                                 "Error in INSERT statement: no INTO found");
                         }
 
                         Token = Tokenizer.nextToken();
 
-                        if ((relatedTable =
-                                (TransferTable) DbStmts.get(Token)) != null) {
+                        if ((relatedTable = (TransferTable) DbStmts.get(Token))
+                                != null) {
                             relatedTable.Stmts.bDelete     = true;
                             relatedTable.Stmts.bInsert     = true;
                             relatedTable.Stmts.sDestInsert = currentLine;
@@ -481,10 +499,9 @@ class TransferSQLText extends DataAccessPoint {
                     } catch (NoSuchElementException NSE) {
                         continue;
                     }
-                } else if (Token.toUpperCase().equals("ALTER")) {
+                } else if (Token.equalsIgnoreCase("ALTER")) {
                     try {
-                        if (!Tokenizer.nextToken().toUpperCase().equals(
-                                "TABLE")) {
+                        if (!Tokenizer.nextToken().equalsIgnoreCase("TABLE")) {
                             continue;
                         }
 
@@ -520,14 +537,13 @@ class TransferSQLText extends DataAccessPoint {
 
                         relatedTable.Stmts.bDrop = true;
                         relatedTable.Stmts.sDestDrop =
-                            "ALTER TABLE " + name + " DROP CONSTRAINT "
-                            + Token + ";" + relatedTable.Stmts.sDestDrop;
-
+                            "ALTER TABLE " + name + " DROP CONSTRAINT " + Token
+                            + ";" + relatedTable.Stmts.sDestDrop;
                         continue;
                     } catch (NoSuchElementException NSE) {
                         continue;
                     }
-                } else if (!Token.toUpperCase().equals("CREATE")) {
+                } else if (!Token.equalsIgnoreCase("CREATE")) {
                     continue;
                 }
 
@@ -547,14 +563,17 @@ class TransferSQLText extends DataAccessPoint {
                         relatedTable.Stmts.bDrop   = true;
 
 //                        relatedTable.Stmts.sDestCreate = currentLine;
-                        relatedTable.Stmts.sDestCreate =
-                            translateTypes(currentLine, TTable, Dest);
+                        relatedTable.Stmts.sDestCreate = translateTypes(
+                            currentLine,
+                            TTable,
+                            Dest);
                         relatedTable.Stmts.sDestDrop =
                             "DROP " + relatedTable.Stmts.sType + " " + name
                             + ";";
 
-                        DbStmts.put(relatedTable.Stmts.sSourceTable,
-                                    relatedTable);
+                        DbStmts.put(
+                            relatedTable.Stmts.sSourceTable,
+                            relatedTable);
                     } catch (NoSuchElementException NSE) {
                         continue;
                     }
@@ -562,15 +581,13 @@ class TransferSQLText extends DataAccessPoint {
 
                 if (Token.equals("INDEX") || Token.equals("UNIQUE")) {
                     try {
-                        while ((Token =
-                                Tokenizer.nextToken()).toUpperCase().equals(
-                                    "INDEX")) {}
+                        while ((Token = Tokenizer.nextToken()).equalsIgnoreCase(
+                                "INDEX")) {}
 
-                        String IndexdropCommand = "DROP INDEX " + Token
-                                                  + " ;";
+                        String IndexdropCommand = "DROP INDEX " + Token + " ;";
 
                         while ((Token = Tokenizer.nextToken(
-                                " (")).toUpperCase().equals("ON")) {}
+                                " (")).equalsIgnoreCase("ON")) {}
 
                         name = Token;
 
@@ -592,7 +609,7 @@ class TransferSQLText extends DataAccessPoint {
                         relatedTable.Stmts.bCreateIndex     = true;
                         relatedTable.Stmts.bDropIndex       = true;
                         relatedTable.Stmts.sDestCreateIndex += currentLine;
-                        relatedTable.Stmts.sDestDropIndex += IndexdropCommand;
+                        relatedTable.Stmts.sDestDropIndex   += IndexdropCommand;
                     } catch (NoSuchElementException NSE) {
                         continue;
                     }
@@ -603,8 +620,10 @@ class TransferSQLText extends DataAccessPoint {
         }
     }
 
-    Vector getTables(String sCatalog,
-                     String[] sSchemas) throws DataAccessPointException {
+    Vector getTables(
+            String sCatalog,
+            String[] sSchemas)
+            throws DataAccessPointException {
 
         Vector AllTables = new Vector();
 
@@ -633,9 +652,10 @@ class TransferSQLText extends DataAccessPoint {
         return AllTables;
     }
 
-    void getTableStructure(TransferTable TTable,
-                           DataAccessPoint Dest)
-                           throws DataAccessPointException {
+    void getTableStructure(
+            TransferTable TTable,
+            DataAccessPoint Dest)
+            throws DataAccessPointException {
 
         if (!StructureAlreadyParsed) {
             if (WTextRead != null) {
@@ -650,8 +670,9 @@ class TransferSQLText extends DataAccessPoint {
         }
     }
 
-    TransferResultSet getData(String statement)
-    throws DataAccessPointException {
+    TransferResultSet getData(
+            String statement)
+            throws DataAccessPointException {
 
         StringTokenizer Tokenizer;
         String          tableName = "";
@@ -659,7 +680,7 @@ class TransferSQLText extends DataAccessPoint {
         try {
             Tokenizer = new StringTokenizer(statement);
 
-            while (!Tokenizer.nextToken().toUpperCase().equals("FROM")) {}
+            while (!Tokenizer.nextToken().equalsIgnoreCase("FROM")) {}
 
             tableName = Tokenizer.nextToken(" ;");
         } catch (NoSuchElementException NSE) {
@@ -678,8 +699,9 @@ class TransferSQLText extends DataAccessPoint {
         return (this.parseFileForData(tableName));
     }
 
-    TransferResultSet parseFileForData(String tableName)
-    throws DataAccessPointException {
+    TransferResultSet parseFileForData(
+            String tableName)
+            throws DataAccessPointException {
 
         TransferResultSet trsData = new TransferResultSet();
         StringTokenizer   Tokenizer;
@@ -710,12 +732,12 @@ class TransferSQLText extends DataAccessPoint {
                     continue;
                 }
 
-                if (!Token.toUpperCase().equals("INSERT")) {
+                if (!Token.equalsIgnoreCase("INSERT")) {
                     continue;
                 }
 
                 try {
-                    if (!Tokenizer.nextToken().toUpperCase().equals("INTO")) {
+                    if (!Tokenizer.nextToken().equalsIgnoreCase("INTO")) {
                         throw new DataAccessPointException(
                             "Error in INSERT statement: no INTO found");
                     }
@@ -734,7 +756,7 @@ class TransferSQLText extends DataAccessPoint {
                     while ((currentLine = WTextRead.readLine()) != null) {
                         currentLine = currentLine.trim();
 
-                        boolean newLine = (currentLine.length() == 0);
+                        boolean newLine = currentLine.isEmpty();
 
                         if (newLine) {
                             int iColumnNb = 0;
@@ -749,17 +771,16 @@ class TransferSQLText extends DataAccessPoint {
 
                             for (int Idx = 0; Idx < iColumnNb; Idx++) {
                                 Names[Idx + 1] =
-                                    (String) vColumnNames.elementAt(Idx);
+                                    (String) vColumnNames.elementAt(
+                                        Idx);
                                 Types[Idx + 1] =
                                     ((Integer) vColumnTypes.elementAt(
                                         Idx)).intValue();
-                                Values[Idx + 1] =
-                                    vColumnValues.elementAt(Idx);
+                                Values[Idx + 1] = vColumnValues.elementAt(Idx);
                             }
 
                             try {
-                                trsData.addRow(Names, Types, Values,
-                                               iColumnNb);
+                                trsData.addRow(Names, Types, Values, iColumnNb);
                             } catch (Exception e) {
                                 throw new DataAccessPointException(
                                     e.getMessage());
@@ -770,7 +791,6 @@ class TransferSQLText extends DataAccessPoint {
                             vColumnNames.removeAllElements();
                             vColumnValues.removeAllElements();
                             vColumnTypes.removeAllElements();
-
                             continue;
                         }
 
@@ -778,8 +798,8 @@ class TransferSQLText extends DataAccessPoint {
                         Token     = Tokenizer.nextToken("=");
 
                         if (Token.equals("Number of Rows")) {
-                            int iNbRows =
-                                Integer.parseInt(Tokenizer.nextToken());
+                            int iNbRows = Integer.parseInt(
+                                Tokenizer.nextToken());
 
                             if (iNbRows != iParsedRows) {
                                 throw new DataAccessPointException(
@@ -817,9 +837,9 @@ class TransferSQLText extends DataAccessPoint {
                         Token = Tokenizer.nextToken(" =");
 
                         if (Token.equals("value")) {
-                            int iStart = currentLine.indexOf("value=") + 6;
-                            String sValue =
-                                currentLine.substring(iStart).trim();
+                            int    iStart = currentLine.indexOf("value=") + 6;
+                            String sValue = currentLine.substring(iStart)
+                                                       .trim();
 
                             if (sValue.contains("<null>")) {
                                 vColumnValues.addElement(null);
