@@ -1,7 +1,7 @@
 /*
  * For work developed by the HSQL Development Group:
  *
- * Copyright (c) 2001-2022, The HSQL Development Group
+ * Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -71,6 +71,7 @@
 package org.hsqldb.util;
 
 import java.io.Serializable;
+
 import java.util.Hashtable;
 
 // fredt@users 20011220 - patch 481239 by xponsard@users - enhancements
@@ -96,8 +97,12 @@ class TransferTable implements Serializable {
     SQLStatements   Stmts = null;
     Traceable       tracer;
 
-    TransferTable(DataAccessPoint src, String name, String schema,
-                  String type, Traceable t) {
+    TransferTable(
+            DataAccessPoint src,
+            String name,
+            String schema,
+            String type,
+            Traceable t) {
 
         Stmts         = new SQLStatements();
         sourceDb      = src;
@@ -113,15 +118,14 @@ class TransferTable implements Serializable {
         tracer                   = t;
 
         if (Stmts.sType.compareTo("TABLE") == 0) {
-            Stmts.sSourceSelect = "SELECT * FROM "
-                                  + src.helper.formatName(Stmts.sSourceTable);
+            Stmts.sSourceSelect = "SELECT * FROM " + src.helper.formatName(
+                Stmts.sSourceTable);
         } else if (Stmts.sType.compareTo("VIEW") == 0) {
             Stmts.sSourceSelect = "";
         }
     }
 
     void setDest(String _Schema, DataAccessPoint dest) {
-
         destDb = dest;
 
         dest.helper.setSchema(_Schema);
@@ -130,8 +134,10 @@ class TransferTable implements Serializable {
     /**
      * extractTableStructure
      */
-    void extractTableStructure(DataAccessPoint Source,
-                               DataAccessPoint Destination) throws Exception {
+    void extractTableStructure(
+            DataAccessPoint Source,
+            DataAccessPoint Destination)
+            throws Exception {
         initTypes();
         Source.getTableStructure(this, Destination);
     }
@@ -165,12 +171,14 @@ class TransferTable implements Serializable {
                 int nextsemicolon = Stmts.sDestDropIndex.indexOf(';');
 
                 while (nextsemicolon > lastsemicolon) {
-                    Statement = Stmts.sDestDropIndex.substring(lastsemicolon,
-                            nextsemicolon);
+                    Statement = Stmts.sDestDropIndex.substring(
+                        lastsemicolon,
+                        nextsemicolon);
 
                     while (Statement.charAt(Statement.length() - 1) == ';') {
-                        Statement = Statement.substring(0, Statement.length()
-                                                        - 1);
+                        Statement = Statement.substring(
+                            0,
+                            Statement.length() - 1);
                     }
 
                     try {
@@ -197,12 +205,14 @@ class TransferTable implements Serializable {
                 int nextsemicolon = Stmts.sDestDelete.indexOf(';');
 
                 while (nextsemicolon > lastsemicolon) {
-                    Statement = Stmts.sDestDelete.substring(lastsemicolon,
-                            nextsemicolon);
+                    Statement = Stmts.sDestDelete.substring(
+                        lastsemicolon,
+                        nextsemicolon);
 
                     while (Statement.charAt(Statement.length() - 1) == ';') {
-                        Statement = Statement.substring(0, Statement.length()
-                                                        - 1);
+                        Statement = Statement.substring(
+                            0,
+                            Statement.length() - 1);
                     }
 
                     try {
@@ -213,9 +223,8 @@ class TransferTable implements Serializable {
                     }
 
                     lastsemicolon = nextsemicolon + 1;
-                    nextsemicolon = lastsemicolon
-                                    + Stmts.sDestDelete.substring(
-                                        lastsemicolon).indexOf(';');
+                    nextsemicolon = lastsemicolon + Stmts.sDestDelete.substring(
+                        lastsemicolon).indexOf(';');
                 }
             }
 
@@ -229,12 +238,14 @@ class TransferTable implements Serializable {
                 int nextsemicolon = Stmts.sDestDrop.indexOf(';');
 
                 while (nextsemicolon > lastsemicolon) {
-                    Statement = Stmts.sDestDrop.substring(lastsemicolon,
-                                                          nextsemicolon);
+                    Statement = Stmts.sDestDrop.substring(
+                        lastsemicolon,
+                        nextsemicolon);
 
                     while (Statement.charAt(Statement.length() - 1) == ';') {
-                        Statement = Statement.substring(0, Statement.length()
-                                                        - 1);
+                        Statement = Statement.substring(
+                            0,
+                            Statement.length() - 1);
                     }
 
                     try {
@@ -245,9 +256,8 @@ class TransferTable implements Serializable {
                     }
 
                     lastsemicolon = nextsemicolon + 1;
-                    nextsemicolon = lastsemicolon
-                                    + Stmts.sDestDrop.substring(
-                                        lastsemicolon).indexOf(';');
+                    nextsemicolon = lastsemicolon + Stmts.sDestDrop.substring(
+                        lastsemicolon).indexOf(';');
                 }
             }
 
@@ -261,21 +271,22 @@ class TransferTable implements Serializable {
                 int nextsemicolon = Stmts.sDestCreate.indexOf(';');
 
                 while (nextsemicolon > lastsemicolon) {
-                    Statement = Stmts.sDestCreate.substring(lastsemicolon,
-                            nextsemicolon);
+                    Statement = Stmts.sDestCreate.substring(
+                        lastsemicolon,
+                        nextsemicolon);
 
                     while (Statement.charAt(Statement.length() - 1) == ';') {
-                        Statement = Statement.substring(0, Statement.length()
-                                                        - 1);
+                        Statement = Statement.substring(
+                            0,
+                            Statement.length() - 1);
                     }
 
                     tracer.trace("Executing " + Statement);
                     destDb.execute(Statement);
 
                     lastsemicolon = nextsemicolon + 1;
-                    nextsemicolon = lastsemicolon
-                                    + Stmts.sDestCreate.substring(
-                                        lastsemicolon).indexOf(';');
+                    nextsemicolon = lastsemicolon + Stmts.sDestCreate.substring(
+                        lastsemicolon).indexOf(';');
                 }
             }
         } catch (Exception e) {
@@ -285,7 +296,7 @@ class TransferTable implements Serializable {
                 }
             } catch (Exception e1) {}
 
-            throw (e);
+            throw(e);
         }
 
         if (!destDb.getAutoCommit()) {
@@ -339,7 +350,7 @@ class TransferTable implements Serializable {
                 }
             } catch (Exception e1) {}
 
-            throw (e);
+            throw(e);
         }
 
         if (!destDb.getAutoCommit()) {
@@ -380,12 +391,14 @@ class TransferTable implements Serializable {
                 int nextsemicolon = Stmts.sDestCreateIndex.indexOf(';');
 
                 while (nextsemicolon > lastsemicolon) {
-                    Statement = Stmts.sDestCreateIndex.substring(lastsemicolon,
-                            nextsemicolon);
+                    Statement = Stmts.sDestCreateIndex.substring(
+                        lastsemicolon,
+                        nextsemicolon);
 
                     while (Statement.charAt(Statement.length() - 1) == ';') {
-                        Statement = Statement.substring(0, Statement.length()
-                                                        - 1);
+                        Statement = Statement.substring(
+                            0,
+                            Statement.length() - 1);
                     }
 
                     try {
@@ -412,12 +425,14 @@ class TransferTable implements Serializable {
                 int nextsemicolon = Stmts.sDestAlter.indexOf(';');
 
                 while (nextsemicolon > lastsemicolon) {
-                    Statement = Stmts.sDestAlter.substring(lastsemicolon,
-                                                           nextsemicolon);
+                    Statement = Stmts.sDestAlter.substring(
+                        lastsemicolon,
+                        nextsemicolon);
 
                     while (Statement.charAt(Statement.length() - 1) == ';') {
-                        Statement = Statement.substring(0, Statement.length()
-                                                        - 1);
+                        Statement = Statement.substring(
+                            0,
+                            Statement.length() - 1);
                     }
 
                     try {
@@ -428,9 +443,8 @@ class TransferTable implements Serializable {
                     }
 
                     lastsemicolon = nextsemicolon + 1;
-                    nextsemicolon = lastsemicolon
-                                    + Stmts.sDestAlter.substring(
-                                        lastsemicolon).indexOf(';');
+                    nextsemicolon = lastsemicolon + Stmts.sDestAlter.substring(
+                        lastsemicolon).indexOf(';');
                 }
             }
         } catch (Exception e) {
@@ -440,7 +454,7 @@ class TransferTable implements Serializable {
                 }
             } catch (Exception e1) {}
 
-            throw (e);
+            throw(e);
         }
 
         if (!destDb.getAutoCommit()) {
