@@ -1,4 +1,4 @@
-/* Copyright (c) 2001-2022, The HSQL Development Group
+/* Copyright (c) 2001-2024, The HSQL Development Group
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
- 
+
 
 package org.hsqldb.util.preprocessor;
 
@@ -37,7 +37,7 @@ import java.io.UnsupportedEncodingException;
 import java.util.Stack;
 
 /*
- * $Id: Preprocessor.java 6550 2022-06-08 11:09:08Z fredt $
+ * $Id: Preprocessor.java 6721 2024-04-03 17:05:14Z fredt $
  */
 /**
  * Simple text document preprocessor.
@@ -350,7 +350,7 @@ public class Preprocessor {
             this.resolver = resolver;
         }
 
-        if (predefined == null || predefined.trim().length() == 0) {
+        if (predefined == null || predefined.trim().isEmpty()) {
             this.defines = new Defines();
         } else {
             predefined = this.resolver.resolveProperties(predefined);
